/****************************************************************************
** Meta object code from reading C++ file 'chatwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/viewer/chatwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chatwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ChatWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto ChatWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10ChatWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ChatWindow",
        "nameChanged",
        "",
        "ChatWindow*",
        "view",
        "newName",
        "updateInfo",
        "info",
        "updateTabNotification",
        "chatWin",
        "Konversation::TabNotifyType",
        "type",
        "unseenEventsCountChanged",
        "unseenEventsCount",
        "setStatusBarTempText",
        "clearStatusBarTempText",
        "closing",
        "myself",
        "showView",
        "windowActivationRequested",
        "updateAppearance",
        "logText",
        "text",
        "adjustFocus",
        "appendInputText",
        "fromCursor",
        "indicateAway",
        "away",
        "setNotificationsEnabled",
        "enable",
        "activateTabNotification",
        "resetTabNotification",
        "resetUnseenEventsCount",
        "serverOnline",
        "online"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(ChatWindow *, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'updateInfo'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'updateTabNotification'
        QtMocHelpers::SignalData<void(ChatWindow *, const Konversation::TabNotifyType &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'unseenEventsCountChanged'
        QtMocHelpers::SignalData<void(ChatWindow *, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 9 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'setStatusBarTempText'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'clearStatusBarTempText'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closing'
        QtMocHelpers::SignalData<void(ChatWindow *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 17 },
        }}),
        // Signal 'showView'
        QtMocHelpers::SignalData<void(ChatWindow *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 17 },
        }}),
        // Signal 'windowActivationRequested'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAppearance'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'logText'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'adjustFocus'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appendInputText'
        QtMocHelpers::SlotData<void(const QString &, bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'indicateAway'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setNotificationsEnabled'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'activateTabNotification'
        QtMocHelpers::SlotData<void(Konversation::TabNotifyType)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'resetTabNotification'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetUnseenEventsCount'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'serverOnline'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ChatWindow, qt_meta_tag_ZN10ChatWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ChatWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ChatWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ChatWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ChatWindowE_t>.metaTypes,
    nullptr
} };

void ChatWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ChatWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->updateInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->updateTabNotification((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Konversation::TabNotifyType>>(_a[2]))); break;
        case 3: _t->unseenEventsCountChanged((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->setStatusBarTempText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->clearStatusBarTempText(); break;
        case 6: _t->closing((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1]))); break;
        case 7: _t->showView((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1]))); break;
        case 8: _t->windowActivationRequested(); break;
        case 9: _t->updateAppearance(); break;
        case 10: _t->logText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->adjustFocus(); break;
        case 12: _t->appendInputText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->indicateAway((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setNotificationsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->activateTabNotification((*reinterpret_cast<std::add_pointer_t<Konversation::TabNotifyType>>(_a[1]))); break;
        case 16: _t->resetTabNotification(); break;
        case 17: _t->resetUnseenEventsCount(); break;
        case 18: _t->serverOnline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ChatWindow::*)(ChatWindow * , const QString & )>(_a, &ChatWindow::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChatWindow::*)(const QString & )>(_a, &ChatWindow::updateInfo, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChatWindow::*)(ChatWindow * , const Konversation::TabNotifyType & )>(_a, &ChatWindow::updateTabNotification, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChatWindow::*)(ChatWindow * , int )>(_a, &ChatWindow::unseenEventsCountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChatWindow::*)(const QString & )>(_a, &ChatWindow::setStatusBarTempText, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChatWindow::*)()>(_a, &ChatWindow::clearStatusBarTempText, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChatWindow::*)(ChatWindow * )>(_a, &ChatWindow::closing, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChatWindow::*)(ChatWindow * )>(_a, &ChatWindow::showView, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChatWindow::*)()>(_a, &ChatWindow::windowActivationRequested, 8))
            return;
    }
}

const QMetaObject *ChatWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChatWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ChatWindowE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ChatWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void ChatWindow::nameChanged(ChatWindow * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ChatWindow::updateInfo(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ChatWindow::updateTabNotification(ChatWindow * _t1, const Konversation::TabNotifyType & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void ChatWindow::unseenEventsCountChanged(ChatWindow * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void ChatWindow::setStatusBarTempText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ChatWindow::clearStatusBarTempText()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ChatWindow::closing(ChatWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ChatWindow::showView(ChatWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ChatWindow::windowActivationRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
