/****************************************************************************
** Meta object code from reading C++ file 'ircinput.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/viewer/ircinput.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ircinput.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8IRCInputE_t {};
} // unnamed namespace

template <> constexpr inline auto IRCInput::qt_create_metaobjectdata<qt_meta_tag_ZN8IRCInputE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IRCInput",
        "nickCompletion",
        "",
        "endCompletion",
        "textPasted",
        "text",
        "submit",
        "envelopeCommand",
        "paste",
        "useSelection",
        "showCompletionList",
        "nicks",
        "setText",
        "preserveContents",
        "setLastCompletion",
        "completion",
        "setOverwriteMode",
        "updateAppearance",
        "getHistory",
        "up",
        "insertCompletion",
        "nick",
        "disableSpellChecking",
        "setSpellChecking",
        "set",
        "maybeResize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nickCompletion'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endCompletion'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textPasted'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'submit'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'envelopeCommand'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'showCompletionList'
        QtMocHelpers::SlotData<void(const QStringList &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 11 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<void(const QString &, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setLastCompletion'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setOverwriteMode'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'updateAppearance'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getHistory'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'insertCompletion'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'disableSpellChecking'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setSpellChecking'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'maybeResize'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IRCInput, qt_meta_tag_ZN8IRCInputE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IRCInput::staticMetaObject = { {
    QMetaObject::SuperData::link<KTextEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8IRCInputE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8IRCInputE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8IRCInputE_t>.metaTypes,
    nullptr
} };

void IRCInput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IRCInput *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nickCompletion(); break;
        case 1: _t->endCompletion(); break;
        case 2: _t->textPasted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->submit(); break;
        case 4: _t->envelopeCommand(); break;
        case 5: _t->paste((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->showCompletionList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 7: _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setLastCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setOverwriteMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->updateAppearance(); break;
        case 12: _t->getHistory((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->insertCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->disableSpellChecking(); break;
        case 15: _t->setSpellChecking((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->maybeResize(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IRCInput::*)()>(_a, &IRCInput::nickCompletion, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCInput::*)()>(_a, &IRCInput::endCompletion, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCInput::*)(const QString & )>(_a, &IRCInput::textPasted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCInput::*)()>(_a, &IRCInput::submit, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCInput::*)()>(_a, &IRCInput::envelopeCommand, 4))
            return;
    }
}

const QMetaObject *IRCInput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IRCInput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8IRCInputE_t>.strings))
        return static_cast<void*>(this);
    return KTextEdit::qt_metacast(_clname);
}

int IRCInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void IRCInput::nickCompletion()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IRCInput::endCompletion()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void IRCInput::textPasted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void IRCInput::submit()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void IRCInput::envelopeCommand()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
