/****************************************************************************
** Meta object code from reading C++ file 'transferview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/dcc/transferview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Konversation3DCC12TransferViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::DCC::TransferView::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation3DCC12TransferViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::DCC::TransferView",
        "runSelectedTransfers",
        "",
        "clear",
        "headerCustomContextMenuRequested",
        "QPoint",
        "pos",
        "toggleFilenameColumn",
        "visible",
        "togglePartnerNickColumn",
        "toggleProgressColumn",
        "toggleStartedAtColumn",
        "togglePositionColumn",
        "toggleCurrentSpeedColumn",
        "toggleSenderAdressColumn",
        "toggleStatusColumn",
        "toggleTimeLeftColumn",
        "toogleTypeIconColumn",
        "update",
        "updateModel",
        "transferStatusChanged",
        "Konversation::DCC::Transfer*",
        "transfer",
        "newStatus",
        "oldStatus",
        "rowsAboutToBeRemovedFromModel",
        "QModelIndex",
        "parent",
        "start",
        "end",
        "rowsRemovedFromModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'runSelectedTransfers'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'headerCustomContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'toggleFilenameColumn'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'togglePartnerNickColumn'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'toggleProgressColumn'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'toggleStartedAtColumn'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'togglePositionColumn'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'toggleCurrentSpeedColumn'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'toggleSenderAdressColumn'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'toggleStatusColumn'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'toggleTimeLeftColumn'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'toogleTypeIconColumn'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateModel'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'transferStatusChanged'
        QtMocHelpers::SlotData<void(Konversation::DCC::Transfer *, int, int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'rowsAboutToBeRemovedFromModel'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'rowsRemovedFromModel'
        QtMocHelpers::SlotData<void(int, int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::Int, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferView, qt_meta_tag_ZN12Konversation3DCC12TransferViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konversation::DCC::TransferView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC12TransferViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC12TransferViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation3DCC12TransferViewE_t>.metaTypes,
    nullptr
} };

void Konversation::DCC::TransferView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->runSelectedTransfers(); break;
        case 1: _t->clear(); break;
        case 2: _t->headerCustomContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 3: _t->toggleFilenameColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->togglePartnerNickColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->toggleProgressColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->toggleStartedAtColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->togglePositionColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->toggleCurrentSpeedColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->toggleSenderAdressColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->toggleStatusColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->toggleTimeLeftColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->toogleTypeIconColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->update(); break;
        case 14: _t->updateModel(); break;
        case 15: _t->transferStatusChanged((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 16: _t->rowsAboutToBeRemovedFromModel((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 17: _t->rowsRemovedFromModel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Konversation::DCC::Transfer* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransferView::*)()>(_a, &TransferView::runSelectedTransfers, 0))
            return;
    }
}

const QMetaObject *Konversation::DCC::TransferView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::TransferView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC12TransferViewE_t>.strings))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int Konversation::DCC::TransferView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::TransferView::runSelectedTransfers()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
