/****************************************************************************
** Meta object code from reading C++ file 'viewcontainer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/viewer/viewcontainer.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewcontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ViewMimeDataE_t {};
} // unnamed namespace

template <> constexpr inline auto ViewMimeData::qt_create_metaobjectdata<qt_meta_tag_ZN12ViewMimeDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ViewMimeData"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ViewMimeData, qt_meta_tag_ZN12ViewMimeDataE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ViewMimeData::staticMetaObject = { {
    QMetaObject::SuperData::link<QMimeData::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ViewMimeDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ViewMimeDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ViewMimeDataE_t>.metaTypes,
    nullptr
} };

void ViewMimeData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewMimeData *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ViewMimeData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewMimeData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ViewMimeDataE_t>.strings))
        return static_cast<void*>(this);
    return QMimeData::qt_metacast(_clname);
}

int ViewMimeData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMimeData::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9TabWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TabWidget::qt_create_metaobjectdata<qt_meta_tag_ZN9TabWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TabWidget",
        "contextMenu",
        "",
        "QWidget*",
        "widget",
        "QPoint",
        "pos",
        "tabBarMiddleClicked",
        "index"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'contextMenu'
        QtMocHelpers::SignalData<void(QWidget *, const QPoint &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'tabBarMiddleClicked'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabWidget, qt_meta_tag_ZN9TabWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TabWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QTabWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TabWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TabWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9TabWidgetE_t>.metaTypes,
    nullptr
} };

void TabWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 1: _t->tabBarMiddleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(QWidget * , const QPoint & )>(_a, &TabWidget::contextMenu, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(int )>(_a, &TabWidget::tabBarMiddleClicked, 1))
            return;
    }
}

const QMetaObject *TabWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TabWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int TabWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void TabWidget::contextMenu(QWidget * _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void TabWidget::tabBarMiddleClicked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN13ViewContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto ViewContainer::qt_create_metaobjectdata<qt_meta_tag_ZN13ViewContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ViewContainer",
        "viewChanged",
        "",
        "QModelIndex",
        "idx",
        "setWindowCaption",
        "caption",
        "updateChannelAppearance",
        "contextMenuClosed",
        "resetStatusBar",
        "setStatusBarTempText",
        "text",
        "clearStatusBarTempText",
        "setStatusBarInfoLabel",
        "clearStatusBarInfoLabel",
        "setStatusBarLagLabelShown",
        "shown",
        "updateStatusBarLagLabel",
        "Server*",
        "server",
        "msec",
        "resetStatusBarLagLabel",
        "setStatusBarLagLabelTooLongLag",
        "updateStatusBarSSLLabel",
        "removeStatusBarSSLLabel",
        "autoJoinToggled",
        "Konversation::ServerGroupSettingsPtr",
        "autoConnectOnStartupToggled",
        "frontServerChanging",
        "updateAppearance",
        "saveSplitterSizes",
        "setViewTreeShown",
        "show",
        "updateViews",
        "serverGroup",
        "setViewNotification",
        "ChatWindow*",
        "widget",
        "Konversation::TabNotifyType",
        "type",
        "unsetViewNotification",
        "view",
        "setUnseenEventsNotification",
        "toggleViewNotifications",
        "toggleAutoJoin",
        "toggleConnectOnStartup",
        "showView",
        "goToView",
        "page",
        "showNextView",
        "showPreviousView",
        "showNextActiveView",
        "showLastFocusedView",
        "canMoveViewLeft",
        "canMoveViewRight",
        "moveViewLeft",
        "moveViewRight",
        "closeView",
        "closeViewMiddleClick",
        "closeCurrentView",
        "renameKonsole",
        "cleanupAfterClose",
        "changeViewCharset",
        "index",
        "updateViewEncoding",
        "showViewContextMenu",
        "QWidget*",
        "tab",
        "QPoint",
        "pos",
        "clearView",
        "clearAllViews",
        "findText",
        "findNextText",
        "findPrevText",
        "insertCharacter",
        "insertChar",
        "chr",
        "insertIRCColor",
        "doAutoReplace",
        "focusInputBox",
        "clearViewLines",
        "insertRememberLine",
        "cancelRememberLine",
        "insertMarkerLine",
        "insertRememberLines",
        "resetFrontViewUnseenEventsCount",
        "openLogFile",
        "file",
        "addKonsolePanel",
        "zoomIn",
        "zoomOut",
        "resetFont",
        "addUrlCatcher",
        "closeUrlCatcher",
        "toggleDccPanel",
        "addDccPanel",
        "closeDccPanel",
        "deleteDccPanel",
        "getDccPanel",
        "addDccChat",
        "Konversation::DCC::Chat*",
        "myNick",
        "addStatusView",
        "StatusPanel*",
        "addRawLog",
        "RawLog*",
        "disconnectFrontServer",
        "reconnectFrontServer",
        "showJoinChannelDialog",
        "connectionStateChanged",
        "Konversation::ConnectionState",
        "state",
        "channelJoined",
        "Channel*",
        "channel",
        "addChannel",
        "name",
        "rejoinChannel",
        "openChannelSettings",
        "toggleChannelNicklists",
        "addQuery",
        "Query*",
        "NickInfoPtr",
        "weinitiated",
        "updateQueryChrome",
        "closeQueries",
        "addChannelListPanel",
        "ChannelListPanel*",
        "openChannelList",
        "filter",
        "getList",
        "openNicksOnlinePanel",
        "closeNicksOnlinePanel",
        "viewSwitched",
        "newIndex",
        "onViewTreeDestroyed",
        "object"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'viewChanged'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'setWindowCaption'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'updateChannelAppearance'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contextMenuClosed'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetStatusBar'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setStatusBarTempText'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'clearStatusBarTempText'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setStatusBarInfoLabel'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'clearStatusBarInfoLabel'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setStatusBarLagLabelShown'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'updateStatusBarLagLabel'
        QtMocHelpers::SignalData<void(Server *, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::Int, 20 },
        }}),
        // Signal 'resetStatusBarLagLabel'
        QtMocHelpers::SignalData<void(Server *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'setStatusBarLagLabelTooLongLag'
        QtMocHelpers::SignalData<void(Server *, int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::Int, 20 },
        }}),
        // Signal 'updateStatusBarSSLLabel'
        QtMocHelpers::SignalData<void(Server *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'removeStatusBarSSLLabel'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoJoinToggled'
        QtMocHelpers::SignalData<void(const Konversation::ServerGroupSettingsPtr)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Signal 'autoConnectOnStartupToggled'
        QtMocHelpers::SignalData<void(const Konversation::ServerGroupSettingsPtr)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Signal 'frontServerChanging'
        QtMocHelpers::SignalData<void(Server *)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Slot 'updateAppearance'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveSplitterSizes'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setViewTreeShown'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'setViewTreeShown'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'updateViews'
        QtMocHelpers::SlotData<void(const Konversation::ServerGroupSettingsPtr &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 34 },
        }}),
        // Slot 'updateViews'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setViewNotification'
        QtMocHelpers::SlotData<void(ChatWindow *, const Konversation::TabNotifyType &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { 0x80000000 | 38, 39 },
        }}),
        // Slot 'unsetViewNotification'
        QtMocHelpers::SlotData<void(ChatWindow *)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 41 },
        }}),
        // Slot 'setUnseenEventsNotification'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleViewNotifications'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleAutoJoin'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleConnectOnStartup'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showView'
        QtMocHelpers::SlotData<void(ChatWindow *)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 41 },
        }}),
        // Slot 'goToView'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'showNextView'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showPreviousView'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showNextActiveView'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showLastFocusedView'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'canMoveViewLeft'
        QtMocHelpers::SlotData<bool() const>(53, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canMoveViewRight'
        QtMocHelpers::SlotData<bool() const>(54, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'moveViewLeft'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveViewRight'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeView'
        QtMocHelpers::SlotData<void(int)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 41 },
        }}),
        // Slot 'closeView'
        QtMocHelpers::SlotData<void(ChatWindow *)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 41 },
        }}),
        // Slot 'closeViewMiddleClick'
        QtMocHelpers::SlotData<void(int)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 41 },
        }}),
        // Slot 'closeCurrentView'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'renameKonsole'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanupAfterClose'
        QtMocHelpers::SlotData<void(ChatWindow *)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 41 },
        }}),
        // Slot 'changeViewCharset'
        QtMocHelpers::SlotData<void(int)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 63 },
        }}),
        // Slot 'updateViewEncoding'
        QtMocHelpers::SlotData<void(ChatWindow *)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 41 },
        }}),
        // Slot 'showViewContextMenu'
        QtMocHelpers::SlotData<void(QWidget *, const QPoint &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 66, 67 }, { 0x80000000 | 68, 69 },
        }}),
        // Slot 'clearView'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearAllViews'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findText'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findNextText'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findPrevText'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertCharacter'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertChar'
        QtMocHelpers::SlotData<void(uint)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 77 },
        }}),
        // Slot 'insertIRCColor'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doAutoReplace'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'focusInputBox'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearViewLines'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertRememberLine'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancelRememberLine'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertMarkerLine'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertRememberLines'
        QtMocHelpers::SlotData<void(Server *)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'resetFrontViewUnseenEventsCount'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openLogFile'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openLogFile'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 88 },
        }}),
        // Slot 'addKonsolePanel'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetFont'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addUrlCatcher'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeUrlCatcher'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleDccPanel'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addDccPanel'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeDccPanel'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteDccPanel'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getDccPanel'
        QtMocHelpers::SlotData<ChatWindow *() const>(99, 2, QMC::AccessPublic, 0x80000000 | 36),
        // Slot 'addDccChat'
        QtMocHelpers::SlotData<void(Konversation::DCC::Chat *)>(100, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 101, 102 },
        }}),
        // Slot 'addStatusView'
        QtMocHelpers::SlotData<StatusPanel *(Server *)>(103, 2, QMC::AccessPublic, 0x80000000 | 104, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'addRawLog'
        QtMocHelpers::SlotData<RawLog *(Server *)>(105, 2, QMC::AccessPublic, 0x80000000 | 106, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'disconnectFrontServer'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reconnectFrontServer'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showJoinChannelDialog'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'connectionStateChanged'
        QtMocHelpers::SlotData<void(Server *, Konversation::ConnectionState)>(110, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 111, 112 },
        }}),
        // Slot 'channelJoined'
        QtMocHelpers::SlotData<void(Channel *)>(113, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 114, 115 },
        }}),
        // Slot 'addChannel'
        QtMocHelpers::SlotData<Channel *(Server *, const QString &)>(116, 2, QMC::AccessPublic, 0x80000000 | 114, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QString, 117 },
        }}),
        // Slot 'rejoinChannel'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openChannelSettings'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleChannelNicklists'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addQuery'
        QtMocHelpers::SlotData<Query *(Server *, const NickInfoPtr &, bool)>(121, 2, QMC::AccessPublic, 0x80000000 | 122, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 123, 117 }, { QMetaType::Bool, 124 },
        }}),
        // Slot 'addQuery'
        QtMocHelpers::SlotData<Query *(Server *, const NickInfoPtr &)>(121, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 122, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 123, 117 },
        }}),
        // Slot 'updateQueryChrome'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(125, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 41 }, { QMetaType::QString, 117 },
        }}),
        // Slot 'closeQueries'
        QtMocHelpers::SlotData<void()>(126, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addChannelListPanel'
        QtMocHelpers::SlotData<ChannelListPanel *(Server *)>(127, 2, QMC::AccessPublic, 0x80000000 | 128, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'openChannelList'
        QtMocHelpers::SlotData<void(Server *, const QString &, bool)>(129, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QString, 130 }, { QMetaType::Bool, 131 },
        }}),
        // Slot 'openChannelList'
        QtMocHelpers::SlotData<void(Server *, const QString &)>(129, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QString, 130 },
        }}),
        // Slot 'openChannelList'
        QtMocHelpers::SlotData<void(Server *)>(129, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'openChannelList'
        QtMocHelpers::SlotData<void()>(129, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'openNicksOnlinePanel'
        QtMocHelpers::SlotData<void()>(132, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeNicksOnlinePanel'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'viewSwitched'
        QtMocHelpers::SlotData<void(int)>(134, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 135 },
        }}),
        // Slot 'onViewTreeDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(136, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 137 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ViewContainer, qt_meta_tag_ZN13ViewContainerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ViewContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ViewContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ViewContainerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ViewContainerE_t>.metaTypes,
    nullptr
} };

void ViewContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->viewChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 1: _t->setWindowCaption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->updateChannelAppearance(); break;
        case 3: _t->contextMenuClosed(); break;
        case 4: _t->resetStatusBar(); break;
        case 5: _t->setStatusBarTempText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->clearStatusBarTempText(); break;
        case 7: _t->setStatusBarInfoLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->clearStatusBarInfoLabel(); break;
        case 9: _t->setStatusBarLagLabelShown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->updateStatusBarLagLabel((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->resetStatusBarLagLabel((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 12: _t->setStatusBarLagLabelTooLongLag((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->updateStatusBarSSLLabel((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 14: _t->removeStatusBarSSLLabel(); break;
        case 15: _t->autoJoinToggled((*reinterpret_cast<std::add_pointer_t<Konversation::ServerGroupSettingsPtr>>(_a[1]))); break;
        case 16: _t->autoConnectOnStartupToggled((*reinterpret_cast<std::add_pointer_t<Konversation::ServerGroupSettingsPtr>>(_a[1]))); break;
        case 17: _t->frontServerChanging((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 18: _t->updateAppearance(); break;
        case 19: _t->saveSplitterSizes(); break;
        case 20: _t->setViewTreeShown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->setViewTreeShown(); break;
        case 22: _t->updateViews((*reinterpret_cast<std::add_pointer_t<Konversation::ServerGroupSettingsPtr>>(_a[1]))); break;
        case 23: _t->updateViews(); break;
        case 24: _t->setViewNotification((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Konversation::TabNotifyType>>(_a[2]))); break;
        case 25: _t->unsetViewNotification((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1]))); break;
        case 26: _t->setUnseenEventsNotification(); break;
        case 27: _t->toggleViewNotifications(); break;
        case 28: _t->toggleAutoJoin(); break;
        case 29: _t->toggleConnectOnStartup(); break;
        case 30: _t->showView((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1]))); break;
        case 31: _t->goToView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->showNextView(); break;
        case 33: _t->showPreviousView(); break;
        case 34: _t->showNextActiveView(); break;
        case 35: _t->showLastFocusedView(); break;
        case 36: { bool _r = _t->canMoveViewLeft();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->canMoveViewRight();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->moveViewLeft(); break;
        case 39: _t->moveViewRight(); break;
        case 40: _t->closeView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 41: _t->closeView((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1]))); break;
        case 42: _t->closeViewMiddleClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 43: _t->closeCurrentView(); break;
        case 44: _t->renameKonsole(); break;
        case 45: _t->cleanupAfterClose((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1]))); break;
        case 46: _t->changeViewCharset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->updateViewEncoding((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1]))); break;
        case 48: _t->showViewContextMenu((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 49: _t->clearView(); break;
        case 50: _t->clearAllViews(); break;
        case 51: _t->findText(); break;
        case 52: _t->findNextText(); break;
        case 53: _t->findPrevText(); break;
        case 54: _t->insertCharacter(); break;
        case 55: _t->insertChar((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 56: _t->insertIRCColor(); break;
        case 57: _t->doAutoReplace(); break;
        case 58: _t->focusInputBox(); break;
        case 59: _t->clearViewLines(); break;
        case 60: _t->insertRememberLine(); break;
        case 61: _t->cancelRememberLine(); break;
        case 62: _t->insertMarkerLine(); break;
        case 63: _t->insertRememberLines((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 64: _t->resetFrontViewUnseenEventsCount(); break;
        case 65: _t->openLogFile(); break;
        case 66: _t->openLogFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 67: _t->addKonsolePanel(); break;
        case 68: _t->zoomIn(); break;
        case 69: _t->zoomOut(); break;
        case 70: _t->resetFont(); break;
        case 71: _t->addUrlCatcher(); break;
        case 72: _t->closeUrlCatcher(); break;
        case 73: _t->toggleDccPanel(); break;
        case 74: _t->addDccPanel(); break;
        case 75: _t->closeDccPanel(); break;
        case 76: _t->deleteDccPanel(); break;
        case 77: { ChatWindow* _r = _t->getDccPanel();
            if (_a[0]) *reinterpret_cast<ChatWindow**>(_a[0]) = std::move(_r); }  break;
        case 78: _t->addDccChat((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Chat*>>(_a[1]))); break;
        case 79: { StatusPanel* _r = _t->addStatusView((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<StatusPanel**>(_a[0]) = std::move(_r); }  break;
        case 80: { RawLog* _r = _t->addRawLog((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<RawLog**>(_a[0]) = std::move(_r); }  break;
        case 81: _t->disconnectFrontServer(); break;
        case 82: _t->reconnectFrontServer(); break;
        case 83: _t->showJoinChannelDialog(); break;
        case 84: _t->connectionStateChanged((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionState>>(_a[2]))); break;
        case 85: _t->channelJoined((*reinterpret_cast<std::add_pointer_t<Channel*>>(_a[1]))); break;
        case 86: { Channel* _r = _t->addChannel((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Channel**>(_a[0]) = std::move(_r); }  break;
        case 87: _t->rejoinChannel(); break;
        case 88: _t->openChannelSettings(); break;
        case 89: _t->toggleChannelNicklists(); break;
        case 90: { Query* _r = _t->addQuery((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NickInfoPtr>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Query**>(_a[0]) = std::move(_r); }  break;
        case 91: { Query* _r = _t->addQuery((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NickInfoPtr>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Query**>(_a[0]) = std::move(_r); }  break;
        case 92: _t->updateQueryChrome((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 93: _t->closeQueries(); break;
        case 94: { ChannelListPanel* _r = _t->addChannelListPanel((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ChannelListPanel**>(_a[0]) = std::move(_r); }  break;
        case 95: _t->openChannelList((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 96: _t->openChannelList((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 97: _t->openChannelList((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 98: _t->openChannelList(); break;
        case 99: _t->openNicksOnlinePanel(); break;
        case 100: _t->closeNicksOnlinePanel(); break;
        case 101: _t->viewSwitched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 102: _t->onViewTreeDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 47:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 48:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 63:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 79:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 80:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 84:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 86:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 90:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 91:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 92:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 94:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 95:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 96:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 97:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(const QModelIndex & )>(_a, &ViewContainer::viewChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(const QString & )>(_a, &ViewContainer::setWindowCaption, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)()>(_a, &ViewContainer::updateChannelAppearance, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)()>(_a, &ViewContainer::contextMenuClosed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)()>(_a, &ViewContainer::resetStatusBar, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(const QString & )>(_a, &ViewContainer::setStatusBarTempText, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)()>(_a, &ViewContainer::clearStatusBarTempText, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(const QString & )>(_a, &ViewContainer::setStatusBarInfoLabel, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)()>(_a, &ViewContainer::clearStatusBarInfoLabel, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(bool )>(_a, &ViewContainer::setStatusBarLagLabelShown, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(Server * , int )>(_a, &ViewContainer::updateStatusBarLagLabel, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(Server * )>(_a, &ViewContainer::resetStatusBarLagLabel, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(Server * , int )>(_a, &ViewContainer::setStatusBarLagLabelTooLongLag, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(Server * )>(_a, &ViewContainer::updateStatusBarSSLLabel, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)()>(_a, &ViewContainer::removeStatusBarSSLLabel, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(const Konversation::ServerGroupSettingsPtr )>(_a, &ViewContainer::autoJoinToggled, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(const Konversation::ServerGroupSettingsPtr )>(_a, &ViewContainer::autoConnectOnStartupToggled, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewContainer::*)(Server * )>(_a, &ViewContainer::frontServerChanging, 17))
            return;
    }
}

const QMetaObject *ViewContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ViewContainerE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int ViewContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 103)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 103;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 103)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 103;
    }
    return _id;
}

// SIGNAL 0
void ViewContainer::viewChanged(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ViewContainer::setWindowCaption(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ViewContainer::updateChannelAppearance()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ViewContainer::contextMenuClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ViewContainer::resetStatusBar()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ViewContainer::setStatusBarTempText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ViewContainer::clearStatusBarTempText()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ViewContainer::setStatusBarInfoLabel(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ViewContainer::clearStatusBarInfoLabel()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ViewContainer::setStatusBarLagLabelShown(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ViewContainer::updateStatusBarLagLabel(Server * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void ViewContainer::resetStatusBarLagLabel(Server * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ViewContainer::setStatusBarLagLabelTooLongLag(Server * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void ViewContainer::updateStatusBarSSLLabel(Server * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void ViewContainer::removeStatusBarSSLLabel()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void ViewContainer::autoJoinToggled(const Konversation::ServerGroupSettingsPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void ViewContainer::autoConnectOnStartupToggled(const Konversation::ServerGroupSettingsPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void ViewContainer::frontServerChanging(Server * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}
QT_WARNING_POP
