/********************************************************************************
** Form generated from reading UI file 'transferdetailedinfopanelui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSFERDETAILEDINFOPANELUI_H
#define UI_TRANSFERDETAILEDINFOPANELUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ksqueezedtextlabel.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_DccTransferDetailedInfoPanelUI
{
public:
    QGridLayout *gridLayout;
    QLabel *textLabel12;
    QLabel *m_labelDccType;
    QLabel *textLabel4;
    KSqueezedTextLabel *m_labelFilename;
    QLabel *textLabel23;
    QLabel *m_labelPartner;
    QLabel *textLabel1_3;
    QLabel *m_labelSelf;
    QLabel *textLabel10;
    KSqueezedTextLabel *m_labelStatus;
    QLabel *textLabel18;
    QProgressBar *m_progress;
    QLabel *textLabel3;
    QHBoxLayout *hboxLayout;
    KUrlRequester *m_urlreqLocation;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DccTransferDetailedInfoPanelUI)
    {
        if (DccTransferDetailedInfoPanelUI->objectName().isEmpty())
            DccTransferDetailedInfoPanelUI->setObjectName("DccTransferDetailedInfoPanelUI");
        DccTransferDetailedInfoPanelUI->resize(213, 193);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DccTransferDetailedInfoPanelUI->sizePolicy().hasHeightForWidth());
        DccTransferDetailedInfoPanelUI->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(DccTransferDetailedInfoPanelUI);
        gridLayout->setObjectName("gridLayout");
        textLabel12 = new QLabel(DccTransferDetailedInfoPanelUI);
        textLabel12->setObjectName("textLabel12");
        textLabel12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel12->setWordWrap(false);

        gridLayout->addWidget(textLabel12, 0, 0, 1, 1);

        m_labelDccType = new QLabel(DccTransferDetailedInfoPanelUI);
        m_labelDccType->setObjectName("m_labelDccType");
        m_labelDccType->setWordWrap(false);

        gridLayout->addWidget(m_labelDccType, 0, 1, 1, 1);

        textLabel4 = new QLabel(DccTransferDetailedInfoPanelUI);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel4->setWordWrap(false);

        gridLayout->addWidget(textLabel4, 1, 0, 1, 1);

        m_labelFilename = new KSqueezedTextLabel(DccTransferDetailedInfoPanelUI);
        m_labelFilename->setObjectName("m_labelFilename");

        gridLayout->addWidget(m_labelFilename, 1, 1, 1, 1);

        textLabel23 = new QLabel(DccTransferDetailedInfoPanelUI);
        textLabel23->setObjectName("textLabel23");
        textLabel23->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel23->setWordWrap(false);

        gridLayout->addWidget(textLabel23, 2, 0, 1, 1);

        m_labelPartner = new QLabel(DccTransferDetailedInfoPanelUI);
        m_labelPartner->setObjectName("m_labelPartner");
        m_labelPartner->setWordWrap(false);

        gridLayout->addWidget(m_labelPartner, 2, 1, 1, 1);

        textLabel1_3 = new QLabel(DccTransferDetailedInfoPanelUI);
        textLabel1_3->setObjectName("textLabel1_3");
        textLabel1_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel1_3->setWordWrap(false);

        gridLayout->addWidget(textLabel1_3, 3, 0, 1, 1);

        m_labelSelf = new QLabel(DccTransferDetailedInfoPanelUI);
        m_labelSelf->setObjectName("m_labelSelf");
        m_labelSelf->setWordWrap(false);

        gridLayout->addWidget(m_labelSelf, 3, 1, 1, 1);

        textLabel10 = new QLabel(DccTransferDetailedInfoPanelUI);
        textLabel10->setObjectName("textLabel10");
        textLabel10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel10->setWordWrap(false);

        gridLayout->addWidget(textLabel10, 4, 0, 1, 1);

        m_labelStatus = new KSqueezedTextLabel(DccTransferDetailedInfoPanelUI);
        m_labelStatus->setObjectName("m_labelStatus");

        gridLayout->addWidget(m_labelStatus, 4, 1, 1, 1);

        textLabel18 = new QLabel(DccTransferDetailedInfoPanelUI);
        textLabel18->setObjectName("textLabel18");
        textLabel18->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel18->setWordWrap(false);

        gridLayout->addWidget(textLabel18, 5, 0, 1, 1);

        m_progress = new QProgressBar(DccTransferDetailedInfoPanelUI);
        m_progress->setObjectName("m_progress");

        gridLayout->addWidget(m_progress, 5, 1, 1, 1);

        textLabel3 = new QLabel(DccTransferDetailedInfoPanelUI);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel3->setWordWrap(false);

        gridLayout->addWidget(textLabel3, 6, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        m_urlreqLocation = new KUrlRequester(DccTransferDetailedInfoPanelUI);
        m_urlreqLocation->setObjectName("m_urlreqLocation");
        m_urlreqLocation->setEnabled(true);

        hboxLayout->addWidget(m_urlreqLocation);


        gridLayout->addLayout(hboxLayout, 6, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 1, 1, 1);


        retranslateUi(DccTransferDetailedInfoPanelUI);

        QMetaObject::connectSlotsByName(DccTransferDetailedInfoPanelUI);
    } // setupUi

    void retranslateUi(QWidget *DccTransferDetailedInfoPanelUI)
    {
        textLabel12->setText(tr2i18n("Type:", nullptr));
        textLabel4->setText(tr2i18n("Filename:", nullptr));
        m_labelFilename->setText(QString());
        textLabel23->setText(tr2i18n("Partner:", nullptr));
        textLabel1_3->setText(tr2i18n("Self:", nullptr));
        textLabel10->setText(tr2i18n("Status:", nullptr));
        m_labelStatus->setText(QString());
        textLabel18->setText(tr2i18n("Progress:", nullptr));
        textLabel3->setText(tr2i18n("Location:", nullptr));
        (void)DccTransferDetailedInfoPanelUI;
    } // retranslateUi

};

namespace Ui {
    class DccTransferDetailedInfoPanelUI: public Ui_DccTransferDetailedInfoPanelUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRANSFERDETAILEDINFOPANELUI_H

