/********************************************************************************
** Form generated from reading UI file 'transferdetailedtimeinfopanelui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSFERDETAILEDTIMEINFOPANELUI_H
#define UI_TRANSFERDETAILEDTIMEINFOPANELUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DccTransferDetailedTimeInfoPanelUI
{
public:
    QHBoxLayout *horizontalLayout;
    QFormLayout *formLayout_2;
    QLabel *textLabel19;
    QLabel *m_labelCurrentPosition;
    QLabel *textLabel21;
    QLabel *m_labelFileSize;
    QLabel *textLabel14;
    QLabel *m_labelIsResumed;
    QLabel *textLabel1_2;
    QLabel *m_labelCurrentSpeed;
    QLabel *textLabel1;
    QLabel *m_labelAverageSpeed;
    QFrame *line3;
    QFormLayout *formLayout;
    QLabel *textLabel6;
    QLabel *m_labelTransferringTime;
    QLabel *textLabel8;
    QLabel *m_labelTimeLeft;
    QLabel *textLabel5;
    QLabel *m_labelTimeOffered;
    QLabel *textLabel6_2;
    QLabel *m_labelTimeStarted;
    QLabel *textLabel7;
    QLabel *m_labelTimeFinished;

    void setupUi(QWidget *DccTransferDetailedTimeInfoPanelUI)
    {
        if (DccTransferDetailedTimeInfoPanelUI->objectName().isEmpty())
            DccTransferDetailedTimeInfoPanelUI->setObjectName("DccTransferDetailedTimeInfoPanelUI");
        DccTransferDetailedTimeInfoPanelUI->resize(303, 128);
        horizontalLayout = new QHBoxLayout(DccTransferDetailedTimeInfoPanelUI);
        horizontalLayout->setSpacing(4);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        formLayout_2 = new QFormLayout();
        formLayout_2->setContentsMargins(9, 9, 9, 9);
        formLayout_2->setObjectName("formLayout_2");
        textLabel19 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel19->setObjectName("textLabel19");
        textLabel19->setWordWrap(false);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel19);

        m_labelCurrentPosition = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelCurrentPosition->setObjectName("m_labelCurrentPosition");
        m_labelCurrentPosition->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelCurrentPosition->setWordWrap(false);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, m_labelCurrentPosition);

        textLabel21 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel21->setObjectName("textLabel21");
        textLabel21->setWordWrap(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel21);

        m_labelFileSize = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelFileSize->setObjectName("m_labelFileSize");
        m_labelFileSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelFileSize->setWordWrap(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, m_labelFileSize);

        textLabel14 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel14->setObjectName("textLabel14");
        textLabel14->setWordWrap(false);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, textLabel14);

        m_labelIsResumed = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelIsResumed->setObjectName("m_labelIsResumed");
        m_labelIsResumed->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelIsResumed->setWordWrap(false);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, m_labelIsResumed);

        textLabel1_2 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, textLabel1_2);

        m_labelCurrentSpeed = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelCurrentSpeed->setObjectName("m_labelCurrentSpeed");
        m_labelCurrentSpeed->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelCurrentSpeed->setWordWrap(false);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, m_labelCurrentSpeed);

        textLabel1 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, textLabel1);

        m_labelAverageSpeed = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelAverageSpeed->setObjectName("m_labelAverageSpeed");
        m_labelAverageSpeed->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelAverageSpeed->setWordWrap(false);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, m_labelAverageSpeed);


        horizontalLayout->addLayout(formLayout_2);

        line3 = new QFrame(DccTransferDetailedTimeInfoPanelUI);
        line3->setObjectName("line3");
        line3->setFrameShape(QFrame::VLine);
        line3->setFrameShadow(QFrame::Sunken);

        horizontalLayout->addWidget(line3);

        formLayout = new QFormLayout();
#ifndef UI_Q_OS_MAC
        formLayout->setContentsMargins(9, 9, 9, 9);
#endif
        formLayout->setObjectName("formLayout");
        textLabel6 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel6->setObjectName("textLabel6");
        textLabel6->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel6);

        m_labelTransferringTime = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelTransferringTime->setObjectName("m_labelTransferringTime");
        m_labelTransferringTime->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelTransferringTime->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_labelTransferringTime);

        textLabel8 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel8->setObjectName("textLabel8");
        textLabel8->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel8);

        m_labelTimeLeft = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelTimeLeft->setObjectName("m_labelTimeLeft");
        m_labelTimeLeft->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelTimeLeft->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, m_labelTimeLeft);

        textLabel5 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel5->setObjectName("textLabel5");
        textLabel5->setWordWrap(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, textLabel5);

        m_labelTimeOffered = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelTimeOffered->setObjectName("m_labelTimeOffered");
        m_labelTimeOffered->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelTimeOffered->setWordWrap(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, m_labelTimeOffered);

        textLabel6_2 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel6_2->setObjectName("textLabel6_2");
        textLabel6_2->setWordWrap(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, textLabel6_2);

        m_labelTimeStarted = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelTimeStarted->setObjectName("m_labelTimeStarted");
        m_labelTimeStarted->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelTimeStarted->setWordWrap(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, m_labelTimeStarted);

        textLabel7 = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        textLabel7->setObjectName("textLabel7");
        textLabel7->setWordWrap(false);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, textLabel7);

        m_labelTimeFinished = new QLabel(DccTransferDetailedTimeInfoPanelUI);
        m_labelTimeFinished->setObjectName("m_labelTimeFinished");
        m_labelTimeFinished->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_labelTimeFinished->setWordWrap(false);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, m_labelTimeFinished);


        horizontalLayout->addLayout(formLayout);


        retranslateUi(DccTransferDetailedTimeInfoPanelUI);

        QMetaObject::connectSlotsByName(DccTransferDetailedTimeInfoPanelUI);
    } // setupUi

    void retranslateUi(QWidget *DccTransferDetailedTimeInfoPanelUI)
    {
        textLabel19->setText(tr2i18n("Current position:", nullptr));
        textLabel21->setText(tr2i18n("File size:", nullptr));
        textLabel14->setText(tr2i18n("Resumed:", nullptr));
        textLabel1_2->setText(tr2i18n("Current speed:", nullptr));
        textLabel1->setText(tr2i18n("Average speed:", nullptr));
        textLabel6->setText(tr2i18n("Transferring time:", nullptr));
        textLabel8->setText(tr2i18n("Estimated time left:", nullptr));
        textLabel5->setText(tr2i18n("Offered at:", nullptr));
        textLabel6_2->setText(tr2i18n("Started at:", nullptr));
        textLabel7->setText(tr2i18n("Finished at:", nullptr));
        (void)DccTransferDetailedTimeInfoPanelUI;
    } // retranslateUi

};

namespace Ui {
    class DccTransferDetailedTimeInfoPanelUI: public Ui_DccTransferDetailedTimeInfoPanelUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRANSFERDETAILEDTIMEINFOPANELUI_H

