/********************************************************************************
** Form generated from reading UI file 'quickbuttons_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUICKBUTTONS_CONFIGUI_H
#define UI_QUICKBUTTONS_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_QuickButtons_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox3;
    QHBoxLayout *hboxLayout;
    QLabel *placeholderHelpLabel;
    QTreeWidget *buttonListView;
    QVBoxLayout *vboxLayout;
    QPushButton *newButton;
    QPushButton *removeButton;
    QSpacerItem *spacer1;
    QFormLayout *formLayout;
    QLabel *nameLabel;
    KLineEdit *nameInput;
    QLabel *actionLabel;
    KLineEdit *actionInput;
    QCheckBox *kcfg_ShowQuickButtonsInContextMenu;

    void setupUi(QWidget *QuickButtons_ConfigUI)
    {
        if (QuickButtons_ConfigUI->objectName().isEmpty())
            QuickButtons_ConfigUI->setObjectName("QuickButtons_ConfigUI");
        QuickButtons_ConfigUI->resize(485, 302);
        gridLayout = new QGridLayout(QuickButtons_ConfigUI);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        groupBox3 = new QGroupBox(QuickButtons_ConfigUI);
        groupBox3->setObjectName("groupBox3");
        groupBox3->setFlat(false);
        hboxLayout = new QHBoxLayout(groupBox3);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(-1, 4, -1, -1);
        placeholderHelpLabel = new QLabel(groupBox3);
        placeholderHelpLabel->setObjectName("placeholderHelpLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(placeholderHelpLabel->sizePolicy().hasHeightForWidth());
        placeholderHelpLabel->setSizePolicy(sizePolicy);
        placeholderHelpLabel->setTextFormat(Qt::PlainText);
        placeholderHelpLabel->setWordWrap(false);

        hboxLayout->addWidget(placeholderHelpLabel);


        gridLayout->addWidget(groupBox3, 3, 0, 1, 1);

        buttonListView = new QTreeWidget(QuickButtons_ConfigUI);
        buttonListView->setObjectName("buttonListView");
        buttonListView->setDragEnabled(true);
        buttonListView->setDragDropMode(QAbstractItemView::InternalMove);
        buttonListView->setRootIsDecorated(false);
        buttonListView->setAllColumnsShowFocus(true);

        gridLayout->addWidget(buttonListView, 0, 0, 1, 1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        newButton = new QPushButton(QuickButtons_ConfigUI);
        newButton->setObjectName("newButton");

        vboxLayout->addWidget(newButton);

        removeButton = new QPushButton(QuickButtons_ConfigUI);
        removeButton->setObjectName("removeButton");

        vboxLayout->addWidget(removeButton);

        spacer1 = new QSpacerItem(20, 230, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer1);


        gridLayout->addLayout(vboxLayout, 0, 1, 4, 1);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        nameLabel = new QLabel(QuickButtons_ConfigUI);
        nameLabel->setObjectName("nameLabel");
        nameLabel->setEnabled(false);
        nameLabel->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, nameLabel);

        nameInput = new KLineEdit(QuickButtons_ConfigUI);
        nameInput->setObjectName("nameInput");
        nameInput->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(nameInput->sizePolicy().hasHeightForWidth());
        nameInput->setSizePolicy(sizePolicy1);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, nameInput);

        actionLabel = new QLabel(QuickButtons_ConfigUI);
        actionLabel->setObjectName("actionLabel");
        actionLabel->setEnabled(false);
        actionLabel->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, actionLabel);

        actionInput = new KLineEdit(QuickButtons_ConfigUI);
        actionInput->setObjectName("actionInput");
        actionInput->setEnabled(false);
        sizePolicy1.setHeightForWidth(actionInput->sizePolicy().hasHeightForWidth());
        actionInput->setSizePolicy(sizePolicy1);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, actionInput);


        gridLayout->addLayout(formLayout, 1, 0, 1, 1);

        kcfg_ShowQuickButtonsInContextMenu = new QCheckBox(QuickButtons_ConfigUI);
        kcfg_ShowQuickButtonsInContextMenu->setObjectName("kcfg_ShowQuickButtonsInContextMenu");

        gridLayout->addWidget(kcfg_ShowQuickButtonsInContextMenu, 2, 0, 1, 1);

        QWidget::setTabOrder(buttonListView, newButton);
        QWidget::setTabOrder(newButton, removeButton);
        QWidget::setTabOrder(removeButton, nameInput);
        QWidget::setTabOrder(nameInput, actionInput);
        QWidget::setTabOrder(actionInput, kcfg_ShowQuickButtonsInContextMenu);

        retranslateUi(QuickButtons_ConfigUI);

        QMetaObject::connectSlotsByName(QuickButtons_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *QuickButtons_ConfigUI)
    {
        groupBox3->setTitle(tr2i18n("Available Placeholders", nullptr));
        placeholderHelpLabel->setText(tr2i18n("%c: Current channel\n"
"%i: Input box contents\n"
"%k: Channel key\n"
"%K: Server password\n"
"%n: Send command directly to the server instead of your input box\n"
"%o: Current nickname\n"
"%s<term>%: term used to separate nicknames in %u\n"
"%u: List of selected nicknames", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = buttonListView->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Button Action", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Button Name", nullptr));
        newButton->setText(tr2i18n("New", nullptr));
        removeButton->setText(tr2i18n("Remove", nullptr));
        nameLabel->setText(tr2i18n("Button name:", nullptr));
        actionLabel->setText(tr2i18n("Button action:", nullptr));
        kcfg_ShowQuickButtonsInContextMenu->setText(tr2i18n("Show quick buttons that operate on nicknames in nickname context menus", nullptr));
        (void)QuickButtons_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class QuickButtons_ConfigUI: public Ui_QuickButtons_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QUICKBUTTONS_CONFIGUI_H

