/********************************************************************************
** Form generated from reading UI file 'alias_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ALIAS_CONFIGUI_H
#define UI_ALIAS_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_Alias_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QTreeWidget *aliasListView;
    QVBoxLayout *vboxLayout;
    QPushButton *newButton;
    QPushButton *removeButton;
    QSpacerItem *spacer18;
    QFormLayout *formLayout;
    QLabel *aliasLabel;
    KLineEdit *aliasInput;
    QLabel *replacementLabel;
    KLineEdit *replacementInput;

    void setupUi(QWidget *Alias_ConfigUI)
    {
        if (Alias_ConfigUI->objectName().isEmpty())
            Alias_ConfigUI->setObjectName("Alias_ConfigUI");
        Alias_ConfigUI->resize(292, 206);
        gridLayout = new QGridLayout(Alias_ConfigUI);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        aliasListView = new QTreeWidget(Alias_ConfigUI);
        aliasListView->setObjectName("aliasListView");
        aliasListView->setAcceptDrops(true);
        aliasListView->setDragEnabled(true);
        aliasListView->setDragDropMode(QAbstractItemView::InternalMove);
        aliasListView->setRootIsDecorated(false);
        aliasListView->setAllColumnsShowFocus(true);

        gridLayout->addWidget(aliasListView, 0, 0, 1, 1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        newButton = new QPushButton(Alias_ConfigUI);
        newButton->setObjectName("newButton");

        vboxLayout->addWidget(newButton);

        removeButton = new QPushButton(Alias_ConfigUI);
        removeButton->setObjectName("removeButton");

        vboxLayout->addWidget(removeButton);

        spacer18 = new QSpacerItem(20, 350, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer18);


        gridLayout->addLayout(vboxLayout, 0, 1, 2, 1);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        aliasLabel = new QLabel(Alias_ConfigUI);
        aliasLabel->setObjectName("aliasLabel");
        aliasLabel->setEnabled(false);
        aliasLabel->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, aliasLabel);

        aliasInput = new KLineEdit(Alias_ConfigUI);
        aliasInput->setObjectName("aliasInput");
        aliasInput->setEnabled(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, aliasInput);

        replacementLabel = new QLabel(Alias_ConfigUI);
        replacementLabel->setObjectName("replacementLabel");
        replacementLabel->setEnabled(false);
        replacementLabel->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, replacementLabel);

        replacementInput = new KLineEdit(Alias_ConfigUI);
        replacementInput->setObjectName("replacementInput");
        replacementInput->setEnabled(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, replacementInput);


        gridLayout->addLayout(formLayout, 1, 0, 1, 1);

        QWidget::setTabOrder(aliasListView, aliasInput);
        QWidget::setTabOrder(aliasInput, replacementInput);
        QWidget::setTabOrder(replacementInput, newButton);
        QWidget::setTabOrder(newButton, removeButton);

        retranslateUi(Alias_ConfigUI);

        QMetaObject::connectSlotsByName(Alias_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *Alias_ConfigUI)
    {
        QTreeWidgetItem *___qtreewidgetitem = aliasListView->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Replacement", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Alias", nullptr));
        newButton->setText(tr2i18n("&New", nullptr));
        removeButton->setText(tr2i18n("&Remove", nullptr));
        aliasLabel->setText(tr2i18n("Alias:", nullptr));
        replacementLabel->setText(tr2i18n("Replacement:", nullptr));
        (void)Alias_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class Alias_ConfigUI: public Ui_Alias_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ALIAS_CONFIGUI_H

