/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
*/

/********************************************************************************
** Form generated from reading UI file 'colorsappearance_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORSAPPEARANCE_CONFIG_H
#define UI_COLORSAPPEARANCE_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ColorsAppearance_Config
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox1;
    QGridLayout *gridLayout1;
    QCheckBox *kcfg_InputFieldsBackgroundColor;
    KColorButton *kcfg_TimeColor;
    KColorButton *kcfg_AlternateBackgroundColor;
    KColorButton *kcfg_QueryMessageColor;
    KColorButton *kcfg_CommandMessageColor;
    KColorButton *kcfg_BacklogMessageColor;
    KColorButton *kcfg_TextViewBackgroundColor;
    KColorButton *kcfg_ServerMessageColor;
    KColorButton *kcfg_HyperlinkColor;
    KColorButton *kcfg_ChannelMessageColor;
    KColorButton *kcfg_ActionMessageColor;
    QSpacerItem *spacer185;
    QSpacerItem *spacer186;
    QSpacerItem *spacer187;
    QSpacerItem *spacer188;
    QSpacerItem *spacer189;
    QSpacerItem *spacer190;
    QSpacerItem *spacer191;
    QSpacerItem *spacer192;
    QSpacerItem *spacer193;
    QSpacerItem *spacer194;
    QLabel *textLabel3;
    QLabel *textLabel2_2;
    QLabel *textLabel1_2;
    QLabel *textLabel2;
    QLabel *textLabel1;
    QLabel *textLabel4;
    QLabel *textLabel5;
    QLabel *textLabel1_8;
    QLabel *textLabel1_9;
    QLabel *textLabel1_10;
    QGroupBox *kcfg_UseColoredNicks;
    QGridLayout *gridLayout2;
    QLabel *textLabel9;
    KColorButton *kcfg_NickColor4;
    QLabel *textLabel8;
    KColorButton *kcfg_NickColor5;
    QLabel *textLabel7;
    KColorButton *kcfg_NickColor2;
    KColorButton *kcfg_NickColor3;
    QLabel *textLabel6;
    QSpacerItem *spacer196;
    QSpacerItem *spacer197;
    QSpacerItem *spacer197_2;
    QSpacerItem *spacer196_2;
    KColorButton *kcfg_NickColor0;
    QLabel *textLabel4_2;
    KColorButton *kcfg_NickColor1;
    QLabel *textLabel5_2;
    QSpacerItem *spacer197_3;
    QSpacerItem *spacer196_3;
    KColorButton *kcfg_NickColor7;
    KColorButton *kcfg_NickColor6;
    QLabel *textLabel11;
    QLabel *textLabel10;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1_3;
    KColorButton *kcfg_NickColor8;
    QSpacerItem *spacer204;
    QGroupBox *kcfg_AllowColorCodes;
    QGridLayout *gridLayout3;
    QLabel *textLabel12_2;
    QLabel *textLabel12_3;
    QLabel *textLabel12_4;
    KColorButton *kcfg_IrcColorCode3;
    KColorButton *kcfg_IrcColorCode2;
    KColorButton *kcfg_IrcColorCode0;
    KColorButton *kcfg_IrcColorCode1;
    QLabel *textLabel12_14;
    QLabel *textLabel12_8;
    QLabel *textLabel12_7;
    QLabel *textLabel12_6;
    QLabel *textLabel12_5;
    KColorButton *kcfg_IrcColorCode5;
    KColorButton *kcfg_IrcColorCode4;
    KColorButton *kcfg_IrcColorCode7;
    KColorButton *kcfg_IrcColorCode6;
    QSpacerItem *spacer211_4;
    QSpacerItem *spacer211_3;
    QSpacerItem *spacer211_2;
    QSpacerItem *spacer211;
    QSpacerItem *spacer211_3_2;
    QSpacerItem *spacer211_5;
    QSpacerItem *spacer211_2_2;
    QSpacerItem *spacer211_4_2;
    KColorButton *kcfg_IrcColorCode11;
    QLabel *textLabel12_12;
    KColorButton *kcfg_IrcColorCode9;
    KColorButton *kcfg_IrcColorCode10;
    KColorButton *kcfg_IrcColorCode8;
    QLabel *textLabel12_10;
    QLabel *textLabel12_9;
    QLabel *textLabel12_11;
    QSpacerItem *spacer211_6;
    QSpacerItem *spacer211_2_3;
    QSpacerItem *spacer211_3_3;
    QSpacerItem *spacer211_4_3;
    KColorButton *kcfg_IrcColorCode15;
    QLabel *textLabel12_13;
    KColorButton *kcfg_IrcColorCode13;
    QLabel *textLabel12_16;
    KColorButton *kcfg_IrcColorCode12;
    KColorButton *kcfg_IrcColorCode14;
    QLabel *textLabel12_15;
    QLabel *textLabel12;
    QSpacerItem *spacer227;

    void setupUi(QWidget *ColorsAppearance_Config)
    {
        if (ColorsAppearance_Config->objectName().isEmpty())
            ColorsAppearance_Config->setObjectName("ColorsAppearance_Config");
        ColorsAppearance_Config->resize(457, 558);
        gridLayout = new QGridLayout(ColorsAppearance_Config);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        groupBox1 = new QGroupBox(ColorsAppearance_Config);
        groupBox1->setObjectName("groupBox1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox1->sizePolicy().hasHeightForWidth());
        groupBox1->setSizePolicy(sizePolicy);
        gridLayout1 = new QGridLayout(groupBox1);
        gridLayout1->setObjectName("gridLayout1");
        kcfg_InputFieldsBackgroundColor = new QCheckBox(groupBox1);
        kcfg_InputFieldsBackgroundColor->setObjectName("kcfg_InputFieldsBackgroundColor");

        gridLayout1->addWidget(kcfg_InputFieldsBackgroundColor, 5, 0, 1, 5);

        kcfg_TimeColor = new KColorButton(groupBox1);
        kcfg_TimeColor->setObjectName("kcfg_TimeColor");

        gridLayout1->addWidget(kcfg_TimeColor, 3, 4, 1, 1);

        kcfg_AlternateBackgroundColor = new KColorButton(groupBox1);
        kcfg_AlternateBackgroundColor->setObjectName("kcfg_AlternateBackgroundColor");

        gridLayout1->addWidget(kcfg_AlternateBackgroundColor, 4, 4, 1, 1);

        kcfg_QueryMessageColor = new KColorButton(groupBox1);
        kcfg_QueryMessageColor->setObjectName("kcfg_QueryMessageColor");

        gridLayout1->addWidget(kcfg_QueryMessageColor, 2, 4, 1, 1);

        kcfg_CommandMessageColor = new KColorButton(groupBox1);
        kcfg_CommandMessageColor->setObjectName("kcfg_CommandMessageColor");

        gridLayout1->addWidget(kcfg_CommandMessageColor, 1, 4, 1, 1);

        kcfg_BacklogMessageColor = new KColorButton(groupBox1);
        kcfg_BacklogMessageColor->setObjectName("kcfg_BacklogMessageColor");

        gridLayout1->addWidget(kcfg_BacklogMessageColor, 0, 4, 1, 1);

        kcfg_TextViewBackgroundColor = new KColorButton(groupBox1);
        kcfg_TextViewBackgroundColor->setObjectName("kcfg_TextViewBackgroundColor");

        gridLayout1->addWidget(kcfg_TextViewBackgroundColor, 4, 1, 1, 1);

        kcfg_ServerMessageColor = new KColorButton(groupBox1);
        kcfg_ServerMessageColor->setObjectName("kcfg_ServerMessageColor");

        gridLayout1->addWidget(kcfg_ServerMessageColor, 3, 1, 1, 1);

        kcfg_HyperlinkColor = new KColorButton(groupBox1);
        kcfg_HyperlinkColor->setObjectName("kcfg_HyperlinkColor");

        gridLayout1->addWidget(kcfg_HyperlinkColor, 2, 1, 1, 1);

        kcfg_ChannelMessageColor = new KColorButton(groupBox1);
        kcfg_ChannelMessageColor->setObjectName("kcfg_ChannelMessageColor");

        gridLayout1->addWidget(kcfg_ChannelMessageColor, 1, 1, 1, 1);

        kcfg_ActionMessageColor = new KColorButton(groupBox1);
        kcfg_ActionMessageColor->setObjectName("kcfg_ActionMessageColor");

        gridLayout1->addWidget(kcfg_ActionMessageColor, 0, 1, 1, 1);

        spacer185 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer185, 0, 2, 1, 1);

        spacer186 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer186, 1, 2, 1, 1);

        spacer187 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer187, 2, 2, 1, 1);

        spacer188 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer188, 3, 2, 1, 1);

        spacer189 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer189, 4, 2, 1, 1);

        spacer190 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer190, 0, 5, 1, 1);

        spacer191 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer191, 1, 5, 1, 1);

        spacer192 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer192, 2, 5, 1, 1);

        spacer193 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer193, 3, 5, 1, 1);

        spacer194 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacer194, 4, 5, 1, 1);

        textLabel3 = new QLabel(groupBox1);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        gridLayout1->addWidget(textLabel3, 4, 0, 1, 1);

        textLabel2_2 = new QLabel(groupBox1);
        textLabel2_2->setObjectName("textLabel2_2");
        textLabel2_2->setWordWrap(false);

        gridLayout1->addWidget(textLabel2_2, 3, 0, 1, 1);

        textLabel1_2 = new QLabel(groupBox1);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        gridLayout1->addWidget(textLabel1_2, 2, 0, 1, 1);

        textLabel2 = new QLabel(groupBox1);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout1->addWidget(textLabel2, 1, 0, 1, 1);

        textLabel1 = new QLabel(groupBox1);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        gridLayout1->addWidget(textLabel1, 0, 0, 1, 1);

        textLabel4 = new QLabel(groupBox1);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setWordWrap(false);

        gridLayout1->addWidget(textLabel4, 0, 3, 1, 1);

        textLabel5 = new QLabel(groupBox1);
        textLabel5->setObjectName("textLabel5");
        textLabel5->setWordWrap(false);

        gridLayout1->addWidget(textLabel5, 1, 3, 1, 1);

        textLabel1_8 = new QLabel(groupBox1);
        textLabel1_8->setObjectName("textLabel1_8");
        textLabel1_8->setWordWrap(false);

        gridLayout1->addWidget(textLabel1_8, 2, 3, 1, 1);

        textLabel1_9 = new QLabel(groupBox1);
        textLabel1_9->setObjectName("textLabel1_9");
        textLabel1_9->setWordWrap(false);

        gridLayout1->addWidget(textLabel1_9, 3, 3, 1, 1);

        textLabel1_10 = new QLabel(groupBox1);
        textLabel1_10->setObjectName("textLabel1_10");
        textLabel1_10->setWordWrap(false);

        gridLayout1->addWidget(textLabel1_10, 4, 3, 1, 1);


        gridLayout->addWidget(groupBox1, 0, 0, 1, 1);

        kcfg_UseColoredNicks = new QGroupBox(ColorsAppearance_Config);
        kcfg_UseColoredNicks->setObjectName("kcfg_UseColoredNicks");
        kcfg_UseColoredNicks->setEnabled(true);
        kcfg_UseColoredNicks->setCheckable(true);
        gridLayout2 = new QGridLayout(kcfg_UseColoredNicks);
        gridLayout2->setObjectName("gridLayout2");
        textLabel9 = new QLabel(kcfg_UseColoredNicks);
        textLabel9->setObjectName("textLabel9");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(textLabel9->sizePolicy().hasHeightForWidth());
        textLabel9->setSizePolicy(sizePolicy1);
        textLabel9->setWordWrap(false);

        gridLayout2->addWidget(textLabel9, 1, 6, 1, 1);

        kcfg_NickColor4 = new KColorButton(kcfg_UseColoredNicks);
        kcfg_NickColor4->setObjectName("kcfg_NickColor4");

        gridLayout2->addWidget(kcfg_NickColor4, 0, 7, 1, 1);

        textLabel8 = new QLabel(kcfg_UseColoredNicks);
        textLabel8->setObjectName("textLabel8");
        sizePolicy1.setHeightForWidth(textLabel8->sizePolicy().hasHeightForWidth());
        textLabel8->setSizePolicy(sizePolicy1);
        textLabel8->setWordWrap(false);

        gridLayout2->addWidget(textLabel8, 0, 6, 1, 1);

        kcfg_NickColor5 = new KColorButton(kcfg_UseColoredNicks);
        kcfg_NickColor5->setObjectName("kcfg_NickColor5");

        gridLayout2->addWidget(kcfg_NickColor5, 1, 7, 1, 1);

        textLabel7 = new QLabel(kcfg_UseColoredNicks);
        textLabel7->setObjectName("textLabel7");
        sizePolicy1.setHeightForWidth(textLabel7->sizePolicy().hasHeightForWidth());
        textLabel7->setSizePolicy(sizePolicy1);
        textLabel7->setWordWrap(false);

        gridLayout2->addWidget(textLabel7, 1, 3, 1, 1);

        kcfg_NickColor2 = new KColorButton(kcfg_UseColoredNicks);
        kcfg_NickColor2->setObjectName("kcfg_NickColor2");

        gridLayout2->addWidget(kcfg_NickColor2, 0, 4, 1, 1);

        kcfg_NickColor3 = new KColorButton(kcfg_UseColoredNicks);
        kcfg_NickColor3->setObjectName("kcfg_NickColor3");

        gridLayout2->addWidget(kcfg_NickColor3, 1, 4, 1, 1);

        textLabel6 = new QLabel(kcfg_UseColoredNicks);
        textLabel6->setObjectName("textLabel6");
        sizePolicy1.setHeightForWidth(textLabel6->sizePolicy().hasHeightForWidth());
        textLabel6->setSizePolicy(sizePolicy1);
        textLabel6->setWordWrap(false);

        gridLayout2->addWidget(textLabel6, 0, 3, 1, 1);

        spacer196 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacer196, 0, 5, 1, 1);

        spacer197 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacer197, 1, 5, 1, 1);

        spacer197_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacer197_2, 1, 2, 1, 1);

        spacer196_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacer196_2, 0, 2, 1, 1);

        kcfg_NickColor0 = new KColorButton(kcfg_UseColoredNicks);
        kcfg_NickColor0->setObjectName("kcfg_NickColor0");

        gridLayout2->addWidget(kcfg_NickColor0, 0, 1, 1, 1);

        textLabel4_2 = new QLabel(kcfg_UseColoredNicks);
        textLabel4_2->setObjectName("textLabel4_2");
        sizePolicy1.setHeightForWidth(textLabel4_2->sizePolicy().hasHeightForWidth());
        textLabel4_2->setSizePolicy(sizePolicy1);
        textLabel4_2->setWordWrap(false);

        gridLayout2->addWidget(textLabel4_2, 0, 0, 1, 1);

        kcfg_NickColor1 = new KColorButton(kcfg_UseColoredNicks);
        kcfg_NickColor1->setObjectName("kcfg_NickColor1");

        gridLayout2->addWidget(kcfg_NickColor1, 1, 1, 1, 1);

        textLabel5_2 = new QLabel(kcfg_UseColoredNicks);
        textLabel5_2->setObjectName("textLabel5_2");
        sizePolicy1.setHeightForWidth(textLabel5_2->sizePolicy().hasHeightForWidth());
        textLabel5_2->setSizePolicy(sizePolicy1);
        textLabel5_2->setWordWrap(false);

        gridLayout2->addWidget(textLabel5_2, 1, 0, 1, 1);

        spacer197_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacer197_3, 1, 8, 1, 1);

        spacer196_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacer196_3, 0, 8, 1, 1);

        kcfg_NickColor7 = new KColorButton(kcfg_UseColoredNicks);
        kcfg_NickColor7->setObjectName("kcfg_NickColor7");

        gridLayout2->addWidget(kcfg_NickColor7, 1, 10, 1, 1);

        kcfg_NickColor6 = new KColorButton(kcfg_UseColoredNicks);
        kcfg_NickColor6->setObjectName("kcfg_NickColor6");

        gridLayout2->addWidget(kcfg_NickColor6, 0, 10, 1, 1);

        textLabel11 = new QLabel(kcfg_UseColoredNicks);
        textLabel11->setObjectName("textLabel11");
        sizePolicy1.setHeightForWidth(textLabel11->sizePolicy().hasHeightForWidth());
        textLabel11->setSizePolicy(sizePolicy1);
        textLabel11->setWordWrap(false);

        gridLayout2->addWidget(textLabel11, 1, 9, 1, 1);

        textLabel10 = new QLabel(kcfg_UseColoredNicks);
        textLabel10->setObjectName("textLabel10");
        sizePolicy1.setHeightForWidth(textLabel10->sizePolicy().hasHeightForWidth());
        textLabel10->setSizePolicy(sizePolicy1);
        textLabel10->setWordWrap(false);

        gridLayout2->addWidget(textLabel10, 0, 9, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        textLabel1_3 = new QLabel(kcfg_UseColoredNicks);
        textLabel1_3->setObjectName("textLabel1_3");
        textLabel1_3->setWordWrap(false);

        hboxLayout->addWidget(textLabel1_3);

        kcfg_NickColor8 = new KColorButton(kcfg_UseColoredNicks);
        kcfg_NickColor8->setObjectName("kcfg_NickColor8");

        hboxLayout->addWidget(kcfg_NickColor8);

        spacer204 = new QSpacerItem(271, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacer204);


        gridLayout2->addLayout(hboxLayout, 2, 0, 1, 12);


        gridLayout->addWidget(kcfg_UseColoredNicks, 1, 0, 1, 1);

        kcfg_AllowColorCodes = new QGroupBox(ColorsAppearance_Config);
        kcfg_AllowColorCodes->setObjectName("kcfg_AllowColorCodes");
        kcfg_AllowColorCodes->setEnabled(true);
        kcfg_AllowColorCodes->setCheckable(true);
        gridLayout3 = new QGridLayout(kcfg_AllowColorCodes);
        gridLayout3->setObjectName("gridLayout3");
        textLabel12_2 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_2->setObjectName("textLabel12_2");
        sizePolicy1.setHeightForWidth(textLabel12_2->sizePolicy().hasHeightForWidth());
        textLabel12_2->setSizePolicy(sizePolicy1);
        textLabel12_2->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_2, 1, 0, 1, 1);

        textLabel12_3 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_3->setObjectName("textLabel12_3");
        sizePolicy1.setHeightForWidth(textLabel12_3->sizePolicy().hasHeightForWidth());
        textLabel12_3->setSizePolicy(sizePolicy1);
        textLabel12_3->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_3, 2, 0, 1, 1);

        textLabel12_4 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_4->setObjectName("textLabel12_4");
        sizePolicy1.setHeightForWidth(textLabel12_4->sizePolicy().hasHeightForWidth());
        textLabel12_4->setSizePolicy(sizePolicy1);
        textLabel12_4->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_4, 3, 0, 1, 1);

        kcfg_IrcColorCode3 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode3->setObjectName("kcfg_IrcColorCode3");

        gridLayout3->addWidget(kcfg_IrcColorCode3, 3, 1, 1, 1);

        kcfg_IrcColorCode2 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode2->setObjectName("kcfg_IrcColorCode2");

        gridLayout3->addWidget(kcfg_IrcColorCode2, 2, 1, 1, 1);

        kcfg_IrcColorCode0 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode0->setObjectName("kcfg_IrcColorCode0");

        gridLayout3->addWidget(kcfg_IrcColorCode0, 0, 1, 1, 1);

        kcfg_IrcColorCode1 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode1->setObjectName("kcfg_IrcColorCode1");

        gridLayout3->addWidget(kcfg_IrcColorCode1, 1, 1, 1, 1);

        textLabel12_14 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_14->setObjectName("textLabel12_14");
        sizePolicy1.setHeightForWidth(textLabel12_14->sizePolicy().hasHeightForWidth());
        textLabel12_14->setSizePolicy(sizePolicy1);
        textLabel12_14->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_14, 0, 0, 1, 1);

        textLabel12_8 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_8->setObjectName("textLabel12_8");
        textLabel12_8->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_8, 3, 3, 1, 1);

        textLabel12_7 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_7->setObjectName("textLabel12_7");
        textLabel12_7->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_7, 2, 3, 1, 1);

        textLabel12_6 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_6->setObjectName("textLabel12_6");
        textLabel12_6->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_6, 1, 3, 1, 1);

        textLabel12_5 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_5->setObjectName("textLabel12_5");
        textLabel12_5->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_5, 0, 3, 1, 1);

        kcfg_IrcColorCode5 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode5->setObjectName("kcfg_IrcColorCode5");

        gridLayout3->addWidget(kcfg_IrcColorCode5, 1, 4, 1, 1);

        kcfg_IrcColorCode4 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode4->setObjectName("kcfg_IrcColorCode4");

        gridLayout3->addWidget(kcfg_IrcColorCode4, 0, 4, 1, 1);

        kcfg_IrcColorCode7 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode7->setObjectName("kcfg_IrcColorCode7");

        gridLayout3->addWidget(kcfg_IrcColorCode7, 3, 4, 1, 1);

        kcfg_IrcColorCode6 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode6->setObjectName("kcfg_IrcColorCode6");

        gridLayout3->addWidget(kcfg_IrcColorCode6, 2, 4, 1, 1);

        spacer211_4 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_4, 3, 2, 1, 1);

        spacer211_3 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_3, 2, 2, 1, 1);

        spacer211_2 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_2, 1, 2, 1, 1);

        spacer211 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211, 0, 2, 1, 1);

        spacer211_3_2 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_3_2, 2, 5, 1, 1);

        spacer211_5 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_5, 0, 5, 1, 1);

        spacer211_2_2 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_2_2, 1, 5, 1, 1);

        spacer211_4_2 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_4_2, 3, 5, 1, 1);

        kcfg_IrcColorCode11 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode11->setObjectName("kcfg_IrcColorCode11");

        gridLayout3->addWidget(kcfg_IrcColorCode11, 3, 7, 1, 1);

        textLabel12_12 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_12->setObjectName("textLabel12_12");
        textLabel12_12->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_12, 3, 6, 1, 1);

        kcfg_IrcColorCode9 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode9->setObjectName("kcfg_IrcColorCode9");

        gridLayout3->addWidget(kcfg_IrcColorCode9, 1, 7, 1, 1);

        kcfg_IrcColorCode10 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode10->setObjectName("kcfg_IrcColorCode10");

        gridLayout3->addWidget(kcfg_IrcColorCode10, 2, 7, 1, 1);

        kcfg_IrcColorCode8 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode8->setObjectName("kcfg_IrcColorCode8");

        gridLayout3->addWidget(kcfg_IrcColorCode8, 0, 7, 1, 1);

        textLabel12_10 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_10->setObjectName("textLabel12_10");
        textLabel12_10->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_10, 1, 6, 1, 1);

        textLabel12_9 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_9->setObjectName("textLabel12_9");
        textLabel12_9->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_9, 0, 6, 1, 1);

        textLabel12_11 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_11->setObjectName("textLabel12_11");
        textLabel12_11->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_11, 2, 6, 1, 1);

        spacer211_6 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_6, 0, 8, 1, 1);

        spacer211_2_3 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_2_3, 1, 8, 1, 1);

        spacer211_3_3 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_3_3, 2, 8, 1, 1);

        spacer211_4_3 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacer211_4_3, 3, 8, 1, 1);

        kcfg_IrcColorCode15 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode15->setObjectName("kcfg_IrcColorCode15");

        gridLayout3->addWidget(kcfg_IrcColorCode15, 3, 10, 1, 1);

        textLabel12_13 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_13->setObjectName("textLabel12_13");
        textLabel12_13->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_13, 0, 9, 1, 1);

        kcfg_IrcColorCode13 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode13->setObjectName("kcfg_IrcColorCode13");

        gridLayout3->addWidget(kcfg_IrcColorCode13, 1, 10, 1, 1);

        textLabel12_16 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_16->setObjectName("textLabel12_16");
        textLabel12_16->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_16, 3, 9, 1, 1);

        kcfg_IrcColorCode12 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode12->setObjectName("kcfg_IrcColorCode12");

        gridLayout3->addWidget(kcfg_IrcColorCode12, 0, 10, 1, 1);

        kcfg_IrcColorCode14 = new KColorButton(kcfg_AllowColorCodes);
        kcfg_IrcColorCode14->setObjectName("kcfg_IrcColorCode14");

        gridLayout3->addWidget(kcfg_IrcColorCode14, 2, 10, 1, 1);

        textLabel12_15 = new QLabel(kcfg_AllowColorCodes);
        textLabel12_15->setObjectName("textLabel12_15");
        textLabel12_15->setWordWrap(false);

        gridLayout3->addWidget(textLabel12_15, 2, 9, 1, 1);

        textLabel12 = new QLabel(kcfg_AllowColorCodes);
        textLabel12->setObjectName("textLabel12");
        textLabel12->setWordWrap(false);

        gridLayout3->addWidget(textLabel12, 1, 9, 1, 1);


        gridLayout->addWidget(kcfg_AllowColorCodes, 2, 0, 1, 1);

        spacer227 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacer227, 3, 0, 1, 1);

#if QT_CONFIG(shortcut)
        textLabel3->setBuddy(kcfg_TextViewBackgroundColor);
        textLabel2_2->setBuddy(kcfg_ServerMessageColor);
        textLabel1_2->setBuddy(kcfg_HyperlinkColor);
        textLabel2->setBuddy(kcfg_ChannelMessageColor);
        textLabel1->setBuddy(kcfg_ActionMessageColor);
        textLabel4->setBuddy(kcfg_BacklogMessageColor);
        textLabel5->setBuddy(kcfg_CommandMessageColor);
        textLabel1_8->setBuddy(kcfg_QueryMessageColor);
        textLabel1_9->setBuddy(kcfg_TimeColor);
        textLabel1_10->setBuddy(kcfg_AlternateBackgroundColor);
        textLabel1_3->setBuddy(kcfg_NickColor8);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_ActionMessageColor, kcfg_ChannelMessageColor);
        QWidget::setTabOrder(kcfg_ChannelMessageColor, kcfg_HyperlinkColor);
        QWidget::setTabOrder(kcfg_HyperlinkColor, kcfg_ServerMessageColor);
        QWidget::setTabOrder(kcfg_ServerMessageColor, kcfg_TextViewBackgroundColor);
        QWidget::setTabOrder(kcfg_TextViewBackgroundColor, kcfg_BacklogMessageColor);
        QWidget::setTabOrder(kcfg_BacklogMessageColor, kcfg_CommandMessageColor);
        QWidget::setTabOrder(kcfg_CommandMessageColor, kcfg_QueryMessageColor);
        QWidget::setTabOrder(kcfg_QueryMessageColor, kcfg_TimeColor);
        QWidget::setTabOrder(kcfg_TimeColor, kcfg_AlternateBackgroundColor);
        QWidget::setTabOrder(kcfg_AlternateBackgroundColor, kcfg_InputFieldsBackgroundColor);
        QWidget::setTabOrder(kcfg_InputFieldsBackgroundColor, kcfg_UseColoredNicks);
        QWidget::setTabOrder(kcfg_UseColoredNicks, kcfg_NickColor0);
        QWidget::setTabOrder(kcfg_NickColor0, kcfg_NickColor1);
        QWidget::setTabOrder(kcfg_NickColor1, kcfg_NickColor2);
        QWidget::setTabOrder(kcfg_NickColor2, kcfg_NickColor3);
        QWidget::setTabOrder(kcfg_NickColor3, kcfg_NickColor4);
        QWidget::setTabOrder(kcfg_NickColor4, kcfg_NickColor5);
        QWidget::setTabOrder(kcfg_NickColor5, kcfg_NickColor6);
        QWidget::setTabOrder(kcfg_NickColor6, kcfg_NickColor7);
        QWidget::setTabOrder(kcfg_NickColor7, kcfg_NickColor8);
        QWidget::setTabOrder(kcfg_NickColor8, kcfg_AllowColorCodes);
        QWidget::setTabOrder(kcfg_AllowColorCodes, kcfg_IrcColorCode0);
        QWidget::setTabOrder(kcfg_IrcColorCode0, kcfg_IrcColorCode1);
        QWidget::setTabOrder(kcfg_IrcColorCode1, kcfg_IrcColorCode2);
        QWidget::setTabOrder(kcfg_IrcColorCode2, kcfg_IrcColorCode3);
        QWidget::setTabOrder(kcfg_IrcColorCode3, kcfg_IrcColorCode4);
        QWidget::setTabOrder(kcfg_IrcColorCode4, kcfg_IrcColorCode5);
        QWidget::setTabOrder(kcfg_IrcColorCode5, kcfg_IrcColorCode6);
        QWidget::setTabOrder(kcfg_IrcColorCode6, kcfg_IrcColorCode7);
        QWidget::setTabOrder(kcfg_IrcColorCode7, kcfg_IrcColorCode8);
        QWidget::setTabOrder(kcfg_IrcColorCode8, kcfg_IrcColorCode9);
        QWidget::setTabOrder(kcfg_IrcColorCode9, kcfg_IrcColorCode10);
        QWidget::setTabOrder(kcfg_IrcColorCode10, kcfg_IrcColorCode11);
        QWidget::setTabOrder(kcfg_IrcColorCode11, kcfg_IrcColorCode12);
        QWidget::setTabOrder(kcfg_IrcColorCode12, kcfg_IrcColorCode13);
        QWidget::setTabOrder(kcfg_IrcColorCode13, kcfg_IrcColorCode14);
        QWidget::setTabOrder(kcfg_IrcColorCode14, kcfg_IrcColorCode15);

        retranslateUi(ColorsAppearance_Config);
        QObject::connect(kcfg_InputFieldsBackgroundColor, SIGNAL(toggled(bool)), kcfg_AlternateBackgroundColor, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(ColorsAppearance_Config);
    } // setupUi

    void retranslateUi(QWidget *ColorsAppearance_Config)
    {
        groupBox1->setTitle(tr2i18n("Custom Colors", nullptr));
        kcfg_InputFieldsBackgroundColor->setText(tr2i18n("&Use custom colors for input box, nickname list and tab list", nullptr));
        kcfg_TimeColor->setText(QString());
        kcfg_AlternateBackgroundColor->setText(QString());
        kcfg_QueryMessageColor->setText(QString());
        kcfg_CommandMessageColor->setText(QString());
        kcfg_BacklogMessageColor->setText(QString());
        kcfg_TextViewBackgroundColor->setText(QString());
        kcfg_ServerMessageColor->setText(QString());
        kcfg_HyperlinkColor->setText(QString());
        kcfg_ChannelMessageColor->setText(QString());
        kcfg_ActionMessageColor->setText(QString());
        textLabel3->setText(tr2i18n("&Background:", nullptr));
        textLabel2_2->setText(tr2i18n("&Server message:", nullptr));
        textLabel1_2->setText(tr2i18n("H&yperlink:", nullptr));
        textLabel2->setText(tr2i18n("Channel &message:", nullptr));
        textLabel1->setText(tr2i18n("Actio&n:", nullptr));
        textLabel4->setText(tr2i18n("Bac&klog:", nullptr));
        textLabel5->setText(tr2i18n("Comman&d message:", nullptr));
        textLabel1_8->setText(tr2i18n("&Query message:", nullptr));
        textLabel1_9->setText(tr2i18n("&Timestamp:", nullptr));
        textLabel1_10->setText(tr2i18n("A&lternate background:", nullptr));
        kcfg_UseColoredNicks->setTitle(tr2i18n("Colored Nicks", nullptr));
        textLabel9->setText(tr2i18n("5:", nullptr));
        kcfg_NickColor4->setText(QString());
        textLabel8->setText(tr2i18n("4:", nullptr));
        kcfg_NickColor5->setText(QString());
        textLabel7->setText(tr2i18n("3:", nullptr));
        kcfg_NickColor2->setText(QString());
        kcfg_NickColor3->setText(QString());
        textLabel6->setText(tr2i18n("2:", nullptr));
        kcfg_NickColor0->setText(QString());
        textLabel4_2->setText(tr2i18n("0:", nullptr));
        kcfg_NickColor1->setText(QString());
        textLabel5_2->setText(tr2i18n("1:", nullptr));
        kcfg_NickColor7->setText(QString());
        kcfg_NickColor6->setText(QString());
        textLabel11->setText(tr2i18n("7:", nullptr));
        textLabel10->setText(tr2i18n("6:", nullptr));
        textLabel1_3->setText(tr2i18n("&Own nick color:", nullptr));
        kcfg_NickColor8->setText(QString());
#if QT_CONFIG(whatsthis)
        kcfg_AllowColorCodes->setWhatsThis(tr2i18n("By enabling this option, color codes added to IRC messages will be displayed in your chat window as colored text. You can add color codes to your messages, by selecting Insert -> IRC Color", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AllowColorCodes->setTitle(tr2i18n("&Allow Colored Text in IRC Messages", nullptr));
        textLabel12_2->setText(tr2i18n("1:", nullptr));
        textLabel12_3->setText(tr2i18n("2:", nullptr));
        textLabel12_4->setText(tr2i18n("3:", nullptr));
        kcfg_IrcColorCode3->setText(QString());
        kcfg_IrcColorCode2->setText(QString());
        kcfg_IrcColorCode0->setText(QString());
        kcfg_IrcColorCode1->setText(QString());
        textLabel12_14->setText(tr2i18n("0:", nullptr));
        textLabel12_8->setText(tr2i18n("7:", nullptr));
        textLabel12_7->setText(tr2i18n("6:", nullptr));
        textLabel12_6->setText(tr2i18n("5:", nullptr));
        textLabel12_5->setText(tr2i18n("4:", nullptr));
        kcfg_IrcColorCode5->setText(QString());
        kcfg_IrcColorCode4->setText(QString());
        kcfg_IrcColorCode7->setText(QString());
        kcfg_IrcColorCode6->setText(QString());
        kcfg_IrcColorCode11->setText(QString());
        textLabel12_12->setText(tr2i18n("11:", nullptr));
        kcfg_IrcColorCode9->setText(QString());
        kcfg_IrcColorCode10->setText(QString());
        kcfg_IrcColorCode8->setText(QString());
        textLabel12_10->setText(tr2i18n("9:", nullptr));
        textLabel12_9->setText(tr2i18n("8:", nullptr));
        textLabel12_11->setText(tr2i18n("10:", nullptr));
        kcfg_IrcColorCode15->setText(QString());
        textLabel12_13->setText(tr2i18n("12:", nullptr));
        kcfg_IrcColorCode13->setText(QString());
        textLabel12_16->setText(tr2i18n("15:", nullptr));
        kcfg_IrcColorCode12->setText(QString());
        kcfg_IrcColorCode14->setText(QString());
        textLabel12_15->setText(tr2i18n("14:", nullptr));
        textLabel12->setText(tr2i18n("13:", nullptr));
        (void)ColorsAppearance_Config;
    } // retranslateUi

};

namespace Ui {
    class ColorsAppearance_Config: public Ui_ColorsAppearance_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLORSAPPEARANCE_CONFIG_H

