/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // konversationui.rc
  0x0,0x0,0x2,0x73,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xb4,0x8,0x4d,0x13,0x0,0xd6,0x1a,0x4c,0x1d,0x50,0x57,0xe,
  0x8f,0xa1,0x2c,0xe6,0x12,0x9b,0x74,0x82,0x50,0x7a,0xc9,0xb,0xf2,0x54,0x4e,0xe7,
  0xb2,0x14,0x90,0x8a,0x68,0x5b,0x54,0x9d,0xd5,0x9,0x4a,0x0,0x3f,0x0,0x43,0x0,
  0xec,0x5b,0xee,0x72,0x63,0x54,0xd3,0xaa,0x43,0x88,0xd6,0xbb,0x3e,0xd6,0xe9,0x6c,
  0x93,0xc3,0x4d,0xb1,0xf2,0x69,0x26,0xd1,0xb8,0xa8,0x36,0x23,0x87,0x28,0x2,0x14,
  0xa,0xb,0x11,0xad,0x65,0x7d,0xf4,0x4e,0xcf,0x32,0xb5,0x10,0xb9,0xc1,0x3d,0x0,
  0x12,0xcb,0xbd,0x1b,0x7c,0x23,0x87,0x5a,0x51,0xc4,0x51,0xa1,0x5c,0x28,0x91,0x56,
  0x52,0xe4,0x98,0x5c,0x2a,0xc,0x49,0x23,0x70,0x8,0xaf,0xbf,0x10,0xcb,0x2d,0x7a,
  0x50,0x7e,0xa7,0xaf,0x3a,0x6,0x7f,0x7d,0xd8,0xad,0x7e,0x3e,0x3d,0x9b,0x5a,0xed,
  0xc9,0x97,0x33,0x2c,0x1d,0xb3,0xdb,0xaa,0xe7,0x62,0xbe,0xf6,0xea,0x92,0x70,0x8,
  0xe1,0x7,0x59,0x3e,0x49,0xe2,0x7f,0xb9,0x8b,0x53,0x63,0xab,0xac,0xc9,0x76,0x75,
  0xcd,0x8f,0x8d,0x9c,0xa4,0x48,0xfc,0x50,0x5d,0x92,0xf6,0xfa,0x4c,0x3e,0xc6,0x9b,
  0xf4,0xe8,0x37,0x7c,0x50,0xae,0x57,0xac,0x9e,0x6c,0x8e,0xc5,0x53,0xea,0xdc,0xb0,
  0xf4,0xa0,0x2f,0x84,0xdb,0xe4,0x70,0xd0,0x53,0x5f,0x7f,0xd3,0x51,0x4d,0x97,0xa5,
  0xd3,0xc9,0xa5,0xd5,0xff,0x74,0x8a,0x19,0xd3,0xf9,0xd,0x3b,0xa9,0xc6,0xd,0xf3,
  0xe6,0xc7,0x8d,0xb5,0x26,0x1c,0x1e,0x6,0xce,0x6,0x5,0x1,0x0,0x40,0x42,0x2b,
  0xa9,0xe1,0xbb,0x42,0x18,0xab,0xb8,0xe9,0x9c,0x4e,0xd1,0xca,0xaa,0x7f,0x21,0xa6,
  0x77,0x6a,0x79,0xaf,0xca,0x44,0x8f,0xb9,0x22,0xf1,0xcb,0xc7,0xbe,0x4c,0x79,0xf5,
  0xf8,0xde,0x9a,0xeb,0x9c,0xda,0x63,0x63,0xaf,0xab,0x65,0x97,0x56,0x1d,0xb7,0xcd,
  0xe5,0xd8,0x34,0xa3,0xcf,0xab,0x9d,0x55,0x27,0x9d,0x7f,0xa,0x80,0x81,0xa0,0xf1,
  0x8d,0x52,0x8a,0x48,0x8a,0x41,0x6b,0x34,0x6,0x20,0x44,0x40,0x90,0x43,0x55,0xe6,
  0x1,0x34,0xe0,0x3,0x84,0xb,0x56,0x3c,0x3,0x92,0x37,0x90,0xd8,0x47,0x4c,0x38,
  0xb7,0x88,0xb9,0x73,0x97,0x2b,0x62,0x6c,0x11,0xa1,0xad,0x36,0xd,0xb,0xbb,0x8,
  0x6e,0xc2,0x1a,0xb5,0x3d,0x7,0xd9,0x95,0x48,0x8,0x65,0x71,0xa,0xd1,0x7d,0x6d,
  0xd7,0x89,0x6e,0xd4,0xd3,0xd2,0x34,0x69,0x5a,0x5,0x68,0x8b,0x68,0x9d,0x2b,0xf1,
  0x21,0x38,0xb7,0xa0,0x30,0x26,0x3c,0x99,0xe4,0xda,0x62,0x12,0x1e,0x68,0x14,0xd,
  0x9,0x28,0xcb,0xcc,0x2a,0xd8,0xc2,0x0,0x2a,0x99,0x70,0xcc,0x8a,0x87,0x8f,0xc,
  0xed,0x67,0x62,0x10,0x4e,0xdd,0xd4,0x2f,0x32,0x30,0x4b,0x4d,0x97,0xdf,0xd6,0x35,
  0x4c,0xcd,0x68,0x62,0x50,0xc6,0x80,0x3,0xc6,0xf9,0x44,0x4b,0xe8,0x24,0xe0,0x72,
  0xe,0x49,0x6a,0x0,0x16,0x46,0x10,0xcc,0x57,0xd7,0x25,0x76,0x8a,0x7b,0x21,0x83,
  0xd,0xc2,0xd6,0xea,0xd2,0xe4,0xf0,0x95,0xe7,0xc0,0xec,0x96,0x4c,0xbe,0xd,0xf0,
  0xd,0x7,0xcb,0xc7,0x57,0x6b,0xed,0x21,0x6a,0xb3,0x62,0x53,0xb8,0xf6,0x86,0xd4,
  0xcc,0xe3,0x7,0x6e,0xe2,0x69,0xb1,0xf2,0x72,0x8a,0xd9,0x22,0xb6,0x6b,0x73,0x88,
  0x3a,0xdc,0xca,0x4c,0x74,0xb0,0x92,0x2b,0x84,0x6c,0x25,0xa4,0x10,0x25,0x84,0x85,
  0x8b,0xd9,0x9e,0x14,0x1a,0x7f,0xc2,0xe8,0xa0,0x8a,0x78,0xb6,0x11,0x5c,0x9f,0xd1,
  0xfd,0x73,0xb1,0xd4,0xd1,0x4e,0x5,0x30,0xd1,0xa9,0x2b,0xa2,0xe,0x68,0xe,0x35,
  0xdb,0x65,0xab,0xf0,0x3e,0x60,0x26,0x96,0xb2,0xbb,0x65,0xa6,0xdc,0x81,0xb2,0x26,
  0x6,0x51,0x10,0x9c,0x32,0x2b,0x17,0xd,0x74,0x4e,0x26,0x64,0x79,0xda,0xb5,0x25,
  0xbf,0x13,0xdc,0x15,0x17,0x20,0xd5,0x81,0x74,0xf0,0xb1,0x43,0x9f,0x83,0x73,0x2,
  0x4a,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // konversation
  0x0,0xc,
  0x7,0xd4,0x19,0xde,
  0x0,0x6b,
  0x0,0x6f,0x0,0x6e,0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x73,0x0,0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,
    // konversationui.rc
  0x0,0x11,
  0xe,0xa1,0x46,0xa3,
  0x0,0x6b,
  0x0,0x6f,0x0,0x6e,0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x73,0x0,0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9d,0x79,0x11,0x38,0xa8,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9d,0x79,0x11,0x38,0xa8,
  // :/kxmlgui5/konversation
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9d,0x79,0x11,0x38,0xa8,
  // :/kxmlgui5/konversation/konversationui.rc
  0x0,0x0,0x0,0x34,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9d,0x79,0x11,0x38,0xa8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_konversation)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_konversation)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_konversation)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_konversation)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_konversation)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_konversation)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
