/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
*/

/********************************************************************************
** Form generated from reading UI file 'tabs_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABS_CONFIGUI_H
#define UI_TABS_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Tabs_PreferencesUI
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *lookGBox;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *placementLabel;
    QComboBox *kcfg_TabPlacement;
    QSpacerItem *spacer4;
    QCheckBox *kcfg_CloseButtons;
    QCheckBox *kcfg_ShowTabBarCloseButton;
    QGroupBox *focusGBox;
    QVBoxLayout *vboxLayout2;
    QCheckBox *kcfg_BringToFront;
    QCheckBox *kcfg_FocusNewQueries;
    QGroupBox *mouseGBox;
    QVBoxLayout *vboxLayout3;
    QCheckBox *kcfg_MiddleClickClose;
    QSpacerItem *spacer1;

    void setupUi(QWidget *Tabs_PreferencesUI)
    {
        if (Tabs_PreferencesUI->objectName().isEmpty())
            Tabs_PreferencesUI->setObjectName("Tabs_PreferencesUI");
        Tabs_PreferencesUI->resize(373, 312);
        vboxLayout = new QVBoxLayout(Tabs_PreferencesUI);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        lookGBox = new QGroupBox(Tabs_PreferencesUI);
        lookGBox->setObjectName("lookGBox");
        vboxLayout1 = new QVBoxLayout(lookGBox);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        placementLabel = new QLabel(lookGBox);
        placementLabel->setObjectName("placementLabel");
        placementLabel->setWordWrap(false);

        hboxLayout->addWidget(placementLabel);

        kcfg_TabPlacement = new QComboBox(lookGBox);
        kcfg_TabPlacement->addItem(QString());
        kcfg_TabPlacement->addItem(QString());
        kcfg_TabPlacement->addItem(QString());
        kcfg_TabPlacement->setObjectName("kcfg_TabPlacement");

        hboxLayout->addWidget(kcfg_TabPlacement);

        spacer4 = new QSpacerItem(111, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacer4);


        vboxLayout1->addLayout(hboxLayout);

        kcfg_CloseButtons = new QCheckBox(lookGBox);
        kcfg_CloseButtons->setObjectName("kcfg_CloseButtons");

        vboxLayout1->addWidget(kcfg_CloseButtons);

        kcfg_ShowTabBarCloseButton = new QCheckBox(lookGBox);
        kcfg_ShowTabBarCloseButton->setObjectName("kcfg_ShowTabBarCloseButton");

        vboxLayout1->addWidget(kcfg_ShowTabBarCloseButton);


        vboxLayout->addWidget(lookGBox);

        focusGBox = new QGroupBox(Tabs_PreferencesUI);
        focusGBox->setObjectName("focusGBox");
        vboxLayout2 = new QVBoxLayout(focusGBox);
        vboxLayout2->setObjectName("vboxLayout2");
        kcfg_BringToFront = new QCheckBox(focusGBox);
        kcfg_BringToFront->setObjectName("kcfg_BringToFront");

        vboxLayout2->addWidget(kcfg_BringToFront);

        kcfg_FocusNewQueries = new QCheckBox(focusGBox);
        kcfg_FocusNewQueries->setObjectName("kcfg_FocusNewQueries");

        vboxLayout2->addWidget(kcfg_FocusNewQueries);


        vboxLayout->addWidget(focusGBox);

        mouseGBox = new QGroupBox(Tabs_PreferencesUI);
        mouseGBox->setObjectName("mouseGBox");
        vboxLayout3 = new QVBoxLayout(mouseGBox);
        vboxLayout3->setObjectName("vboxLayout3");
        kcfg_MiddleClickClose = new QCheckBox(mouseGBox);
        kcfg_MiddleClickClose->setObjectName("kcfg_MiddleClickClose");

        vboxLayout3->addWidget(kcfg_MiddleClickClose);


        vboxLayout->addWidget(mouseGBox);

        spacer1 = new QSpacerItem(20, 100, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer1);


        retranslateUi(Tabs_PreferencesUI);

        QMetaObject::connectSlotsByName(Tabs_PreferencesUI);
    } // setupUi

    void retranslateUi(QWidget *Tabs_PreferencesUI)
    {
        Tabs_PreferencesUI->setWindowTitle(tr2i18n("TabBar_Config", nullptr));
        lookGBox->setTitle(tr2i18n("Look", nullptr));
        placementLabel->setText(tr2i18n("Placement:", nullptr));
        kcfg_TabPlacement->setItemText(0, tr2i18n("Top", nullptr));
        kcfg_TabPlacement->setItemText(1, tr2i18n("Bottom", nullptr));
        kcfg_TabPlacement->setItemText(2, tr2i18n("Left", nullptr));

        kcfg_CloseButtons->setText(tr2i18n("Show &close button on tabs", nullptr));
        kcfg_ShowTabBarCloseButton->setText(tr2i18n("Show a close button on the &right side of the tab bar", nullptr));
        focusGBox->setTitle(tr2i18n("Focus", nullptr));
        kcfg_BringToFront->setText(tr2i18n("&Focus new tabs", nullptr));
        kcfg_FocusNewQueries->setText(tr2i18n("Focus new &queries", nullptr));
        mouseGBox->setTitle(tr2i18n("Mouse", nullptr));
        kcfg_MiddleClickClose->setText(tr2i18n("&Middle-click on a tab to close it", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Tabs_PreferencesUI: public Ui_Tabs_PreferencesUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TABS_CONFIGUI_H

