/****************************************************************************
** Meta object code from reading C++ file 'server.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/irc/server.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'server.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6ServerE_t {};
} // unnamed namespace

template <> constexpr inline auto Server::qt_create_metaobjectdata<qt_meta_tag_ZN6ServerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Server",
        "destroyed",
        "",
        "connectionId",
        "nicknameChanged",
        "serverLag",
        "Server*",
        "server",
        "msec",
        "tooLongLag",
        "resetLag",
        "nicksNowOnline",
        "list",
        "changed",
        "awayState",
        "away",
        "multiServerCommand",
        "command",
        "parameter",
        "serverOnline",
        "state",
        "sentStat",
        "bytes",
        "encodedBytes",
        "IRCQueue*",
        "whichQueue",
        "nickInfoChanged",
        "NickInfoPtr",
        "nickInfo",
        "channelNickChanged",
        "channel",
        "channelMembersChanged",
        "channelName",
        "joined",
        "parted",
        "nickname",
        "channelJoinedOrUnjoined",
        "watchedNickChanged",
        "online",
        "awayInsertRememberLine",
        "sslInitFailure",
        "sslConnected",
        "connectionStateChanged",
        "Konversation::ConnectionState",
        "showView",
        "ChatWindow*",
        "view",
        "addDccPanel",
        "addDccChat",
        "Konversation::DCC::Chat*",
        "chat",
        "connectToIRCServer",
        "connectToIRCServerIn",
        "delay",
        "queue",
        "line",
        "QueuePriority",
        "priority",
        "queueList",
        "buffer",
        "setNickname",
        "newNickname",
        "addQuery",
        "Query*",
        "weinitiated",
        "closeQuery",
        "name",
        "closeChannel",
        "reconnectServer",
        "quitMessage",
        "disconnectServer",
        "quitServer",
        "openDccChat",
        "openDccWBoard",
        "requestDccChat",
        "partnerNick",
        "extension",
        "numericalOwnIp",
        "ownPort",
        "acceptDccGet",
        "nick",
        "file",
        "requestBan",
        "users",
        "option",
        "requestUnban",
        "mask",
        "addDccSend",
        "recipient",
        "QUrl",
        "fileURL",
        "passive",
        "altFileName",
        "fileSize",
        "removeQuery",
        "query",
        "notifyListStarted",
        "serverGroupId",
        "startNotifyTimer",
        "notifyTimeout",
        "sendJoinCommand",
        "password",
        "requestAway",
        "reason",
        "requestUnaway",
        "requestChannelList",
        "requestWhois",
        "requestWho",
        "requestUserhost",
        "nicks",
        "requestTopic",
        "resolveUserhost",
        "addRawLog",
        "show",
        "closeRawLog",
        "addToChannelList",
        "topic",
        "closeChannelListPanel",
        "sendMultiServerCommand",
        "executeMultiServerCommand",
        "showSSLDialog",
        "sendToAllChannels",
        "text",
        "sendToAllChannelsAndQueries",
        "enableIdentifyMsg",
        "enabled",
        "identifyMsgEnabled",
        "addBan",
        "ban",
        "removeBan",
        "pongReceived",
        "initKeyExchange",
        "receiver",
        "parseInitKeyX",
        "sender",
        "pubKey",
        "parseFinishKeyX",
        "startNickInfoChangedTimer",
        "startChannelNickChangedTimer",
        "involuntaryQuit",
        "reconnectInvoluntary",
        "requestAvailableCapabilies",
        "capInitiateNegotiation",
        "availableCaps",
        "capReply",
        "capEndNegotiation",
        "capCheckIgnored",
        "capAcknowledged",
        "CapModifiers",
        "modifiers",
        "capDenied",
        "sendAuthenticate",
        "message",
        "capDel",
        "unavailableCaps",
        "hostFound",
        "preShellCommandExited",
        "exitCode",
        "QProcess::ExitStatus",
        "exitStatus",
        "preShellCommandError",
        "QProcess::ProcessError",
        "eror",
        "socketConnected",
        "startAwayTimer",
        "incoming",
        "processIncomingData",
        "toServer",
        "closed",
        "broken",
        "QAbstractSocket::SocketError",
        "error",
        "sslError",
        "QList<QSslError>",
        "connectionEstablished",
        "ownHost",
        "notifyResponse",
        "nicksOnline",
        "slotNewDccTransferItemQueued",
        "Konversation::DCC::Transfer*",
        "transfer",
        "startReverseDccSendTransfer",
        "sourceNick",
        "dccArguments",
        "startReverseDccChat",
        "dccArgument",
        "addDccGet",
        "requestDccSend",
        "resumeDccGetTransfer",
        "resumeDccSendTransfer",
        "rejectDccSendTransfer",
        "dccGetDone",
        "item",
        "dccSendDone",
        "dccStatusChanged",
        "newStatus",
        "oldStatus",
        "arguments",
        "rejectDccChat",
        "scriptNotFound",
        "scriptExecutionError",
        "userhost",
        "hostmask",
        "ircOp",
        "setTopicAuthor",
        "author",
        "t",
        "endOfWho",
        "target",
        "endOfNames",
        "invitation",
        "gotOwnResolvedHostByWelcome",
        "QHostInfo",
        "res",
        "gotOwnResolvedHostByUserhost",
        "sendPing",
        "updateLongPongLag",
        "updateEncoding",
        "sendNickInfoChangedSignals",
        "sendChannelNickChangedSignals",
        "requestOpenChannelListPanel",
        "filter",
        "doPreShellCommand"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'destroyed'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'nicknameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'serverLag'
        QtMocHelpers::SignalData<void(Server *, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'tooLongLag'
        QtMocHelpers::SignalData<void(Server *, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'resetLag'
        QtMocHelpers::SignalData<void(Server *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'nicksNowOnline'
        QtMocHelpers::SignalData<void(Server *, const QStringList &, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QStringList, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Signal 'awayState'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'multiServerCommand'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'serverOnline'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Signal 'sentStat'
        QtMocHelpers::SignalData<void(int, int, IRCQueue *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Signal 'nickInfoChanged'
        QtMocHelpers::SignalData<void(Server *, const NickInfoPtr)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 27, 28 },
        }}),
        // Signal 'nickInfoChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'channelNickChanged'
        QtMocHelpers::SignalData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Signal 'channelMembersChanged'
        QtMocHelpers::SignalData<void(Server *, const QString &, bool, bool, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 32 }, { QMetaType::Bool, 33 }, { QMetaType::Bool, 34 },
            { QMetaType::QString, 35 },
        }}),
        // Signal 'channelJoinedOrUnjoined'
        QtMocHelpers::SignalData<void(Server *, const QString &, bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 32 }, { QMetaType::Bool, 33 },
        }}),
        // Signal 'watchedNickChanged'
        QtMocHelpers::SignalData<void(Server *, const QString &, bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 35 }, { QMetaType::Bool, 38 },
        }}),
        // Signal 'awayInsertRememberLine'
        QtMocHelpers::SignalData<void(Server *)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sslInitFailure'
        QtMocHelpers::SignalData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sslConnected'
        QtMocHelpers::SignalData<void(Server *)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'connectionStateChanged'
        QtMocHelpers::SignalData<void(Server *, Konversation::ConnectionState)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 43, 20 },
        }}),
        // Signal 'showView'
        QtMocHelpers::SignalData<void(ChatWindow *)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Signal 'addDccPanel'
        QtMocHelpers::SignalData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addDccChat'
        QtMocHelpers::SignalData<void(Konversation::DCC::Chat *)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Slot 'connectToIRCServer'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'connectToIRCServerIn'
        QtMocHelpers::SlotData<void(uint)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 53 },
        }}),
        // Slot 'queue'
        QtMocHelpers::SlotData<bool(const QString &, enum QueuePriority)>(54, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 55 }, { 0x80000000 | 56, 57 },
        }}),
        // Slot 'queue'
        QtMocHelpers::SlotData<bool(const QString &)>(54, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 55 },
        }}),
        // Slot 'queueList'
        QtMocHelpers::SlotData<bool(const QStringList &, enum QueuePriority)>(58, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 59 }, { 0x80000000 | 56, 57 },
        }}),
        // Slot 'queueList'
        QtMocHelpers::SlotData<bool(const QStringList &)>(58, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QStringList, 59 },
        }}),
        // Slot 'setNickname'
        QtMocHelpers::SlotData<void(const QString &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'addQuery'
        QtMocHelpers::SlotData<Query *(const NickInfoPtr &, bool)>(62, 2, QMC::AccessPublic, 0x80000000 | 63, {{
            { 0x80000000 | 27, 28 }, { QMetaType::Bool, 64 },
        }}),
        // Slot 'closeQuery'
        QtMocHelpers::SlotData<void(const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
        // Slot 'closeChannel'
        QtMocHelpers::SlotData<void(const QString &)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
        // Slot 'reconnectServer'
        QtMocHelpers::SlotData<void(const QString &)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 69 },
        }}),
        // Slot 'reconnectServer'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'disconnectServer'
        QtMocHelpers::SlotData<void(const QString &)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 69 },
        }}),
        // Slot 'disconnectServer'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'quitServer'
        QtMocHelpers::SlotData<void(const QString &)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 69 },
        }}),
        // Slot 'quitServer'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'openDccChat'
        QtMocHelpers::SlotData<void(const QString &)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'openDccWBoard'
        QtMocHelpers::SlotData<void(const QString &)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'requestDccChat'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, quint16)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::QString, 76 }, { QMetaType::QString, 77 }, { QMetaType::UShort, 78 },
        }}),
        // Slot 'acceptDccGet'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 81 },
        }}),
        // Slot 'requestBan'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &, const QString &)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 83 }, { QMetaType::QString, 30 }, { QMetaType::QString, 84 },
        }}),
        // Slot 'requestUnban'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 86 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'addDccSend'
        QtMocHelpers::SlotData<void(const QString &, const QUrl &, bool, const QString &, quint64)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 88 }, { 0x80000000 | 89, 90 }, { QMetaType::Bool, 91 }, { QMetaType::QString, 92 },
            { QMetaType::ULongLong, 93 },
        }}),
        // Slot 'addDccSend'
        QtMocHelpers::SlotData<void(const QString &, const QUrl &, bool, const QString &)>(87, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 88 }, { 0x80000000 | 89, 90 }, { QMetaType::Bool, 91 }, { QMetaType::QString, 92 },
        }}),
        // Slot 'addDccSend'
        QtMocHelpers::SlotData<void(const QString &, const QUrl &, bool)>(87, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 88 }, { 0x80000000 | 89, 90 }, { QMetaType::Bool, 91 },
        }}),
        // Slot 'addDccSend'
        QtMocHelpers::SlotData<void(const QString &, const QUrl &)>(87, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 88 }, { 0x80000000 | 89, 90 },
        }}),
        // Slot 'removeQuery'
        QtMocHelpers::SlotData<void(Query *)>(94, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 95 },
        }}),
        // Slot 'notifyListStarted'
        QtMocHelpers::SlotData<void(int)>(96, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 97 },
        }}),
        // Slot 'startNotifyTimer'
        QtMocHelpers::SlotData<void(int)>(98, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'startNotifyTimer'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'notifyTimeout'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendJoinCommand'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(100, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 101 },
        }}),
        // Slot 'sendJoinCommand'
        QtMocHelpers::SlotData<void(const QString &)>(100, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'requestAway'
        QtMocHelpers::SlotData<void(const QString &)>(102, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 103 },
        }}),
        // Slot 'requestAway'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'requestUnaway'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestChannelList'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestWhois'
        QtMocHelpers::SlotData<void(const QString &)>(106, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'requestWho'
        QtMocHelpers::SlotData<void(const QString &)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'requestUserhost'
        QtMocHelpers::SlotData<void(const QString &)>(108, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 109 },
        }}),
        // Slot 'requestTopic'
        QtMocHelpers::SlotData<void(const QString &)>(110, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'resolveUserhost'
        QtMocHelpers::SlotData<void(const QString &)>(111, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'addRawLog'
        QtMocHelpers::SlotData<void(bool)>(112, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 113 },
        }}),
        // Slot 'closeRawLog'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addToChannelList'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(115, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::Int, 83 }, { QMetaType::QString, 116 },
        }}),
        // Slot 'closeChannelListPanel'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendMultiServerCommand'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(118, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'executeMultiServerCommand'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(119, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'showSSLDialog'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendToAllChannels'
        QtMocHelpers::SlotData<void(const QString &)>(121, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 122 },
        }}),
        // Slot 'sendToAllChannelsAndQueries'
        QtMocHelpers::SlotData<void(const QString &)>(123, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 122 },
        }}),
        // Slot 'enableIdentifyMsg'
        QtMocHelpers::SlotData<void(bool)>(124, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 125 },
        }}),
        // Slot 'identifyMsgEnabled'
        QtMocHelpers::SlotData<bool()>(126, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'addBan'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(127, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 128 },
        }}),
        // Slot 'removeBan'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(129, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 128 },
        }}),
        // Slot 'pongReceived'
        QtMocHelpers::SlotData<void()>(130, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'initKeyExchange'
        QtMocHelpers::SlotData<void(const QString &)>(131, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 132 },
        }}),
        // Slot 'parseInitKeyX'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(133, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 134 }, { QMetaType::QString, 135 },
        }}),
        // Slot 'parseFinishKeyX'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(136, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 134 }, { QMetaType::QString, 135 },
        }}),
        // Slot 'startNickInfoChangedTimer'
        QtMocHelpers::SlotData<void()>(137, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startChannelNickChangedTimer'
        QtMocHelpers::SlotData<void(const QString &)>(138, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'involuntaryQuit'
        QtMocHelpers::SlotData<void()>(139, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reconnectInvoluntary'
        QtMocHelpers::SlotData<void()>(140, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestAvailableCapabilies'
        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'capInitiateNegotiation'
        QtMocHelpers::SlotData<void(const QString &)>(142, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 143 },
        }}),
        // Slot 'capReply'
        QtMocHelpers::SlotData<void()>(144, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'capEndNegotiation'
        QtMocHelpers::SlotData<void()>(145, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'capCheckIgnored'
        QtMocHelpers::SlotData<void()>(146, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'capAcknowledged'
        QtMocHelpers::SlotData<void(const QString &, CapModifiers)>(147, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 66 }, { 0x80000000 | 148, 149 },
        }}),
        // Slot 'capDenied'
        QtMocHelpers::SlotData<void(const QString &)>(150, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
        // Slot 'sendAuthenticate'
        QtMocHelpers::SlotData<void(const QString &)>(151, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 152 },
        }}),
        // Slot 'capDel'
        QtMocHelpers::SlotData<void(const QString &)>(153, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 154 },
        }}),
        // Slot 'hostFound'
        QtMocHelpers::SlotData<void()>(155, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'preShellCommandExited'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(156, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 157 }, { 0x80000000 | 158, 159 },
        }}),
        // Slot 'preShellCommandError'
        QtMocHelpers::SlotData<void(QProcess::ProcessError)>(160, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 161, 162 },
        }}),
        // Slot 'socketConnected'
        QtMocHelpers::SlotData<void()>(163, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startAwayTimer'
        QtMocHelpers::SlotData<void()>(164, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'incoming'
        QtMocHelpers::SlotData<void()>(165, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processIncomingData'
        QtMocHelpers::SlotData<void()>(166, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toServer'
        QtMocHelpers::SlotData<void(const QString &, IRCQueue *)>(167, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 24, 2 },
        }}),
        // Slot 'closed'
        QtMocHelpers::SlotData<void()>(168, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'broken'
        QtMocHelpers::SlotData<void(QAbstractSocket::SocketError)>(169, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 170, 171 },
        }}),
        // Slot 'sslError'
        QtMocHelpers::SlotData<void(const QList<QSslError> &)>(172, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 173, 2 },
        }}),
        // Slot 'connectionEstablished'
        QtMocHelpers::SlotData<void(const QString &)>(174, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 175 },
        }}),
        // Slot 'notifyResponse'
        QtMocHelpers::SlotData<void(const QString &)>(176, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 177 },
        }}),
        // Slot 'slotNewDccTransferItemQueued'
        QtMocHelpers::SlotData<void(Konversation::DCC::Transfer *)>(178, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 179, 180 },
        }}),
        // Slot 'startReverseDccSendTransfer'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(181, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 182 }, { QMetaType::QStringList, 183 },
        }}),
        // Slot 'startReverseDccChat'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(184, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 182 }, { QMetaType::QStringList, 185 },
        }}),
        // Slot 'addDccGet'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(186, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 182 }, { QMetaType::QStringList, 183 },
        }}),
        // Slot 'requestDccSend'
        QtMocHelpers::SlotData<void()>(187, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'requestDccSend'
        QtMocHelpers::SlotData<void(const QString &)>(187, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 88 },
        }}),
        // Slot 'resumeDccGetTransfer'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(188, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 182 }, { QMetaType::QStringList, 183 },
        }}),
        // Slot 'resumeDccSendTransfer'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(189, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 182 }, { QMetaType::QStringList, 183 },
        }}),
        // Slot 'rejectDccSendTransfer'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(190, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 182 }, { QMetaType::QStringList, 183 },
        }}),
        // Slot 'dccGetDone'
        QtMocHelpers::SlotData<void(Konversation::DCC::Transfer *)>(191, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 179, 192 },
        }}),
        // Slot 'dccSendDone'
        QtMocHelpers::SlotData<void(Konversation::DCC::Transfer *)>(193, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 179, 192 },
        }}),
        // Slot 'dccStatusChanged'
        QtMocHelpers::SlotData<void(Konversation::DCC::Transfer *, int, int)>(194, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 179, 192 }, { QMetaType::Int, 195 }, { QMetaType::Int, 196 },
        }}),
        // Slot 'addDccChat'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 182 }, { QMetaType::QStringList, 197 },
        }}),
        // Slot 'rejectDccChat'
        QtMocHelpers::SlotData<void(const QString &)>(198, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 182 },
        }}),
        // Slot 'scriptNotFound'
        QtMocHelpers::SlotData<void(const QString &)>(199, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
        // Slot 'scriptExecutionError'
        QtMocHelpers::SlotData<void(const QString &)>(200, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
        // Slot 'userhost'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool, bool)>(201, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 202 }, { QMetaType::Bool, 15 }, { QMetaType::Bool, 203 },
        }}),
        // Slot 'setTopicAuthor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QDateTime &)>(204, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 205 }, { QMetaType::QDateTime, 206 },
        }}),
        // Slot 'endOfWho'
        QtMocHelpers::SlotData<void(const QString &)>(207, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 208 },
        }}),
        // Slot 'endOfNames'
        QtMocHelpers::SlotData<void(const QString &)>(209, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 208 },
        }}),
        // Slot 'invitation'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(210, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'gotOwnResolvedHostByWelcome'
        QtMocHelpers::SlotData<void(const QHostInfo &)>(211, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 212, 213 },
        }}),
        // Slot 'gotOwnResolvedHostByUserhost'
        QtMocHelpers::SlotData<void(const QHostInfo &)>(214, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 212, 213 },
        }}),
        // Slot 'sendPing'
        QtMocHelpers::SlotData<void()>(215, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLongPongLag'
        QtMocHelpers::SlotData<void()>(216, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateEncoding'
        QtMocHelpers::SlotData<void()>(217, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sendNickInfoChangedSignals'
        QtMocHelpers::SlotData<void()>(218, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sendChannelNickChangedSignals'
        QtMocHelpers::SlotData<void()>(219, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'requestOpenChannelListPanel'
        QtMocHelpers::SlotData<void(const QString &)>(220, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 221 },
        }}),
        // Slot 'doPreShellCommand'
        QtMocHelpers::SlotData<void()>(222, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Server, qt_meta_tag_ZN6ServerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Server::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ServerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ServerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6ServerE_t>.metaTypes,
    nullptr
} };

void Server::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Server *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->destroyed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->nicknameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->serverLag((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->tooLongLag((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->resetLag((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 5: _t->nicksNowOnline((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 6: _t->awayState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->multiServerCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->serverOnline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->sentStat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<IRCQueue*>>(_a[3]))); break;
        case 10: _t->nickInfoChanged((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NickInfoPtr>>(_a[2]))); break;
        case 11: _t->nickInfoChanged(); break;
        case 12: _t->channelNickChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->channelMembersChanged((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 14: _t->channelJoinedOrUnjoined((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 15: _t->watchedNickChanged((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 16: _t->awayInsertRememberLine((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 17: _t->sslInitFailure(); break;
        case 18: _t->sslConnected((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 19: _t->connectionStateChanged((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionState>>(_a[2]))); break;
        case 20: _t->showView((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1]))); break;
        case 21: _t->addDccPanel(); break;
        case 22: _t->addDccChat((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Chat*>>(_a[1]))); break;
        case 23: _t->connectToIRCServer(); break;
        case 24: _t->connectToIRCServerIn((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 25: { bool _r = _t->queue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum QueuePriority>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->queue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->queueList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum QueuePriority>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->queueList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->setNickname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: { Query* _r = _t->addQuery((*reinterpret_cast<std::add_pointer_t<NickInfoPtr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Query**>(_a[0]) = std::move(_r); }  break;
        case 31: _t->closeQuery((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->closeChannel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->reconnectServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->reconnectServer(); break;
        case 35: _t->disconnectServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 36: _t->disconnectServer(); break;
        case 37: _t->quitServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->quitServer(); break;
        case 39: _t->openDccChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->openDccWBoard((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: _t->requestDccChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<quint16>>(_a[4]))); break;
        case 42: _t->acceptDccGet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 43: _t->requestBan((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 44: _t->requestUnban((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 45: _t->addDccSend((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[5]))); break;
        case 46: _t->addDccSend((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 47: _t->addDccSend((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 48: _t->addDccSend((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 49: _t->removeQuery((*reinterpret_cast<std::add_pointer_t<Query*>>(_a[1]))); break;
        case 50: _t->notifyListStarted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->startNotifyTimer((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->startNotifyTimer(); break;
        case 53: _t->notifyTimeout(); break;
        case 54: _t->sendJoinCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 55: _t->sendJoinCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 56: _t->requestAway((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 57: _t->requestAway(); break;
        case 58: _t->requestUnaway(); break;
        case 59: _t->requestChannelList(); break;
        case 60: _t->requestWhois((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 61: _t->requestWho((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 62: _t->requestUserhost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 63: _t->requestTopic((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 64: _t->resolveUserhost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 65: _t->addRawLog((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 66: _t->closeRawLog(); break;
        case 67: _t->addToChannelList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 68: _t->closeChannelListPanel(); break;
        case 69: _t->sendMultiServerCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 70: _t->executeMultiServerCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 71: _t->showSSLDialog(); break;
        case 72: _t->sendToAllChannels((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 73: _t->sendToAllChannelsAndQueries((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 74: _t->enableIdentifyMsg((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 75: { bool _r = _t->identifyMsgEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 76: _t->addBan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 77: _t->removeBan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 78: _t->pongReceived(); break;
        case 79: _t->initKeyExchange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 80: _t->parseInitKeyX((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 81: _t->parseFinishKeyX((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 82: _t->startNickInfoChangedTimer(); break;
        case 83: _t->startChannelNickChangedTimer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 84: _t->involuntaryQuit(); break;
        case 85: _t->reconnectInvoluntary(); break;
        case 86: _t->requestAvailableCapabilies(); break;
        case 87: _t->capInitiateNegotiation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 88: _t->capReply(); break;
        case 89: _t->capEndNegotiation(); break;
        case 90: _t->capCheckIgnored(); break;
        case 91: _t->capAcknowledged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<CapModifiers>>(_a[2]))); break;
        case 92: _t->capDenied((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 93: _t->sendAuthenticate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 94: _t->capDel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 95: _t->hostFound(); break;
        case 96: _t->preShellCommandExited((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        case 97: _t->preShellCommandError((*reinterpret_cast<std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        case 98: _t->socketConnected(); break;
        case 99: _t->startAwayTimer(); break;
        case 100: _t->incoming(); break;
        case 101: _t->processIncomingData(); break;
        case 102: _t->toServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<IRCQueue*>>(_a[2]))); break;
        case 103: _t->closed(); break;
        case 104: _t->broken((*reinterpret_cast<std::add_pointer_t<QAbstractSocket::SocketError>>(_a[1]))); break;
        case 105: _t->sslError((*reinterpret_cast<std::add_pointer_t<QList<QSslError>>>(_a[1]))); break;
        case 106: _t->connectionEstablished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 107: _t->notifyResponse((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 108: _t->slotNewDccTransferItemQueued((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1]))); break;
        case 109: _t->startReverseDccSendTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 110: _t->startReverseDccChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 111: _t->addDccGet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 112: _t->requestDccSend(); break;
        case 113: _t->requestDccSend((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 114: _t->resumeDccGetTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 115: _t->resumeDccSendTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 116: _t->rejectDccSendTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 117: _t->dccGetDone((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1]))); break;
        case 118: _t->dccSendDone((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1]))); break;
        case 119: _t->dccStatusChanged((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 120: _t->addDccChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 121: _t->rejectDccChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 122: _t->scriptNotFound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 123: _t->scriptExecutionError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 124: _t->userhost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 125: _t->setTopicAuthor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[3]))); break;
        case 126: _t->endOfWho((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 127: _t->endOfNames((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 128: _t->invitation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 129: _t->gotOwnResolvedHostByWelcome((*reinterpret_cast<std::add_pointer_t<QHostInfo>>(_a[1]))); break;
        case 130: _t->gotOwnResolvedHostByUserhost((*reinterpret_cast<std::add_pointer_t<QHostInfo>>(_a[1]))); break;
        case 131: _t->sendPing(); break;
        case 132: _t->updateLongPongLag(); break;
        case 133: _t->updateEncoding(); break;
        case 134: _t->sendNickInfoChangedSignals(); break;
        case 135: _t->sendChannelNickChangedSignals(); break;
        case 136: _t->requestOpenChannelListPanel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 137: _t->doPreShellCommand(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        case 104:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSocket::SocketError >(); break;
            }
            break;
        case 105:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QSslError> >(); break;
            }
            break;
        case 129:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QHostInfo >(); break;
            }
            break;
        case 130:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QHostInfo >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Server::*)(int )>(_a, &Server::destroyed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(const QString & )>(_a, &Server::nicknameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * , int )>(_a, &Server::serverLag, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * , int )>(_a, &Server::tooLongLag, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * )>(_a, &Server::resetLag, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * , const QStringList & , bool )>(_a, &Server::nicksNowOnline, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(bool )>(_a, &Server::awayState, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(const QString & , const QString & )>(_a, &Server::multiServerCommand, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(bool )>(_a, &Server::serverOnline, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(int , int , IRCQueue * )>(_a, &Server::sentStat, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * , const NickInfoPtr )>(_a, &Server::nickInfoChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)()>(_a, &Server::nickInfoChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(const QString & )>(_a, &Server::channelNickChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * , const QString & , bool , bool , const QString & )>(_a, &Server::channelMembersChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * , const QString & , bool )>(_a, &Server::channelJoinedOrUnjoined, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * , const QString & , bool )>(_a, &Server::watchedNickChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * )>(_a, &Server::awayInsertRememberLine, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)()>(_a, &Server::sslInitFailure, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * )>(_a, &Server::sslConnected, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Server * , Konversation::ConnectionState )>(_a, &Server::connectionStateChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(ChatWindow * )>(_a, &Server::showView, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)()>(_a, &Server::addDccPanel, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(Konversation::DCC::Chat * )>(_a, &Server::addDccChat, 22))
            return;
    }
}

const QMetaObject *Server::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Server::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ServerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Server::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 138)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 138;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 138)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 138;
    }
    return _id;
}

// SIGNAL 0
void Server::destroyed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Server::nicknameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Server::serverLag(Server * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Server::tooLongLag(Server * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Server::resetLag(Server * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Server::nicksNowOnline(Server * _t1, const QStringList & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Server::awayState(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Server::multiServerCommand(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Server::serverOnline(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Server::sentStat(int _t1, int _t2, IRCQueue * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3);
}

// SIGNAL 10
void Server::nickInfoChanged(Server * _t1, const NickInfoPtr _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void Server::nickInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Server::channelNickChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Server::channelMembersChanged(Server * _t1, const QString & _t2, bool _t3, bool _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 14
void Server::channelJoinedOrUnjoined(Server * _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void Server::watchedNickChanged(Server * _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void Server::awayInsertRememberLine(Server * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Server::sslInitFailure()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Server::sslConnected(Server * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Server::connectionStateChanged(Server * _t1, Konversation::ConnectionState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void Server::showView(ChatWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void Server::addDccPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Server::addDccChat(Konversation::DCC::Chat * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}
QT_WARNING_POP
