/****************************************************************************
** Meta object code from reading C++ file 'connectionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/connectionmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'connectionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17ConnectionManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ConnectionManager::qt_create_metaobjectdata<qt_meta_tag_ZN17ConnectionManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ConnectionManager",
        "connectionListChanged",
        "",
        "connectionChangedState",
        "Server*",
        "server",
        "Konversation::ConnectionState",
        "state",
        "connectionChangedAwayState",
        "away",
        "requestReconnect",
        "identityOnline",
        "identityId",
        "identityOffline",
        "closeServerList",
        "connectTo",
        "Konversation::ConnectionFlag",
        "flag",
        "target",
        "port",
        "password",
        "nick",
        "channel",
        "useSSL",
        "serverGroupId",
        "QList<QUrl>",
        "list",
        "ConnectionSettings",
        "settings",
        "quitServers",
        "reconnectServers",
        "involuntaryQuitServers",
        "reconnectInvoluntary",
        "delistConnection",
        "connectionId",
        "handleConnectionStateChange",
        "handleReconnect",
        "onOnlineStateChanged",
        "QNetworkInformation::Reachability",
        "reachability"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionListChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectionChangedState'
        QtMocHelpers::SignalData<void(Server *, Konversation::ConnectionState)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'connectionChangedAwayState'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'requestReconnect'
        QtMocHelpers::SignalData<void(Server *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'identityOnline'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'identityOffline'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'closeServerList'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'connectTo'
        QtMocHelpers::SlotData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &, const QString &, const QString &, bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 }, { QMetaType::Bool, 23 },
        }}),
        // Slot 'connectTo'
        QtMocHelpers::SlotData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &, const QString &, const QString &)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'connectTo'
        QtMocHelpers::SlotData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &, const QString &)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
            { QMetaType::QString, 21 },
        }}),
        // Slot 'connectTo'
        QtMocHelpers::SlotData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
        }}),
        // Slot 'connectTo'
        QtMocHelpers::SlotData<void(Konversation::ConnectionFlag, const QString &, const QString &)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'connectTo'
        QtMocHelpers::SlotData<void(Konversation::ConnectionFlag, const QString &)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'connectTo'
        QtMocHelpers::SlotData<void(Konversation::ConnectionFlag, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'connectTo'
        QtMocHelpers::SlotData<void(Konversation::ConnectionFlag, const QList<QUrl> &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'connectTo'
        QtMocHelpers::SlotData<void(Konversation::ConnectionFlag, ConnectionSettings)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { 0x80000000 | 27, 28 },
        }}),
        // Slot 'quitServers'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reconnectServers'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'involuntaryQuitServers'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reconnectInvoluntary'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'delistConnection'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'handleConnectionStateChange'
        QtMocHelpers::SlotData<void(Server *, Konversation::ConnectionState)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'handleReconnect'
        QtMocHelpers::SlotData<void(Server *)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'onOnlineStateChanged'
        QtMocHelpers::SlotData<void(QNetworkInformation::Reachability)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ConnectionManager, qt_meta_tag_ZN17ConnectionManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ConnectionManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ConnectionManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ConnectionManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ConnectionManagerE_t>.metaTypes,
    nullptr
} };

void ConnectionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConnectionManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionListChanged(); break;
        case 1: _t->connectionChangedState((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionState>>(_a[2]))); break;
        case 2: _t->connectionChangedAwayState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->requestReconnect((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 4: _t->identityOnline((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->identityOffline((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->closeServerList(); break;
        case 7: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7]))); break;
        case 8: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 9: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 10: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 11: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 12: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2]))); break;
        case 15: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ConnectionSettings>>(_a[2]))); break;
        case 16: _t->quitServers(); break;
        case 17: _t->reconnectServers(); break;
        case 18: _t->involuntaryQuitServers(); break;
        case 19: _t->reconnectInvoluntary(); break;
        case 20: _t->delistConnection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->handleConnectionStateChange((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionState>>(_a[2]))); break;
        case 22: _t->handleReconnect((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 23: _t->onOnlineStateChanged((*reinterpret_cast<std::add_pointer_t<QNetworkInformation::Reachability>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ConnectionManager::*)()>(_a, &ConnectionManager::connectionListChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectionManager::*)(Server * , Konversation::ConnectionState )>(_a, &ConnectionManager::connectionChangedState, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectionManager::*)(bool )>(_a, &ConnectionManager::connectionChangedAwayState, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectionManager::*)(Server * )>(_a, &ConnectionManager::requestReconnect, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectionManager::*)(int )>(_a, &ConnectionManager::identityOnline, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectionManager::*)(int )>(_a, &ConnectionManager::identityOffline, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConnectionManager::*)()>(_a, &ConnectionManager::closeServerList, 6))
            return;
    }
}

const QMetaObject *ConnectionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConnectionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ConnectionManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ConnectionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void ConnectionManager::connectionListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ConnectionManager::connectionChangedState(Server * _t1, Konversation::ConnectionState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void ConnectionManager::connectionChangedAwayState(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ConnectionManager::requestReconnect(Server * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ConnectionManager::identityOnline(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ConnectionManager::identityOffline(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ConnectionManager::closeServerList()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
