// This file is generated by kconfig_compiler_kf6 from konversation.kcfg.
// All changes you do to this file will be lost.

#include "preferences_base.h"

const char* const PreferencesBase::EnumColorNameToString[] = { "ActionMessage", "BacklogMessage", "ChannelMessage", "CommandMessage", "QueryMessage", "ServerMessage", "Time", "Action", "TextViewBackground", "AlternateBackground", "Hyperlink" };

PreferencesBase::PreferencesBase( )
  : KConfigSkeleton( QStringLiteral( "konversationrc" ) )
{
  setCurrentGroup( QStringLiteral( "Appearance" ) );

  mShowMenuBarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowMenuBar" ), mShowMenuBar, true );
  mShowMenuBarItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowMenuBar") );
  addItem( mShowMenuBarItem, QStringLiteral( "ShowMenuBar" ) );
  mTextFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "TextFont" ), mTextFont, QFontDatabase::systemFont(QFontDatabase::GeneralFont) );
  mTextFontItem->setLabel( QCoreApplication::translate("PreferencesBase", "TextFont") );
  addItem( mTextFontItem, QStringLiteral( "TextFont" ) );
  mListFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "ListFont" ), mListFont, QFontDatabase::systemFont(QFontDatabase::GeneralFont) );
  mListFontItem->setLabel( QCoreApplication::translate("PreferencesBase", "ListFont") );
  addItem( mListFontItem, QStringLiteral( "ListFont" ) );
  mTabFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "TabFont" ), mTabFont, QFontDatabase::systemFont(QFontDatabase::GeneralFont) );
  mTabFontItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabFont") );
  addItem( mTabFontItem, QStringLiteral( "TabFont" ) );
  mCustomTextFontItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CustomTextFont" ), mCustomTextFont, false );
  mCustomTextFontItem->setLabel( QCoreApplication::translate("PreferencesBase", "CustomTextFont") );
  addItem( mCustomTextFontItem, QStringLiteral( "CustomTextFont" ) );
  mCustomListFontItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CustomListFont" ), mCustomListFont, false );
  mCustomListFontItem->setLabel( QCoreApplication::translate("PreferencesBase", "CustomListFont") );
  addItem( mCustomListFontItem, QStringLiteral( "CustomListFont" ) );
  mCustomTabFontItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CustomTabFont" ), mCustomTabFont, false );
  mCustomTabFontItem->setLabel( QCoreApplication::translate("PreferencesBase", "CustomTabFont") );
  addItem( mCustomTabFontItem, QStringLiteral( "CustomTabFont" ) );
  mTimestampingItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Timestamping" ), mTimestamping, true );
  mTimestampingItem->setLabel( QCoreApplication::translate("PreferencesBase", "Timestamping") );
  addItem( mTimestampingItem, QStringLiteral( "Timestamping" ) );
  mShowDateItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowDate" ), mShowDate, false );
  mShowDateItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowDate") );
  addItem( mShowDateItem, QStringLiteral( "ShowDate" ) );
  mShowDateLineItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowDateLine" ), mShowDateLine, false );
  mShowDateLineItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowDateLine") );
  addItem( mShowDateLineItem, QStringLiteral( "ShowDateLine" ) );
  mTimestampFormatItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TimestampFormat" ), mTimestampFormat, QStringLiteral( "hh:mm" ) );
  mTimestampFormatItem->setLabel( QCoreApplication::translate("PreferencesBase", "TimestampFormat") );
  addItem( mTimestampFormatItem, QStringLiteral( "TimestampFormat" ) );
  mShowBacklogItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowBacklog" ), mShowBacklog, true );
  mShowBacklogItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowBacklog") );
  addItem( mShowBacklogItem, QStringLiteral( "ShowBacklog" ) );
  mBacklogLinesItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "BacklogLines" ), mBacklogLines, 10 );
  mBacklogLinesItem->setLabel( QCoreApplication::translate("PreferencesBase", "BacklogLines") );
  addItem( mBacklogLinesItem, QStringLiteral( "BacklogLines" ) );
  mShowNickListItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowNickList" ), mShowNickList, true );
  mShowNickListItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowNickList") );
  addItem( mShowNickListItem, QStringLiteral( "ShowNickList" ) );
  mShowQuickButtonsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowQuickButtons" ), mShowQuickButtons, false );
  mShowQuickButtonsItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowQuickButtons") );
  addItem( mShowQuickButtonsItem, QStringLiteral( "ShowQuickButtons" ) );
  mShowQuickButtonsInContextMenuItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowQuickButtonsInContextMenu" ), mShowQuickButtonsInContextMenu, true );
  mShowQuickButtonsInContextMenuItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowQuickButtonsInContextMenu") );
  addItem( mShowQuickButtonsInContextMenuItem, QStringLiteral( "ShowQuickButtonsInContextMenu" ) );
  mShowModeButtonsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowModeButtons" ), mShowModeButtons, false );
  mShowModeButtonsItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowModeButtons") );
  addItem( mShowModeButtonsItem, QStringLiteral( "ShowModeButtons" ) );
  mCloseButtonsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CloseButtons" ), mCloseButtons, false );
  mCloseButtonsItem->setLabel( QCoreApplication::translate("PreferencesBase", "CloseButtons") );
  addItem( mCloseButtonsItem, QStringLiteral( "CloseButtons" ) );
  mAutoUserhostItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoUserhost" ), mAutoUserhost, false );
  mAutoUserhostItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutoUserhost") );
  addItem( mAutoUserhostItem, QStringLiteral( "AutoUserhost" ) );
  mUseSpacingItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseSpacing" ), mUseSpacing, false );
  mUseSpacingItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseSpacing") );
  addItem( mUseSpacingItem, QStringLiteral( "UseSpacing" ) );
  mSpacingItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Spacing" ), mSpacing, QApplication::style()->layoutSpacing(QSizePolicy::DefaultType, QSizePolicy::DefaultType, Qt::Horizontal) );
  mSpacingItem->setLabel( QCoreApplication::translate("PreferencesBase", "Spacing") );
  addItem( mSpacingItem, QStringLiteral( "Spacing" ) );
  mMarginItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Margin" ), mMargin, QApplication::style()->pixelMetric(QStyle::PM_LayoutLeftMargin) );
  mMarginItem->setLabel( QCoreApplication::translate("PreferencesBase", "Margin") );
  addItem( mMarginItem, QStringLiteral( "Margin" ) );
  mBackgroundImageItem = new KConfigSkeleton::ItemUrl( currentGroup(), QStringLiteral( "BackgroundImage" ), mBackgroundImage );
  mBackgroundImageItem->setLabel( QCoreApplication::translate("PreferencesBase", "BackgroundImage") );
  addItem( mBackgroundImageItem, QStringLiteral( "BackgroundImage" ) );
  mIrcColorCodeItem[0] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode0" ), mIrcColorCode[0], QColor( "#ffffff" ) );
  mIrcColorCodeItem[0]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[0], QStringLiteral( "IrcColorCode0" ) );
  mIrcColorCodeItem[1] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode1" ), mIrcColorCode[1], QColor( "#000000" ) );
  mIrcColorCodeItem[1]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[1], QStringLiteral( "IrcColorCode1" ) );
  mIrcColorCodeItem[2] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode2" ), mIrcColorCode[2], QColor( "#000080" ) );
  mIrcColorCodeItem[2]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[2], QStringLiteral( "IrcColorCode2" ) );
  mIrcColorCodeItem[3] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode3" ), mIrcColorCode[3], QColor( "#008000" ) );
  mIrcColorCodeItem[3]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[3], QStringLiteral( "IrcColorCode3" ) );
  mIrcColorCodeItem[4] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode4" ), mIrcColorCode[4], QColor( "#ff0000" ) );
  mIrcColorCodeItem[4]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[4], QStringLiteral( "IrcColorCode4" ) );
  mIrcColorCodeItem[5] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode5" ), mIrcColorCode[5], QColor( "#a52a2a" ) );
  mIrcColorCodeItem[5]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[5], QStringLiteral( "IrcColorCode5" ) );
  mIrcColorCodeItem[6] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode6" ), mIrcColorCode[6], QColor( "#800080" ) );
  mIrcColorCodeItem[6]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[6], QStringLiteral( "IrcColorCode6" ) );
  mIrcColorCodeItem[7] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode7" ), mIrcColorCode[7], QColor( "#ff8000" ) );
  mIrcColorCodeItem[7]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[7], QStringLiteral( "IrcColorCode7" ) );
  mIrcColorCodeItem[8] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode8" ), mIrcColorCode[8], QColor( "#808000" ) );
  mIrcColorCodeItem[8]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[8], QStringLiteral( "IrcColorCode8" ) );
  mIrcColorCodeItem[9] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode9" ), mIrcColorCode[9], QColor( "#00ff00" ) );
  mIrcColorCodeItem[9]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[9], QStringLiteral( "IrcColorCode9" ) );
  mIrcColorCodeItem[10] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode10" ), mIrcColorCode[10], QColor( "#008080" ) );
  mIrcColorCodeItem[10]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[10], QStringLiteral( "IrcColorCode10" ) );
  mIrcColorCodeItem[11] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode11" ), mIrcColorCode[11], QColor( "#00ffff" ) );
  mIrcColorCodeItem[11]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[11], QStringLiteral( "IrcColorCode11" ) );
  mIrcColorCodeItem[12] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode12" ), mIrcColorCode[12], QColor( "#0000ff" ) );
  mIrcColorCodeItem[12]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[12], QStringLiteral( "IrcColorCode12" ) );
  mIrcColorCodeItem[13] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode13" ), mIrcColorCode[13], QColor( "#ffc0cb" ) );
  mIrcColorCodeItem[13]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[13], QStringLiteral( "IrcColorCode13" ) );
  mIrcColorCodeItem[14] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode14" ), mIrcColorCode[14], QColor( "#a0a0a0" ) );
  mIrcColorCodeItem[14]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[14], QStringLiteral( "IrcColorCode14" ) );
  mIrcColorCodeItem[15] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "IrcColorCode15" ), mIrcColorCode[15], QColor( "#c0c0c0" ) );
  mIrcColorCodeItem[15]->setLabel( QCoreApplication::translate("PreferencesBase", "IrcColorCodeIrcColorCode$(colorNumber)") );
  addItem( mIrcColorCodeItem[15], QStringLiteral( "IrcColorCode15" ) );
  mAllowColorCodesItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AllowColorCodes" ), mAllowColorCodes, true );
  mAllowColorCodesItem->setLabel( QCoreApplication::translate("PreferencesBase", "AllowColorCodes") );
  addItem( mAllowColorCodesItem, QStringLiteral( "AllowColorCodes" ) );
  mNickColorItem[0] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor0" ), mNickColor[0], QColor( "#E90E7F" ) );
  mNickColorItem[0]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[0], QStringLiteral( "NickColor0" ) );
  mNickColorItem[1] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor1" ), mNickColor[1], QColor( "#8E55E9" ) );
  mNickColorItem[1]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[1], QStringLiteral( "NickColor1" ) );
  mNickColorItem[2] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor2" ), mNickColor[2], QColor( "#B30E0E" ) );
  mNickColorItem[2]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[2], QStringLiteral( "NickColor2" ) );
  mNickColorItem[3] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor3" ), mNickColor[3], QColor( "#18B33C" ) );
  mNickColorItem[3]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[3], QStringLiteral( "NickColor3" ) );
  mNickColorItem[4] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor4" ), mNickColor[4], QColor( "#58ADB3" ) );
  mNickColorItem[4]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[4], QStringLiteral( "NickColor4" ) );
  mNickColorItem[5] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor5" ), mNickColor[5], QColor( "#9E54B3" ) );
  mNickColorItem[5]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[5], QStringLiteral( "NickColor5" ) );
  mNickColorItem[6] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor6" ), mNickColor[6], QColor( "#B39875" ) );
  mNickColorItem[6]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[6], QStringLiteral( "NickColor6" ) );
  mNickColorItem[7] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor7" ), mNickColor[7], QColor( "#3176B3" ) );
  mNickColorItem[7]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[7], QStringLiteral( "NickColor7" ) );
  mNickColorItem[8] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor8" ), mNickColor[8], QColor( "#000001" ) );
  mNickColorItem[8]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[8], QStringLiteral( "NickColor8" ) );
  mNickColorItem[9] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "NickColor9" ), mNickColor[9], QColor(128, 128, 128) );
  mNickColorItem[9]->setLabel( QCoreApplication::translate("PreferencesBase", "NickColorNickColor$(nickNumber)") );
  addItem( mNickColorItem[9], QStringLiteral( "NickColor9" ) );
  mUseColoredNicksItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseColoredNicks" ), mUseColoredNicks, true );
  mUseColoredNicksItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseColoredNicks") );
  addItem( mUseColoredNicksItem, QStringLiteral( "UseColoredNicks" ) );
  mShowTabBarCloseButtonItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowTabBarCloseButton" ), mShowTabBarCloseButton, true );
  mShowTabBarCloseButtonItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowTabBarCloseButton") );
  addItem( mShowTabBarCloseButtonItem, QStringLiteral( "ShowTabBarCloseButton" ) );
  mShowTopicItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowTopic" ), mShowTopic, true );
  mShowTopicItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowTopic") );
  addItem( mShowTopicItem, QStringLiteral( "ShowTopic" ) );
  mShowNicknameBoxItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowNicknameBox" ), mShowNicknameBox, true );
  mShowNicknameBoxItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowNicknameBox") );
  addItem( mShowNicknameBoxItem, QStringLiteral( "ShowNicknameBox" ) );
  mUseBoldNicksItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseBoldNicks" ), mUseBoldNicks, false );
  mUseBoldNicksItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseBoldNicks") );
  addItem( mUseBoldNicksItem, QStringLiteral( "UseBoldNicks" ) );
  mUseLiteralModesItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseLiteralModes" ), mUseLiteralModes, false );
  mUseLiteralModesItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseLiteralModes") );
  addItem( mUseLiteralModesItem, QStringLiteral( "UseLiteralModes" ) );
  mFocusNewQueriesItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusNewQueries" ), mFocusNewQueries, true );
  mFocusNewQueriesItem->setLabel( QCoreApplication::translate("PreferencesBase", "FocusNewQueries") );
  addItem( mFocusNewQueriesItem, QStringLiteral( "FocusNewQueries" ) );
  mShowIRCViewScrollBarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowIRCViewScrollBar" ), mShowIRCViewScrollBar, true );
  mShowIRCViewScrollBarItem->setLabel( QCoreApplication::translate("PreferencesBase", "Hide the scrollbar") );
  addItem( mShowIRCViewScrollBarItem, QStringLiteral( "ShowIRCViewScrollBar" ) );

  setCurrentGroup( QStringLiteral( "General Options" ) );

  mSpellCheckingItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SpellChecking" ), mSpellChecking, false );
  mSpellCheckingItem->setLabel( QCoreApplication::translate("PreferencesBase", "SpellChecking") );
  mSpellCheckingItem->setWhatsThis( QCoreApplication::translate("PreferencesBase", "Enable if you want all the IRC input lines to check your spelling as you type") );
  addItem( mSpellCheckingItem, QStringLiteral( "SpellChecking" ) );
  mCustomVersionReplyEnabledItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CustomVersionReplyEnabled" ), mCustomVersionReplyEnabled, false );
  mCustomVersionReplyEnabledItem->setLabel( QCoreApplication::translate("PreferencesBase", "CustomVersionReplyEnabled") );
  addItem( mCustomVersionReplyEnabledItem, QStringLiteral( "CustomVersionReplyEnabled" ) );
  mCustomVersionReplyItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CustomVersionReply" ), mCustomVersionReply );
  mCustomVersionReplyItem->setLabel( QCoreApplication::translate("PreferencesBase", "CustomVersionReply") );
  addItem( mCustomVersionReplyItem, QStringLiteral( "CustomVersionReply" ) );
  mUseMultiRowInputBoxItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseMultiRowInputBox" ), mUseMultiRowInputBox, false );
  mUseMultiRowInputBoxItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseMultiRowInputBox") );
  mUseMultiRowInputBoxItem->setWhatsThis( QCoreApplication::translate("PreferencesBase", "Enabling this will cause the input box to grow vertically when it fills up.") );
  addItem( mUseMultiRowInputBoxItem, QStringLiteral( "UseMultiRowInputBox" ) );
  mCommandCharItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CommandChar" ), mCommandChar, QStringLiteral( "/" ) );
  mCommandCharItem->setLabel( QCoreApplication::translate("PreferencesBase", "CommandChar") );
  addItem( mCommandCharItem, QStringLiteral( "CommandChar" ) );
  mPreShellCommandItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PreShellCommand" ), mPreShellCommand );
  mPreShellCommandItem->setLabel( QCoreApplication::translate("PreferencesBase", "PreShellCommand") );
  addItem( mPreShellCommandItem, QStringLiteral( "PreShellCommand" ) );
  mShowTrayIconItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowTrayIcon" ), mShowTrayIcon, false );
  mShowTrayIconItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowTrayIcon") );
  addItem( mShowTrayIconItem, QStringLiteral( "ShowTrayIcon" ) );
  mTrayNotifyItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TrayNotify" ), mTrayNotify, false );
  mTrayNotifyItem->setLabel( QCoreApplication::translate("PreferencesBase", "TrayNotify") );
  addItem( mTrayNotifyItem, QStringLiteral( "TrayNotify" ) );
  mTrayNotifyOnlyOwnNickItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TrayNotifyOnlyOwnNick" ), mTrayNotifyOnlyOwnNick, false );
  mTrayNotifyOnlyOwnNickItem->setLabel( QCoreApplication::translate("PreferencesBase", "TrayNotifyOnlyOwnNick") );
  addItem( mTrayNotifyOnlyOwnNickItem, QStringLiteral( "TrayNotifyOnlyOwnNick" ) );
  mTrayNotifyBlinkItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TrayNotifyBlink" ), mTrayNotifyBlink, true );
  mTrayNotifyBlinkItem->setLabel( QCoreApplication::translate("PreferencesBase", "TrayNotifyBlink") );
  addItem( mTrayNotifyBlinkItem, QStringLiteral( "TrayNotifyBlink" ) );
  mHideToTrayOnStartupItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideToTrayOnStartup" ), mHideToTrayOnStartup, false );
  mHideToTrayOnStartupItem->setLabel( QCoreApplication::translate("PreferencesBase", "Start with hidden main window") );
  addItem( mHideToTrayOnStartupItem, QStringLiteral( "HideToTrayOnStartup" ) );
  mTrayActivateNoWindowItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TrayActivateNoWindow" ), mTrayActivateNoWindow, false );
  mTrayActivateNoWindowItem->setLabel( QCoreApplication::translate("PreferencesBase", "TrayActivateNoWindow") );
  addItem( mTrayActivateNoWindowItem, QStringLiteral( "TrayActivateNoWindow" ) );
  mShowBackgroundImageItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowBackgroundImage" ), mShowBackgroundImage, false );
  mShowBackgroundImageItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowBackgroundImage") );
  addItem( mShowBackgroundImageItem, QStringLiteral( "ShowBackgroundImage" ) );
  mMultilineEditSizeItem = new KConfigSkeleton::ItemSize( currentGroup(), QStringLiteral( "MultilineEditGeometry" ), mMultilineEditSize );
  mMultilineEditSizeItem->setLabel( QCoreApplication::translate("PreferencesBase", "MultilineEditGeometry") );
  addItem( mMultilineEditSizeItem, QStringLiteral( "MultilineEditSize" ) );
  mLogfileBufferSizeItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "LogfileBufferSize" ), mLogfileBufferSize, 100 );
  mLogfileBufferSizeItem->setLabel( QCoreApplication::translate("PreferencesBase", "LogfileBufferSize") );
  addItem( mLogfileBufferSizeItem, QStringLiteral( "LogfileBufferSize" ) );
  mScrollbackMaxItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ScrollbackMax" ), mScrollbackMax, 1000 );
  mScrollbackMaxItem->setLabel( QCoreApplication::translate("PreferencesBase", "ScrollbackMax") );
  addItem( mScrollbackMaxItem, QStringLiteral( "ScrollbackMax" ) );
  mAutoWhoNicksLimitItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "AutoWhoNicksLimit" ), mAutoWhoNicksLimit, 200 );
  mAutoWhoNicksLimitItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutoWhoNicksLimit") );
  addItem( mAutoWhoNicksLimitItem, QStringLiteral( "AutoWhoNicksLimit" ) );
  mAutoWhoContinuousEnabledItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoWhoContinuousEnabled" ), mAutoWhoContinuousEnabled, true );
  mAutoWhoContinuousEnabledItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutoWhoContinuousEnabled") );
  addItem( mAutoWhoContinuousEnabledItem, QStringLiteral( "AutoWhoContinuousEnabled" ) );
  mAutoWhoContinuousIntervalItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "AutoWhoContinuousInterval" ), mAutoWhoContinuousInterval, 90 );
  mAutoWhoContinuousIntervalItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutoWhoContinuousInterval") );
  addItem( mAutoWhoContinuousIntervalItem, QStringLiteral( "AutoWhoContinuousInterval" ) );
  mShowRealNamesItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowRealNames" ), mShowRealNames, false );
  mShowRealNamesItem->setLabel( QCoreApplication::translate("PreferencesBase", "&Show real names next to nicknames") );
  addItem( mShowRealNamesItem, QStringLiteral( "ShowRealNames" ) );
  mChannelDoubleClickActionItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ChannelDoubleClickAction" ), mChannelDoubleClickAction, QStringLiteral( "/QUERY %u%n" ) );
  mChannelDoubleClickActionItem->setLabel( QCoreApplication::translate("PreferencesBase", "ChannelDoubleClickAction") );
  addItem( mChannelDoubleClickActionItem, QStringLiteral( "ChannelDoubleClickAction" ) );
  mNotifyDoubleClickActionItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "NotifyDoubleClickAction" ), mNotifyDoubleClickAction, QStringLiteral( "/QUERY %u%n" ) );
  mNotifyDoubleClickActionItem->setLabel( QCoreApplication::translate("PreferencesBase", "NotifyDoubleClickAction") );
  addItem( mNotifyDoubleClickActionItem, QStringLiteral( "NotifyDoubleClickAction" ) );
  mBeepItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Beep" ), mBeep, false );
  mBeepItem->setLabel( QCoreApplication::translate("PreferencesBase", "Beep") );
  addItem( mBeepItem, QStringLiteral( "Beep" ) );
  mRawLogItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RawLog" ), mRawLog, false );
  mRawLogItem->setLabel( QCoreApplication::translate("PreferencesBase", "RawLog") );
  addItem( mRawLogItem, QStringLiteral( "RawLog" ) );
  mVersionReplyItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "VersionReply" ), mVersionReply );
  mVersionReplyItem->setLabel( QCoreApplication::translate("PreferencesBase", "VersionReply") );
  addItem( mVersionReplyItem, QStringLiteral( "VersionReply" ) );
  mMaximumLagTimeItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MaximumLag" ), mMaximumLagTime, 180 );
  mMaximumLagTimeItem->setLabel( QCoreApplication::translate("PreferencesBase", "MaximumLag") );
  addItem( mMaximumLagTimeItem, QStringLiteral( "MaximumLagTime" ) );
  mRedirectServerAndAppMsgToStatusPaneItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RedirectServerAndAppMsgToStatusPane" ), mRedirectServerAndAppMsgToStatusPane, false );
  mRedirectServerAndAppMsgToStatusPaneItem->setLabel( QCoreApplication::translate("PreferencesBase", "RedirectServerAndAppMsgToStatusPane") );
  addItem( mRedirectServerAndAppMsgToStatusPaneItem, QStringLiteral( "RedirectServerAndAppMsgToStatusPane" ) );
  mDisableNotifyWhileAwayItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisableNotifyWhileAway" ), mDisableNotifyWhileAway, false );
  mDisableNotifyWhileAwayItem->setLabel( QCoreApplication::translate("PreferencesBase", "DisableNotifyWhileAway") );
  addItem( mDisableNotifyWhileAwayItem, QStringLiteral( "DisableNotifyWhileAway" ) );
  mAutoAwayPollIntervalItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "AutoAwayPollInterval" ), mAutoAwayPollInterval, 10 );
  mAutoAwayPollIntervalItem->setMinValue(10);
  mAutoAwayPollIntervalItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutoAwayPollInterval") );
  addItem( mAutoAwayPollIntervalItem, QStringLiteral( "AutoAwayPollInterval" ) );
  mAutomaticRememberLineItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomaticRememberLine" ), mAutomaticRememberLine, false );
  mAutomaticRememberLineItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutomaticRememberLine") );
  addItem( mAutomaticRememberLineItem, QStringLiteral( "AutomaticRememberLine" ) );
  mAutomaticRememberLineOnlyOnTextChangeItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomaticRememberLineOnlyOnTextChange" ), mAutomaticRememberLineOnlyOnTextChange, true );
  mAutomaticRememberLineOnlyOnTextChangeItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutomaticRememberLineOnlyOnTextChange") );
  addItem( mAutomaticRememberLineOnlyOnTextChangeItem, QStringLiteral( "AutomaticRememberLineOnlyOnTextChange" ) );
  mMarkerLineInAllViewsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MarkerLineInAllViews" ), mMarkerLineInAllViews, false );
  mMarkerLineInAllViewsItem->setLabel( QCoreApplication::translate("PreferencesBase", "MarkerLineInAllViews") );
  addItem( mMarkerLineInAllViewsItem, QStringLiteral( "MarkerLineInAllViews" ) );

  setCurrentGroup( QStringLiteral( "Sort Nicknames" ) );

  mSortByStatusItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SortByStatus" ), mSortByStatus, false );
  mSortByStatusItem->setLabel( QCoreApplication::translate("PreferencesBase", "SortByStatus") );
  addItem( mSortByStatusItem, QStringLiteral( "SortByStatus" ) );
  mSortByActivityItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SortByActivity" ), mSortByActivity, false );
  mSortByActivityItem->setLabel( QCoreApplication::translate("PreferencesBase", "SortByActivity") );
  addItem( mSortByActivityItem, QStringLiteral( "SortByActivity" ) );
  mSortCaseInsensitiveItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SortCaseInsensitive" ), mSortCaseInsensitive, true );
  mSortCaseInsensitiveItem->setLabel( QCoreApplication::translate("PreferencesBase", "SortCaseInsensitive") );
  addItem( mSortCaseInsensitiveItem, QStringLiteral( "SortCaseInsensitive" ) );

  setCurrentGroup( QStringLiteral( "LauncherEntry" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuesLauncherEntryCountMode;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("CountEvents");
    choice.label = QCoreApplication::translate("PreferencesBase", "All events");
    valuesLauncherEntryCountMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("CountChannelAndQueries");
    choice.label = QCoreApplication::translate("PreferencesBase", "Channels and queries with events");
    valuesLauncherEntryCountMode.append( choice );
  }
  mLauncherEntryCountModeItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "LauncherEntryCountMode" ), mLauncherEntryCountMode, valuesLauncherEntryCountMode );
  mLauncherEntryCountModeItem->setLabel( QCoreApplication::translate("PreferencesBase", "LauncherEntryCountMode") );
  addItem( mLauncherEntryCountModeItem, QStringLiteral( "LauncherEntryCountMode" ) );
  mLauncherEntryCountUseNickItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LauncherEntryCountUseNick" ), mLauncherEntryCountUseNick, true );
  mLauncherEntryCountUseNickItem->setLabel( QCoreApplication::translate("PreferencesBase", "LauncherEntryCountUseNick") );
  addItem( mLauncherEntryCountUseNickItem, QStringLiteral( "LauncherEntryCountUseNick" ) );
  mLauncherEntryCountUseHighlightsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LauncherEntryCountUseHighlights" ), mLauncherEntryCountUseHighlights, false );
  mLauncherEntryCountUseHighlightsItem->setLabel( QCoreApplication::translate("PreferencesBase", "LauncherEntryCountUseHighlights") );
  addItem( mLauncherEntryCountUseHighlightsItem, QStringLiteral( "LauncherEntryCountUseHighlights" ) );
  mLauncherEntryCountUsePrivateItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LauncherEntryCountUsePrivate" ), mLauncherEntryCountUsePrivate, true );
  mLauncherEntryCountUsePrivateItem->setLabel( QCoreApplication::translate("PreferencesBase", "LauncherEntryCountUsePrivate") );
  addItem( mLauncherEntryCountUsePrivateItem, QStringLiteral( "LauncherEntryCountUsePrivate" ) );
  mLauncherEntryCountUseMsgsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LauncherEntryCountUseMsgs" ), mLauncherEntryCountUseMsgs, false );
  mLauncherEntryCountUseMsgsItem->setLabel( QCoreApplication::translate("PreferencesBase", "LauncherEntryCountUseMsgs") );
  addItem( mLauncherEntryCountUseMsgsItem, QStringLiteral( "LauncherEntryCountUseMsgs" ) );
  mLauncherEntryCountUseSystemItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LauncherEntryCountUseSystem" ), mLauncherEntryCountUseSystem, false );
  mLauncherEntryCountUseSystemItem->setLabel( QCoreApplication::translate("PreferencesBase", "LauncherEntryCountUseSystem") );
  addItem( mLauncherEntryCountUseSystemItem, QStringLiteral( "LauncherEntryCountUseSystem" ) );
  mLauncherEntryCountUseChannelEventsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LauncherEntryCountUseChannelEvents" ), mLauncherEntryCountUseChannelEvents, false );
  mLauncherEntryCountUseChannelEventsItem->setLabel( QCoreApplication::translate("PreferencesBase", "LauncherEntryCountUseChannelEvents") );
  addItem( mLauncherEntryCountUseChannelEventsItem, QStringLiteral( "LauncherEntryCountUseChannelEvents" ) );

  setCurrentGroup( QStringLiteral( "OSD" ) );

  mUseOSDItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseOSD" ), mUseOSD, false );
  mUseOSDItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseOSD") );
  addItem( mUseOSDItem, QStringLiteral( "UseOSD" ) );
  mOSDShowOwnNickItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowOwnNick" ), mOSDShowOwnNick, false );
  mOSDShowOwnNickItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowOwnNick") );
  addItem( mOSDShowOwnNickItem, QStringLiteral( "OSDShowOwnNick" ) );
  mOSDShowChannelItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowChannel" ), mOSDShowChannel, false );
  mOSDShowChannelItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowChannel") );
  addItem( mOSDShowChannelItem, QStringLiteral( "OSDShowChannel" ) );
  mOSDShowQueryItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowQuery" ), mOSDShowQuery, false );
  mOSDShowQueryItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowQuery") );
  addItem( mOSDShowQueryItem, QStringLiteral( "OSDShowQuery" ) );
  mOSDShowChannelEventItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowChannelEvent" ), mOSDShowChannelEvent, false );
  mOSDShowChannelEventItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowChannelEvent") );
  addItem( mOSDShowChannelEventItem, QStringLiteral( "OSDShowChannelEvent" ) );
  mOSDFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "OSDFont" ), mOSDFont, QFontDatabase::systemFont(QFontDatabase::GeneralFont) );
  mOSDFontItem->setLabel( QCoreApplication::translate("PreferencesBase", "OSDFont") );
  addItem( mOSDFontItem, QStringLiteral( "OSDFont" ) );
  mOSDUseCustomColorsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "OSDUseCustomColors" ), mOSDUseCustomColors, false );
  mOSDUseCustomColorsItem->setLabel( QCoreApplication::translate("PreferencesBase", "OSDUseCustomColors") );
  addItem( mOSDUseCustomColorsItem, QStringLiteral( "OSDUseCustomColors" ) );
  mOSDDurationItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "OSDDuration" ), mOSDDuration, 3000 );
  mOSDDurationItem->setLabel( QCoreApplication::translate("PreferencesBase", "OSDDuration") );
  addItem( mOSDDurationItem, QStringLiteral( "OSDDuration" ) );
  mOSDScreenItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "OSDScreen" ), mOSDScreen, 0 );
  mOSDScreenItem->setLabel( QCoreApplication::translate("PreferencesBase", "OSDScreen") );
  addItem( mOSDScreenItem, QStringLiteral( "OSDScreen" ) );
  mOSDDrawShadowItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "OSDDrawShadow" ), mOSDDrawShadow, false );
  mOSDDrawShadowItem->setLabel( QCoreApplication::translate("PreferencesBase", "OSDDrawShadow") );
  addItem( mOSDDrawShadowItem, QStringLiteral( "OSDDrawShadow" ) );
  mOSDOffsetXItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "OffsetX" ), mOSDOffsetX, 30 );
  mOSDOffsetXItem->setLabel( QCoreApplication::translate("PreferencesBase", "OffsetX") );
  addItem( mOSDOffsetXItem, QStringLiteral( "OSDOffsetX" ) );
  mOSDOffsetYItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "OffsetY" ), mOSDOffsetY, 50 );
  mOSDOffsetYItem->setLabel( QCoreApplication::translate("PreferencesBase", "OffsetY") );
  addItem( mOSDOffsetYItem, QStringLiteral( "OSDOffsetY" ) );
  mOSDAlignmentItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Alignment" ), mOSDAlignment, 0 );
  mOSDAlignmentItem->setLabel( QCoreApplication::translate("PreferencesBase", "Alignment") );
  addItem( mOSDAlignmentItem, QStringLiteral( "OSDAlignment" ) );
  mOSDTextColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "OSDTextColor" ), mOSDTextColor, QColor( "#ffffff" ) );
  mOSDTextColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "OSDTextColor") );
  addItem( mOSDTextColorItem, QStringLiteral( "OSDTextColor" ) );
  mOSDBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "OSDBackgroundColor" ), mOSDBackgroundColor );
  mOSDBackgroundColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "OSDBackgroundColor") );
  addItem( mOSDBackgroundColorItem, QStringLiteral( "OSDBackgroundColor" ) );
  mOSDCheckDesktopLockItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "OSDCheckDesktopLock" ), mOSDCheckDesktopLock, true );
  mOSDCheckDesktopLockItem->setLabel( QCoreApplication::translate("PreferencesBase", "OSDCheckDesktopLock") );
  addItem( mOSDCheckDesktopLockItem, QStringLiteral( "OSDCheckDesktopLock" ) );

  setCurrentGroup( QStringLiteral( "Notify List" ) );

  mNotifyDelayItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "NotifyDelay" ), mNotifyDelay, 20 );
  mNotifyDelayItem->setLabel( QCoreApplication::translate("PreferencesBase", "NotifyDelay") );
  addItem( mNotifyDelayItem, QStringLiteral( "NotifyDelay" ) );
  mUseNotifyItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseNotify" ), mUseNotify, true );
  mUseNotifyItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseNotify") );
  addItem( mUseNotifyItem, QStringLiteral( "UseNotify" ) );
  mOpenWatchedNicksAtStartupItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "OnStartup" ), mOpenWatchedNicksAtStartup, false );
  mOpenWatchedNicksAtStartupItem->setLabel( QCoreApplication::translate("PreferencesBase", "Open Watched Nicks tab at application startup") );
  addItem( mOpenWatchedNicksAtStartupItem, QStringLiteral( "OpenWatchedNicksAtStartup" ) );

  setCurrentGroup( QStringLiteral( "Highlight List" ) );

  mHighlightSoundsEnabledItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HighlightSoundsEnabled" ), mHighlightSoundsEnabled, false );
  mHighlightSoundsEnabledItem->setLabel( QCoreApplication::translate("PreferencesBase", "HighlightSoundsEnabled") );
  addItem( mHighlightSoundsEnabledItem, QStringLiteral( "HighlightSoundsEnabled" ) );
  mHighlightNickItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HighlightNick" ), mHighlightNick, true );
  mHighlightNickItem->setLabel( QCoreApplication::translate("PreferencesBase", "HighlightNick") );
  addItem( mHighlightNickItem, QStringLiteral( "HighlightNick" ) );
  mHighlightNickColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "HighlightNickColor" ), mHighlightNickColor, QColor( "#FF0000" ) );
  mHighlightNickColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "HighlightNickColor") );
  addItem( mHighlightNickColorItem, QStringLiteral( "HighlightNickColor" ) );
  mHighlightOwnLinesItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HighlightOwnLines" ), mHighlightOwnLines, false );
  mHighlightOwnLinesItem->setLabel( QCoreApplication::translate("PreferencesBase", "HighlightOwnLines") );
  addItem( mHighlightOwnLinesItem, QStringLiteral( "HighlightOwnLines" ) );
  mHighlightOwnLinesColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "HighlightOwnLinesColor" ), mHighlightOwnLinesColor, QColor( "#ff0000" ) );
  mHighlightOwnLinesColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "HighlightOwnLinesColor") );
  addItem( mHighlightOwnLinesColorItem, QStringLiteral( "HighlightOwnLinesColor" ) );
  mHighlightItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Highlight" ), mHighlight );
  mHighlightItem->setLabel( QCoreApplication::translate("PreferencesBase", "Highlight") );
  addItem( mHighlightItem, QStringLiteral( "Highlight" ) );

  setCurrentGroup( QStringLiteral( "Aliases" ) );

  mAliasListItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "AliasList" ), mAliasList );
  mAliasListItem->setLabel( QCoreApplication::translate("PreferencesBase", "AliasList") );
  addItem( mAliasListItem, QStringLiteral( "AliasList" ) );

  setCurrentGroup( QStringLiteral( "Nick Completion" ) );

  mNickCompletionModeItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Mode" ), mNickCompletionMode, 0 );
  mNickCompletionModeItem->setLabel( QCoreApplication::translate("PreferencesBase", "Mode") );
  addItem( mNickCompletionModeItem, QStringLiteral( "NickCompletionMode" ) );
  mNickCompleteSuffixStartItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SuffixStart" ), mNickCompleteSuffixStart, QStringLiteral( ": " ) );
  mNickCompleteSuffixStartItem->setLabel( QCoreApplication::translate("PreferencesBase", "SuffixStart") );
  addItem( mNickCompleteSuffixStartItem, QStringLiteral( "NickCompleteSuffixStart" ) );
  mNickCompleteSuffixMiddleItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SuffixMiddle" ), mNickCompleteSuffixMiddle, QStringLiteral(" ") );
  mNickCompleteSuffixMiddleItem->setLabel( QCoreApplication::translate("PreferencesBase", "SuffixMiddle") );
  addItem( mNickCompleteSuffixMiddleItem, QStringLiteral( "NickCompleteSuffixMiddle" ) );
  mPrefixCharacterItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PrefixCharacter" ), mPrefixCharacter );
  mPrefixCharacterItem->setLabel( QCoreApplication::translate("PreferencesBase", "PrefixCharacter") );
  addItem( mPrefixCharacterItem, QStringLiteral( "PrefixCharacter" ) );
  mNickCompletionCaseSensitiveItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CaseSensitive" ), mNickCompletionCaseSensitive, false );
  mNickCompletionCaseSensitiveItem->setLabel( QCoreApplication::translate("PreferencesBase", "CaseSensitive") );
  addItem( mNickCompletionCaseSensitiveItem, QStringLiteral( "NickCompletionCaseSensitive" ) );

  setCurrentGroup( QStringLiteral( "DCC Settings" ) );

  mDccBufferSizeItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "BufferSize" ), mDccBufferSize, 16384 );
  mDccBufferSizeItem->setLabel( QCoreApplication::translate("PreferencesBase", "BufferSize") );
  addItem( mDccBufferSizeItem, QStringLiteral( "DccBufferSize" ) );
  mDccMethodToGetOwnIpItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MethodToGetOwnIp" ), mDccMethodToGetOwnIp, 1 );
  mDccMethodToGetOwnIpItem->setLabel( QCoreApplication::translate("PreferencesBase", "MethodToGetOwnIp") );
  addItem( mDccMethodToGetOwnIpItem, QStringLiteral( "DccMethodToGetOwnIp" ) );
  mDccSpecificOwnIpItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SpecificOwnIp" ), mDccSpecificOwnIp, QStringLiteral( "0.0.0.0" ) );
  mDccSpecificOwnIpItem->setLabel( QCoreApplication::translate("PreferencesBase", "SpecificOwnIp") );
  addItem( mDccSpecificOwnIpItem, QStringLiteral( "DccSpecificOwnIp" ) );
  mDccSpecificSendPortsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SpecificSendPorts" ), mDccSpecificSendPorts, true );
  mDccSpecificSendPortsItem->setLabel( QCoreApplication::translate("PreferencesBase", "SpecificSendPorts") );
  addItem( mDccSpecificSendPortsItem, QStringLiteral( "DccSpecificSendPorts" ) );
  mDccSendPortsFirstItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "SendPortsFirst" ), mDccSendPortsFirst, 1026 );
  mDccSendPortsFirstItem->setLabel( QCoreApplication::translate("PreferencesBase", "SendPortsFirst") );
  addItem( mDccSendPortsFirstItem, QStringLiteral( "DccSendPortsFirst" ) );
  mDccSendPortsLastItem = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SendPortsLast" ), mDccSendPortsLast, 7000 );
  mDccSendPortsLastItem->setLabel( QCoreApplication::translate("PreferencesBase", "SendPortsLast") );
  addItem( mDccSendPortsLastItem, QStringLiteral( "DccSendPortsLast" ) );
  mDccSpecificChatPortsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SpecificChatPorts" ), mDccSpecificChatPorts, true );
  mDccSpecificChatPortsItem->setLabel( QCoreApplication::translate("PreferencesBase", "SpecificChatPorts") );
  addItem( mDccSpecificChatPortsItem, QStringLiteral( "DccSpecificChatPorts" ) );
  mDccChatPortsFirstItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ChatPortsFirst" ), mDccChatPortsFirst, 1026 );
  mDccChatPortsFirstItem->setLabel( QCoreApplication::translate("PreferencesBase", "ChatPortsFirst") );
  addItem( mDccChatPortsFirstItem, QStringLiteral( "DccChatPortsFirst" ) );
  mDccChatPortsLastItem = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "ChatPortsLast" ), mDccChatPortsLast, 7000 );
  mDccChatPortsLastItem->setLabel( QCoreApplication::translate("PreferencesBase", "ChatPortsLast") );
  addItem( mDccChatPortsLastItem, QStringLiteral( "DccChatPortsLast" ) );
  mDccAddPartnerItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AddPartner" ), mDccAddPartner, false );
  mDccAddPartnerItem->setLabel( QCoreApplication::translate("PreferencesBase", "AddPartner") );
  addItem( mDccAddPartnerItem, QStringLiteral( "DccAddPartner" ) );
  mDccCreateFolderItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CreateFolder" ), mDccCreateFolder, false );
  mDccCreateFolderItem->setLabel( QCoreApplication::translate("PreferencesBase", "CreateFolder") );
  addItem( mDccCreateFolderItem, QStringLiteral( "DccCreateFolder" ) );
  mDccSpaceToUnderscoreItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SpaceToUnderscore" ), mDccSpaceToUnderscore, true );
  mDccSpaceToUnderscoreItem->setLabel( QCoreApplication::translate("PreferencesBase", "SpaceToUnderscore") );
  addItem( mDccSpaceToUnderscoreItem, QStringLiteral( "DccSpaceToUnderscore" ) );
  mDccAutoGetItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoGet" ), mDccAutoGet, false );
  mDccAutoGetItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutoGet") );
  addItem( mDccAutoGetItem, QStringLiteral( "DccAutoGet" ) );
  mDccAutoResumeItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoResume" ), mDccAutoResume, true );
  mDccAutoResumeItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutoResume") );
  addItem( mDccAutoResumeItem, QStringLiteral( "DccAutoResume" ) );
  mDccChatAutoAcceptItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ChatAutoAccept" ), mDccChatAutoAccept, false );
  mDccChatAutoAcceptItem->setLabel( QCoreApplication::translate("PreferencesBase", "ChatAutoAccept") );
  addItem( mDccChatAutoAcceptItem, QStringLiteral( "DccChatAutoAccept" ) );
  mDccFastSendItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FastSend" ), mDccFastSend, true );
  mDccFastSendItem->setLabel( QCoreApplication::translate("PreferencesBase", "FastSend") );
  addItem( mDccFastSendItem, QStringLiteral( "DccFastSend" ) );
  mDccSendTimeoutItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "SendTimeout" ), mDccSendTimeout, 180 );
  mDccSendTimeoutItem->setLabel( QCoreApplication::translate("PreferencesBase", "SendTimeout") );
  addItem( mDccSendTimeoutItem, QStringLiteral( "DccSendTimeout" ) );
  mDccIPv4FallbackItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "IPv4Fallback" ), mDccIPv4Fallback, false );
  mDccIPv4FallbackItem->setLabel( QCoreApplication::translate("PreferencesBase", "IPv4Fallback") );
  addItem( mDccIPv4FallbackItem, QStringLiteral( "DccIPv4Fallback" ) );
  mDccIPv4FallbackIfaceItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "IPv4FallbackIface" ), mDccIPv4FallbackIface, QStringLiteral( "eth0" ) );
  mDccIPv4FallbackIfaceItem->setLabel( QCoreApplication::translate("PreferencesBase", "IPv4FallbackIface") );
  addItem( mDccIPv4FallbackIfaceItem, QStringLiteral( "DccIPv4FallbackIface" ) );
  mDccPassiveSendItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "PassiveSend" ), mDccPassiveSend, false );
  mDccPassiveSendItem->setLabel( QCoreApplication::translate("PreferencesBase", "PassiveSend") );
  addItem( mDccPassiveSendItem, QStringLiteral( "DccPassiveSend" ) );
  mDccUPnPItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UPnP" ), mDccUPnP, false );
  mDccUPnPItem->setLabel( QCoreApplication::translate("PreferencesBase", "UPnP") );
  addItem( mDccUPnPItem, QStringLiteral( "DccUPnP" ) );
  QList<int> defaultDccColumnWidths;
  defaultDccColumnWidths.append( 47 );
  defaultDccColumnWidths.append( 90 );
  defaultDccColumnWidths.append( 103 );
  defaultDccColumnWidths.append( 173 );
  defaultDccColumnWidths.append( 70 );
  defaultDccColumnWidths.append( 87 );
  defaultDccColumnWidths.append( 157 );
  defaultDccColumnWidths.append( 87 );
  defaultDccColumnWidths.append( 96 );
  defaultDccColumnWidths.append( 165 );

  mDccColumnWidthsItem = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "ColumnWidths" ), mDccColumnWidths, defaultDccColumnWidths );
  mDccColumnWidthsItem->setLabel( QCoreApplication::translate("PreferencesBase", "ColumnWidths") );
  addItem( mDccColumnWidthsItem, QStringLiteral( "DccColumnWidths" ) );
  QList<int> defaultDccColumnOrders;
  defaultDccColumnOrders.append( 0 );
  defaultDccColumnOrders.append( 1 );
  defaultDccColumnOrders.append( 2 );
  defaultDccColumnOrders.append( 3 );
  defaultDccColumnOrders.append( 4 );
  defaultDccColumnOrders.append( 5 );
  defaultDccColumnOrders.append( 6 );
  defaultDccColumnOrders.append( 7 );
  defaultDccColumnOrders.append( 8 );
  defaultDccColumnOrders.append( 9 );

  mDccColumnOrdersItem = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "ColumnOrder" ), mDccColumnOrders, defaultDccColumnOrders );
  mDccColumnOrdersItem->setLabel( QCoreApplication::translate("PreferencesBase", "ColumnOrder") );
  addItem( mDccColumnOrdersItem, QStringLiteral( "DccColumnOrders" ) );
  QList<int> defaultDccColumnVisibles;
  defaultDccColumnVisibles.append( 1 );
  defaultDccColumnVisibles.append( 1 );
  defaultDccColumnVisibles.append( 1 );
  defaultDccColumnVisibles.append( 1 );
  defaultDccColumnVisibles.append( 1 );
  defaultDccColumnVisibles.append( 1 );
  defaultDccColumnVisibles.append( 1 );
  defaultDccColumnVisibles.append( 1 );
  defaultDccColumnVisibles.append( 1 );
  defaultDccColumnVisibles.append( 1 );

  mDccColumnVisiblesItem = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "ColumnVisible" ), mDccColumnVisibles, defaultDccColumnVisibles );
  mDccColumnVisiblesItem->setLabel( QCoreApplication::translate("PreferencesBase", "ColumnVisible") );
  addItem( mDccColumnVisiblesItem, QStringLiteral( "DccColumnVisibles" ) );
  mDccColumnSortedItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ColumnSorted" ), mDccColumnSorted, 1 );
  mDccColumnSortedItem->setLabel( QCoreApplication::translate("PreferencesBase", "ColumnSorted") );
  addItem( mDccColumnSortedItem, QStringLiteral( "DccColumnSorted" ) );
  mDccColumnSortDescendingItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ColumnSortDescending" ), mDccColumnSortDescending, true );
  mDccColumnSortDescendingItem->setLabel( QCoreApplication::translate("PreferencesBase", "ColumnSortDescending") );
  addItem( mDccColumnSortDescendingItem, QStringLiteral( "DccColumnSortDescending" ) );

  setCurrentGroup( QStringLiteral( "Path Settings" ) );

  mLogfilePathItem = new KConfigSkeleton::ItemUrl( currentGroup(), QStringLiteral( "LogfilePath" ), mLogfilePath, QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation)+QLatin1String("/logs")) );
  mLogfilePathItem->setLabel( QCoreApplication::translate("PreferencesBase", "LogfilePath") );
  addItem( mLogfilePathItem, QStringLiteral( "LogfilePath" ) );
  mDccPathItem = new KConfigSkeleton::ItemUrl( currentGroup(), QStringLiteral( "DccPath" ), mDccPath, QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DownloadLocation)) );
  mDccPathItem->setLabel( QCoreApplication::translate("PreferencesBase", "DccPath") );
  addItem( mDccPathItem, QStringLiteral( "DccPath" ) );

  setCurrentGroup( QStringLiteral( "Flags" ) );

  mLogItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Log" ), mLog, true );
  mLogItem->setLabel( QCoreApplication::translate("PreferencesBase", "Log") );
  addItem( mLogItem, QStringLiteral( "Log" ) );
  mLowerLogItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LowerLog" ), mLowerLog, true );
  mLowerLogItem->setLabel( QCoreApplication::translate("PreferencesBase", "LowerLog") );
  addItem( mLowerLogItem, QStringLiteral( "LowerLog" ) );
  mAddHostnameToLogItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AddHostnameToLog" ), mAddHostnameToLog, false );
  mAddHostnameToLogItem->setLabel( QCoreApplication::translate("PreferencesBase", "AddHostnameToLog") );
  addItem( mAddHostnameToLogItem, QStringLiteral( "AddHostnameToLog" ) );
  mPrivateOnlyItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "PrivateOnly" ), mPrivateOnly, false );
  mPrivateOnlyItem->setLabel( QCoreApplication::translate("PreferencesBase", "PrivateOnly") );
  addItem( mPrivateOnlyItem, QStringLiteral( "PrivateOnly" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesTabPlacement;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Top");
    valuesTabPlacement.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Bottom");
    valuesTabPlacement.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Left");
    valuesTabPlacement.append( choice );
  }
  mTabPlacementItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "TabPlacement" ), mTabPlacement, valuesTabPlacement, Left );
  mTabPlacementItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabPlacement") );
  addItem( mTabPlacementItem, QStringLiteral( "TabPlacement" ) );
  mMiddleClickCloseItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MiddleClickClose" ), mMiddleClickClose, false );
  mMiddleClickCloseItem->setLabel( QCoreApplication::translate("PreferencesBase", "MiddleClickClose") );
  addItem( mMiddleClickCloseItem, QStringLiteral( "MiddleClickClose" ) );
  mUseClickableNicksItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseClickableNicks" ), mUseClickableNicks, true );
  mUseClickableNicksItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseClickableNicks") );
  addItem( mUseClickableNicksItem, QStringLiteral( "UseClickableNicks" ) );
  mBringToFrontItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "BringToFront" ), mBringToFront, false );
  mBringToFrontItem->setLabel( QCoreApplication::translate("PreferencesBase", "BringToFront") );
  addItem( mBringToFrontItem, QStringLiteral( "BringToFront" ) );
  mHideUnimportantEventsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideUnimportantEvents" ), mHideUnimportantEvents, false );
  mHideUnimportantEventsItem->setLabel( QCoreApplication::translate("PreferencesBase", "HideUnimportantEvents") );
  addItem( mHideUnimportantEventsItem, QStringLiteral( "HideUnimportantEvents" ) );
  mHideUnimportantEventsExcludeActiveItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideUnimportantEventsExcludeActive" ), mHideUnimportantEventsExcludeActive, false );
  mHideUnimportantEventsExcludeActiveItem->setLabel( QCoreApplication::translate("PreferencesBase", "HideUnimportantEventsExcludeActive") );
  addItem( mHideUnimportantEventsExcludeActiveItem, QStringLiteral( "HideUnimportantEventsExcludeActive" ) );
  mHideUnimportantEventsExcludeActiveThresholdItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "HideUnimportantEventsExcludeActiveThreshold" ), mHideUnimportantEventsExcludeActiveThreshold, 1 );
  mHideUnimportantEventsExcludeActiveThresholdItem->setLabel( QCoreApplication::translate("PreferencesBase", "HideUnimportantEventsExcludeActiveThreshold") );
  addItem( mHideUnimportantEventsExcludeActiveThresholdItem, QStringLiteral( "HideUnimportantEventsExcludeActiveThreshold" ) );
  mDisableExpansionItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisableExpansion" ), mDisableExpansion, false );
  mDisableExpansionItem->setLabel( QCoreApplication::translate("PreferencesBase", "DisableExpansion") );
  addItem( mDisableExpansionItem, QStringLiteral( "DisableExpansion" ) );
  mAutoReconnectItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoReconnect" ), mAutoReconnect, true );
  mAutoReconnectItem->setLabel( QCoreApplication::translate("PreferencesBase", "AutoReconnect") );
  addItem( mAutoReconnectItem, QStringLiteral( "AutoReconnect" ) );
  mReconnectDelayItem = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "ReconnectDelay" ), mReconnectDelay, 10 );
  mReconnectDelayItem->setLabel( QCoreApplication::translate("PreferencesBase", "ReconnectDelay") );
  addItem( mReconnectDelayItem, QStringLiteral( "ReconnectDelay" ) );
  mReconnectCountItem = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "ReconnectCount" ), mReconnectCount, 0 );
  mReconnectCountItem->setLabel( QCoreApplication::translate("PreferencesBase", "ReconnectCount") );
  addItem( mReconnectCountItem, QStringLiteral( "ReconnectCount" ) );
  mEncryptionTypeItem = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "EncryptionType" ), mEncryptionType, 0 );
  mEncryptionTypeItem->setLabel( QCoreApplication::translate("PreferencesBase", "EncryptionType") );
  addItem( mEncryptionTypeItem, QStringLiteral( "EncryptionType" ) );
  mFixedMOTDItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FixedMOTD" ), mFixedMOTD, true );
  mFixedMOTDItem->setLabel( QCoreApplication::translate("PreferencesBase", "FixedMOTD") );
  addItem( mFixedMOTDItem, QStringLiteral( "FixedMOTD" ) );
  mSkipMOTDItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SkipMOTD" ), mSkipMOTD, false );
  mSkipMOTDItem->setLabel( QCoreApplication::translate("PreferencesBase", "SkipMOTD") );
  addItem( mSkipMOTDItem, QStringLiteral( "SkipMOTD" ) );
  mShowServerListItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowServerList" ), mShowServerList, true );
  mShowServerListItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowServerList") );
  addItem( mShowServerListItem, QStringLiteral( "ShowServerList" ) );
  mInputFieldsBackgroundColorItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "InputFieldsBackgroundColor" ), mInputFieldsBackgroundColor, false );
  mInputFieldsBackgroundColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "InputFieldsBackgroundColor") );
  addItem( mInputFieldsBackgroundColorItem, QStringLiteral( "InputFieldsBackgroundColor" ) );

  setCurrentGroup( QStringLiteral( "Web Browser Settings" ) );

  mUseCustomBrowserItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseCustomBrowser" ), mUseCustomBrowser, false );
  mUseCustomBrowserItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseCustomBrowser") );
  addItem( mUseCustomBrowserItem, QStringLiteral( "UseCustomBrowser" ) );
  mWebBrowserCmdItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "WebBrowserCmd" ), mWebBrowserCmd, QStringLiteral( "firefox '%u'" ) );
  mWebBrowserCmdItem->setLabel( QCoreApplication::translate("PreferencesBase", "WebBrowserCmd") );
  addItem( mWebBrowserCmdItem, QStringLiteral( "WebBrowserCmd" ) );

  setCurrentGroup( QStringLiteral( "External Log Viewer" ) );

  mUseExternalLogViewerItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseExternalLogViewer" ), mUseExternalLogViewer, false );
  mUseExternalLogViewerItem->setLabel( QCoreApplication::translate("PreferencesBase", "UseExternalLogViewer") );
  addItem( mUseExternalLogViewerItem, QStringLiteral( "UseExternalLogViewer" ) );

  setCurrentGroup( QStringLiteral( "Themes" ) );

  mIconThemeItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "IconTheme" ), mIconTheme, QStringLiteral( "default" ) );
  mIconThemeItem->setLabel( QCoreApplication::translate("PreferencesBase", "IconTheme") );
  addItem( mIconThemeItem, QStringLiteral( "IconTheme" ) );

  setCurrentGroup( QStringLiteral( "PreferencesDialog" ) );

  mPreferencesDialogSizeItem = new KConfigSkeleton::ItemSize( currentGroup(), QStringLiteral( "Size" ), mPreferencesDialogSize );
  mPreferencesDialogSizeItem->setLabel( QCoreApplication::translate("PreferencesBase", "Size") );
  addItem( mPreferencesDialogSizeItem, QStringLiteral( "PreferencesDialogSize" ) );
  mLastActiveModuleItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "LastActiveModule" ), mLastActiveModule );
  mLastActiveModuleItem->setLabel( QCoreApplication::translate("PreferencesBase", "LastActiveModule") );
  addItem( mLastActiveModuleItem, QStringLiteral( "LastActiveModule" ) );

  setCurrentGroup( QStringLiteral( "ServerListDialog" ) );

  mServerListDialogSizeItem = new KConfigSkeleton::ItemSize( currentGroup(), QStringLiteral( "Size" ), mServerListDialogSize );
  mServerListDialogSizeItem->setLabel( QCoreApplication::translate("PreferencesBase", "Size") );
  addItem( mServerListDialogSizeItem, QStringLiteral( "ServerListDialogSize" ) );

  setCurrentGroup( QStringLiteral( "Message Text Colors" ) );

  mColorItem[0] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "ActionMessage" ), mColor[0], QColor( "#0000ff" ) );
  mColorItem[0]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[0], QStringLiteral( "ActionMessageColor" ) );
  mColorItem[1] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "BacklogMessage" ), mColor[1], QColor( "#aaaaaa" ) );
  mColorItem[1]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[1], QStringLiteral( "BacklogMessageColor" ) );
  mColorItem[2] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "ChannelMessage" ), mColor[2], QColor( "#000000" ) );
  mColorItem[2]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[2], QStringLiteral( "ChannelMessageColor" ) );
  mColorItem[3] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "CommandMessage" ), mColor[3], QColor( "#960096" ) );
  mColorItem[3]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[3], QStringLiteral( "CommandMessageColor" ) );
  mColorItem[4] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "QueryMessage" ), mColor[4], QColor( "#000000" ) );
  mColorItem[4]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[4], QStringLiteral( "QueryMessageColor" ) );
  mColorItem[5] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "ServerMessage" ), mColor[5], QColor( "#91640a" ) );
  mColorItem[5]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[5], QStringLiteral( "ServerMessageColor" ) );
  mColorItem[6] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Time" ), mColor[6], QColor( "#709070" ) );
  mColorItem[6]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[6], QStringLiteral( "TimeColor" ) );
  mColorItem[7] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Action" ), mColor[7], QColor( "#0000ff" ) );
  mColorItem[7]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[7], QStringLiteral( "ActionColor" ) );
  mColorItem[8] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "TextViewBackground" ), mColor[8], QColor( "#ffffff" ) );
  mColorItem[8]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[8], QStringLiteral( "TextViewBackgroundColor" ) );
  mColorItem[9] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "AlternateBackground" ), mColor[9], QColor( "#EDF4F9" ) );
  mColorItem[9]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[9], QStringLiteral( "AlternateBackgroundColor" ) );
  mColorItem[10] = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Hyperlink" ), mColor[10], QColor( "#0000ff" ) );
  mColorItem[10]->setLabel( QCoreApplication::translate("PreferencesBase", "$(colorName)Color") );
  addItem( mColorItem[10], QStringLiteral( "HyperlinkColor" ) );

  setCurrentGroup( QStringLiteral( "Tab Notifications" ) );

  mTabNotificationsTextItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabNotificationsText" ), mTabNotificationsText, true );
  mTabNotificationsTextItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsText") );
  addItem( mTabNotificationsTextItem, QStringLiteral( "TabNotificationsText" ) );
  mTabNotificationsLedsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabNotificationsLeds" ), mTabNotificationsLeds, false );
  mTabNotificationsLedsItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsLeds") );
  addItem( mTabNotificationsLedsItem, QStringLiteral( "TabNotificationsLeds" ) );
  mTabNotificationsSystemItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabNotificationsSystem" ), mTabNotificationsSystem, true );
  mTabNotificationsSystemItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsSystem") );
  addItem( mTabNotificationsSystemItem, QStringLiteral( "TabNotificationsSystem" ) );
  mTabNotificationsSystemColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "TabNotificationsSystemColor" ), mTabNotificationsSystemColor, QColor( "#C3C300" ) );
  mTabNotificationsSystemColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsSystemColor") );
  addItem( mTabNotificationsSystemColorItem, QStringLiteral( "TabNotificationsSystemColor" ) );
  mTabNotificationsMsgsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabNotificationsMsgs" ), mTabNotificationsMsgs, true );
  mTabNotificationsMsgsItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsMsgs") );
  addItem( mTabNotificationsMsgsItem, QStringLiteral( "TabNotificationsMsgs" ) );
  mTabNotificationsMsgsColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "TabNotificationsMsgsColor" ), mTabNotificationsMsgsColor, QColor( "#008000" ) );
  mTabNotificationsMsgsColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsMsgsColor") );
  addItem( mTabNotificationsMsgsColorItem, QStringLiteral( "TabNotificationsMsgsColor" ) );
  mTabNotificationsPrivateItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabNotificationsPrivate" ), mTabNotificationsPrivate, true );
  mTabNotificationsPrivateItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsPrivate") );
  addItem( mTabNotificationsPrivateItem, QStringLiteral( "TabNotificationsPrivate" ) );
  mTabNotificationsPrivateColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "TabNotificationsPrivateColor" ), mTabNotificationsPrivateColor, QColor( "#800000" ) );
  mTabNotificationsPrivateColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsPrivateColor") );
  addItem( mTabNotificationsPrivateColorItem, QStringLiteral( "TabNotificationsPrivateColor" ) );
  mTabNotificationsEventsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabNotificationsEvents" ), mTabNotificationsEvents, false );
  mTabNotificationsEventsItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsEvents") );
  addItem( mTabNotificationsEventsItem, QStringLiteral( "TabNotificationsEvents" ) );
  mTabNotificationsEventsColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "TabNotificationsEventsColor" ), mTabNotificationsEventsColor, QColor( "#008000" ) );
  mTabNotificationsEventsColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsEventsColor") );
  addItem( mTabNotificationsEventsColorItem, QStringLiteral( "TabNotificationsEventsColor" ) );
  mTabNotificationsNickItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabNotificationsNick" ), mTabNotificationsNick, true );
  mTabNotificationsNickItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsNick") );
  addItem( mTabNotificationsNickItem, QStringLiteral( "TabNotificationsNick" ) );
  mTabNotificationsNickColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "TabNotificationsNickColor" ), mTabNotificationsNickColor, QColor( "#FF0000" ) );
  mTabNotificationsNickColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsNickColor") );
  addItem( mTabNotificationsNickColorItem, QStringLiteral( "TabNotificationsNickColor" ) );
  mTabNotificationsHighlightsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabNotificationsHighlights" ), mTabNotificationsHighlights, true );
  mTabNotificationsHighlightsItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsHighlights") );
  addItem( mTabNotificationsHighlightsItem, QStringLiteral( "TabNotificationsHighlights" ) );
  mTabNotificationsHighlightsColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "TabNotificationsHighlightsColor" ), mTabNotificationsHighlightsColor, QColor( "#FF0000" ) );
  mTabNotificationsHighlightsColorItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsHighlightsColor") );
  addItem( mTabNotificationsHighlightsColorItem, QStringLiteral( "TabNotificationsHighlightsColor" ) );
  mTabNotificationsOverrideItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabNotificationsOverride" ), mTabNotificationsOverride, false );
  mTabNotificationsOverrideItem->setLabel( QCoreApplication::translate("PreferencesBase", "TabNotificationsOverride") );
  addItem( mTabNotificationsOverrideItem, QStringLiteral( "TabNotificationsOverride" ) );

  setCurrentGroup( QStringLiteral( "Sort Nicknames" ) );

  mSortOrderItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SortOrder" ), mSortOrder, QStringLiteral( "qpohv-" ) );
  mSortOrderItem->setLabel( QCoreApplication::translate("PreferencesBase", "SortOrder") );
  addItem( mSortOrderItem, QStringLiteral( "SortOrder" ) );

  setCurrentGroup( QStringLiteral( "QueueRates" ) );


  const QList<int> defaultRate[3] = {
    { 15, 60, 0 },
    { 40, 60, 0 },
    {  1,  1, 0 },
  };
        
  mQueueRateItem[0] = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "EmptyingRate 0" ), mQueueRate[0], defaultRate[0] );
  mQueueRateItem[0]->setLabel( QCoreApplication::translate("PreferencesBase", "EmptyingRate queueRate$(QueueIndex)") );
  addItem( mQueueRateItem[0], QStringLiteral( "queueRate0" ) );
  mQueueRateItem[1] = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "EmptyingRate 1" ), mQueueRate[1], defaultRate[1] );
  mQueueRateItem[1]->setLabel( QCoreApplication::translate("PreferencesBase", "EmptyingRate queueRate$(QueueIndex)") );
  addItem( mQueueRateItem[1], QStringLiteral( "queueRate1" ) );
  mQueueRateItem[2] = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "EmptyingRate 2" ), mQueueRate[2], defaultRate[2] );
  mQueueRateItem[2]->setLabel( QCoreApplication::translate("PreferencesBase", "EmptyingRate queueRate$(QueueIndex)") );
  addItem( mQueueRateItem[2], QStringLiteral( "queueRate2" ) );
  mShowQueueTunerItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowQueueTuner" ), mShowQueueTuner, false );
  mShowQueueTunerItem->setLabel( QCoreApplication::translate("PreferencesBase", "ShowQueueTuner") );
  addItem( mShowQueueTunerItem, QStringLiteral( "ShowQueueTuner" ) );

  setCurrentGroup( QStringLiteral( "Proxy" ) );

  mProxyEnabledItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ProxyEnabled" ), mProxyEnabled, false );
  mProxyEnabledItem->setLabel( QCoreApplication::translate("PreferencesBase", "ProxyEnabled") );
  addItem( mProxyEnabledItem, QStringLiteral( "ProxyEnabled" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesProxyType;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Socksv5Proxy");
    valuesProxyType.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("HTTPProxy");
    valuesProxyType.append( choice );
  }
  mProxyTypeItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "ProxyType" ), mProxyType, valuesProxyType, Socksv5Proxy );
  mProxyTypeItem->setLabel( QCoreApplication::translate("PreferencesBase", "ProxyType") );
  addItem( mProxyTypeItem, QStringLiteral( "ProxyType" ) );
  mProxyAddressItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ProxyAddress" ), mProxyAddress );
  mProxyAddressItem->setLabel( QCoreApplication::translate("PreferencesBase", "ProxyAddress") );
  addItem( mProxyAddressItem, QStringLiteral( "ProxyAddress" ) );
  mProxyPortItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ProxyPort" ), mProxyPort, 8080 );
  mProxyPortItem->setLabel( QCoreApplication::translate("PreferencesBase", "ProxyPort") );
  addItem( mProxyPortItem, QStringLiteral( "ProxyPort" ) );
  mProxyUsernameItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ProxyUsername" ), mProxyUsername );
  mProxyUsernameItem->setLabel( QCoreApplication::translate("PreferencesBase", "ProxyUsername") );
  addItem( mProxyUsernameItem, QStringLiteral( "ProxyUsername" ) );
  mProxyPasswordItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ProxyPassword" ), mProxyPassword );
  mProxyPasswordItem->setLabel( QCoreApplication::translate("PreferencesBase", "ProxyPassword") );
  addItem( mProxyPasswordItem, QStringLiteral( "ProxyPassword" ) );
}

PreferencesBase::~PreferencesBase()
{
}

