/****************************************************************************
** Meta object code from reading C++ file 'ircview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/viewer/ircview.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ircview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17IrcViewMarkerLineE_t {};
} // unnamed namespace

template <> constexpr inline auto IrcViewMarkerLine::qt_create_metaobjectdata<qt_meta_tag_ZN17IrcViewMarkerLineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IrcViewMarkerLine"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IrcViewMarkerLine, qt_meta_tag_ZN17IrcViewMarkerLineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IrcViewMarkerLine::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IrcViewMarkerLineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IrcViewMarkerLineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IrcViewMarkerLineE_t>.metaTypes,
    nullptr
} };

void IrcViewMarkerLine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IrcViewMarkerLine *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *IrcViewMarkerLine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IrcViewMarkerLine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IrcViewMarkerLineE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QTextObjectInterface"))
        return static_cast< QTextObjectInterface*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QTextObjectInterface"))
        return static_cast< QTextObjectInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int IrcViewMarkerLine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7IRCViewE_t {};
} // unnamed namespace

template <> constexpr inline auto IRCView::qt_create_metaobjectdata<qt_meta_tag_ZN7IRCViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IRCView",
        "gotFocus",
        "",
        "textToLog",
        "text",
        "sendFile",
        "autoText",
        "textPasted",
        "useSelection",
        "urlsDropped",
        "QList<QUrl>",
        "urls",
        "doSearch",
        "doSearchNext",
        "doSearchPrevious",
        "setStatusBarTempText",
        "clearStatusBarTempText",
        "insertMarkerLine",
        "insertRememberLine",
        "cancelRememberLine",
        "clearLines",
        "blockDeleted",
        "Burr*",
        "b",
        "cullMarkedLine",
        "append",
        "nick",
        "message",
        "QHash<QString,QString>",
        "messageTags",
        "label",
        "appendRaw",
        "self",
        "appendLog",
        "appendQuery",
        "inChannel",
        "appendQueryAction",
        "appendChannelAction",
        "appendServerMessage",
        "type",
        "parseURL",
        "appendCommandMessage",
        "command",
        "appendBacklogMessage",
        "firstColumn",
        "findText",
        "findNextText",
        "findPreviousText",
        "increaseFontSize",
        "decreaseFontSize",
        "resetFontSize",
        "highlightedSlot",
        "QUrl",
        "link",
        "handleAnchorClicked",
        "url"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gotFocus'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textToLog'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'sendFile'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoText'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'textPasted'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'urlsDropped'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'doSearch'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doSearchNext'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doSearchPrevious'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setStatusBarTempText'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'clearStatusBarTempText'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertMarkerLine'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertRememberLine'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancelRememberLine'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearLines'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'blockDeleted'
        QtMocHelpers::SlotData<void(Burr *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'cullMarkedLine'
        QtMocHelpers::SlotData<void(int, int, int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'append'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'append'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'append'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'appendRaw'
        QtMocHelpers::SlotData<void(const QString &, bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'appendRaw'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'appendLog'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'appendQuery'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &, bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'appendQuery'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &)>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'appendQueryAction'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'appendChannelAction'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'appendServerMessage'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &, bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'appendServerMessage'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &)>(38, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 39 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'appendServerMessage'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(38, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 39 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'appendCommandMessage'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &, bool, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 42 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 }, { QMetaType::Bool, 40 },
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'appendCommandMessage'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &, bool)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 42 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'appendCommandMessage'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QHash<QString,QString> &)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 42 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'appendBacklogMessage'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'findText'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findNextText'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findPreviousText'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'increaseFontSize'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'decreaseFontSize'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetFontSize'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'highlightedSlot'
        QtMocHelpers::SlotData<void(const QUrl &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 53 },
        }}),
        // Slot 'handleAnchorClicked'
        QtMocHelpers::SlotData<void(const QUrl &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 55 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IRCView, qt_meta_tag_ZN7IRCViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IRCView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTextBrowser::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7IRCViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7IRCViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7IRCViewE_t>.metaTypes,
    nullptr
} };

void IRCView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IRCView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gotFocus(); break;
        case 1: _t->textToLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->sendFile(); break;
        case 3: _t->autoText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->textPasted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->urlsDropped((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 6: _t->doSearch(); break;
        case 7: _t->doSearchNext(); break;
        case 8: _t->doSearchPrevious(); break;
        case 9: _t->setStatusBarTempText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->clearStatusBarTempText(); break;
        case 11: _t->insertMarkerLine(); break;
        case 12: _t->insertRememberLine(); break;
        case 13: _t->cancelRememberLine(); break;
        case 14: _t->clearLines(); break;
        case 15: _t->blockDeleted((*reinterpret_cast<std::add_pointer_t<Burr*>>(_a[1]))); break;
        case 16: _t->cullMarkedLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 17: _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 18: _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3]))); break;
        case 19: _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->appendRaw((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 21: _t->appendRaw((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->appendLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->appendQuery((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 24: _t->appendQuery((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3]))); break;
        case 25: _t->appendQueryAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3]))); break;
        case 26: _t->appendChannelAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3]))); break;
        case 27: _t->appendServerMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 28: _t->appendServerMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3]))); break;
        case 29: _t->appendServerMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: _t->appendCommandMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 31: _t->appendCommandMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 32: _t->appendCommandMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QHash<QString,QString>>>(_a[3]))); break;
        case 33: _t->appendBacklogMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 34: _t->findText(); break;
        case 35: _t->findNextText(); break;
        case 36: _t->findPreviousText(); break;
        case 37: _t->increaseFontSize(); break;
        case 38: _t->decreaseFontSize(); break;
        case 39: _t->resetFontSize(); break;
        case 40: _t->highlightedSlot((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 41: _t->handleAnchorClicked((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)()>(_a, &IRCView::gotFocus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)(const QString & )>(_a, &IRCView::textToLog, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)()>(_a, &IRCView::sendFile, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)(const QString & )>(_a, &IRCView::autoText, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)(bool )>(_a, &IRCView::textPasted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)(const QList<QUrl> & )>(_a, &IRCView::urlsDropped, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)()>(_a, &IRCView::doSearch, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)()>(_a, &IRCView::doSearchNext, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)()>(_a, &IRCView::doSearchPrevious, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)(const QString & )>(_a, &IRCView::setStatusBarTempText, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (IRCView::*)()>(_a, &IRCView::clearStatusBarTempText, 10))
            return;
    }
}

const QMetaObject *IRCView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IRCView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7IRCViewE_t>.strings))
        return static_cast<void*>(this);
    return QTextBrowser::qt_metacast(_clname);
}

int IRCView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTextBrowser::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 42)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 42;
    }
    return _id;
}

// SIGNAL 0
void IRCView::gotFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IRCView::textToLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void IRCView::sendFile()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IRCView::autoText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void IRCView::textPasted(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void IRCView::urlsDropped(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void IRCView::doSearch()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void IRCView::doSearchNext()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void IRCView::doSearchPrevious()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void IRCView::setStatusBarTempText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void IRCView::clearStatusBarTempText()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
