/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
*/

/********************************************************************************
** Form generated from reading UI file 'dcc_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DCC_CONFIGUI_H
#define UI_DCC_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "kpluralhandlingspinbox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_DCC_ConfigUI
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *dccPathLbl;
    KUrlRequester *kcfg_DccPath;
    QCheckBox *kcfg_DccAddPartner;
    QCheckBox *kcfg_DccCreateFolder;
    QCheckBox *kcfg_DccSpaceToUnderscore;
    QCheckBox *kcfg_DccAutoGet;
    QCheckBox *kcfg_DccAutoResume;
    QCheckBox *kcfg_DccFastSend;
    QCheckBox *kcfg_DccPassiveSend;
    QCheckBox *kcfg_DccChatAutoAccept;
    QCheckBox *kcfg_DccUPnP;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_DccIPv4Fallback;
    QComboBox *kcfg_DccIPv4FallbackIface;
    QSpacerItem *horizontalSpacer;
    QLabel *textLabel7;
    KPluralHandlingSpinBox *kcfg_DccSendTimeout;
    QLabel *textLabel6;
    KPluralHandlingSpinBox *kcfg_DccBufferSize;
    QGroupBox *groupBox1;
    QFormLayout *formLayout_2;
    QLabel *textLabel4;
    QComboBox *kcfg_DccMethodToGetOwnIp;
    QLabel *ownIP;
    KLineEdit *kcfg_DccSpecificOwnIp;
    QGroupBox *groupBox2;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_DccSpecificSendPorts;
    QHBoxLayout *horizontalLayout_3;
    QSpinBox *kcfg_DccSendPortsFirst;
    QLabel *textLabel1_2;
    QSpinBox *kcfg_DccSendPortsLast;
    QCheckBox *kcfg_DccSpecificChatPorts;
    QHBoxLayout *horizontalLayout_4;
    QSpinBox *kcfg_DccChatPortsFirst;
    QLabel *textLabel2_2;
    QSpinBox *kcfg_DccChatPortsLast;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *spacer4_2;

    void setupUi(QWidget *DCC_ConfigUI)
    {
        if (DCC_ConfigUI->objectName().isEmpty())
            DCC_ConfigUI->setObjectName("DCC_ConfigUI");
        DCC_ConfigUI->resize(502, 575);
        verticalLayout = new QVBoxLayout(DCC_ConfigUI);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        dccPathLbl = new QLabel(DCC_ConfigUI);
        dccPathLbl->setObjectName("dccPathLbl");
        dccPathLbl->setWordWrap(false);

        horizontalLayout_2->addWidget(dccPathLbl);

        kcfg_DccPath = new KUrlRequester(DCC_ConfigUI);
        kcfg_DccPath->setObjectName("kcfg_DccPath");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_DccPath->sizePolicy().hasHeightForWidth());
        kcfg_DccPath->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(kcfg_DccPath);


        formLayout->setLayout(0, QFormLayout::ItemRole::SpanningRole, horizontalLayout_2);

        kcfg_DccAddPartner = new QCheckBox(DCC_ConfigUI);
        kcfg_DccAddPartner->setObjectName("kcfg_DccAddPartner");

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, kcfg_DccAddPartner);

        kcfg_DccCreateFolder = new QCheckBox(DCC_ConfigUI);
        kcfg_DccCreateFolder->setObjectName("kcfg_DccCreateFolder");

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, kcfg_DccCreateFolder);

        kcfg_DccSpaceToUnderscore = new QCheckBox(DCC_ConfigUI);
        kcfg_DccSpaceToUnderscore->setObjectName("kcfg_DccSpaceToUnderscore");

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, kcfg_DccSpaceToUnderscore);

        kcfg_DccAutoGet = new QCheckBox(DCC_ConfigUI);
        kcfg_DccAutoGet->setObjectName("kcfg_DccAutoGet");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, kcfg_DccAutoGet);

        kcfg_DccAutoResume = new QCheckBox(DCC_ConfigUI);
        kcfg_DccAutoResume->setObjectName("kcfg_DccAutoResume");

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, kcfg_DccAutoResume);

        kcfg_DccFastSend = new QCheckBox(DCC_ConfigUI);
        kcfg_DccFastSend->setObjectName("kcfg_DccFastSend");

        formLayout->setWidget(6, QFormLayout::ItemRole::SpanningRole, kcfg_DccFastSend);

        kcfg_DccPassiveSend = new QCheckBox(DCC_ConfigUI);
        kcfg_DccPassiveSend->setObjectName("kcfg_DccPassiveSend");

        formLayout->setWidget(7, QFormLayout::ItemRole::SpanningRole, kcfg_DccPassiveSend);

        kcfg_DccChatAutoAccept = new QCheckBox(DCC_ConfigUI);
        kcfg_DccChatAutoAccept->setObjectName("kcfg_DccChatAutoAccept");

        formLayout->setWidget(8, QFormLayout::ItemRole::SpanningRole, kcfg_DccChatAutoAccept);

        kcfg_DccUPnP = new QCheckBox(DCC_ConfigUI);
        kcfg_DccUPnP->setObjectName("kcfg_DccUPnP");

        formLayout->setWidget(9, QFormLayout::ItemRole::SpanningRole, kcfg_DccUPnP);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_DccIPv4Fallback = new QCheckBox(DCC_ConfigUI);
        kcfg_DccIPv4Fallback->setObjectName("kcfg_DccIPv4Fallback");

        horizontalLayout->addWidget(kcfg_DccIPv4Fallback);

        kcfg_DccIPv4FallbackIface = new QComboBox(DCC_ConfigUI);
        kcfg_DccIPv4FallbackIface->setObjectName("kcfg_DccIPv4FallbackIface");
        kcfg_DccIPv4FallbackIface->setEnabled(false);

        horizontalLayout->addWidget(kcfg_DccIPv4FallbackIface);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        formLayout->setLayout(10, QFormLayout::ItemRole::SpanningRole, horizontalLayout);

        textLabel7 = new QLabel(DCC_ConfigUI);
        textLabel7->setObjectName("textLabel7");
        textLabel7->setWordWrap(false);

        formLayout->setWidget(11, QFormLayout::ItemRole::LabelRole, textLabel7);

        kcfg_DccSendTimeout = new KPluralHandlingSpinBox(DCC_ConfigUI);
        kcfg_DccSendTimeout->setObjectName("kcfg_DccSendTimeout");
        kcfg_DccSendTimeout->setMinimum(1);
        kcfg_DccSendTimeout->setMaximum(300);

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, kcfg_DccSendTimeout);

        textLabel6 = new QLabel(DCC_ConfigUI);
        textLabel6->setObjectName("textLabel6");
        textLabel6->setWordWrap(false);

        formLayout->setWidget(12, QFormLayout::ItemRole::LabelRole, textLabel6);

        kcfg_DccBufferSize = new KPluralHandlingSpinBox(DCC_ConfigUI);
        kcfg_DccBufferSize->setObjectName("kcfg_DccBufferSize");
        kcfg_DccBufferSize->setMinimum(1024);
        kcfg_DccBufferSize->setMaximum(65536);
        kcfg_DccBufferSize->setSingleStep(128);

        formLayout->setWidget(12, QFormLayout::ItemRole::FieldRole, kcfg_DccBufferSize);


        verticalLayout->addLayout(formLayout);

        groupBox1 = new QGroupBox(DCC_ConfigUI);
        groupBox1->setObjectName("groupBox1");
        formLayout_2 = new QFormLayout(groupBox1);
        formLayout_2->setObjectName("formLayout_2");
        textLabel4 = new QLabel(groupBox1);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setWordWrap(false);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel4);

        kcfg_DccMethodToGetOwnIp = new QComboBox(groupBox1);
        kcfg_DccMethodToGetOwnIp->setObjectName("kcfg_DccMethodToGetOwnIp");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_DccMethodToGetOwnIp);

        ownIP = new QLabel(groupBox1);
        ownIP->setObjectName("ownIP");
        ownIP->setWordWrap(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, ownIP);

        kcfg_DccSpecificOwnIp = new KLineEdit(groupBox1);
        kcfg_DccSpecificOwnIp->setObjectName("kcfg_DccSpecificOwnIp");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_DccSpecificOwnIp);


        verticalLayout->addWidget(groupBox1);

        groupBox2 = new QGroupBox(DCC_ConfigUI);
        groupBox2->setObjectName("groupBox2");
        gridLayout = new QGridLayout(groupBox2);
        gridLayout->setObjectName("gridLayout");
        kcfg_DccSpecificSendPorts = new QCheckBox(groupBox2);
        kcfg_DccSpecificSendPorts->setObjectName("kcfg_DccSpecificSendPorts");

        gridLayout->addWidget(kcfg_DccSpecificSendPorts, 0, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        kcfg_DccSendPortsFirst = new QSpinBox(groupBox2);
        kcfg_DccSendPortsFirst->setObjectName("kcfg_DccSendPortsFirst");
        kcfg_DccSendPortsFirst->setEnabled(false);
        kcfg_DccSendPortsFirst->setMinimum(1026);
        kcfg_DccSendPortsFirst->setMaximum(65535);

        horizontalLayout_3->addWidget(kcfg_DccSendPortsFirst);

        textLabel1_2 = new QLabel(groupBox2);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setEnabled(false);
        textLabel1_2->setAlignment(Qt::AlignCenter);
        textLabel1_2->setWordWrap(false);

        horizontalLayout_3->addWidget(textLabel1_2);

        kcfg_DccSendPortsLast = new QSpinBox(groupBox2);
        kcfg_DccSendPortsLast->setObjectName("kcfg_DccSendPortsLast");
        kcfg_DccSendPortsLast->setEnabled(false);
        kcfg_DccSendPortsLast->setMinimum(1027);
        kcfg_DccSendPortsLast->setMaximum(65535);

        horizontalLayout_3->addWidget(kcfg_DccSendPortsLast);


        gridLayout->addLayout(horizontalLayout_3, 0, 1, 1, 1);

        kcfg_DccSpecificChatPorts = new QCheckBox(groupBox2);
        kcfg_DccSpecificChatPorts->setObjectName("kcfg_DccSpecificChatPorts");

        gridLayout->addWidget(kcfg_DccSpecificChatPorts, 1, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        kcfg_DccChatPortsFirst = new QSpinBox(groupBox2);
        kcfg_DccChatPortsFirst->setObjectName("kcfg_DccChatPortsFirst");
        kcfg_DccChatPortsFirst->setEnabled(false);
        kcfg_DccChatPortsFirst->setMinimum(1026);
        kcfg_DccChatPortsFirst->setMaximum(65535);

        horizontalLayout_4->addWidget(kcfg_DccChatPortsFirst);

        textLabel2_2 = new QLabel(groupBox2);
        textLabel2_2->setObjectName("textLabel2_2");
        textLabel2_2->setEnabled(false);
        textLabel2_2->setAlignment(Qt::AlignCenter);
        textLabel2_2->setWordWrap(false);

        horizontalLayout_4->addWidget(textLabel2_2);

        kcfg_DccChatPortsLast = new QSpinBox(groupBox2);
        kcfg_DccChatPortsLast->setObjectName("kcfg_DccChatPortsLast");
        kcfg_DccChatPortsLast->setEnabled(false);
        kcfg_DccChatPortsLast->setMinimum(1027);
        kcfg_DccChatPortsLast->setMaximum(65535);

        horizontalLayout_4->addWidget(kcfg_DccChatPortsLast);


        gridLayout->addLayout(horizontalLayout_4, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 2, 1, 1);


        verticalLayout->addWidget(groupBox2);

        spacer4_2 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacer4_2);

#if QT_CONFIG(shortcut)
        dccPathLbl->setBuddy(kcfg_DccPath);
        textLabel7->setBuddy(kcfg_DccSendTimeout);
        textLabel6->setBuddy(kcfg_DccBufferSize);
        textLabel4->setBuddy(kcfg_DccMethodToGetOwnIp);
        ownIP->setBuddy(kcfg_DccSpecificOwnIp);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_DccPath, kcfg_DccAddPartner);
        QWidget::setTabOrder(kcfg_DccAddPartner, kcfg_DccCreateFolder);
        QWidget::setTabOrder(kcfg_DccCreateFolder, kcfg_DccSpaceToUnderscore);
        QWidget::setTabOrder(kcfg_DccSpaceToUnderscore, kcfg_DccAutoGet);
        QWidget::setTabOrder(kcfg_DccAutoGet, kcfg_DccAutoResume);
        QWidget::setTabOrder(kcfg_DccAutoResume, kcfg_DccFastSend);
        QWidget::setTabOrder(kcfg_DccFastSend, kcfg_DccPassiveSend);
        QWidget::setTabOrder(kcfg_DccPassiveSend, kcfg_DccChatAutoAccept);
        QWidget::setTabOrder(kcfg_DccChatAutoAccept, kcfg_DccUPnP);
        QWidget::setTabOrder(kcfg_DccUPnP, kcfg_DccIPv4Fallback);
        QWidget::setTabOrder(kcfg_DccIPv4Fallback, kcfg_DccIPv4FallbackIface);
        QWidget::setTabOrder(kcfg_DccIPv4FallbackIface, kcfg_DccSendTimeout);
        QWidget::setTabOrder(kcfg_DccSendTimeout, kcfg_DccBufferSize);
        QWidget::setTabOrder(kcfg_DccBufferSize, kcfg_DccMethodToGetOwnIp);
        QWidget::setTabOrder(kcfg_DccMethodToGetOwnIp, kcfg_DccSpecificOwnIp);
        QWidget::setTabOrder(kcfg_DccSpecificOwnIp, kcfg_DccSpecificSendPorts);
        QWidget::setTabOrder(kcfg_DccSpecificSendPorts, kcfg_DccSendPortsFirst);
        QWidget::setTabOrder(kcfg_DccSendPortsFirst, kcfg_DccSendPortsLast);
        QWidget::setTabOrder(kcfg_DccSendPortsLast, kcfg_DccSpecificChatPorts);
        QWidget::setTabOrder(kcfg_DccSpecificChatPorts, kcfg_DccChatPortsFirst);
        QWidget::setTabOrder(kcfg_DccChatPortsFirst, kcfg_DccChatPortsLast);

        retranslateUi(DCC_ConfigUI);
        QObject::connect(kcfg_DccSpecificSendPorts, &QCheckBox::toggled, kcfg_DccSendPortsFirst, &QSpinBox::setEnabled);
        QObject::connect(kcfg_DccSpecificSendPorts, &QCheckBox::toggled, textLabel1_2, &QLabel::setEnabled);
        QObject::connect(kcfg_DccSpecificSendPorts, &QCheckBox::toggled, kcfg_DccSendPortsLast, &QSpinBox::setEnabled);
        QObject::connect(kcfg_DccSpecificChatPorts, &QCheckBox::toggled, kcfg_DccChatPortsFirst, &QSpinBox::setEnabled);
        QObject::connect(kcfg_DccSpecificChatPorts, &QCheckBox::toggled, textLabel2_2, &QLabel::setEnabled);
        QObject::connect(kcfg_DccSpecificChatPorts, &QCheckBox::toggled, kcfg_DccChatPortsLast, &QSpinBox::setEnabled);
        QObject::connect(kcfg_DccIPv4Fallback, &QCheckBox::toggled, kcfg_DccIPv4FallbackIface, &QComboBox::setEnabled);

        QMetaObject::connectSlotsByName(DCC_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *DCC_ConfigUI)
    {
        DCC_ConfigUI->setWindowTitle(tr2i18n("DCC_Settings", nullptr));
        dccPathLbl->setText(tr2i18n("Download &folder:", nullptr));
        kcfg_DccAddPartner->setText(tr2i18n("&Add sender to file name", nullptr));
        kcfg_DccCreateFolder->setText(tr2i18n("Cr&eate folder for sender", nullptr));
        kcfg_DccSpaceToUnderscore->setText(tr2i18n("Convert spaces in file names to underscores before sending", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_DccSpaceToUnderscore->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        kcfg_DccAutoGet->setText(tr2i18n("Automaticall&y accept download offer", nullptr));
        kcfg_DccAutoResume->setText(tr2i18n("Au&tomatically resume download", nullptr));
        kcfg_DccFastSend->setText(tr2i18n("Enable fast DCC send (Might &not work with all clients)", nullptr));
        kcfg_DccPassiveSend->setText(tr2i18n("Enable passive DCC send", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_DccPassiveSend->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        kcfg_DccChatAutoAccept->setText(tr2i18n("Automatically accept DCC chat offer", nullptr));
        kcfg_DccUPnP->setText(tr2i18n("Enable UPnP for NAT traversal", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_DccIPv4Fallback->setWhatsThis(tr2i18n("If this option enabled dcc transfers for IPv6 connections will be done over IPv4 interface set here", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_DccIPv4Fallback->setText(tr2i18n("Fallback to an IPv&4 interface for DCC send:", nullptr));
        textLabel7->setText(tr2i18n("DCC send t&imeout:", nullptr));
        textLabel6->setText(tr2i18n("Buffer si&ze:", nullptr));
        groupBox1->setTitle(tr2i18n("IP", nullptr));
        textLabel4->setText(tr2i18n("&Method to get own IP:", nullptr));
        ownIP->setText(tr2i18n("O&wn IP:", nullptr));
        groupBox2->setTitle(tr2i18n("Ports", nullptr));
        kcfg_DccSpecificSendPorts->setText(tr2i18n("Enable specific &ports for DCC transfer server:", nullptr));
        textLabel1_2->setText(tr2i18n("to", nullptr));
        kcfg_DccSpecificChatPorts->setText(tr2i18n("Enable specific p&orts for DCC chat:", nullptr));
        textLabel2_2->setText(tr2i18n("to", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DCC_ConfigUI: public Ui_DCC_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DCC_CONFIGUI_H

