/********************************************************************************
** Form generated from reading UI file 'highlight_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HIGHLIGHT_CONFIGUI_H
#define UI_HIGHLIGHT_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "highlighttreewidget.h"
#include "kcolorbutton.h"
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_Highlight_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QCheckBox *kcfg_HighlightSoundsEnabled;
    KColorButton *kcfg_HighlightNickColor;
    KColorButton *kcfg_HighlightOwnLinesColor;
    QCheckBox *kcfg_HighlightNick;
    QCheckBox *kcfg_HighlightOwnLines;
    QSpacerItem *spacer11;
    QSpacerItem *spacer1;
    QSpacerItem *spacer2;
    QGroupBox *groupBox1;
    QGridLayout *highlightLayout;
    HighlightTreeWidget *highlightListView;
    QVBoxLayout *vboxLayout;
    QPushButton *newButton;
    QPushButton *removeButton;
    QSpacerItem *spacer27;
    QFormLayout *formLayout;
    QLabel *patternLabel;
    KLineEdit *patternInput;
    QLabel *colorLabel;
    KColorButton *patternColor;
    QLabel *soundLabel;
    QHBoxLayout *horizontalLayout_2;
    KUrlRequester *soundURL;
    QToolButton *soundPlayBtn;
    QLabel *autoTextLabel;
    KLineEdit *autoTextInput;
    QLabel *chatWindowsLabel;
    KLineEdit *chatWindowsInput;
    QLabel *enableNotificationsLabel;
    QCheckBox *enableNotificationsCheckbox;

    void setupUi(QWidget *Highlight_ConfigUI)
    {
        if (Highlight_ConfigUI->objectName().isEmpty())
            Highlight_ConfigUI->setObjectName("Highlight_ConfigUI");
        Highlight_ConfigUI->resize(614, 585);
        gridLayout = new QGridLayout(Highlight_ConfigUI);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_HighlightSoundsEnabled = new QCheckBox(Highlight_ConfigUI);
        kcfg_HighlightSoundsEnabled->setObjectName("kcfg_HighlightSoundsEnabled");

        gridLayout->addWidget(kcfg_HighlightSoundsEnabled, 1, 0, 1, 1);

        kcfg_HighlightNickColor = new KColorButton(Highlight_ConfigUI);
        kcfg_HighlightNickColor->setObjectName("kcfg_HighlightNickColor");
        kcfg_HighlightNickColor->setEnabled(false);

        gridLayout->addWidget(kcfg_HighlightNickColor, 2, 1, 1, 1);

        kcfg_HighlightOwnLinesColor = new KColorButton(Highlight_ConfigUI);
        kcfg_HighlightOwnLinesColor->setObjectName("kcfg_HighlightOwnLinesColor");
        kcfg_HighlightOwnLinesColor->setEnabled(false);

        gridLayout->addWidget(kcfg_HighlightOwnLinesColor, 3, 1, 1, 1);

        kcfg_HighlightNick = new QCheckBox(Highlight_ConfigUI);
        kcfg_HighlightNick->setObjectName("kcfg_HighlightNick");

        gridLayout->addWidget(kcfg_HighlightNick, 2, 0, 1, 1);

        kcfg_HighlightOwnLines = new QCheckBox(Highlight_ConfigUI);
        kcfg_HighlightOwnLines->setObjectName("kcfg_HighlightOwnLines");

        gridLayout->addWidget(kcfg_HighlightOwnLines, 3, 0, 1, 1);

        spacer11 = new QSpacerItem(120, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer11, 1, 1, 1, 2);

        spacer1 = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer1, 2, 2, 1, 1);

        spacer2 = new QSpacerItem(50, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer2, 3, 2, 1, 1);

        groupBox1 = new QGroupBox(Highlight_ConfigUI);
        groupBox1->setObjectName("groupBox1");
        highlightLayout = new QGridLayout(groupBox1);
        highlightLayout->setObjectName("highlightLayout");
        highlightListView = new HighlightTreeWidget(groupBox1);
        highlightListView->setObjectName("highlightListView");
        highlightListView->setAcceptDrops(true);
        highlightListView->setDragEnabled(true);
        highlightListView->setDragDropMode(QAbstractItemView::InternalMove);
        highlightListView->setRootIsDecorated(false);
        highlightListView->setAllColumnsShowFocus(true);

        highlightLayout->addWidget(highlightListView, 0, 0, 1, 1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        newButton = new QPushButton(groupBox1);
        newButton->setObjectName("newButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(newButton->sizePolicy().hasHeightForWidth());
        newButton->setSizePolicy(sizePolicy);

        vboxLayout->addWidget(newButton);

        removeButton = new QPushButton(groupBox1);
        removeButton->setObjectName("removeButton");
        sizePolicy.setHeightForWidth(removeButton->sizePolicy().hasHeightForWidth());
        removeButton->setSizePolicy(sizePolicy);

        vboxLayout->addWidget(removeButton);

        spacer27 = new QSpacerItem(20, 250, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer27);


        highlightLayout->addLayout(vboxLayout, 0, 1, 1, 1);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        patternLabel = new QLabel(groupBox1);
        patternLabel->setObjectName("patternLabel");
        patternLabel->setEnabled(false);
        patternLabel->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, patternLabel);

        patternInput = new KLineEdit(groupBox1);
        patternInput->setObjectName("patternInput");
        patternInput->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(patternInput->sizePolicy().hasHeightForWidth());
        patternInput->setSizePolicy(sizePolicy1);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, patternInput);

        colorLabel = new QLabel(groupBox1);
        colorLabel->setObjectName("colorLabel");
        colorLabel->setEnabled(false);
        colorLabel->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, colorLabel);

        patternColor = new KColorButton(groupBox1);
        patternColor->setObjectName("patternColor");
        patternColor->setEnabled(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, patternColor);

        soundLabel = new QLabel(groupBox1);
        soundLabel->setObjectName("soundLabel");
        soundLabel->setEnabled(false);
        soundLabel->setWordWrap(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, soundLabel);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        soundURL = new KUrlRequester(groupBox1);
        soundURL->setObjectName("soundURL");
        soundURL->setEnabled(false);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(soundURL->sizePolicy().hasHeightForWidth());
        soundURL->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(soundURL);

        soundPlayBtn = new QToolButton(groupBox1);
        soundPlayBtn->setObjectName("soundPlayBtn");
        soundPlayBtn->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(soundPlayBtn->sizePolicy().hasHeightForWidth());
        soundPlayBtn->setSizePolicy(sizePolicy3);

        horizontalLayout_2->addWidget(soundPlayBtn);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        autoTextLabel = new QLabel(groupBox1);
        autoTextLabel->setObjectName("autoTextLabel");
        autoTextLabel->setEnabled(false);
        autoTextLabel->setWordWrap(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, autoTextLabel);

        autoTextInput = new KLineEdit(groupBox1);
        autoTextInput->setObjectName("autoTextInput");
        autoTextInput->setEnabled(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, autoTextInput);

        chatWindowsLabel = new QLabel(groupBox1);
        chatWindowsLabel->setObjectName("chatWindowsLabel");
        chatWindowsLabel->setEnabled(false);
        chatWindowsLabel->setWordWrap(false);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, chatWindowsLabel);

        chatWindowsInput = new KLineEdit(groupBox1);
        chatWindowsInput->setObjectName("chatWindowsInput");
        chatWindowsInput->setEnabled(false);
        sizePolicy1.setHeightForWidth(chatWindowsInput->sizePolicy().hasHeightForWidth());
        chatWindowsInput->setSizePolicy(sizePolicy1);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, chatWindowsInput);

        enableNotificationsLabel = new QLabel(groupBox1);
        enableNotificationsLabel->setObjectName("enableNotificationsLabel");
        enableNotificationsLabel->setEnabled(false);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, enableNotificationsLabel);

        enableNotificationsCheckbox = new QCheckBox(groupBox1);
        enableNotificationsCheckbox->setObjectName("enableNotificationsCheckbox");
        enableNotificationsCheckbox->setEnabled(false);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, enableNotificationsCheckbox);


        highlightLayout->addLayout(formLayout, 1, 0, 1, 1);


        gridLayout->addWidget(groupBox1, 0, 0, 1, 3);

#if QT_CONFIG(shortcut)
        patternLabel->setBuddy(patternInput);
        soundLabel->setBuddy(soundURL);
        autoTextLabel->setBuddy(autoTextInput);
        chatWindowsLabel->setBuddy(chatWindowsInput);
        enableNotificationsLabel->setBuddy(enableNotificationsCheckbox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(highlightListView, newButton);
        QWidget::setTabOrder(newButton, removeButton);
        QWidget::setTabOrder(removeButton, patternInput);
        QWidget::setTabOrder(patternInput, patternColor);
        QWidget::setTabOrder(patternColor, soundURL);
        QWidget::setTabOrder(soundURL, soundPlayBtn);
        QWidget::setTabOrder(soundPlayBtn, autoTextInput);
        QWidget::setTabOrder(autoTextInput, chatWindowsInput);
        QWidget::setTabOrder(chatWindowsInput, enableNotificationsCheckbox);
        QWidget::setTabOrder(enableNotificationsCheckbox, kcfg_HighlightSoundsEnabled);
        QWidget::setTabOrder(kcfg_HighlightSoundsEnabled, kcfg_HighlightNick);
        QWidget::setTabOrder(kcfg_HighlightNick, kcfg_HighlightNickColor);
        QWidget::setTabOrder(kcfg_HighlightNickColor, kcfg_HighlightOwnLines);
        QWidget::setTabOrder(kcfg_HighlightOwnLines, kcfg_HighlightOwnLinesColor);

        retranslateUi(Highlight_ConfigUI);
        QObject::connect(kcfg_HighlightNick, SIGNAL(toggled(bool)), kcfg_HighlightNickColor, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_HighlightOwnLines, SIGNAL(toggled(bool)), kcfg_HighlightOwnLinesColor, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(Highlight_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *Highlight_ConfigUI)
    {
        kcfg_HighlightSoundsEnabled->setText(tr2i18n("Ena&ble sound for highlights", nullptr));
        kcfg_HighlightNickColor->setText(QString());
        kcfg_HighlightOwnLinesColor->setText(QString());
        kcfg_HighlightNick->setText(tr2i18n("Alwa&ys highlight own current nick:", nullptr));
        kcfg_HighlightOwnLines->setText(tr2i18n("Always highlight own &lines:", nullptr));
        groupBox1->setTitle(tr2i18n("Highlight List", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = highlightListView->headerItem();
        ___qtreewidgetitem->setText(4, tr2i18n("Chat Windows", nullptr));
        ___qtreewidgetitem->setText(3, tr2i18n("Auto Text", nullptr));
        ___qtreewidgetitem->setText(2, tr2i18n("Sound", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Highlights", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("RegEx", nullptr));
        newButton->setText(tr2i18n("&New", nullptr));
        removeButton->setText(tr2i18n("&Remove", nullptr));
        patternLabel->setText(tr2i18n("&Pattern:", nullptr));
        colorLabel->setText(tr2i18n("Color:", nullptr));
        patternColor->setText(QString());
        soundLabel->setText(tr2i18n("&Sound:", nullptr));
#if QT_CONFIG(tooltip)
        soundPlayBtn->setToolTip(tr2i18n("Test sound", nullptr));
#endif // QT_CONFIG(tooltip)
        soundPlayBtn->setText(QString());
        autoTextLabel->setText(tr2i18n("A&uto text:", nullptr));
        chatWindowsLabel->setText(tr2i18n("Chat windows:", nullptr));
#if QT_CONFIG(whatsthis)
        chatWindowsInput->setWhatsThis(tr2i18n("This highlight will only be searched for in chat windows listed here by name, or in all chat windows if the field is left empty. Multiple names have to be separated by commas.", nullptr));
#endif // QT_CONFIG(whatsthis)
        enableNotificationsLabel->setText(tr2i18n("Enable &notifications:", nullptr));
        enableNotificationsCheckbox->setText(QString());
        (void)Highlight_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class Highlight_ConfigUI: public Ui_Highlight_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // HIGHLIGHT_CONFIGUI_H

