/****************************************************************************
** Meta object code from reading C++ file 'transfermanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/dcc/transfermanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transfermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Konversation3DCC15TransferManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::DCC::TransferManager::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation3DCC15TransferManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::DCC::TransferManager",
        "newTransferAdded",
        "",
        "Konversation::DCC::Transfer*",
        "transfer",
        "newDccTransferQueued",
        "fileURLChanged",
        "Konversation::DCC::TransferRecv*",
        "slotTransferStatusChanged",
        "item",
        "newStatus",
        "oldStatus",
        "removeSendItem",
        "removeRecvItem",
        "removeChatItem",
        "Konversation::DCC::Chat*",
        "chat",
        "slotSettingsChanged",
        "upnpRouterDiscovered",
        "Konversation::UPnP::UPnPRouter*",
        "router"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newTransferAdded'
        QtMocHelpers::SignalData<void(Konversation::DCC::Transfer *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'newDccTransferQueued'
        QtMocHelpers::SignalData<void(Konversation::DCC::Transfer *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fileURLChanged'
        QtMocHelpers::SignalData<void(Konversation::DCC::TransferRecv *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 4 },
        }}),
        // Slot 'slotTransferStatusChanged'
        QtMocHelpers::SlotData<void(Konversation::DCC::Transfer *, int, int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'removeSendItem'
        QtMocHelpers::SlotData<void(Konversation::DCC::Transfer *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 9 },
        }}),
        // Slot 'removeRecvItem'
        QtMocHelpers::SlotData<void(Konversation::DCC::Transfer *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 9 },
        }}),
        // Slot 'removeChatItem'
        QtMocHelpers::SlotData<void(Konversation::DCC::Chat *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotSettingsChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'upnpRouterDiscovered'
        QtMocHelpers::SlotData<void(Konversation::UPnP::UPnPRouter *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferManager, qt_meta_tag_ZN12Konversation3DCC15TransferManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konversation::DCC::TransferManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC15TransferManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC15TransferManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation3DCC15TransferManagerE_t>.metaTypes,
    nullptr
} };

void Konversation::DCC::TransferManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newTransferAdded((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1]))); break;
        case 1: _t->newDccTransferQueued((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1]))); break;
        case 2: _t->fileURLChanged((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::TransferRecv*>>(_a[1]))); break;
        case 3: _t->slotTransferStatusChanged((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->removeSendItem((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1]))); break;
        case 5: _t->removeRecvItem((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[1]))); break;
        case 6: _t->removeChatItem((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Chat*>>(_a[1]))); break;
        case 7: _t->slotSettingsChanged(); break;
        case 8: _t->upnpRouterDiscovered((*reinterpret_cast<std::add_pointer_t<Konversation::UPnP::UPnPRouter*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransferManager::*)(Konversation::DCC::Transfer * )>(_a, &TransferManager::newTransferAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferManager::*)(Konversation::DCC::Transfer * )>(_a, &TransferManager::newDccTransferQueued, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferManager::*)(Konversation::DCC::TransferRecv * )>(_a, &TransferManager::fileURLChanged, 2))
            return;
    }
}

const QMetaObject *Konversation::DCC::TransferManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::TransferManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC15TransferManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::DCC::TransferManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::TransferManager::newTransferAdded(Konversation::DCC::Transfer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Konversation::DCC::TransferManager::newDccTransferQueued(Konversation::DCC::Transfer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Konversation::DCC::TransferManager::fileURLChanged(Konversation::DCC::TransferRecv * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
