/********************************************************************************
** Form generated from reading UI file 'autoreplace_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOREPLACE_CONFIGUI_H
#define UI_AUTOREPLACE_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_Autoreplace_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QTreeWidget *patternListView;
    QVBoxLayout *vboxLayout;
    QPushButton *newButton;
    QPushButton *removeButton;
    QSpacerItem *spacer1;
    QFormLayout *formLayout;
    QLabel *directionLabel;
    QComboBox *directionCombo;
    QLabel *patternLabel;
    KLineEdit *patternInput;
    QLabel *replacementLabel;
    KLineEdit *replacementInput;

    void setupUi(QWidget *Autoreplace_ConfigUI)
    {
        if (Autoreplace_ConfigUI->objectName().isEmpty())
            Autoreplace_ConfigUI->setObjectName("Autoreplace_ConfigUI");
        Autoreplace_ConfigUI->resize(586, 576);
        gridLayout = new QGridLayout(Autoreplace_ConfigUI);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        patternListView = new QTreeWidget(Autoreplace_ConfigUI);
        patternListView->setObjectName("patternListView");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(patternListView->sizePolicy().hasHeightForWidth());
        patternListView->setSizePolicy(sizePolicy);
        patternListView->setAcceptDrops(true);
        patternListView->setDragEnabled(true);
        patternListView->setDragDropMode(QAbstractItemView::InternalMove);
        patternListView->setRootIsDecorated(false);
        patternListView->setAllColumnsShowFocus(true);
        patternListView->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout->addWidget(patternListView, 0, 0, 1, 1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        newButton = new QPushButton(Autoreplace_ConfigUI);
        newButton->setObjectName("newButton");

        vboxLayout->addWidget(newButton);

        removeButton = new QPushButton(Autoreplace_ConfigUI);
        removeButton->setObjectName("removeButton");

        vboxLayout->addWidget(removeButton);

        spacer1 = new QSpacerItem(20, 506, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer1);


        gridLayout->addLayout(vboxLayout, 0, 1, 2, 1);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        directionLabel = new QLabel(Autoreplace_ConfigUI);
        directionLabel->setObjectName("directionLabel");
        directionLabel->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(directionLabel->sizePolicy().hasHeightForWidth());
        directionLabel->setSizePolicy(sizePolicy1);
        directionLabel->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, directionLabel);

        directionCombo = new QComboBox(Autoreplace_ConfigUI);
        directionCombo->setObjectName("directionCombo");
        directionCombo->setEnabled(false);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(directionCombo->sizePolicy().hasHeightForWidth());
        directionCombo->setSizePolicy(sizePolicy2);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, directionCombo);

        patternLabel = new QLabel(Autoreplace_ConfigUI);
        patternLabel->setObjectName("patternLabel");
        patternLabel->setEnabled(false);
        sizePolicy1.setHeightForWidth(patternLabel->sizePolicy().hasHeightForWidth());
        patternLabel->setSizePolicy(sizePolicy1);
        patternLabel->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, patternLabel);

        patternInput = new KLineEdit(Autoreplace_ConfigUI);
        patternInput->setObjectName("patternInput");
        patternInput->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(patternInput->sizePolicy().hasHeightForWidth());
        patternInput->setSizePolicy(sizePolicy3);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, patternInput);

        replacementLabel = new QLabel(Autoreplace_ConfigUI);
        replacementLabel->setObjectName("replacementLabel");
        replacementLabel->setEnabled(false);
        sizePolicy1.setHeightForWidth(replacementLabel->sizePolicy().hasHeightForWidth());
        replacementLabel->setSizePolicy(sizePolicy1);
        replacementLabel->setWordWrap(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, replacementLabel);

        replacementInput = new KLineEdit(Autoreplace_ConfigUI);
        replacementInput->setObjectName("replacementInput");
        replacementInput->setEnabled(false);
        sizePolicy3.setHeightForWidth(replacementInput->sizePolicy().hasHeightForWidth());
        replacementInput->setSizePolicy(sizePolicy3);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, replacementInput);


        gridLayout->addLayout(formLayout, 1, 0, 1, 1);

        QWidget::setTabOrder(patternListView, newButton);
        QWidget::setTabOrder(newButton, removeButton);
        QWidget::setTabOrder(removeButton, directionCombo);
        QWidget::setTabOrder(directionCombo, patternInput);
        QWidget::setTabOrder(patternInput, replacementInput);

        retranslateUi(Autoreplace_ConfigUI);

        QMetaObject::connectSlotsByName(Autoreplace_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *Autoreplace_ConfigUI)
    {
        QTreeWidgetItem *___qtreewidgetitem = patternListView->headerItem();
        ___qtreewidgetitem->setText(3, tr2i18n("Replace With", nullptr));
        ___qtreewidgetitem->setText(2, tr2i18n("Find", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Replace In", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("RegEx", nullptr));
        newButton->setText(tr2i18n("Ne&w", nullptr));
        removeButton->setText(tr2i18n("R&emove", nullptr));
        directionLabel->setText(tr2i18n("Replace in:", nullptr));
        patternLabel->setText(tr2i18n("Find:", nullptr));
        replacementLabel->setText(tr2i18n("Replace with:", nullptr));
        (void)Autoreplace_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class Autoreplace_ConfigUI: public Ui_Autoreplace_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // AUTOREPLACE_CONFIGUI_H

