/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

*/

/********************************************************************************
** Form generated from reading UI file 'generalbehavior_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALBEHAVIOR_CONFIGUI_H
#define UI_GENERALBEHAVIOR_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_GeneralBehavior_ConfigUI
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *kcfg_ShowTrayIcon;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_TrayNotify;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *indentTrayNotifyOnlyOwnNickSpacer;
    QCheckBox *kcfg_TrayNotifyOnlyOwnNick;
    QCheckBox *kcfg_TrayActivateNoWindow;
    QCheckBox *kcfg_HideToTrayOnStartup;
    QGroupBox *middleLabel;
    QFormLayout *formLayout;
    QLabel *modeLbl;
    QComboBox *kcfg_NickCompletionMode;
    QLabel *startOfLineLabel;
    QHBoxLayout *horizontalLayout_2;
    KLineEdit *kcfg_NickCompleteSuffixStart;
    QLabel *textLabel3;
    KLineEdit *kcfg_NickCompleteSuffixMiddle;
    QSpacerItem *horizontalSpacer;
    QCheckBox *kcfg_NickCompletionCaseSensitive;
    QGroupBox *miscGBox;
    QFormLayout *formLayout_2;
    QCheckBox *kcfg_DisableNotifyWhileAway;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *kcfg_UseCustomBrowser;
    KLineEdit *kcfg_WebBrowserCmd;
    QLabel *commandCharLabel;
    KLineEdit *kcfg_CommandChar;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *kcfg_CustomVersionReplyEnabled;
    KLineEdit *kcfg_CustomVersionReply;
    QCheckBox *kcfg_UseMultiRowInputBox;
    QSpacerItem *spacer52;

    void setupUi(QWidget *GeneralBehavior_ConfigUI)
    {
        if (GeneralBehavior_ConfigUI->objectName().isEmpty())
            GeneralBehavior_ConfigUI->setObjectName("GeneralBehavior_ConfigUI");
        GeneralBehavior_ConfigUI->resize(508, 477);
        verticalLayout_2 = new QVBoxLayout(GeneralBehavior_ConfigUI);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_ShowTrayIcon = new QGroupBox(GeneralBehavior_ConfigUI);
        kcfg_ShowTrayIcon->setObjectName("kcfg_ShowTrayIcon");
        kcfg_ShowTrayIcon->setCheckable(true);
        kcfg_ShowTrayIcon->setChecked(false);
        verticalLayout = new QVBoxLayout(kcfg_ShowTrayIcon);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_TrayNotify = new QCheckBox(kcfg_ShowTrayIcon);
        kcfg_TrayNotify->setObjectName("kcfg_TrayNotify");

        verticalLayout->addWidget(kcfg_TrayNotify);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        indentTrayNotifyOnlyOwnNickSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(indentTrayNotifyOnlyOwnNickSpacer);

        kcfg_TrayNotifyOnlyOwnNick = new QCheckBox(kcfg_ShowTrayIcon);
        kcfg_TrayNotifyOnlyOwnNick->setObjectName("kcfg_TrayNotifyOnlyOwnNick");
        kcfg_TrayNotifyOnlyOwnNick->setEnabled(false);

        horizontalLayout->addWidget(kcfg_TrayNotifyOnlyOwnNick);


        verticalLayout->addLayout(horizontalLayout);

        kcfg_TrayActivateNoWindow = new QCheckBox(kcfg_ShowTrayIcon);
        kcfg_TrayActivateNoWindow->setObjectName("kcfg_TrayActivateNoWindow");

        verticalLayout->addWidget(kcfg_TrayActivateNoWindow);

        kcfg_HideToTrayOnStartup = new QCheckBox(kcfg_ShowTrayIcon);
        kcfg_HideToTrayOnStartup->setObjectName("kcfg_HideToTrayOnStartup");

        verticalLayout->addWidget(kcfg_HideToTrayOnStartup);


        verticalLayout_2->addWidget(kcfg_ShowTrayIcon);

        middleLabel = new QGroupBox(GeneralBehavior_ConfigUI);
        middleLabel->setObjectName("middleLabel");
        formLayout = new QFormLayout(middleLabel);
        formLayout->setObjectName("formLayout");
        modeLbl = new QLabel(middleLabel);
        modeLbl->setObjectName("modeLbl");
        modeLbl->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, modeLbl);

        kcfg_NickCompletionMode = new QComboBox(middleLabel);
        kcfg_NickCompletionMode->addItem(QString());
        kcfg_NickCompletionMode->addItem(QString());
        kcfg_NickCompletionMode->addItem(QString());
        kcfg_NickCompletionMode->setObjectName("kcfg_NickCompletionMode");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_NickCompletionMode);

        startOfLineLabel = new QLabel(middleLabel);
        startOfLineLabel->setObjectName("startOfLineLabel");
        startOfLineLabel->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, startOfLineLabel);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_NickCompleteSuffixStart = new KLineEdit(middleLabel);
        kcfg_NickCompleteSuffixStart->setObjectName("kcfg_NickCompleteSuffixStart");

        horizontalLayout_2->addWidget(kcfg_NickCompleteSuffixStart);

        textLabel3 = new QLabel(middleLabel);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        horizontalLayout_2->addWidget(textLabel3);

        kcfg_NickCompleteSuffixMiddle = new KLineEdit(middleLabel);
        kcfg_NickCompleteSuffixMiddle->setObjectName("kcfg_NickCompleteSuffixMiddle");

        horizontalLayout_2->addWidget(kcfg_NickCompleteSuffixMiddle);

        horizontalSpacer = new QSpacerItem(40, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        kcfg_NickCompletionCaseSensitive = new QCheckBox(middleLabel);
        kcfg_NickCompletionCaseSensitive->setObjectName("kcfg_NickCompletionCaseSensitive");

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, kcfg_NickCompletionCaseSensitive);


        verticalLayout_2->addWidget(middleLabel);

        miscGBox = new QGroupBox(GeneralBehavior_ConfigUI);
        miscGBox->setObjectName("miscGBox");
        formLayout_2 = new QFormLayout(miscGBox);
        formLayout_2->setObjectName("formLayout_2");
        kcfg_DisableNotifyWhileAway = new QCheckBox(miscGBox);
        kcfg_DisableNotifyWhileAway->setObjectName("kcfg_DisableNotifyWhileAway");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::SpanningRole, kcfg_DisableNotifyWhileAway);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        kcfg_UseCustomBrowser = new QCheckBox(miscGBox);
        kcfg_UseCustomBrowser->setObjectName("kcfg_UseCustomBrowser");

        horizontalLayout_4->addWidget(kcfg_UseCustomBrowser);

        kcfg_WebBrowserCmd = new KLineEdit(miscGBox);
        kcfg_WebBrowserCmd->setObjectName("kcfg_WebBrowserCmd");
        kcfg_WebBrowserCmd->setEnabled(false);

        horizontalLayout_4->addWidget(kcfg_WebBrowserCmd);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::SpanningRole, horizontalLayout_4);

        commandCharLabel = new QLabel(miscGBox);
        commandCharLabel->setObjectName("commandCharLabel");
        commandCharLabel->setWordWrap(false);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, commandCharLabel);

        kcfg_CommandChar = new KLineEdit(miscGBox);
        kcfg_CommandChar->setObjectName("kcfg_CommandChar");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_CommandChar->sizePolicy().hasHeightForWidth());
        kcfg_CommandChar->setSizePolicy(sizePolicy);
        kcfg_CommandChar->setMaxLength(1);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_CommandChar);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        kcfg_CustomVersionReplyEnabled = new QCheckBox(miscGBox);
        kcfg_CustomVersionReplyEnabled->setObjectName("kcfg_CustomVersionReplyEnabled");

        horizontalLayout_3->addWidget(kcfg_CustomVersionReplyEnabled);

        kcfg_CustomVersionReply = new KLineEdit(miscGBox);
        kcfg_CustomVersionReply->setObjectName("kcfg_CustomVersionReply");
        kcfg_CustomVersionReply->setEnabled(false);

        horizontalLayout_3->addWidget(kcfg_CustomVersionReply);


        formLayout_2->setLayout(3, QFormLayout::ItemRole::SpanningRole, horizontalLayout_3);

        kcfg_UseMultiRowInputBox = new QCheckBox(miscGBox);
        kcfg_UseMultiRowInputBox->setObjectName("kcfg_UseMultiRowInputBox");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::SpanningRole, kcfg_UseMultiRowInputBox);


        verticalLayout_2->addWidget(miscGBox);

        spacer52 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacer52);

#if QT_CONFIG(shortcut)
        modeLbl->setBuddy(kcfg_NickCompletionMode);
        startOfLineLabel->setBuddy(kcfg_NickCompleteSuffixStart);
        textLabel3->setBuddy(kcfg_NickCompleteSuffixMiddle);
        commandCharLabel->setBuddy(kcfg_CommandChar);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_ShowTrayIcon, kcfg_TrayNotify);
        QWidget::setTabOrder(kcfg_TrayNotify, kcfg_TrayNotifyOnlyOwnNick);
        QWidget::setTabOrder(kcfg_TrayNotifyOnlyOwnNick, kcfg_HideToTrayOnStartup);
        QWidget::setTabOrder(kcfg_HideToTrayOnStartup, kcfg_NickCompletionMode);
        QWidget::setTabOrder(kcfg_NickCompletionMode, kcfg_NickCompleteSuffixStart);
        QWidget::setTabOrder(kcfg_NickCompleteSuffixStart, kcfg_NickCompleteSuffixMiddle);
        QWidget::setTabOrder(kcfg_NickCompleteSuffixMiddle, kcfg_NickCompletionCaseSensitive);
        QWidget::setTabOrder(kcfg_NickCompletionCaseSensitive, kcfg_DisableNotifyWhileAway);
        QWidget::setTabOrder(kcfg_DisableNotifyWhileAway, kcfg_UseCustomBrowser);
        QWidget::setTabOrder(kcfg_UseCustomBrowser, kcfg_WebBrowserCmd);
        QWidget::setTabOrder(kcfg_WebBrowserCmd, kcfg_CommandChar);
        QWidget::setTabOrder(kcfg_CommandChar, kcfg_CustomVersionReplyEnabled);
        QWidget::setTabOrder(kcfg_CustomVersionReplyEnabled, kcfg_CustomVersionReply);
        QWidget::setTabOrder(kcfg_CustomVersionReply, kcfg_UseMultiRowInputBox);

        retranslateUi(GeneralBehavior_ConfigUI);
        QObject::connect(kcfg_TrayNotify, &QCheckBox::toggled, kcfg_TrayNotifyOnlyOwnNick, &QCheckBox::setEnabled);
        QObject::connect(kcfg_UseCustomBrowser, SIGNAL(toggled(bool)), kcfg_WebBrowserCmd, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_CustomVersionReplyEnabled, SIGNAL(toggled(bool)), kcfg_CustomVersionReply, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(GeneralBehavior_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *GeneralBehavior_ConfigUI)
    {
        kcfg_ShowTrayIcon->setTitle(tr2i18n("Enable System Tray", nullptr));
        kcfg_TrayNotify->setText(tr2i18n("&Use system tray for new message notification", nullptr));
        kcfg_TrayNotifyOnlyOwnNick->setText(tr2i18n("Only &notify when a highlight is triggered or your current nick is used", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_TrayActivateNoWindow->setToolTip(tr2i18n("When the Konversation window is closed, the tray icon will be set to \"active\", which will cause it to become visible in tray implementations that only offer access \"active\" icons.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_TrayActivateNoWindow->setText(tr2i18n("Tray icon becomes \"active\" when the window is closed", nullptr));
        kcfg_HideToTrayOnStartup->setText(tr2i18n("Hide window on startup", nullptr));
        middleLabel->setTitle(tr2i18n("Nickname Completion", nullptr));
        modeLbl->setText(tr2i18n("Completion &mode:", nullptr));
        kcfg_NickCompletionMode->setItemText(0, tr2i18n("Inline Cycle", nullptr));
        kcfg_NickCompletionMode->setItemText(1, tr2i18n("Shell-Like", nullptr));
        kcfg_NickCompletionMode->setItemText(2, tr2i18n("Shell-Like with Completion Box", nullptr));

        startOfLineLabel->setText(tr2i18n("Suffi&x at start of line:", nullptr));
        textLabel3->setText(tr2i18n("&Elsewhere:", nullptr));
        kcfg_NickCompletionCaseSensitive->setText(tr2i18n("Case sensitive", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_NickCompletionCaseSensitive->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        miscGBox->setTitle(tr2i18n("Miscellaneous", nullptr));
        kcfg_DisableNotifyWhileAway->setText(tr2i18n("Disable notifications while &away", nullptr));
        kcfg_UseCustomBrowser->setText(tr2i18n("Use custom web &browser:", nullptr));
        commandCharLabel->setText(tr2i18n("Comman&d char:", nullptr));
        kcfg_CustomVersionReplyEnabled->setText(tr2i18n("Use custom &version reply:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_CustomVersionReply->setWhatsThis(tr2i18n("<qt>Here you can set a custom reply for <b>CTCP <i>VERSION</i></b> requests.</qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseMultiRowInputBox->setText(tr2i18n("Input box expands with text", nullptr));
        (void)GeneralBehavior_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class GeneralBehavior_ConfigUI: public Ui_GeneralBehavior_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALBEHAVIOR_CONFIGUI_H

