/********************************************************************************
** Form generated from reading UI file 'chatwindowbehaviour_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHATWINDOWBEHAVIOUR_CONFIG_H
#define UI_CHATWINDOWBEHAVIOUR_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpluralhandlingspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_ChatwindowBehaviour_Config
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox3;
    QFormLayout *formLayout_2;
    QCheckBox *kcfg_Beep;
    QCheckBox *kcfg_HideUnimportantEvents;
    QCheckBox *kcfg_DisableExpansion;
    QCheckBox *kcfg_RedirectServerAndAppMsgToStatusPane;
    QCheckBox *kcfg_UseLiteralModes;
    KPluralHandlingSpinBox *kcfg_ScrollbackMax;
    QLabel *textLabel1;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *indentHideUnimportantEventsExcludeActiveSpacer;
    QCheckBox *kcfg_HideUnimportantEventsExcludeActive;
    QComboBox *kcfg_HideUnimportantEventsExcludeActiveThreshold;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBox3_2;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_AutomaticRememberLine;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *indentAutomaticRememberLineOnlyOnTextChangeSpacer;
    QCheckBox *kcfg_AutomaticRememberLineOnlyOnTextChange;
    QCheckBox *kcfg_MarkerLineInAllViews;
    QGroupBox *kcfg_AutoWhoContinuousEnabled;
    QFormLayout *gridLayout;
    QLabel *textLabel2;
    KPluralHandlingSpinBox *kcfg_AutoWhoNicksLimit;
    QLabel *whoIntervalLbl;
    KPluralHandlingSpinBox *kcfg_AutoWhoContinuousInterval;
    QSpacerItem *spacer6;

    void setupUi(QWidget *ChatwindowBehaviour_Config)
    {
        if (ChatwindowBehaviour_Config->objectName().isEmpty())
            ChatwindowBehaviour_Config->setObjectName("ChatwindowBehaviour_Config");
        ChatwindowBehaviour_Config->resize(489, 534);
        verticalLayout_2 = new QVBoxLayout(ChatwindowBehaviour_Config);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        groupBox3 = new QGroupBox(ChatwindowBehaviour_Config);
        groupBox3->setObjectName("groupBox3");
        formLayout_2 = new QFormLayout(groupBox3);
        formLayout_2->setObjectName("formLayout_2");
        kcfg_Beep = new QCheckBox(groupBox3);
        kcfg_Beep->setObjectName("kcfg_Beep");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::SpanningRole, kcfg_Beep);

        kcfg_HideUnimportantEvents = new QCheckBox(groupBox3);
        kcfg_HideUnimportantEvents->setObjectName("kcfg_HideUnimportantEvents");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::SpanningRole, kcfg_HideUnimportantEvents);

        kcfg_DisableExpansion = new QCheckBox(groupBox3);
        kcfg_DisableExpansion->setObjectName("kcfg_DisableExpansion");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::SpanningRole, kcfg_DisableExpansion);

        kcfg_RedirectServerAndAppMsgToStatusPane = new QCheckBox(groupBox3);
        kcfg_RedirectServerAndAppMsgToStatusPane->setObjectName("kcfg_RedirectServerAndAppMsgToStatusPane");

        formLayout_2->setWidget(8, QFormLayout::ItemRole::SpanningRole, kcfg_RedirectServerAndAppMsgToStatusPane);

        kcfg_UseLiteralModes = new QCheckBox(groupBox3);
        kcfg_UseLiteralModes->setObjectName("kcfg_UseLiteralModes");

        formLayout_2->setWidget(10, QFormLayout::ItemRole::SpanningRole, kcfg_UseLiteralModes);

        kcfg_ScrollbackMax = new KPluralHandlingSpinBox(groupBox3);
        kcfg_ScrollbackMax->setObjectName("kcfg_ScrollbackMax");
        kcfg_ScrollbackMax->setMinimumSize(QSize(120, 0));
        kcfg_ScrollbackMax->setMaximum(10000);

        formLayout_2->setWidget(11, QFormLayout::ItemRole::FieldRole, kcfg_ScrollbackMax);

        textLabel1 = new QLabel(groupBox3);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        formLayout_2->setWidget(11, QFormLayout::ItemRole::LabelRole, textLabel1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        indentHideUnimportantEventsExcludeActiveSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(indentHideUnimportantEventsExcludeActiveSpacer);

        kcfg_HideUnimportantEventsExcludeActive = new QCheckBox(groupBox3);
        kcfg_HideUnimportantEventsExcludeActive->setObjectName("kcfg_HideUnimportantEventsExcludeActive");
        kcfg_HideUnimportantEventsExcludeActive->setEnabled(false);

        horizontalLayout->addWidget(kcfg_HideUnimportantEventsExcludeActive);

        kcfg_HideUnimportantEventsExcludeActiveThreshold = new QComboBox(groupBox3);
        kcfg_HideUnimportantEventsExcludeActiveThreshold->addItem(QString());
        kcfg_HideUnimportantEventsExcludeActiveThreshold->addItem(QString());
        kcfg_HideUnimportantEventsExcludeActiveThreshold->addItem(QString());
        kcfg_HideUnimportantEventsExcludeActiveThreshold->addItem(QString());
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setObjectName("kcfg_HideUnimportantEventsExcludeActiveThreshold");
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_HideUnimportantEventsExcludeActiveThreshold->sizePolicy().hasHeightForWidth());
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(kcfg_HideUnimportantEventsExcludeActiveThreshold);

        horizontalSpacer_2 = new QSpacerItem(40, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        formLayout_2->setLayout(3, QFormLayout::ItemRole::SpanningRole, horizontalLayout);


        verticalLayout_2->addWidget(groupBox3);

        groupBox3_2 = new QGroupBox(ChatwindowBehaviour_Config);
        groupBox3_2->setObjectName("groupBox3_2");
        verticalLayout = new QVBoxLayout(groupBox3_2);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_AutomaticRememberLine = new QCheckBox(groupBox3_2);
        kcfg_AutomaticRememberLine->setObjectName("kcfg_AutomaticRememberLine");

        verticalLayout->addWidget(kcfg_AutomaticRememberLine);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        indentAutomaticRememberLineOnlyOnTextChangeSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(indentAutomaticRememberLineOnlyOnTextChangeSpacer);

        kcfg_AutomaticRememberLineOnlyOnTextChange = new QCheckBox(groupBox3_2);
        kcfg_AutomaticRememberLineOnlyOnTextChange->setObjectName("kcfg_AutomaticRememberLineOnlyOnTextChange");
        kcfg_AutomaticRememberLineOnlyOnTextChange->setEnabled(false);

        horizontalLayout_2->addWidget(kcfg_AutomaticRememberLineOnlyOnTextChange);


        verticalLayout->addLayout(horizontalLayout_2);

        kcfg_MarkerLineInAllViews = new QCheckBox(groupBox3_2);
        kcfg_MarkerLineInAllViews->setObjectName("kcfg_MarkerLineInAllViews");

        verticalLayout->addWidget(kcfg_MarkerLineInAllViews);


        verticalLayout_2->addWidget(groupBox3_2);

        kcfg_AutoWhoContinuousEnabled = new QGroupBox(ChatwindowBehaviour_Config);
        kcfg_AutoWhoContinuousEnabled->setObjectName("kcfg_AutoWhoContinuousEnabled");
        kcfg_AutoWhoContinuousEnabled->setCheckable(true);
        kcfg_AutoWhoContinuousEnabled->setChecked(false);
        gridLayout = new QFormLayout(kcfg_AutoWhoContinuousEnabled);
        gridLayout->setObjectName("gridLayout");
        textLabel2 = new QLabel(kcfg_AutoWhoContinuousEnabled);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel2);

        kcfg_AutoWhoNicksLimit = new KPluralHandlingSpinBox(kcfg_AutoWhoContinuousEnabled);
        kcfg_AutoWhoNicksLimit->setObjectName("kcfg_AutoWhoNicksLimit");
        kcfg_AutoWhoNicksLimit->setMinimumSize(QSize(140, 0));
        kcfg_AutoWhoNicksLimit->setMinimum(0);
        kcfg_AutoWhoNicksLimit->setMaximum(1000);
        kcfg_AutoWhoNicksLimit->setValue(300);

        gridLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_AutoWhoNicksLimit);

        whoIntervalLbl = new QLabel(kcfg_AutoWhoContinuousEnabled);
        whoIntervalLbl->setObjectName("whoIntervalLbl");
        whoIntervalLbl->setWordWrap(false);

        gridLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, whoIntervalLbl);

        kcfg_AutoWhoContinuousInterval = new KPluralHandlingSpinBox(kcfg_AutoWhoContinuousEnabled);
        kcfg_AutoWhoContinuousInterval->setObjectName("kcfg_AutoWhoContinuousInterval");
        kcfg_AutoWhoContinuousInterval->setEnabled(false);
        kcfg_AutoWhoContinuousInterval->setMinimumSize(QSize(140, 0));
        kcfg_AutoWhoContinuousInterval->setMinimum(30);
        kcfg_AutoWhoContinuousInterval->setMaximum(1000);

        gridLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_AutoWhoContinuousInterval);


        verticalLayout_2->addWidget(kcfg_AutoWhoContinuousEnabled);

        spacer6 = new QSpacerItem(41, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacer6);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(kcfg_ScrollbackMax);
        textLabel2->setBuddy(kcfg_AutoWhoNicksLimit);
        whoIntervalLbl->setBuddy(kcfg_AutoWhoContinuousInterval);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_Beep, kcfg_HideUnimportantEvents);
        QWidget::setTabOrder(kcfg_HideUnimportantEvents, kcfg_HideUnimportantEventsExcludeActive);
        QWidget::setTabOrder(kcfg_HideUnimportantEventsExcludeActive, kcfg_HideUnimportantEventsExcludeActiveThreshold);
        QWidget::setTabOrder(kcfg_HideUnimportantEventsExcludeActiveThreshold, kcfg_DisableExpansion);
        QWidget::setTabOrder(kcfg_DisableExpansion, kcfg_RedirectServerAndAppMsgToStatusPane);
        QWidget::setTabOrder(kcfg_RedirectServerAndAppMsgToStatusPane, kcfg_UseLiteralModes);
        QWidget::setTabOrder(kcfg_UseLiteralModes, kcfg_ScrollbackMax);
        QWidget::setTabOrder(kcfg_ScrollbackMax, kcfg_AutomaticRememberLine);
        QWidget::setTabOrder(kcfg_AutomaticRememberLine, kcfg_AutomaticRememberLineOnlyOnTextChange);
        QWidget::setTabOrder(kcfg_AutomaticRememberLineOnlyOnTextChange, kcfg_MarkerLineInAllViews);
        QWidget::setTabOrder(kcfg_MarkerLineInAllViews, kcfg_AutoWhoContinuousEnabled);
        QWidget::setTabOrder(kcfg_AutoWhoContinuousEnabled, kcfg_AutoWhoNicksLimit);
        QWidget::setTabOrder(kcfg_AutoWhoNicksLimit, kcfg_AutoWhoContinuousInterval);

        retranslateUi(ChatwindowBehaviour_Config);
        QObject::connect(kcfg_AutoWhoContinuousEnabled, SIGNAL(toggled(bool)), kcfg_AutoWhoContinuousInterval, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_AutomaticRememberLine, &QCheckBox::toggled, kcfg_AutomaticRememberLineOnlyOnTextChange, &QCheckBox::setEnabled);
        QObject::connect(kcfg_HideUnimportantEvents, &QCheckBox::toggled, kcfg_HideUnimportantEventsExcludeActive, &QCheckBox::setEnabled);
        QObject::connect(kcfg_HideUnimportantEvents, &QCheckBox::toggled, kcfg_HideUnimportantEventsExcludeActiveThreshold, &QComboBox::setEnabled);

        QMetaObject::connectSlotsByName(ChatwindowBehaviour_Config);
    } // setupUi

    void retranslateUi(QWidget *ChatwindowBehaviour_Config)
    {
        groupBox3->setTitle(tr2i18n("General", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_Beep->setWhatsThis(tr2i18n("Sounds the system bell when you receive an ASCII BEL (0x07) control character", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Beep->setText(tr2i18n("Enable s&ystem bell on incoming ASCII BEL", nullptr));
        kcfg_HideUnimportantEvents->setText(tr2i18n("Hide &Join/Part/Nick events", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_DisableExpansion->setWhatsThis(tr2i18n("Do not expand variables when sending text to the server. A variable starts with '%'; for example, %B will expand to the characters needed to make a text bold.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_DisableExpansion->setText(tr2i18n("Disable variable (e.g. %C, %B, %G...) e&xpansion", nullptr));
        kcfg_RedirectServerAndAppMsgToStatusPane->setText(tr2i18n("&Redirect status messages to the server status window", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_UseLiteralModes->setWhatsThis(tr2i18n("Keep channel mode string as a combination of characters instead of translating them into human readable words. E.g. '*** Channel modes: no messages from outside' will become '*** Channel modes: n'", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseLiteralModes->setText(tr2i18n("Show raw mode characters (e.g. +o) instead of descriptions", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_ScrollbackMax->setWhatsThis(tr2i18n("How many lines to keep in buffers, 0 = unlimited", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ScrollbackMax->setSpecialValueText(tr2i18n("Unlimited", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel1->setWhatsThis(tr2i18n("How many lines to keep in buffers, 0 = unlimited", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1->setText(tr2i18n("Scrollbac&k limit:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_HideUnimportantEventsExcludeActive->setWhatsThis(tr2i18n("If checked, only events concerning active and watched nicks will be displayed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_HideUnimportantEventsExcludeActive->setText(tr2i18n("Except for watched nicks and nicks active within the", nullptr));
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setItemText(0, tr2i18n("last 10 min", "Is prefaced with: Except for watched nicks and nicks active within the"));
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setItemText(1, tr2i18n("last hour", "Is prefaced with: Except for watched nicks and nicks active within the"));
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setItemText(2, tr2i18n("last day", "Is prefaced with: Except for watched nicks and nicks active within the"));
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setItemText(3, tr2i18n("last week", "Is prefaced with: Except for watched nicks and nicks active within the"));

        groupBox3_2->setTitle(tr2i18n("Marker Lines", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_AutomaticRememberLine->setWhatsThis(tr2i18n("Inserts a remember line into the chat window when you switch to another chat window or minimize the application.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AutomaticRememberLine->setText(tr2i18n("Mark the last position in a chat window when it is hidden", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_AutomaticRememberLine->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        kcfg_AutomaticRememberLineOnlyOnTextChange->setText(tr2i18n("Move the line only when new text is about to be shown", nullptr));
        kcfg_MarkerLineInAllViews->setText(tr2i18n("Show manually inserted lines in all chat windows", nullptr));
        kcfg_AutoWhoContinuousEnabled->setTitle(tr2i18n("Enable Automatic User Information Look Up (/WHO)", nullptr));
        textLabel2->setText(tr2i18n("&Max. number of users in a channel:", nullptr));
        whoIntervalLbl->setText(tr2i18n("Update inter&val:", nullptr));
        kcfg_AutoWhoContinuousInterval->setPrefix(QString());
        (void)ChatwindowBehaviour_Config;
    } // retranslateUi

};

namespace Ui {
    class ChatwindowBehaviour_Config: public Ui_ChatwindowBehaviour_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHATWINDOWBEHAVIOUR_CONFIG_H

