/****************************************************************************
** Meta object code from reading C++ file 'inputfilter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/irc/inputfilter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputfilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11InputFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto InputFilter::qt_create_metaobjectdata<qt_meta_tag_ZN11InputFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputFilter",
        "welcome",
        "",
        "ownHost",
        "notifyResponse",
        "nicksOnline",
        "startReverseDccSendTransfer",
        "sourceNick",
        "dccArgument",
        "startReverseDccChat",
        "addDccGet",
        "resumeDccGetTransfer",
        "resumeDccSendTransfer",
        "rejectDccSendTransfer",
        "rejectDccChat",
        "userhost",
        "nick",
        "hostmask",
        "away",
        "ircOp",
        "topicAuthor",
        "channel",
        "author",
        "t",
        "endOfWho",
        "target",
        "endOfNames",
        "addChannelListPanel",
        "addToChannelList",
        "users",
        "topic",
        "endOfChannelList",
        "invitation",
        "addDccChat",
        "arguments"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'welcome'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'notifyResponse'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'startReverseDccSendTransfer'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Signal 'startReverseDccChat'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Signal 'addDccGet'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Signal 'resumeDccGetTransfer'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Signal 'resumeDccSendTransfer'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Signal 'rejectDccSendTransfer'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Signal 'rejectDccChat'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'userhost'
        QtMocHelpers::SignalData<void(const QString &, const QString &, bool, bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::Bool, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Signal 'topicAuthor'
        QtMocHelpers::SignalData<void(const QString &, const QString &, QDateTime)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 }, { QMetaType::QDateTime, 23 },
        }}),
        // Signal 'endOfWho'
        QtMocHelpers::SignalData<void(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'endOfNames'
        QtMocHelpers::SignalData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'addChannelListPanel'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addToChannelList'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::Int, 29 }, { QMetaType::QString, 30 },
        }}),
        // Signal 'endOfChannelList'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invitation'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 21 },
        }}),
        // Signal 'addDccChat'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::QStringList, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InputFilter, qt_meta_tag_ZN11InputFilterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InputFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InputFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InputFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11InputFilterE_t>.metaTypes,
    nullptr
} };

void InputFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InputFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->welcome((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->notifyResponse((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->startReverseDccSendTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 3: _t->startReverseDccChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 4: _t->addDccGet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 5: _t->resumeDccGetTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 6: _t->resumeDccSendTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 7: _t->rejectDccSendTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 8: _t->rejectDccChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->userhost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 10: _t->topicAuthor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[3]))); break;
        case 11: _t->endOfWho((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->endOfNames((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->addChannelListPanel(); break;
        case 14: _t->addToChannelList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->endOfChannelList(); break;
        case 16: _t->invitation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->addDccChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & )>(_a, &InputFilter::welcome, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & )>(_a, &InputFilter::notifyResponse, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QStringList & )>(_a, &InputFilter::startReverseDccSendTransfer, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QStringList & )>(_a, &InputFilter::startReverseDccChat, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QStringList & )>(_a, &InputFilter::addDccGet, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QStringList & )>(_a, &InputFilter::resumeDccGetTransfer, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QStringList & )>(_a, &InputFilter::resumeDccSendTransfer, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QStringList & )>(_a, &InputFilter::rejectDccSendTransfer, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & )>(_a, &InputFilter::rejectDccChat, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QString & , bool , bool )>(_a, &InputFilter::userhost, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QString & , QDateTime )>(_a, &InputFilter::topicAuthor, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & )>(_a, &InputFilter::endOfWho, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & )>(_a, &InputFilter::endOfNames, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)()>(_a, &InputFilter::addChannelListPanel, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , int , const QString & )>(_a, &InputFilter::addToChannelList, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)()>(_a, &InputFilter::endOfChannelList, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QString & )>(_a, &InputFilter::invitation, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputFilter::*)(const QString & , const QStringList & )>(_a, &InputFilter::addDccChat, 17))
            return;
    }
}

const QMetaObject *InputFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InputFilterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int InputFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void InputFilter::welcome(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void InputFilter::notifyResponse(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void InputFilter::startReverseDccSendTransfer(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void InputFilter::startReverseDccChat(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void InputFilter::addDccGet(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void InputFilter::resumeDccGetTransfer(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void InputFilter::resumeDccSendTransfer(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void InputFilter::rejectDccSendTransfer(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void InputFilter::rejectDccChat(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void InputFilter::userhost(const QString & _t1, const QString & _t2, bool _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 10
void InputFilter::topicAuthor(const QString & _t1, const QString & _t2, QDateTime _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void InputFilter::endOfWho(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void InputFilter::endOfNames(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void InputFilter::addChannelListPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void InputFilter::addToChannelList(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void InputFilter::endOfChannelList()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void InputFilter::invitation(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}

// SIGNAL 17
void InputFilter::addDccChat(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}
QT_WARNING_POP
