/********************************************************************************
** Form generated from reading UI file 'channeldialogui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHANNELDIALOGUI_H
#define UI_CHANNELDIALOGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "kpasswordlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ChannelDialogUI
{
public:
    QGridLayout *gridLayout;
    KPasswordLineEdit *m_passwordEdit;
    KLineEdit *m_channelEdit;
    QLabel *passwordLbl;
    QLabel *channelLbl;

    void setupUi(QWidget *ChannelDialogUI)
    {
        if (ChannelDialogUI->objectName().isEmpty())
            ChannelDialogUI->setObjectName("ChannelDialogUI");
        ChannelDialogUI->resize(204, 64);
        gridLayout = new QGridLayout(ChannelDialogUI);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        m_passwordEdit = new KPasswordLineEdit(ChannelDialogUI);
        m_passwordEdit->setObjectName("m_passwordEdit");

        gridLayout->addWidget(m_passwordEdit, 1, 1, 1, 1);

        m_channelEdit = new KLineEdit(ChannelDialogUI);
        m_channelEdit->setObjectName("m_channelEdit");
        m_channelEdit->setMaxLength(50);

        gridLayout->addWidget(m_channelEdit, 0, 1, 1, 1);

        passwordLbl = new QLabel(ChannelDialogUI);
        passwordLbl->setObjectName("passwordLbl");
        passwordLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(passwordLbl, 1, 0, 1, 1);

        channelLbl = new QLabel(ChannelDialogUI);
        channelLbl->setObjectName("channelLbl");
        channelLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(channelLbl, 0, 0, 1, 1);

        m_passwordEdit->raise();
        m_channelEdit->raise();
        passwordLbl->raise();
        channelLbl->raise();
#if QT_CONFIG(shortcut)
        passwordLbl->setBuddy(m_passwordEdit);
        channelLbl->setBuddy(m_channelEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ChannelDialogUI);

        QMetaObject::connectSlotsByName(ChannelDialogUI);
    } // setupUi

    void retranslateUi(QWidget *ChannelDialogUI)
    {
        passwordLbl->setText(tr2i18n("Pass&word:", nullptr));
        channelLbl->setText(tr2i18n("C&hannel:", nullptr));
        (void)ChannelDialogUI;
    } // retranslateUi

};

namespace Ui {
    class ChannelDialogUI: public Ui_ChannelDialogUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHANNELDIALOGUI_H

