/****************************************************************************
** Meta object code from reading C++ file 'dbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/dbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Konversation4DBusE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::DBus::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation4DBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::DBus",
        "D-Bus Interface",
        "org.kde.konversation",
        "dbusSay",
        "",
        "server",
        "target",
        "command",
        "dbusInfo",
        "string",
        "dbusInsertMarkerLine",
        "dbusRaw",
        "dbusMultiServerRaw",
        "connectTo",
        "Konversation::ConnectionFlag",
        "flag",
        "hostName",
        "port",
        "password",
        "nick",
        "channel",
        "useSSL",
        "setAway",
        "awaymessage",
        "setBack",
        "sayToAll",
        "message",
        "actionToAll",
        "raw",
        "say",
        "info",
        "debug",
        "error",
        "insertMarkerLine",
        "connectToServer",
        "address",
        "listConnections",
        "listConnectionNames",
        "listServers",
        "listConnectedServers",
        "listJoinedChannels",
        "changeAwayStatus",
        "away"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dbusSay'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'dbusInfo'
        QtMocHelpers::SignalData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'dbusInsertMarkerLine'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dbusRaw'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'dbusMultiServerRaw'
        QtMocHelpers::SignalData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &, const QString &, const QString &, bool)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
            { QMetaType::QString, 19 }, { QMetaType::QString, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &, const QString &, const QString &)>(13, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
            { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &, const QString &)>(13, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
            { QMetaType::QString, 19 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &)>(13, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &)>(13, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &)>(13, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'setAway'
        QtMocHelpers::SlotData<void(const QString &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'setBack'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sayToAll'
        QtMocHelpers::SlotData<void(const QString &)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'actionToAll'
        QtMocHelpers::SlotData<void(const QString &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'raw'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'say'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'info'
        QtMocHelpers::SlotData<void(const QString &)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'debug'
        QtMocHelpers::SlotData<void(const QString &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'error'
        QtMocHelpers::SlotData<void(const QString &)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'insertMarkerLine'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'connectToServer'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &, const QString &)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 }, { QMetaType::Int, 17 }, { QMetaType::QString, 20 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'listConnections'
        QtMocHelpers::SlotData<QStringList()>(36, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'listConnectionNames'
        QtMocHelpers::SlotData<QStringList()>(37, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'listServers'
        QtMocHelpers::SlotData<QStringList()>(38, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'listConnectedServers'
        QtMocHelpers::SlotData<QStringList()>(39, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'listJoinedChannels'
        QtMocHelpers::SlotData<QStringList(const QString &)>(40, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'changeAwayStatus'
        QtMocHelpers::SlotData<void(bool)>(41, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBus, qt_meta_tag_ZN12Konversation4DBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Konversation::DBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation4DBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation4DBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation4DBusE_t>.metaTypes,
    nullptr
} };

void Konversation::DBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dbusSay((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->dbusInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->dbusInsertMarkerLine(); break;
        case 3: _t->dbusRaw((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->dbusMultiServerRaw((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7]))); break;
        case 6: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 7: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 8: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 9: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 10: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->setAway((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->setBack(); break;
        case 13: _t->sayToAll((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->actionToAll((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->raw((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->say((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 17: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->debug((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->insertMarkerLine(); break;
        case 21: _t->connectToServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 22: { QStringList _r = _t->listConnections();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 23: { QStringList _r = _t->listConnectionNames();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 24: { QStringList _r = _t->listServers();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 25: { QStringList _r = _t->listConnectedServers();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 26: { QStringList _r = _t->listJoinedChannels((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->changeAwayStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(const QString & , const QString & , const QString & )>(_a, &DBus::dbusSay, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(const QString & )>(_a, &DBus::dbusInfo, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)()>(_a, &DBus::dbusInsertMarkerLine, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(const QString & , const QString & )>(_a, &DBus::dbusRaw, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(const QString & )>(_a, &DBus::dbusMultiServerRaw, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(Konversation::ConnectionFlag , const QString & , const QString & , const QString & , const QString & , const QString & , bool )>(_a, &DBus::connectTo, 5))
            return;
    }
}

const QMetaObject *Konversation::DBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation4DBusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::DBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DBus::dbusSay(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Konversation::DBus::dbusInfo(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Konversation::DBus::dbusInsertMarkerLine()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Konversation::DBus::dbusRaw(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Konversation::DBus::dbusMultiServerRaw(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Konversation::DBus::connectTo(Konversation::ConnectionFlag _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, bool _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}
namespace {
struct qt_meta_tag_ZN12Konversation9IdentDBusE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::IdentDBus::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation9IdentDBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::IdentDBus",
        "D-Bus Interface",
        "org.kde.konversation",
        "setrealName",
        "",
        "identity",
        "name",
        "getrealName",
        "setIdent",
        "ident",
        "getIdent",
        "setNickname",
        "index",
        "nick",
        "getNickname",
        "setBot",
        "bot",
        "getBot",
        "setPassword",
        "password",
        "getPassword",
        "setNicknameList",
        "newList",
        "getNicknameList",
        "setQuitReason",
        "reason",
        "getQuitReason",
        "setPartReason",
        "getPartReason",
        "setKickReason",
        "getKickReason",
        "setRunAwayCommands",
        "run",
        "getRunAwayCommands",
        "setAwayCommand",
        "command",
        "getAwayCommand",
        "setReturnCommand",
        "getReturnCommand",
        "setAwayNickname",
        "nickname",
        "getAwayNickname",
        "setAwayMessage",
        "message",
        "getAwayMessage",
        "listIdentities"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setrealName'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'getrealName'
        QtMocHelpers::SlotData<QString(const QString &)>(7, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setIdent'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'getIdent'
        QtMocHelpers::SlotData<QString(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setNickname'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'getNickname'
        QtMocHelpers::SlotData<QString(const QString &, int)>(14, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'setBot'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'getBot'
        QtMocHelpers::SlotData<QString(const QString &)>(17, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setPassword'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'getPassword'
        QtMocHelpers::SlotData<QString(const QString &)>(20, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setNicknameList'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QStringList, 22 },
        }}),
        // Slot 'getNicknameList'
        QtMocHelpers::SlotData<QStringList(const QString &)>(23, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setQuitReason'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'getQuitReason'
        QtMocHelpers::SlotData<QString(const QString &)>(26, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setPartReason'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'getPartReason'
        QtMocHelpers::SlotData<QString(const QString &)>(28, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setKickReason'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'getKickReason'
        QtMocHelpers::SlotData<QString(const QString &)>(30, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setRunAwayCommands'
        QtMocHelpers::SlotData<void(const QString &, bool)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'getRunAwayCommands'
        QtMocHelpers::SlotData<bool(const QString &)>(33, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setAwayCommand'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 35 },
        }}),
        // Slot 'getAwayCommand'
        QtMocHelpers::SlotData<QString(const QString &)>(36, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setReturnCommand'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 35 },
        }}),
        // Slot 'getReturnCommand'
        QtMocHelpers::SlotData<QString(const QString &)>(38, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setAwayNickname'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 40 },
        }}),
        // Slot 'getAwayNickname'
        QtMocHelpers::SlotData<QString(const QString &)>(41, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setAwayMessage'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 43 },
        }}),
        // Slot 'getAwayMessage'
        QtMocHelpers::SlotData<QString(const QString &)>(44, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'listIdentities'
        QtMocHelpers::SlotData<QStringList()>(45, 4, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<IdentDBus, qt_meta_tag_ZN12Konversation9IdentDBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Konversation::IdentDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation9IdentDBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation9IdentDBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation9IdentDBusE_t>.metaTypes,
    nullptr
} };

void Konversation::IdentDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IdentDBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setrealName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: { QString _r = _t->getrealName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->setIdent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: { QString _r = _t->getIdent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setNickname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: { QString _r = _t->getNickname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setBot((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: { QString _r = _t->getBot((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: { QString _r = _t->getPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setNicknameList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 11: { QStringList _r = _t->getNicknameList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setQuitReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: { QString _r = _t->getQuitReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setPartReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: { QString _r = _t->getPartReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setKickReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: { QString _r = _t->getKickReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setRunAwayCommands((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 19: { bool _r = _t->getRunAwayCommands((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->setAwayCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 21: { QString _r = _t->getAwayCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setReturnCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: { QString _r = _t->getReturnCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->setAwayNickname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 25: { QString _r = _t->getAwayNickname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->setAwayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: { QString _r = _t->getAwayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 28: { QStringList _r = _t->listIdentities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Konversation::IdentDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::IdentDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation9IdentDBusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::IdentDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    return _id;
}
QT_WARNING_POP
