/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

*/

/********************************************************************************
** Form generated from reading UI file 'connectionbehavior_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONNECTIONBEHAVIOR_CONFIG_H
#define UI_CONNECTIONBEHAVIOR_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "kpasswordlineedit.h"
#include "kpluralhandlingspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_ConnectionBehavior_Config
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *kcfg_AutoReconnect;
    QFormLayout *formLayout;
    QLabel *reconnectDelayLabel;
    QLabel *textLabel1;
    KPluralHandlingSpinBox *kcfg_ReconnectDelay;
    QSpinBox *kcfg_ReconnectCount;
    QGroupBox *debugGBox;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_RawLog;
    QGroupBox *encryptionGBox;
    QFormLayout *encryptionLayout;
    QLabel *label;
    QComboBox *kcfg_EncryptionType;
    QGroupBox *kcfg_ProxyEnabled;
    QFormLayout *proxyLayout;
    QLabel *typeLabel;
    QComboBox *kcfg_ProxyType;
    QLabel *addressLabel;
    KLineEdit *kcfg_ProxyAddress;
    QLabel *portLabel;
    QSpinBox *kcfg_ProxyPort;
    QLabel *usernameLabel;
    KLineEdit *kcfg_ProxyUsername;
    QLabel *passwordLabel;
    KPasswordLineEdit *m_ProxyPassword;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ConnectionBehavior_Config)
    {
        if (ConnectionBehavior_Config->objectName().isEmpty())
            ConnectionBehavior_Config->setObjectName("ConnectionBehavior_Config");
        ConnectionBehavior_Config->resize(435, 432);
        verticalLayout = new QVBoxLayout(ConnectionBehavior_Config);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_AutoReconnect = new QGroupBox(ConnectionBehavior_Config);
        kcfg_AutoReconnect->setObjectName("kcfg_AutoReconnect");
        kcfg_AutoReconnect->setCheckable(true);
        formLayout = new QFormLayout(kcfg_AutoReconnect);
        formLayout->setObjectName("formLayout");
        reconnectDelayLabel = new QLabel(kcfg_AutoReconnect);
        reconnectDelayLabel->setObjectName("reconnectDelayLabel");
        reconnectDelayLabel->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, reconnectDelayLabel);

        textLabel1 = new QLabel(kcfg_AutoReconnect);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel1);

        kcfg_ReconnectDelay = new KPluralHandlingSpinBox(kcfg_AutoReconnect);
        kcfg_ReconnectDelay->setObjectName("kcfg_ReconnectDelay");
        kcfg_ReconnectDelay->setValue(120);
        kcfg_ReconnectDelay->setMinimum(1);
        kcfg_ReconnectDelay->setMaximum(9999);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_ReconnectDelay);

        kcfg_ReconnectCount = new QSpinBox(kcfg_AutoReconnect);
        kcfg_ReconnectCount->setObjectName("kcfg_ReconnectCount");
        kcfg_ReconnectCount->setValue(100);
        kcfg_ReconnectCount->setMinimum(0);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_ReconnectCount);


        verticalLayout->addWidget(kcfg_AutoReconnect);

        debugGBox = new QGroupBox(ConnectionBehavior_Config);
        debugGBox->setObjectName("debugGBox");
        gridLayout = new QGridLayout(debugGBox);
        gridLayout->setObjectName("gridLayout");
        kcfg_RawLog = new QCheckBox(debugGBox);
        kcfg_RawLog->setObjectName("kcfg_RawLog");

        gridLayout->addWidget(kcfg_RawLog, 0, 0, 1, 1);


        verticalLayout->addWidget(debugGBox);

        encryptionGBox = new QGroupBox(ConnectionBehavior_Config);
        encryptionGBox->setObjectName("encryptionGBox");
        encryptionLayout = new QFormLayout(encryptionGBox);
        encryptionLayout->setObjectName("encryptionLayout");
        label = new QLabel(encryptionGBox);
        label->setObjectName("label");

        encryptionLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        kcfg_EncryptionType = new QComboBox(encryptionGBox);
        kcfg_EncryptionType->addItem(QString());
        kcfg_EncryptionType->addItem(QString());
        kcfg_EncryptionType->setObjectName("kcfg_EncryptionType");

        encryptionLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_EncryptionType);


        verticalLayout->addWidget(encryptionGBox);

        kcfg_ProxyEnabled = new QGroupBox(ConnectionBehavior_Config);
        kcfg_ProxyEnabled->setObjectName("kcfg_ProxyEnabled");
        kcfg_ProxyEnabled->setCheckable(true);
        kcfg_ProxyEnabled->setChecked(true);
        proxyLayout = new QFormLayout(kcfg_ProxyEnabled);
        proxyLayout->setObjectName("proxyLayout");
        typeLabel = new QLabel(kcfg_ProxyEnabled);
        typeLabel->setObjectName("typeLabel");

        proxyLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, typeLabel);

        kcfg_ProxyType = new QComboBox(kcfg_ProxyEnabled);
        kcfg_ProxyType->addItem(QString());
        kcfg_ProxyType->addItem(QString());
        kcfg_ProxyType->setObjectName("kcfg_ProxyType");
        kcfg_ProxyType->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        proxyLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_ProxyType);

        addressLabel = new QLabel(kcfg_ProxyEnabled);
        addressLabel->setObjectName("addressLabel");

        proxyLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, addressLabel);

        kcfg_ProxyAddress = new KLineEdit(kcfg_ProxyEnabled);
        kcfg_ProxyAddress->setObjectName("kcfg_ProxyAddress");
        kcfg_ProxyAddress->setEnabled(true);

        proxyLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_ProxyAddress);

        portLabel = new QLabel(kcfg_ProxyEnabled);
        portLabel->setObjectName("portLabel");

        proxyLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, portLabel);

        kcfg_ProxyPort = new QSpinBox(kcfg_ProxyEnabled);
        kcfg_ProxyPort->setObjectName("kcfg_ProxyPort");
        kcfg_ProxyPort->setEnabled(true);
        kcfg_ProxyPort->setMinimum(1);
        kcfg_ProxyPort->setMaximum(65535);

        proxyLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_ProxyPort);

        usernameLabel = new QLabel(kcfg_ProxyEnabled);
        usernameLabel->setObjectName("usernameLabel");

        proxyLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, usernameLabel);

        kcfg_ProxyUsername = new KLineEdit(kcfg_ProxyEnabled);
        kcfg_ProxyUsername->setObjectName("kcfg_ProxyUsername");
        kcfg_ProxyUsername->setEnabled(true);

        proxyLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_ProxyUsername);

        passwordLabel = new QLabel(kcfg_ProxyEnabled);
        passwordLabel->setObjectName("passwordLabel");

        proxyLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, passwordLabel);

        m_ProxyPassword = new KPasswordLineEdit(kcfg_ProxyEnabled);
        m_ProxyPassword->setObjectName("m_ProxyPassword");
        m_ProxyPassword->setEnabled(true);

        proxyLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, m_ProxyPassword);


        verticalLayout->addWidget(kcfg_ProxyEnabled);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        reconnectDelayLabel->setBuddy(kcfg_ReconnectDelay);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_AutoReconnect, kcfg_ReconnectDelay);
        QWidget::setTabOrder(kcfg_ReconnectDelay, kcfg_ReconnectCount);
        QWidget::setTabOrder(kcfg_ReconnectCount, kcfg_RawLog);

        retranslateUi(ConnectionBehavior_Config);

        QMetaObject::connectSlotsByName(ConnectionBehavior_Config);
    } // setupUi

    void retranslateUi(QWidget *ConnectionBehavior_Config)
    {
        kcfg_AutoReconnect->setTitle(tr2i18n("Enable Automatic Reconnect", nullptr));
        reconnectDelayLabel->setText(tr2i18n("Reconnect delay:", nullptr));
        textLabel1->setText(tr2i18n("Reconnection attempts:", nullptr));
        kcfg_ReconnectCount->setSpecialValueText(tr2i18n("Unlimited", nullptr));
        debugGBox->setTitle(tr2i18n("Debug", nullptr));
        kcfg_RawLog->setText(tr2i18n("Show raw &log window when connecting", nullptr));
        encryptionGBox->setTitle(tr2i18n("Encryption", nullptr));
        label->setText(tr2i18n("Default encryption type:", nullptr));
        kcfg_EncryptionType->setItemText(0, tr2i18n("Electronic Codebook (ECB)", nullptr));
        kcfg_EncryptionType->setItemText(1, tr2i18n("Cipher-Block Chaining (CBC)", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_EncryptionType->setWhatsThis(tr2i18n("ECB or Electronic Codebook mode is supported by many encryption clients like FiSH and Mircryption however it is generally considered to be insecure.\n"
"\n"
"CBC or Cipher Block Chaining mode is not supported by FiSH but is supported by Mircryption. If you are going to use key exchange it is best to first find out if your peer has a client that can use CBC otherwise you will be able to see what they are saying, but they will not be able to read what you are saying.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ProxyEnabled->setTitle(tr2i18n("Proxy", nullptr));
        typeLabel->setText(tr2i18n("Type:", nullptr));
        kcfg_ProxyType->setItemText(0, tr2i18n("Socks v5", nullptr));
        kcfg_ProxyType->setItemText(1, tr2i18n("HTTP", nullptr));

        addressLabel->setText(tr2i18n("Address:", nullptr));
        portLabel->setText(tr2i18n("Port:", nullptr));
        usernameLabel->setText(tr2i18n("Username:", nullptr));
        passwordLabel->setText(tr2i18n("Password:", nullptr));
        (void)ConnectionBehavior_Config;
    } // retranslateUi

};

namespace Ui {
    class ConnectionBehavior_Config: public Ui_ConnectionBehavior_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONNECTIONBEHAVIOR_CONFIG_H

