/********************************************************************************
** Form generated from reading UI file 'theme_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_THEME_CONFIGUI_H
#define UI_THEME_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KNSWidgets/Button"

QT_BEGIN_NAMESPACE

class Ui_Theme_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QListWidget *iconThemeIndex;
    QHBoxLayout *hboxLayout;
    KNSWidgets::Button *getButton;
    QPushButton *installButton;
    QPushButton *removeButton;
    QSpacerItem *spacer172;
    QFrame *framePreview;
    QGridLayout *gridLayout1;
    QLabel *previewLabel1;
    QLabel *previewLabel2;
    QLabel *previewLabel3;
    QLabel *previewLabel4;
    QLabel *previewLabel5;
    QLabel *previewLabel6;
    QLabel *previewLabel7;
    QLabel *textLabel2;

    void setupUi(QWidget *Theme_ConfigUI)
    {
        if (Theme_ConfigUI->objectName().isEmpty())
            Theme_ConfigUI->setObjectName("Theme_ConfigUI");
        Theme_ConfigUI->resize(390, 338);
        gridLayout = new QGridLayout(Theme_ConfigUI);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        iconThemeIndex = new QListWidget(Theme_ConfigUI);
        iconThemeIndex->setObjectName("iconThemeIndex");

        gridLayout->addWidget(iconThemeIndex, 0, 0, 1, 3);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        getButton = new KNSWidgets::Button(Theme_ConfigUI);
        getButton->setObjectName("getButton");

        hboxLayout->addWidget(getButton);

        installButton = new QPushButton(Theme_ConfigUI);
        installButton->setObjectName("installButton");

        hboxLayout->addWidget(installButton);

        removeButton = new QPushButton(Theme_ConfigUI);
        removeButton->setObjectName("removeButton");
        removeButton->setEnabled(false);

        hboxLayout->addWidget(removeButton);


        gridLayout->addLayout(hboxLayout, 2, 0, 1, 3);

        spacer172 = new QSpacerItem(131, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer172, 1, 2, 1, 1);

        framePreview = new QFrame(Theme_ConfigUI);
        framePreview->setObjectName("framePreview");
        framePreview->setMinimumSize(QSize(0, 0));
        framePreview->setFrameShape(QFrame::StyledPanel);
        framePreview->setFrameShadow(QFrame::Plain);
        gridLayout1 = new QGridLayout(framePreview);
        gridLayout1->setObjectName("gridLayout1");
        previewLabel1 = new QLabel(framePreview);
        previewLabel1->setObjectName("previewLabel1");
        previewLabel1->setFrameShape(QFrame::NoFrame);
        previewLabel1->setAlignment(Qt::AlignCenter);
        previewLabel1->setWordWrap(false);

        gridLayout1->addWidget(previewLabel1, 0, 0, 1, 1);

        previewLabel2 = new QLabel(framePreview);
        previewLabel2->setObjectName("previewLabel2");
        previewLabel2->setAlignment(Qt::AlignCenter);
        previewLabel2->setWordWrap(false);

        gridLayout1->addWidget(previewLabel2, 0, 1, 1, 1);

        previewLabel3 = new QLabel(framePreview);
        previewLabel3->setObjectName("previewLabel3");
        previewLabel3->setAlignment(Qt::AlignCenter);
        previewLabel3->setWordWrap(false);

        gridLayout1->addWidget(previewLabel3, 0, 2, 1, 1);

        previewLabel4 = new QLabel(framePreview);
        previewLabel4->setObjectName("previewLabel4");
        previewLabel4->setAlignment(Qt::AlignCenter);
        previewLabel4->setWordWrap(false);

        gridLayout1->addWidget(previewLabel4, 0, 3, 1, 1);

        previewLabel5 = new QLabel(framePreview);
        previewLabel5->setObjectName("previewLabel5");
        previewLabel5->setAlignment(Qt::AlignCenter);
        previewLabel5->setWordWrap(false);

        gridLayout1->addWidget(previewLabel5, 0, 4, 1, 1);

        previewLabel6 = new QLabel(framePreview);
        previewLabel6->setObjectName("previewLabel6");
        previewLabel6->setAlignment(Qt::AlignCenter);
        previewLabel6->setWordWrap(false);

        gridLayout1->addWidget(previewLabel6, 0, 5, 1, 1);

        previewLabel7 = new QLabel(framePreview);
        previewLabel7->setObjectName("previewLabel7");
        previewLabel7->setAlignment(Qt::AlignCenter);
        previewLabel7->setWordWrap(false);

        gridLayout1->addWidget(previewLabel7, 0, 6, 1, 1);


        gridLayout->addWidget(framePreview, 1, 1, 1, 1);

        textLabel2 = new QLabel(Theme_ConfigUI);
        textLabel2->setObjectName("textLabel2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel2->sizePolicy().hasHeightForWidth());
        textLabel2->setSizePolicy(sizePolicy);
        textLabel2->setWordWrap(false);

        gridLayout->addWidget(textLabel2, 1, 0, 1, 1);


        retranslateUi(Theme_ConfigUI);

        QMetaObject::connectSlotsByName(Theme_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *Theme_ConfigUI)
    {
        Theme_ConfigUI->setWindowTitle(tr2i18n("Theme_Config", nullptr));
        getButton->setText(tr2i18n("G&et New Themes...", nullptr));
        installButton->setText(tr2i18n("I&nstall from File...", nullptr));
        removeButton->setText(tr2i18n("&Remove Theme", nullptr));
#if QT_CONFIG(tooltip)
        previewLabel1->setToolTip(tr2i18n("Icon for normal users", nullptr));
#endif // QT_CONFIG(tooltip)
        previewLabel1->setText(QString());
#if QT_CONFIG(tooltip)
        previewLabel2->setToolTip(tr2i18n("Icon for away users", nullptr));
#endif // QT_CONFIG(tooltip)
        previewLabel2->setText(QString());
#if QT_CONFIG(tooltip)
        previewLabel3->setToolTip(tr2i18n("Icon for users with voice", nullptr));
#endif // QT_CONFIG(tooltip)
        previewLabel3->setText(QString());
#if QT_CONFIG(tooltip)
        previewLabel4->setToolTip(tr2i18n("Icon for users with half-operator privileges", nullptr));
#endif // QT_CONFIG(tooltip)
        previewLabel4->setText(QString());
#if QT_CONFIG(tooltip)
        previewLabel5->setToolTip(tr2i18n("Icon for users with operator privileges", nullptr));
#endif // QT_CONFIG(tooltip)
        previewLabel5->setText(QString());
#if QT_CONFIG(tooltip)
        previewLabel6->setToolTip(tr2i18n("Icon for users with admin privileges", nullptr));
#endif // QT_CONFIG(tooltip)
        previewLabel6->setText(QString());
#if QT_CONFIG(tooltip)
        previewLabel7->setToolTip(tr2i18n("Icon for users with owner privileges", nullptr));
#endif // QT_CONFIG(tooltip)
        previewLabel7->setText(QString());
        textLabel2->setText(tr2i18n("Preview:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Theme_ConfigUI: public Ui_Theme_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // THEME_CONFIGUI_H

