/********************************************************************************
** Form generated from reading UI file 'pasteeditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PASTEEDITOR_H
#define UI_PASTEEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_PasteEditor
{
public:
    QGridLayout *gridLayout;
    KTextEdit *m_textEditor;
    QPushButton *m_addQuotesButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *m_removeNewlinesButton;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QWidget *PasteEditor)
    {
        if (PasteEditor->objectName().isEmpty())
            PasteEditor->setObjectName("PasteEditor");
        PasteEditor->resize(462, 300);
        gridLayout = new QGridLayout(PasteEditor);
        gridLayout->setObjectName("gridLayout");
        m_textEditor = new KTextEdit(PasteEditor);
        m_textEditor->setObjectName("m_textEditor");

        gridLayout->addWidget(m_textEditor, 1, 0, 1, 3);

        m_addQuotesButton = new QPushButton(PasteEditor);
        m_addQuotesButton->setObjectName("m_addQuotesButton");

        gridLayout->addWidget(m_addQuotesButton, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(139, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        m_removeNewlinesButton = new QPushButton(PasteEditor);
        m_removeNewlinesButton->setObjectName("m_removeNewlinesButton");

        gridLayout->addWidget(m_removeNewlinesButton, 0, 0, 1, 1);

        m_buttonBox = new QDialogButtonBox(PasteEditor);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setStandardButtons(QDialogButtonBox::Cancel);

        gridLayout->addWidget(m_buttonBox, 2, 0, 1, 3);


        retranslateUi(PasteEditor);

        QMetaObject::connectSlotsByName(PasteEditor);
    } // setupUi

    void retranslateUi(QWidget *PasteEditor)
    {
        PasteEditor->setWindowTitle(tr2i18n("Paste Editor", nullptr));
        m_addQuotesButton->setText(tr2i18n("Add &Quotation Indicators", nullptr));
        m_removeNewlinesButton->setText(tr2i18n("&Remove Newlines", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PasteEditor: public Ui_PasteEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PASTEEDITOR_H

