/********************************************************************************
** Form generated from reading UI file 'warnings_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WARNINGS_CONFIGUI_H
#define UI_WARNINGS_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Warnings_ConfigUI
{
public:
    QHBoxLayout *hboxLayout;
    QTreeWidget *dialogListView;

    void setupUi(QWidget *Warnings_ConfigUI)
    {
        if (Warnings_ConfigUI->objectName().isEmpty())
            Warnings_ConfigUI->setObjectName("Warnings_ConfigUI");
        Warnings_ConfigUI->resize(466, 271);
        hboxLayout = new QHBoxLayout(Warnings_ConfigUI);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        dialogListView = new QTreeWidget(Warnings_ConfigUI);
        dialogListView->setObjectName("dialogListView");
        dialogListView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        dialogListView->setRootIsDecorated(false);
        dialogListView->setAllColumnsShowFocus(true);

        hboxLayout->addWidget(dialogListView);


        retranslateUi(Warnings_ConfigUI);

        QMetaObject::connectSlotsByName(Warnings_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *Warnings_ConfigUI)
    {
        QTreeWidgetItem *___qtreewidgetitem = dialogListView->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("Show a warning dialog when...", nullptr));
        (void)Warnings_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class Warnings_ConfigUI: public Ui_Warnings_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WARNINGS_CONFIGUI_H

