/****************************************************************************
** Meta object code from reading C++ file 'query.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/irc/query.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'query.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5QueryE_t {};
} // unnamed namespace

template <> constexpr inline auto Query::qt_create_metaobjectdata<qt_meta_tag_ZN5QueryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Query",
        "sendFile",
        "",
        "recipient",
        "updateQueryChrome",
        "ChatWindow*",
        "sendText",
        "text",
        "indicateAway",
        "show",
        "setEncryptedOutput",
        "connectionStateChanged",
        "Server*",
        "Konversation::ConnectionState",
        "queryTextEntered",
        "queryPassthroughCommand",
        "sendFileMenu",
        "urlsDropped",
        "QList<QUrl>",
        "urls",
        "textPasted",
        "nickInfoChanged",
        "updateNickInfo",
        "server",
        "NickInfoPtr",
        "nickInfo"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sendFile'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'updateQueryChrome'
        QtMocHelpers::SignalData<void(ChatWindow *, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'sendText'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'indicateAway'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'setEncryptedOutput'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'connectionStateChanged'
        QtMocHelpers::SlotData<void(Server *, Konversation::ConnectionState)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { 0x80000000 | 13, 2 },
        }}),
        // Slot 'queryTextEntered'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'queryPassthroughCommand'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sendFileMenu'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'urlsDropped'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'textPasted'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'nickInfoChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateNickInfo'
        QtMocHelpers::SlotData<void(Server *, const NickInfoPtr &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 23 }, { 0x80000000 | 24, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Query, qt_meta_tag_ZN5QueryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Query::staticMetaObject = { {
    QMetaObject::SuperData::link<ChatWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5QueryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5QueryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5QueryE_t>.metaTypes,
    nullptr
} };

void Query::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Query *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sendFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->updateQueryChrome((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->sendText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->indicateAway((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setEncryptedOutput((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->connectionStateChanged((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionState>>(_a[2]))); break;
        case 6: _t->queryTextEntered(); break;
        case 7: _t->queryPassthroughCommand(); break;
        case 8: _t->sendFileMenu(); break;
        case 9: _t->urlsDropped((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 10: _t->textPasted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->nickInfoChanged(); break;
        case 12: _t->updateNickInfo((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NickInfoPtr>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ChatWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Query::*)(const QString & )>(_a, &Query::sendFile, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Query::*)(ChatWindow * , const QString & )>(_a, &Query::updateQueryChrome, 1))
            return;
    }
}

const QMetaObject *Query::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Query::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5QueryE_t>.strings))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int Query::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Query::sendFile(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Query::updateQueryChrome(ChatWindow * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
