/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

*/

/********************************************************************************
** Form generated from reading UI file 'ignore_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IGNORE_CONFIGUI_H
#define UI_IGNORE_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_Ignore_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QTreeWidget *ignoreListView;
    QLabel *textLabel2;
    KLineEdit *txtPattern;
    QGroupBox *grpMessageTypes;
    QGridLayout *gridLayout1;
    QCheckBox *chkCTCP;
    QCheckBox *chkChannel;
    QCheckBox *chkDCC;
    QCheckBox *chkNotice;
    QCheckBox *chkQuery;
    QCheckBox *chkInvite;
    QVBoxLayout *vboxLayout;
    QPushButton *newButton;
    QPushButton *removeButton;
    QPushButton *removeAllButton;
    QSpacerItem *spacer9;

    void setupUi(QWidget *Ignore_ConfigUI)
    {
        if (Ignore_ConfigUI->objectName().isEmpty())
            Ignore_ConfigUI->setObjectName("Ignore_ConfigUI");
        Ignore_ConfigUI->resize(374, 349);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Ignore_ConfigUI->sizePolicy().hasHeightForWidth());
        Ignore_ConfigUI->setSizePolicy(sizePolicy);
        Ignore_ConfigUI->setBaseSize(QSize(300, 200));
        gridLayout = new QGridLayout(Ignore_ConfigUI);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        ignoreListView = new QTreeWidget(Ignore_ConfigUI);
        ignoreListView->setObjectName("ignoreListView");
        ignoreListView->setRootIsDecorated(false);
        ignoreListView->setSortingEnabled(true);

        gridLayout->addWidget(ignoreListView, 0, 0, 1, 2);

        textLabel2 = new QLabel(Ignore_ConfigUI);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout->addWidget(textLabel2, 1, 0, 1, 1);

        txtPattern = new KLineEdit(Ignore_ConfigUI);
        txtPattern->setObjectName("txtPattern");

        gridLayout->addWidget(txtPattern, 1, 1, 1, 1);

        grpMessageTypes = new QGroupBox(Ignore_ConfigUI);
        grpMessageTypes->setObjectName("grpMessageTypes");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(grpMessageTypes->sizePolicy().hasHeightForWidth());
        grpMessageTypes->setSizePolicy(sizePolicy1);
        gridLayout1 = new QGridLayout(grpMessageTypes);
        gridLayout1->setObjectName("gridLayout1");
        chkCTCP = new QCheckBox(grpMessageTypes);
        chkCTCP->setObjectName("chkCTCP");

        gridLayout1->addWidget(chkCTCP, 0, 1, 1, 1);

        chkChannel = new QCheckBox(grpMessageTypes);
        chkChannel->setObjectName("chkChannel");

        gridLayout1->addWidget(chkChannel, 0, 0, 1, 1);

        chkDCC = new QCheckBox(grpMessageTypes);
        chkDCC->setObjectName("chkDCC");

        gridLayout1->addWidget(chkDCC, 1, 1, 1, 1);

        chkNotice = new QCheckBox(grpMessageTypes);
        chkNotice->setObjectName("chkNotice");

        gridLayout1->addWidget(chkNotice, 2, 0, 1, 1);

        chkQuery = new QCheckBox(grpMessageTypes);
        chkQuery->setObjectName("chkQuery");

        gridLayout1->addWidget(chkQuery, 1, 0, 1, 1);

        chkInvite = new QCheckBox(grpMessageTypes);
        chkInvite->setObjectName("chkInvite");

        gridLayout1->addWidget(chkInvite, 2, 1, 1, 1);


        gridLayout->addWidget(grpMessageTypes, 2, 0, 1, 2);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        newButton = new QPushButton(Ignore_ConfigUI);
        newButton->setObjectName("newButton");

        vboxLayout->addWidget(newButton);

        removeButton = new QPushButton(Ignore_ConfigUI);
        removeButton->setObjectName("removeButton");

        vboxLayout->addWidget(removeButton);

        removeAllButton = new QPushButton(Ignore_ConfigUI);
        removeAllButton->setObjectName("removeAllButton");

        vboxLayout->addWidget(removeAllButton);

        spacer9 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer9);


        gridLayout->addLayout(vboxLayout, 0, 2, 3, 1);

        QWidget::setTabOrder(ignoreListView, txtPattern);
        QWidget::setTabOrder(txtPattern, chkChannel);
        QWidget::setTabOrder(chkChannel, chkQuery);
        QWidget::setTabOrder(chkQuery, chkNotice);
        QWidget::setTabOrder(chkNotice, chkCTCP);
        QWidget::setTabOrder(chkCTCP, chkDCC);
        QWidget::setTabOrder(chkDCC, chkInvite);
        QWidget::setTabOrder(chkInvite, newButton);
        QWidget::setTabOrder(newButton, removeButton);
        QWidget::setTabOrder(removeButton, removeAllButton);

        retranslateUi(Ignore_ConfigUI);

        QMetaObject::connectSlotsByName(Ignore_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *Ignore_ConfigUI)
    {
        QTreeWidgetItem *___qtreewidgetitem = ignoreListView->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Type", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Pattern", nullptr));
        textLabel2->setText(tr2i18n("Pattern:", nullptr));
        grpMessageTypes->setTitle(tr2i18n("Message Types", nullptr));
        chkCTCP->setText(tr2i18n("CTCP", nullptr));
        chkChannel->setText(tr2i18n("Channel", nullptr));
        chkDCC->setText(tr2i18n("DCC", nullptr));
        chkNotice->setText(tr2i18n("Notice", nullptr));
        chkQuery->setText(tr2i18n("Query", nullptr));
        chkInvite->setText(tr2i18n("Invite", nullptr));
        newButton->setText(tr2i18n("&New", nullptr));
        removeButton->setText(tr2i18n("&Remove", nullptr));
        removeAllButton->setText(tr2i18n("Remove &All", nullptr));
        (void)Ignore_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class Ignore_ConfigUI: public Ui_Ignore_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IGNORE_CONFIGUI_H

