// This file is generated by kconfig_compiler_kf6 from konversation_state.kcfg.
// All changes you do to this file will be lost.
#ifndef KONVERSATIONSTATE_H
#define KONVERSATIONSTATE_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KonversationState : public KConfigSkeleton
{
  public:

    static KonversationState *self();
    ~KonversationState() override;

    /**
      Set TreeSplitterSizes
    */
    static
    void setTreeSplitterSizes( const QList<int> & v )
    {
      if (!self()->isTreeSplitterSizesImmutable())
        self()->mTreeSplitterSizes = v;
    }

    /**
      Get TreeSplitterSizes
    */
    static
    QList<int> treeSplitterSizes()
    {
      return self()->mTreeSplitterSizes;
    }

    /**
      Is TreeSplitterSizes Immutable
    */
    static
    bool isTreeSplitterSizesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TreeSplitterSizes" ) );
    }

    /**
      Get Item object corresponding to TreeSplitterSizes()
    */
    ItemIntList *treeSplitterSizesItem()
    {
      return mTreeSplitterSizesItem;
    }

    /**
      Set TopicSplitterSizes
    */
    static
    void setTopicSplitterSizes( const QList<int> & v )
    {
      if (!self()->isTopicSplitterSizesImmutable())
        self()->mTopicSplitterSizes = v;
    }

    /**
      Get TopicSplitterSizes
    */
    static
    QList<int> topicSplitterSizes()
    {
      return self()->mTopicSplitterSizes;
    }

    /**
      Is TopicSplitterSizes Immutable
    */
    static
    bool isTopicSplitterSizesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TopicSplitterSizes" ) );
    }

    /**
      Get Item object corresponding to TopicSplitterSizes()
    */
    ItemIntList *topicSplitterSizesItem()
    {
      return mTopicSplitterSizesItem;
    }

    /**
      Set ChannelSplitterSizes
    */
    static
    void setChannelSplitterSizes( const QList<int> & v )
    {
      if (!self()->isChannelSplitterSizesImmutable())
        self()->mChannelSplitterSizes = v;
    }

    /**
      Get ChannelSplitterSizes
    */
    static
    QList<int> channelSplitterSizes()
    {
      return self()->mChannelSplitterSizes;
    }

    /**
      Is ChannelSplitterSizes Immutable
    */
    static
    bool isChannelSplitterSizesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ChannelSplitterSizes" ) );
    }

    /**
      Get Item object corresponding to ChannelSplitterSizes()
    */
    ItemIntList *channelSplitterSizesItem()
    {
      return mChannelSplitterSizesItem;
    }

  protected:
    KonversationState();
    friend class KonversationStateHelper;


    // Appearance
    QList<int> mTreeSplitterSizes;
    QList<int> mTopicSplitterSizes;
    QList<int> mChannelSplitterSizes;

  private:
    ItemIntList *mTreeSplitterSizesItem;
    ItemIntList *mTopicSplitterSizesItem;
    ItemIntList *mChannelSplitterSizesItem;
};

#endif

