/********************************************************************************
** Form generated from reading UI file 'osd_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OSD_CONFIGUI_H
#define UI_OSD_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_OSD_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacer1;
    QCheckBox *kcfg_UseOSD;
    QGroupBox *groupBox2;
    QGridLayout *gridLayout1;
    QCheckBox *kcfg_OSDDrawShadow;
    QLabel *textLabel1;
    KFontRequester *kcfg_OSDFont;
    QSpinBox *kcfg_OSDOffsetX;
    QSpinBox *kcfg_OSDOffsetY;
    QSpinBox *kcfg_OSDAlignment;
    QGroupBox *groupBox3;
    QGridLayout *gridLayout2;
    QCheckBox *kcfg_OSDShowOwnNick;
    QCheckBox *kcfg_OSDShowChannel;
    QCheckBox *kcfg_OSDShowQuery;
    QCheckBox *kcfg_OSDShowChannelEvent;
    QGroupBox *kcfg_OSDUseCustomColors;
    QFormLayout *formLayout;
    QLabel *textLabel2;
    QLabel *textLabel3;
    KColorButton *kcfg_OSDTextColor;
    KColorButton *kcfg_OSDBackgroundColor;
    QGroupBox *groupBox4;
    QFormLayout *formLayout1;
    QLabel *textLabel1_2;
    QLabel *textLabel2_2;
    QSpinBox *kcfg_OSDDuration;
    QComboBox *kcfg_OSDScreen;

    void setupUi(QWidget *OSD_ConfigUI)
    {
        if (OSD_ConfigUI->objectName().isEmpty())
            OSD_ConfigUI->setObjectName("OSD_ConfigUI");
        OSD_ConfigUI->resize(447, 486);
        gridLayout = new QGridLayout(OSD_ConfigUI);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        spacer1 = new QSpacerItem(21, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacer1, 5, 0, 1, 1);

        kcfg_UseOSD = new QCheckBox(OSD_ConfigUI);
        kcfg_UseOSD->setObjectName("kcfg_UseOSD");

        gridLayout->addWidget(kcfg_UseOSD, 0, 0, 1, 1);

        groupBox2 = new QGroupBox(OSD_ConfigUI);
        groupBox2->setObjectName("groupBox2");
        groupBox2->setEnabled(false);
        gridLayout1 = new QGridLayout(groupBox2);
        gridLayout1->setObjectName("gridLayout1");
        kcfg_OSDDrawShadow = new QCheckBox(groupBox2);
        kcfg_OSDDrawShadow->setObjectName("kcfg_OSDDrawShadow");
        kcfg_OSDDrawShadow->setEnabled(false);

        gridLayout1->addWidget(kcfg_OSDDrawShadow, 0, 0, 1, 2);

        textLabel1 = new QLabel(groupBox2);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setEnabled(false);
        textLabel1->setFrameShadow(QFrame::Sunken);
        textLabel1->setWordWrap(false);

        gridLayout1->addWidget(textLabel1, 1, 0, 1, 1);

        kcfg_OSDFont = new KFontRequester(groupBox2);
        kcfg_OSDFont->setObjectName("kcfg_OSDFont");
        kcfg_OSDFont->setEnabled(false);

        gridLayout1->addWidget(kcfg_OSDFont, 1, 1, 1, 1);

        kcfg_OSDOffsetX = new QSpinBox(groupBox2);
        kcfg_OSDOffsetX->setObjectName("kcfg_OSDOffsetX");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_OSDOffsetX->sizePolicy().hasHeightForWidth());
        kcfg_OSDOffsetX->setSizePolicy(sizePolicy);
        kcfg_OSDOffsetX->setMinimum(-2048);
        kcfg_OSDOffsetX->setMaximum(2048);

        gridLayout1->addWidget(kcfg_OSDOffsetX, 0, 2, 1, 1);

        kcfg_OSDOffsetY = new QSpinBox(groupBox2);
        kcfg_OSDOffsetY->setObjectName("kcfg_OSDOffsetY");
        sizePolicy.setHeightForWidth(kcfg_OSDOffsetY->sizePolicy().hasHeightForWidth());
        kcfg_OSDOffsetY->setSizePolicy(sizePolicy);
        kcfg_OSDOffsetY->setMinimum(-2048);
        kcfg_OSDOffsetY->setMaximum(2048);

        gridLayout1->addWidget(kcfg_OSDOffsetY, 0, 3, 1, 1);

        kcfg_OSDAlignment = new QSpinBox(groupBox2);
        kcfg_OSDAlignment->setObjectName("kcfg_OSDAlignment");
        sizePolicy.setHeightForWidth(kcfg_OSDAlignment->sizePolicy().hasHeightForWidth());
        kcfg_OSDAlignment->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(kcfg_OSDAlignment, 0, 4, 1, 1);


        gridLayout->addWidget(groupBox2, 1, 0, 1, 1);

        groupBox3 = new QGroupBox(OSD_ConfigUI);
        groupBox3->setObjectName("groupBox3");
        groupBox3->setEnabled(false);
        gridLayout2 = new QGridLayout(groupBox3);
        gridLayout2->setObjectName("gridLayout2");
        kcfg_OSDShowOwnNick = new QCheckBox(groupBox3);
        kcfg_OSDShowOwnNick->setObjectName("kcfg_OSDShowOwnNick");

        gridLayout2->addWidget(kcfg_OSDShowOwnNick, 0, 0, 1, 1);

        kcfg_OSDShowChannel = new QCheckBox(groupBox3);
        kcfg_OSDShowChannel->setObjectName("kcfg_OSDShowChannel");

        gridLayout2->addWidget(kcfg_OSDShowChannel, 1, 0, 1, 1);

        kcfg_OSDShowQuery = new QCheckBox(groupBox3);
        kcfg_OSDShowQuery->setObjectName("kcfg_OSDShowQuery");

        gridLayout2->addWidget(kcfg_OSDShowQuery, 2, 0, 1, 1);

        kcfg_OSDShowChannelEvent = new QCheckBox(groupBox3);
        kcfg_OSDShowChannelEvent->setObjectName("kcfg_OSDShowChannelEvent");

        gridLayout2->addWidget(kcfg_OSDShowChannelEvent, 3, 0, 1, 1);


        gridLayout->addWidget(groupBox3, 2, 0, 1, 1);

        kcfg_OSDUseCustomColors = new QGroupBox(OSD_ConfigUI);
        kcfg_OSDUseCustomColors->setObjectName("kcfg_OSDUseCustomColors");
        kcfg_OSDUseCustomColors->setEnabled(false);
        kcfg_OSDUseCustomColors->setCheckable(true);
        kcfg_OSDUseCustomColors->setChecked(false);
        formLayout = new QFormLayout(kcfg_OSDUseCustomColors);
        formLayout->setObjectName("formLayout");
        textLabel2 = new QLabel(kcfg_OSDUseCustomColors);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel2);

        textLabel3 = new QLabel(kcfg_OSDUseCustomColors);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel3);

        kcfg_OSDTextColor = new KColorButton(kcfg_OSDUseCustomColors);
        kcfg_OSDTextColor->setObjectName("kcfg_OSDTextColor");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_OSDTextColor);

        kcfg_OSDBackgroundColor = new KColorButton(kcfg_OSDUseCustomColors);
        kcfg_OSDBackgroundColor->setObjectName("kcfg_OSDBackgroundColor");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_OSDBackgroundColor);


        gridLayout->addWidget(kcfg_OSDUseCustomColors, 3, 0, 1, 1);

        groupBox4 = new QGroupBox(OSD_ConfigUI);
        groupBox4->setObjectName("groupBox4");
        groupBox4->setEnabled(false);
        formLayout1 = new QFormLayout(groupBox4);
        formLayout1->setObjectName("formLayout1");
        textLabel1_2 = new QLabel(groupBox4);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        formLayout1->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel1_2);

        textLabel2_2 = new QLabel(groupBox4);
        textLabel2_2->setObjectName("textLabel2_2");
        textLabel2_2->setWordWrap(false);

        formLayout1->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel2_2);

        kcfg_OSDDuration = new QSpinBox(groupBox4);
        kcfg_OSDDuration->setObjectName("kcfg_OSDDuration");
        kcfg_OSDDuration->setMinimum(500);
        kcfg_OSDDuration->setMaximum(10000);
        kcfg_OSDDuration->setSingleStep(100);

        formLayout1->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_OSDDuration);

        kcfg_OSDScreen = new QComboBox(groupBox4);
        kcfg_OSDScreen->setObjectName("kcfg_OSDScreen");

        formLayout1->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_OSDScreen);


        gridLayout->addWidget(groupBox4, 4, 0, 1, 1);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(kcfg_OSDFont);
        textLabel2->setBuddy(kcfg_OSDTextColor);
        textLabel3->setBuddy(kcfg_OSDBackgroundColor);
        textLabel1_2->setBuddy(kcfg_OSDDuration);
        textLabel2_2->setBuddy(kcfg_OSDScreen);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_UseOSD, kcfg_OSDDrawShadow);
        QWidget::setTabOrder(kcfg_OSDDrawShadow, kcfg_OSDFont);
        QWidget::setTabOrder(kcfg_OSDFont, kcfg_OSDOffsetX);
        QWidget::setTabOrder(kcfg_OSDOffsetX, kcfg_OSDOffsetY);
        QWidget::setTabOrder(kcfg_OSDOffsetY, kcfg_OSDAlignment);
        QWidget::setTabOrder(kcfg_OSDAlignment, kcfg_OSDShowOwnNick);
        QWidget::setTabOrder(kcfg_OSDShowOwnNick, kcfg_OSDShowChannel);
        QWidget::setTabOrder(kcfg_OSDShowChannel, kcfg_OSDShowQuery);
        QWidget::setTabOrder(kcfg_OSDShowQuery, kcfg_OSDShowChannelEvent);
        QWidget::setTabOrder(kcfg_OSDShowChannelEvent, kcfg_OSDUseCustomColors);
        QWidget::setTabOrder(kcfg_OSDUseCustomColors, kcfg_OSDTextColor);
        QWidget::setTabOrder(kcfg_OSDTextColor, kcfg_OSDBackgroundColor);
        QWidget::setTabOrder(kcfg_OSDBackgroundColor, kcfg_OSDDuration);
        QWidget::setTabOrder(kcfg_OSDDuration, kcfg_OSDScreen);
        QWidget::setTabOrder(kcfg_OSDScreen, kcfg_OSDUseCustomColors);

        retranslateUi(OSD_ConfigUI);
        QObject::connect(kcfg_UseOSD, &QCheckBox::toggled, kcfg_OSDDrawShadow, &QCheckBox::setEnabled);
        QObject::connect(kcfg_UseOSD, &QCheckBox::toggled, groupBox3, &QGroupBox::setEnabled);
        QObject::connect(kcfg_UseOSD, &QCheckBox::toggled, kcfg_OSDUseCustomColors, &QGroupBox::setEnabled);
        QObject::connect(kcfg_UseOSD, &QCheckBox::toggled, groupBox4, &QGroupBox::setEnabled);
        QObject::connect(kcfg_UseOSD, &QCheckBox::toggled, textLabel1, &QLabel::setEnabled);
        QObject::connect(kcfg_UseOSD, SIGNAL(toggled(bool)), kcfg_OSDFont, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_UseOSD, &QCheckBox::toggled, groupBox2, &QGroupBox::setEnabled);

        QMetaObject::connectSlotsByName(OSD_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *OSD_ConfigUI)
    {
        kcfg_UseOSD->setText(tr2i18n("&Enable On Screen Display", nullptr));
        groupBox2->setTitle(tr2i18n("On &Screen Display", nullptr));
        kcfg_OSDDrawShadow->setText(tr2i18n("&Draw shadows", nullptr));
        textLabel1->setText(tr2i18n("OSD font:", nullptr));
        groupBox3->setTitle(tr2i18n("Show &OSD Message", nullptr));
        kcfg_OSDShowOwnNick->setText(tr2i18n("&If own nick appears in channel message", nullptr));
        kcfg_OSDShowChannel->setText(tr2i18n("On an&y channel message", nullptr));
        kcfg_OSDShowQuery->setText(tr2i18n("On &query activity", nullptr));
        kcfg_OSDShowChannelEvent->setText(tr2i18n("On &Join/Part events", nullptr));
        kcfg_OSDUseCustomColors->setTitle(tr2i18n("Enable Custom Colors", nullptr));
        textLabel2->setText(tr2i18n("Te&xt color:", nullptr));
        textLabel3->setText(tr2i18n("&Background color:", nullptr));
        kcfg_OSDTextColor->setText(QString());
        kcfg_OSDBackgroundColor->setText(QString());
        groupBox4->setTitle(tr2i18n("O&ther Settings", nullptr));
        textLabel1_2->setText(tr2i18n("&Duration:", nullptr));
        textLabel2_2->setText(tr2i18n("S&creen:", nullptr));
        kcfg_OSDDuration->setSuffix(tr2i18n(" ms", nullptr));
        (void)OSD_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class OSD_ConfigUI: public Ui_OSD_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OSD_CONFIGUI_H

