/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

*/

/********************************************************************************
** Form generated from reading UI file 'fontappearance_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FONTAPPEARANCE_CONFIG_H
#define UI_FONTAPPEARANCE_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_FontAppearance_Config
{
public:
    QGridLayout *gridLayout;
    QCheckBox *kcfg_CustomTextFont;
    KFontRequester *kcfg_TextFont;
    QCheckBox *kcfg_CustomListFont;
    KFontRequester *kcfg_ListFont;
    QCheckBox *kcfg_CustomTabFont;
    KFontRequester *kcfg_TabFont;
    QCheckBox *kcfg_FixedMOTD;
    QCheckBox *kcfg_UseBoldNicks;
    QSpacerItem *spacer89;

    void setupUi(QWidget *FontAppearance_Config)
    {
        if (FontAppearance_Config->objectName().isEmpty())
            FontAppearance_Config->setObjectName("FontAppearance_Config");
        FontAppearance_Config->resize(458, 165);
        gridLayout = new QGridLayout(FontAppearance_Config);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        kcfg_CustomTextFont = new QCheckBox(FontAppearance_Config);
        kcfg_CustomTextFont->setObjectName("kcfg_CustomTextFont");
        kcfg_CustomTextFont->setEnabled(true);

        gridLayout->addWidget(kcfg_CustomTextFont, 0, 0, 1, 1);

        kcfg_TextFont = new KFontRequester(FontAppearance_Config);
        kcfg_TextFont->setObjectName("kcfg_TextFont");
        kcfg_TextFont->setEnabled(false);

        gridLayout->addWidget(kcfg_TextFont, 0, 1, 1, 1);

        kcfg_CustomListFont = new QCheckBox(FontAppearance_Config);
        kcfg_CustomListFont->setObjectName("kcfg_CustomListFont");
        kcfg_CustomListFont->setEnabled(true);

        gridLayout->addWidget(kcfg_CustomListFont, 1, 0, 1, 1);

        kcfg_ListFont = new KFontRequester(FontAppearance_Config);
        kcfg_ListFont->setObjectName("kcfg_ListFont");
        kcfg_ListFont->setEnabled(false);

        gridLayout->addWidget(kcfg_ListFont, 1, 1, 1, 1);

        kcfg_CustomTabFont = new QCheckBox(FontAppearance_Config);
        kcfg_CustomTabFont->setObjectName("kcfg_CustomTabFont");
        kcfg_CustomTabFont->setEnabled(true);

        gridLayout->addWidget(kcfg_CustomTabFont, 2, 0, 1, 1);

        kcfg_TabFont = new KFontRequester(FontAppearance_Config);
        kcfg_TabFont->setObjectName("kcfg_TabFont");
        kcfg_TabFont->setEnabled(false);

        gridLayout->addWidget(kcfg_TabFont, 2, 1, 1, 1);

        kcfg_FixedMOTD = new QCheckBox(FontAppearance_Config);
        kcfg_FixedMOTD->setObjectName("kcfg_FixedMOTD");

        gridLayout->addWidget(kcfg_FixedMOTD, 3, 0, 1, 2);

        kcfg_UseBoldNicks = new QCheckBox(FontAppearance_Config);
        kcfg_UseBoldNicks->setObjectName("kcfg_UseBoldNicks");

        gridLayout->addWidget(kcfg_UseBoldNicks, 4, 0, 1, 2);

        spacer89 = new QSpacerItem(20, 161, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacer89, 5, 1, 1, 1);

        QWidget::setTabOrder(kcfg_CustomTextFont, kcfg_TextFont);
        QWidget::setTabOrder(kcfg_TextFont, kcfg_CustomListFont);
        QWidget::setTabOrder(kcfg_CustomListFont, kcfg_ListFont);
        QWidget::setTabOrder(kcfg_ListFont, kcfg_CustomTabFont);
        QWidget::setTabOrder(kcfg_CustomTabFont, kcfg_TabFont);
        QWidget::setTabOrder(kcfg_TabFont, kcfg_FixedMOTD);
        QWidget::setTabOrder(kcfg_FixedMOTD, kcfg_UseBoldNicks);

        retranslateUi(FontAppearance_Config);
        QObject::connect(kcfg_CustomTextFont, SIGNAL(toggled(bool)), kcfg_TextFont, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_CustomListFont, SIGNAL(toggled(bool)), kcfg_ListFont, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_CustomTabFont, SIGNAL(toggled(bool)), kcfg_TabFont, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(FontAppearance_Config);
    } // setupUi

    void retranslateUi(QWidget *FontAppearance_Config)
    {
        kcfg_CustomTextFont->setText(tr2i18n("Chat text:", nullptr));
        kcfg_CustomListFont->setText(tr2i18n("Nickname list:", nullptr));
        kcfg_CustomTabFont->setText(tr2i18n("Tab bar:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_FixedMOTD->setWhatsThis(tr2i18n("Show MOTD (Message Of The Day) message in fixed font", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_FixedMOTD->setText(tr2i18n("Enable fi&xed font for MOTD messages", nullptr));
        kcfg_UseBoldNicks->setText(tr2i18n("Show sender nicknames &bold in the chat view", nullptr));
        (void)FontAppearance_Config;
    } // retranslateUi

};

namespace Ui {
    class FontAppearance_Config: public Ui_FontAppearance_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FONTAPPEARANCE_CONFIG_H

