/****************************************************************************
** Meta object code from reading C++ file 'whiteboardpaintarea.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/dcc/whiteboardpaintarea.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'whiteboardpaintarea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Konversation3DCC19WhiteBoardPaintAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::DCC::WhiteBoardPaintArea::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation3DCC19WhiteBoardPaintAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::DCC::WhiteBoardPaintArea",
        "drawedPencil",
        "",
        "lineWidth",
        "QColor",
        "penColor",
        "brushColor",
        "xFrom",
        "yFrom",
        "xTo",
        "yTo",
        "drawedLine",
        "drawedRectangle",
        "drawedFilledRectangle",
        "drawedEllipse",
        "drawedFilledEllipse",
        "drawedArrow",
        "usedEraser",
        "usedFloodFill",
        "x",
        "y",
        "color",
        "usedText",
        "text",
        "usedTextExtended",
        "QFont",
        "font",
        "textColor",
        "background",
        "colorPicked",
        "setTool",
        "Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool",
        "tool",
        "setForegroundColor",
        "setBackgroundColor",
        "swapColors",
        "newForeground",
        "newBackground",
        "setPenWidth",
        "width",
        "setFont",
        "clear",
        "drawLine",
        "drawRectangle",
        "drawFilledRectangle",
        "drawEllipse",
        "drawFilledEllipse",
        "drawArrow",
        "useEraser",
        "useFloodFill",
        "useBlt",
        "x1src",
        "y1src",
        "x2src",
        "y2src",
        "xdest",
        "ydest",
        "useText",
        "x1",
        "y1",
        "textString",
        "useTextExtended",
        "foreGround",
        "backGround",
        "save",
        "fileName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'drawedPencil'
        QtMocHelpers::SignalData<void(int, const QColor &, const QColor &, int, int, int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { QMetaType::Int, 7 },
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'drawedLine'
        QtMocHelpers::SignalData<void(int, const QColor &, const QColor &, int, int, int, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { QMetaType::Int, 7 },
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'drawedRectangle'
        QtMocHelpers::SignalData<void(int, const QColor &, int, int, int, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
            { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'drawedFilledRectangle'
        QtMocHelpers::SignalData<void(int, const QColor &, const QColor &, int, int, int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { QMetaType::Int, 7 },
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'drawedEllipse'
        QtMocHelpers::SignalData<void(int, const QColor &, int, int, int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
            { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'drawedFilledEllipse'
        QtMocHelpers::SignalData<void(int, const QColor &, const QColor &, int, int, int, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { QMetaType::Int, 7 },
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'drawedArrow'
        QtMocHelpers::SignalData<void(int, const QColor &, int, int, int, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
            { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'usedEraser'
        QtMocHelpers::SignalData<void(int, int, int, int, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
            { QMetaType::Int, 10 },
        }}),
        // Signal 'usedFloodFill'
        QtMocHelpers::SignalData<void(int, int, const QColor &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 }, { 0x80000000 | 4, 21 },
        }}),
        // Signal 'usedText'
        QtMocHelpers::SignalData<void(int, int, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 }, { QMetaType::QString, 23 },
        }}),
        // Signal 'usedTextExtended'
        QtMocHelpers::SignalData<void(int, int, const QFont &, const QColor &, const QColor &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 4, 27 },
            { 0x80000000 | 4, 28 }, { QMetaType::QString, 23 },
        }}),
        // Signal 'colorPicked'
        QtMocHelpers::SignalData<void(const QColor &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 21 },
        }}),
        // Slot 'setTool'
        QtMocHelpers::SlotData<void(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'setForegroundColor'
        QtMocHelpers::SlotData<void(const QColor &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 21 },
        }}),
        // Slot 'setBackgroundColor'
        QtMocHelpers::SlotData<void(const QColor &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 21 },
        }}),
        // Slot 'swapColors'
        QtMocHelpers::SlotData<void(const QColor &, const QColor &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 36 }, { 0x80000000 | 4, 37 },
        }}),
        // Slot 'setPenWidth'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'setFont'
        QtMocHelpers::SlotData<void(const QFont &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'drawLine'
        QtMocHelpers::SlotData<void(int, const QColor &, const QColor &, int, int, int, int)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { QMetaType::Int, 7 },
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'drawRectangle'
        QtMocHelpers::SlotData<void(int, const QColor &, int, int, int, int)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
            { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'drawFilledRectangle'
        QtMocHelpers::SlotData<void(int, const QColor &, const QColor &, int, int, int, int)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { QMetaType::Int, 7 },
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'drawEllipse'
        QtMocHelpers::SlotData<void(int, const QColor &, int, int, int, int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
            { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'drawFilledEllipse'
        QtMocHelpers::SlotData<void(int, const QColor &, const QColor &, int, int, int, int)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { QMetaType::Int, 7 },
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'drawArrow'
        QtMocHelpers::SlotData<void(int, const QColor &, int, int, int, int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
            { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'useEraser'
        QtMocHelpers::SlotData<void(int, int, int, int, int)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
            { QMetaType::Int, 10 },
        }}),
        // Slot 'useFloodFill'
        QtMocHelpers::SlotData<void(int, int, const QColor &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 }, { 0x80000000 | 4, 21 },
        }}),
        // Slot 'useBlt'
        QtMocHelpers::SlotData<void(int, int, int, int, int, int)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 51 }, { QMetaType::Int, 52 }, { QMetaType::Int, 53 }, { QMetaType::Int, 54 },
            { QMetaType::Int, 55 }, { QMetaType::Int, 56 },
        }}),
        // Slot 'useText'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 58 }, { QMetaType::Int, 59 }, { QMetaType::QString, 60 },
        }}),
        // Slot 'useTextExtended'
        QtMocHelpers::SlotData<void(int, int, const QFont &, const QColor &, const QColor &, const QString &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 58 }, { QMetaType::Int, 59 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 4, 62 },
            { 0x80000000 | 4, 63 }, { QMetaType::QString, 60 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void(const QString &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 65 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WhiteBoardPaintArea, qt_meta_tag_ZN12Konversation3DCC19WhiteBoardPaintAreaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konversation::DCC::WhiteBoardPaintArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC19WhiteBoardPaintAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC19WhiteBoardPaintAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation3DCC19WhiteBoardPaintAreaE_t>.metaTypes,
    nullptr
} };

void Konversation::DCC::WhiteBoardPaintArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WhiteBoardPaintArea *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->drawedPencil((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 1: _t->drawedLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 2: _t->drawedRectangle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 3: _t->drawedFilledRectangle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 4: _t->drawedEllipse((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 5: _t->drawedFilledEllipse((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 6: _t->drawedArrow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 7: _t->usedEraser((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 8: _t->usedFloodFill((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3]))); break;
        case 9: _t->usedText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 10: _t->usedTextExtended((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFont>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 11: _t->colorPicked((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 12: _t->setTool((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool>>(_a[1]))); break;
        case 13: _t->setForegroundColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 14: _t->setBackgroundColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 15: _t->swapColors((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        case 16: _t->setPenWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setFont((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 18: _t->clear(); break;
        case 19: _t->drawLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 20: _t->drawRectangle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 21: _t->drawFilledRectangle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 22: _t->drawEllipse((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 23: _t->drawFilledEllipse((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 24: _t->drawArrow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 25: _t->useEraser((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 26: _t->useFloodFill((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3]))); break;
        case 27: _t->useBlt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 28: _t->useText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 29: _t->useTextExtended((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFont>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 30: _t->save((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , const QColor & , const QColor & , int , int , int , int )>(_a, &WhiteBoardPaintArea::drawedPencil, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , const QColor & , const QColor & , int , int , int , int )>(_a, &WhiteBoardPaintArea::drawedLine, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , const QColor & , int , int , int , int )>(_a, &WhiteBoardPaintArea::drawedRectangle, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , const QColor & , const QColor & , int , int , int , int )>(_a, &WhiteBoardPaintArea::drawedFilledRectangle, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , const QColor & , int , int , int , int )>(_a, &WhiteBoardPaintArea::drawedEllipse, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , const QColor & , const QColor & , int , int , int , int )>(_a, &WhiteBoardPaintArea::drawedFilledEllipse, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , const QColor & , int , int , int , int )>(_a, &WhiteBoardPaintArea::drawedArrow, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , int , int , int , int )>(_a, &WhiteBoardPaintArea::usedEraser, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , int , const QColor & )>(_a, &WhiteBoardPaintArea::usedFloodFill, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , int , const QString & )>(_a, &WhiteBoardPaintArea::usedText, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(int , int , const QFont & , const QColor & , const QColor & , const QString & )>(_a, &WhiteBoardPaintArea::usedTextExtended, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardPaintArea::*)(const QColor & )>(_a, &WhiteBoardPaintArea::colorPicked, 11))
            return;
    }
}

const QMetaObject *Konversation::DCC::WhiteBoardPaintArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::WhiteBoardPaintArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC19WhiteBoardPaintAreaE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Konversation::DCC::WhiteBoardPaintArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::WhiteBoardPaintArea::drawedPencil(int _t1, const QColor & _t2, const QColor & _t3, int _t4, int _t5, int _t6, int _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 1
void Konversation::DCC::WhiteBoardPaintArea::drawedLine(int _t1, const QColor & _t2, const QColor & _t3, int _t4, int _t5, int _t6, int _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 2
void Konversation::DCC::WhiteBoardPaintArea::drawedRectangle(int _t1, const QColor & _t2, int _t3, int _t4, int _t5, int _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 3
void Konversation::DCC::WhiteBoardPaintArea::drawedFilledRectangle(int _t1, const QColor & _t2, const QColor & _t3, int _t4, int _t5, int _t6, int _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 4
void Konversation::DCC::WhiteBoardPaintArea::drawedEllipse(int _t1, const QColor & _t2, int _t3, int _t4, int _t5, int _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 5
void Konversation::DCC::WhiteBoardPaintArea::drawedFilledEllipse(int _t1, const QColor & _t2, const QColor & _t3, int _t4, int _t5, int _t6, int _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 6
void Konversation::DCC::WhiteBoardPaintArea::drawedArrow(int _t1, const QColor & _t2, int _t3, int _t4, int _t5, int _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 7
void Konversation::DCC::WhiteBoardPaintArea::usedEraser(int _t1, int _t2, int _t3, int _t4, int _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 8
void Konversation::DCC::WhiteBoardPaintArea::usedFloodFill(int _t1, int _t2, const QColor & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void Konversation::DCC::WhiteBoardPaintArea::usedText(int _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3);
}

// SIGNAL 10
void Konversation::DCC::WhiteBoardPaintArea::usedTextExtended(int _t1, int _t2, const QFont & _t3, const QColor & _t4, const QColor & _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 11
void Konversation::DCC::WhiteBoardPaintArea::colorPicked(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
