/********************************************************************************
** Form generated from reading UI file 'whiteboardtoolbarui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WHITEBOARDTOOLBARUI_H
#define UI_WHITEBOARDTOOLBARUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "whiteboardcolorchooser.h"

QT_BEGIN_NAMESPACE

class Ui_WhiteBoardToolBarUi
{
public:
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout_2;
    QPushButton *m_clearPushButton;
    QPushButton *m_savePushButton;
    QFrame *line;
    QGridLayout *gridLayout;
    QPushButton *m_pencilPushButton;
    QPushButton *m_linePushButton;
    QPushButton *m_rectanglePushButton;
    QPushButton *m_ellipsePushButton;
    QPushButton *m_textPushButton;
    QPushButton *m_selectionPushButton;
    QPushButton *m_eraserPushButton;
    QPushButton *m_fillPushButton;
    QPushButton *m_arrowPushButton;
    QPushButton *m_colorPickerPushButton;
    QFrame *m_lineWidthFrame;
    QVBoxLayout *verticalLayout;
    QSlider *m_lineWidthSlider;
    QLabel *m_lineWidthLabel;
    QListWidget *m_formOptionListWidget;
    QSpacerItem *verticalSpacer;
    Konversation::DCC::WhiteBoardColorChooser *m_colorChooser;

    void setupUi(QWidget *WhiteBoardToolBarUi)
    {
        if (WhiteBoardToolBarUi->objectName().isEmpty())
            WhiteBoardToolBarUi->setObjectName("WhiteBoardToolBarUi");
        WhiteBoardToolBarUi->resize(114, 333);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(WhiteBoardToolBarUi->sizePolicy().hasHeightForWidth());
        WhiteBoardToolBarUi->setSizePolicy(sizePolicy);
        WhiteBoardToolBarUi->setMinimumSize(QSize(100, 0));
        WhiteBoardToolBarUi->setMaximumSize(QSize(114, 16777215));
        verticalLayout_2 = new QVBoxLayout(WhiteBoardToolBarUi);
        verticalLayout_2->setSpacing(2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(1, 0, 1, 0);
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        m_clearPushButton = new QPushButton(WhiteBoardToolBarUi);
        m_clearPushButton->setObjectName("m_clearPushButton");

        gridLayout_2->addWidget(m_clearPushButton, 0, 0, 1, 1);

        m_savePushButton = new QPushButton(WhiteBoardToolBarUi);
        m_savePushButton->setObjectName("m_savePushButton");

        gridLayout_2->addWidget(m_savePushButton, 0, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        line = new QFrame(WhiteBoardToolBarUi);
        line->setObjectName("line");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(line->sizePolicy().hasHeightForWidth());
        line->setSizePolicy(sizePolicy1);
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        m_pencilPushButton = new QPushButton(WhiteBoardToolBarUi);
        m_pencilPushButton->setObjectName("m_pencilPushButton");
        m_pencilPushButton->setCheckable(true);
        m_pencilPushButton->setFlat(true);

        gridLayout->addWidget(m_pencilPushButton, 0, 0, 1, 1);

        m_linePushButton = new QPushButton(WhiteBoardToolBarUi);
        m_linePushButton->setObjectName("m_linePushButton");
        m_linePushButton->setCheckable(true);
        m_linePushButton->setFlat(true);

        gridLayout->addWidget(m_linePushButton, 0, 1, 1, 1);

        m_rectanglePushButton = new QPushButton(WhiteBoardToolBarUi);
        m_rectanglePushButton->setObjectName("m_rectanglePushButton");
        m_rectanglePushButton->setCheckable(true);
        m_rectanglePushButton->setFlat(true);

        gridLayout->addWidget(m_rectanglePushButton, 1, 0, 1, 1);

        m_ellipsePushButton = new QPushButton(WhiteBoardToolBarUi);
        m_ellipsePushButton->setObjectName("m_ellipsePushButton");
        m_ellipsePushButton->setCheckable(true);
        m_ellipsePushButton->setFlat(true);

        gridLayout->addWidget(m_ellipsePushButton, 1, 1, 1, 1);

        m_textPushButton = new QPushButton(WhiteBoardToolBarUi);
        m_textPushButton->setObjectName("m_textPushButton");
        m_textPushButton->setCheckable(true);
        m_textPushButton->setFlat(true);

        gridLayout->addWidget(m_textPushButton, 2, 0, 1, 1);

        m_selectionPushButton = new QPushButton(WhiteBoardToolBarUi);
        m_selectionPushButton->setObjectName("m_selectionPushButton");
        m_selectionPushButton->setCheckable(true);
        m_selectionPushButton->setFlat(true);

        gridLayout->addWidget(m_selectionPushButton, 2, 1, 1, 1);

        m_eraserPushButton = new QPushButton(WhiteBoardToolBarUi);
        m_eraserPushButton->setObjectName("m_eraserPushButton");
        m_eraserPushButton->setCheckable(true);
        m_eraserPushButton->setFlat(true);

        gridLayout->addWidget(m_eraserPushButton, 3, 0, 1, 1);

        m_fillPushButton = new QPushButton(WhiteBoardToolBarUi);
        m_fillPushButton->setObjectName("m_fillPushButton");
        m_fillPushButton->setCheckable(true);
        m_fillPushButton->setFlat(true);

        gridLayout->addWidget(m_fillPushButton, 3, 1, 1, 1);

        m_arrowPushButton = new QPushButton(WhiteBoardToolBarUi);
        m_arrowPushButton->setObjectName("m_arrowPushButton");
        m_arrowPushButton->setCheckable(true);
        m_arrowPushButton->setFlat(true);

        gridLayout->addWidget(m_arrowPushButton, 4, 0, 1, 1);

        m_colorPickerPushButton = new QPushButton(WhiteBoardToolBarUi);
        m_colorPickerPushButton->setObjectName("m_colorPickerPushButton");
        m_colorPickerPushButton->setCheckable(true);
        m_colorPickerPushButton->setFlat(true);

        gridLayout->addWidget(m_colorPickerPushButton, 4, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        m_lineWidthFrame = new QFrame(WhiteBoardToolBarUi);
        m_lineWidthFrame->setObjectName("m_lineWidthFrame");
        m_lineWidthFrame->setMaximumSize(QSize(110, 16777215));
        m_lineWidthFrame->setFrameShape(QFrame::StyledPanel);
        m_lineWidthFrame->setFrameShadow(QFrame::Sunken);
        verticalLayout = new QVBoxLayout(m_lineWidthFrame);
        verticalLayout->setSpacing(2);
        verticalLayout->setContentsMargins(2, 2, 2, 2);
        verticalLayout->setObjectName("verticalLayout");
        m_lineWidthSlider = new QSlider(m_lineWidthFrame);
        m_lineWidthSlider->setObjectName("m_lineWidthSlider");
        m_lineWidthSlider->setMinimum(1);
        m_lineWidthSlider->setMaximum(20);
        m_lineWidthSlider->setPageStep(4);
        m_lineWidthSlider->setValue(1);
        m_lineWidthSlider->setOrientation(Qt::Horizontal);
        m_lineWidthSlider->setTickPosition(QSlider::TicksAbove);

        verticalLayout->addWidget(m_lineWidthSlider);

        m_lineWidthLabel = new QLabel(m_lineWidthFrame);
        m_lineWidthLabel->setObjectName("m_lineWidthLabel");
        m_lineWidthLabel->setMinimumSize(QSize(0, 20));
        m_lineWidthLabel->setMaximumSize(QSize(16777215, 20));
        m_lineWidthLabel->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(m_lineWidthLabel);


        verticalLayout_2->addWidget(m_lineWidthFrame);

        m_formOptionListWidget = new QListWidget(WhiteBoardToolBarUi);
        m_formOptionListWidget->setObjectName("m_formOptionListWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(m_formOptionListWidget->sizePolicy().hasHeightForWidth());
        m_formOptionListWidget->setSizePolicy(sizePolicy2);
        m_formOptionListWidget->setMaximumSize(QSize(109, 50));
        m_formOptionListWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        m_formOptionListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        m_formOptionListWidget->setAutoScroll(false);
        m_formOptionListWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        m_formOptionListWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        m_formOptionListWidget->setTextElideMode(Qt::ElideMiddle);
        m_formOptionListWidget->setResizeMode(QListView::Fixed);
        m_formOptionListWidget->setViewMode(QListView::ListMode);
        m_formOptionListWidget->setUniformItemSizes(true);

        verticalLayout_2->addWidget(m_formOptionListWidget);

        verticalSpacer = new QSpacerItem(20, 116, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        m_colorChooser = new Konversation::DCC::WhiteBoardColorChooser(WhiteBoardToolBarUi);
        m_colorChooser->setObjectName("m_colorChooser");
        m_colorChooser->setMaximumSize(QSize(110, 16777215));

        verticalLayout_2->addWidget(m_colorChooser);

        QWidget::setTabOrder(m_clearPushButton, m_savePushButton);
        QWidget::setTabOrder(m_savePushButton, m_pencilPushButton);
        QWidget::setTabOrder(m_pencilPushButton, m_linePushButton);
        QWidget::setTabOrder(m_linePushButton, m_rectanglePushButton);
        QWidget::setTabOrder(m_rectanglePushButton, m_ellipsePushButton);
        QWidget::setTabOrder(m_ellipsePushButton, m_textPushButton);
        QWidget::setTabOrder(m_textPushButton, m_selectionPushButton);
        QWidget::setTabOrder(m_selectionPushButton, m_eraserPushButton);
        QWidget::setTabOrder(m_eraserPushButton, m_fillPushButton);
        QWidget::setTabOrder(m_fillPushButton, m_arrowPushButton);
        QWidget::setTabOrder(m_arrowPushButton, m_lineWidthSlider);
        QWidget::setTabOrder(m_lineWidthSlider, m_formOptionListWidget);

        retranslateUi(WhiteBoardToolBarUi);

        QMetaObject::connectSlotsByName(WhiteBoardToolBarUi);
    } // setupUi

    void retranslateUi(QWidget *WhiteBoardToolBarUi)
    {
        m_lineWidthLabel->setText(QString());
        (void)WhiteBoardToolBarUi;
    } // retranslateUi

};

namespace Ui {
    class WhiteBoardToolBarUi: public Ui_WhiteBoardToolBarUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WHITEBOARDTOOLBARUI_H

