/********************************************************************************
** Form generated from reading UI file 'identitydialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IDENTITYDIALOG_H
#define UI_IDENTITYDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "keditlistwidget.h"
#include "klineedit.h"
#include "kpasswordlineedit.h"
#include "kpluralhandlingspinbox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_IdentityDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *identityBarHLayout;
    QLabel *label;
    KComboBox *m_identityCBox;
    QHBoxLayout *identityButtonsHLayout;
    QPushButton *newBtn;
    QPushButton *copyBtn;
    QPushButton *m_editBtn;
    QPushButton *m_delBtn;
    QTabWidget *tabWidget;
    QWidget *generalWidget;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *realNameHLayout;
    QLabel *realNameLabel;
    KLineEdit *m_realNameEdit;
    QGroupBox *nickGroupBox;
    QVBoxLayout *verticalLayout_3;
    KEditListWidget *m_nicknameLBox;
    QGroupBox *autoIdentifyGroup;
    QFormLayout *autoIdentifyLayout;
    QLabel *authTypeLabel;
    KComboBox *m_authTypeCombo;
    QLabel *nickservNicknameLabel;
    KLineEdit *m_nickservNicknameEdit;
    QLabel *nickservCommandLabel;
    KLineEdit *m_nickservCommandEdit;
    QLabel *saslAccountLabel;
    KLineEdit *m_saslAccountEdit;
    QLabel *authPasswordLabel;
    KPasswordLineEdit *m_authPasswordEdit;
    QLabel *pemClientCertFileLabel;
    KUrlRequester *m_pemClientCertFile;
    QWidget *awayWidget;
    QFormLayout *formLayout_3;
    QCheckBox *m_insertRememberLineOnAwayChBox;
    QLabel *awayMessageLabel;
    KLineEdit *m_awayMessageEdit;
    QLabel *awayNicknameLabel;
    KLineEdit *m_awayNickEdit;
    QGroupBox *automaticAwayGroup;
    QGridLayout *gridLayout_3;
    QLabel *setAwayAfterLabel;
    KPluralHandlingSpinBox *m_awayInactivitySpin;
    QLabel *timeOfUserInactivityLabel;
    QCheckBox *m_automaticUnawayChBox;
    QGroupBox *awayCommandsGroup;
    QFormLayout *formLayout_2;
    QLabel *awayLabel;
    KLineEdit *m_awayEdit;
    QLabel *unAwayLabel;
    KLineEdit *m_unAwayEdit;
    QSpacerItem *awayWidgetVSpacer;
    QWidget *advancedWidget;
    QFormLayout *formLayout;
    QLabel *sCommandLabel;
    KLineEdit *m_sCommandEdit;
    QLabel *codecLabel;
    KComboBox *m_codecCBox;
    QLabel *loginLabel;
    KLineEdit *m_loginEdit;
    QLabel *quitLabel;
    KLineEdit *m_quitEdit;
    QLabel *partLabel;
    KLineEdit *m_partEdit;
    QLabel *kickLabel;
    KLineEdit *m_kickEdit;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *IdentityDialog)
    {
        if (IdentityDialog->objectName().isEmpty())
            IdentityDialog->setObjectName("IdentityDialog");
        IdentityDialog->resize(406, 640);
        verticalLayout_2 = new QVBoxLayout(IdentityDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        identityBarHLayout = new QHBoxLayout();
        identityBarHLayout->setObjectName("identityBarHLayout");
        label = new QLabel(IdentityDialog);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        identityBarHLayout->addWidget(label);

        m_identityCBox = new KComboBox(IdentityDialog);
        m_identityCBox->setObjectName("m_identityCBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_identityCBox->sizePolicy().hasHeightForWidth());
        m_identityCBox->setSizePolicy(sizePolicy1);

        identityBarHLayout->addWidget(m_identityCBox);

        identityButtonsHLayout = new QHBoxLayout();
        identityButtonsHLayout->setObjectName("identityButtonsHLayout");
        newBtn = new QPushButton(IdentityDialog);
        newBtn->setObjectName("newBtn");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(newBtn->sizePolicy().hasHeightForWidth());
        newBtn->setSizePolicy(sizePolicy2);
        newBtn->setMinimumSize(QSize(28, 28));
        newBtn->setMaximumSize(QSize(28, 28));
        newBtn->setIconSize(QSize(16, 16));

        identityButtonsHLayout->addWidget(newBtn);

        copyBtn = new QPushButton(IdentityDialog);
        copyBtn->setObjectName("copyBtn");
        sizePolicy2.setHeightForWidth(copyBtn->sizePolicy().hasHeightForWidth());
        copyBtn->setSizePolicy(sizePolicy2);
        copyBtn->setMinimumSize(QSize(28, 28));
        copyBtn->setMaximumSize(QSize(28, 28));
        copyBtn->setIconSize(QSize(16, 16));

        identityButtonsHLayout->addWidget(copyBtn);

        m_editBtn = new QPushButton(IdentityDialog);
        m_editBtn->setObjectName("m_editBtn");
        sizePolicy2.setHeightForWidth(m_editBtn->sizePolicy().hasHeightForWidth());
        m_editBtn->setSizePolicy(sizePolicy2);
        m_editBtn->setMinimumSize(QSize(28, 28));
        m_editBtn->setMaximumSize(QSize(28, 28));
        m_editBtn->setIconSize(QSize(16, 16));

        identityButtonsHLayout->addWidget(m_editBtn);

        m_delBtn = new QPushButton(IdentityDialog);
        m_delBtn->setObjectName("m_delBtn");
        sizePolicy2.setHeightForWidth(m_delBtn->sizePolicy().hasHeightForWidth());
        m_delBtn->setSizePolicy(sizePolicy2);
        m_delBtn->setMinimumSize(QSize(28, 28));
        m_delBtn->setMaximumSize(QSize(28, 28));
        m_delBtn->setIconSize(QSize(16, 16));

        identityButtonsHLayout->addWidget(m_delBtn);


        identityBarHLayout->addLayout(identityButtonsHLayout);


        verticalLayout_2->addLayout(identityBarHLayout);

        tabWidget = new QTabWidget(IdentityDialog);
        tabWidget->setObjectName("tabWidget");
        generalWidget = new QWidget();
        generalWidget->setObjectName("generalWidget");
        verticalLayout = new QVBoxLayout(generalWidget);
        verticalLayout->setObjectName("verticalLayout");
        realNameHLayout = new QHBoxLayout();
        realNameHLayout->setObjectName("realNameHLayout");
        realNameLabel = new QLabel(generalWidget);
        realNameLabel->setObjectName("realNameLabel");

        realNameHLayout->addWidget(realNameLabel);

        m_realNameEdit = new KLineEdit(generalWidget);
        m_realNameEdit->setObjectName("m_realNameEdit");

        realNameHLayout->addWidget(m_realNameEdit);


        verticalLayout->addLayout(realNameHLayout);

        nickGroupBox = new QGroupBox(generalWidget);
        nickGroupBox->setObjectName("nickGroupBox");
        verticalLayout_3 = new QVBoxLayout(nickGroupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_nicknameLBox = new KEditListWidget(nickGroupBox);
        m_nicknameLBox->setObjectName("m_nicknameLBox");
        m_nicknameLBox->setCheckAtEntering(true);

        verticalLayout_3->addWidget(m_nicknameLBox);


        verticalLayout->addWidget(nickGroupBox);

        autoIdentifyGroup = new QGroupBox(generalWidget);
        autoIdentifyGroup->setObjectName("autoIdentifyGroup");
        autoIdentifyLayout = new QFormLayout(autoIdentifyGroup);
        autoIdentifyLayout->setObjectName("autoIdentifyLayout");
        autoIdentifyLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        authTypeLabel = new QLabel(autoIdentifyGroup);
        authTypeLabel->setObjectName("authTypeLabel");

        autoIdentifyLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, authTypeLabel);

        m_authTypeCombo = new KComboBox(autoIdentifyGroup);
        m_authTypeCombo->setObjectName("m_authTypeCombo");

        autoIdentifyLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_authTypeCombo);

        nickservNicknameLabel = new QLabel(autoIdentifyGroup);
        nickservNicknameLabel->setObjectName("nickservNicknameLabel");

        autoIdentifyLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, nickservNicknameLabel);

        m_nickservNicknameEdit = new KLineEdit(autoIdentifyGroup);
        m_nickservNicknameEdit->setObjectName("m_nickservNicknameEdit");

        autoIdentifyLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, m_nickservNicknameEdit);

        nickservCommandLabel = new QLabel(autoIdentifyGroup);
        nickservCommandLabel->setObjectName("nickservCommandLabel");

        autoIdentifyLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, nickservCommandLabel);

        m_nickservCommandEdit = new KLineEdit(autoIdentifyGroup);
        m_nickservCommandEdit->setObjectName("m_nickservCommandEdit");

        autoIdentifyLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, m_nickservCommandEdit);

        saslAccountLabel = new QLabel(autoIdentifyGroup);
        saslAccountLabel->setObjectName("saslAccountLabel");

        autoIdentifyLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, saslAccountLabel);

        m_saslAccountEdit = new KLineEdit(autoIdentifyGroup);
        m_saslAccountEdit->setObjectName("m_saslAccountEdit");

        autoIdentifyLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, m_saslAccountEdit);

        authPasswordLabel = new QLabel(autoIdentifyGroup);
        authPasswordLabel->setObjectName("authPasswordLabel");

        autoIdentifyLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, authPasswordLabel);

        m_authPasswordEdit = new KPasswordLineEdit(autoIdentifyGroup);
        m_authPasswordEdit->setObjectName("m_authPasswordEdit");

        autoIdentifyLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, m_authPasswordEdit);

        pemClientCertFileLabel = new QLabel(autoIdentifyGroup);
        pemClientCertFileLabel->setObjectName("pemClientCertFileLabel");

        autoIdentifyLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, pemClientCertFileLabel);

        m_pemClientCertFile = new KUrlRequester(autoIdentifyGroup);
        m_pemClientCertFile->setObjectName("m_pemClientCertFile");

        autoIdentifyLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, m_pemClientCertFile);


        verticalLayout->addWidget(autoIdentifyGroup);

        tabWidget->addTab(generalWidget, QString());
        awayWidget = new QWidget();
        awayWidget->setObjectName("awayWidget");
        formLayout_3 = new QFormLayout(awayWidget);
        formLayout_3->setObjectName("formLayout_3");
        m_insertRememberLineOnAwayChBox = new QCheckBox(awayWidget);
        m_insertRememberLineOnAwayChBox->setObjectName("m_insertRememberLineOnAwayChBox");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::SpanningRole, m_insertRememberLineOnAwayChBox);

        awayMessageLabel = new QLabel(awayWidget);
        awayMessageLabel->setObjectName("awayMessageLabel");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, awayMessageLabel);

        m_awayMessageEdit = new KLineEdit(awayWidget);
        m_awayMessageEdit->setObjectName("m_awayMessageEdit");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, m_awayMessageEdit);

        awayNicknameLabel = new QLabel(awayWidget);
        awayNicknameLabel->setObjectName("awayNicknameLabel");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, awayNicknameLabel);

        m_awayNickEdit = new KLineEdit(awayWidget);
        m_awayNickEdit->setObjectName("m_awayNickEdit");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, m_awayNickEdit);

        automaticAwayGroup = new QGroupBox(awayWidget);
        automaticAwayGroup->setObjectName("automaticAwayGroup");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(automaticAwayGroup->sizePolicy().hasHeightForWidth());
        automaticAwayGroup->setSizePolicy(sizePolicy3);
        automaticAwayGroup->setCheckable(true);
        automaticAwayGroup->setChecked(false);
        gridLayout_3 = new QGridLayout(automaticAwayGroup);
        gridLayout_3->setObjectName("gridLayout_3");
        setAwayAfterLabel = new QLabel(automaticAwayGroup);
        setAwayAfterLabel->setObjectName("setAwayAfterLabel");
        sizePolicy2.setHeightForWidth(setAwayAfterLabel->sizePolicy().hasHeightForWidth());
        setAwayAfterLabel->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(setAwayAfterLabel, 0, 0, 1, 1);

        m_awayInactivitySpin = new KPluralHandlingSpinBox(automaticAwayGroup);
        m_awayInactivitySpin->setObjectName("m_awayInactivitySpin");
        sizePolicy2.setHeightForWidth(m_awayInactivitySpin->sizePolicy().hasHeightForWidth());
        m_awayInactivitySpin->setSizePolicy(sizePolicy2);
        m_awayInactivitySpin->setMinimum(1);

        gridLayout_3->addWidget(m_awayInactivitySpin, 0, 1, 1, 1);

        timeOfUserInactivityLabel = new QLabel(automaticAwayGroup);
        timeOfUserInactivityLabel->setObjectName("timeOfUserInactivityLabel");
        sizePolicy3.setHeightForWidth(timeOfUserInactivityLabel->sizePolicy().hasHeightForWidth());
        timeOfUserInactivityLabel->setSizePolicy(sizePolicy3);

        gridLayout_3->addWidget(timeOfUserInactivityLabel, 0, 2, 1, 1);

        m_automaticUnawayChBox = new QCheckBox(automaticAwayGroup);
        m_automaticUnawayChBox->setObjectName("m_automaticUnawayChBox");

        gridLayout_3->addWidget(m_automaticUnawayChBox, 1, 0, 1, 3);


        formLayout_3->setWidget(3, QFormLayout::ItemRole::SpanningRole, automaticAwayGroup);

        awayCommandsGroup = new QGroupBox(awayWidget);
        awayCommandsGroup->setObjectName("awayCommandsGroup");
        sizePolicy1.setHeightForWidth(awayCommandsGroup->sizePolicy().hasHeightForWidth());
        awayCommandsGroup->setSizePolicy(sizePolicy1);
        awayCommandsGroup->setCheckable(true);
        awayCommandsGroup->setChecked(false);
        formLayout_2 = new QFormLayout(awayCommandsGroup);
        formLayout_2->setObjectName("formLayout_2");
        awayLabel = new QLabel(awayCommandsGroup);
        awayLabel->setObjectName("awayLabel");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, awayLabel);

        m_awayEdit = new KLineEdit(awayCommandsGroup);
        m_awayEdit->setObjectName("m_awayEdit");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, m_awayEdit);

        unAwayLabel = new QLabel(awayCommandsGroup);
        unAwayLabel->setObjectName("unAwayLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, unAwayLabel);

        m_unAwayEdit = new KLineEdit(awayCommandsGroup);
        m_unAwayEdit->setObjectName("m_unAwayEdit");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, m_unAwayEdit);


        formLayout_3->setWidget(4, QFormLayout::ItemRole::SpanningRole, awayCommandsGroup);

        awayWidgetVSpacer = new QSpacerItem(20, 45, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_3->setItem(5, QFormLayout::ItemRole::LabelRole, awayWidgetVSpacer);

        tabWidget->addTab(awayWidget, QString());
        advancedWidget = new QWidget();
        advancedWidget->setObjectName("advancedWidget");
        formLayout = new QFormLayout(advancedWidget);
        formLayout->setObjectName("formLayout");
        sCommandLabel = new QLabel(advancedWidget);
        sCommandLabel->setObjectName("sCommandLabel");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(sCommandLabel->sizePolicy().hasHeightForWidth());
        sCommandLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, sCommandLabel);

        m_sCommandEdit = new KLineEdit(advancedWidget);
        m_sCommandEdit->setObjectName("m_sCommandEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_sCommandEdit);

        codecLabel = new QLabel(advancedWidget);
        codecLabel->setObjectName("codecLabel");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Expanding);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(codecLabel->sizePolicy().hasHeightForWidth());
        codecLabel->setSizePolicy(sizePolicy5);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, codecLabel);

        m_codecCBox = new KComboBox(advancedWidget);
        m_codecCBox->setObjectName("m_codecCBox");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, m_codecCBox);

        loginLabel = new QLabel(advancedWidget);
        loginLabel->setObjectName("loginLabel");
        sizePolicy4.setHeightForWidth(loginLabel->sizePolicy().hasHeightForWidth());
        loginLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, loginLabel);

        m_loginEdit = new KLineEdit(advancedWidget);
        m_loginEdit->setObjectName("m_loginEdit");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, m_loginEdit);

        quitLabel = new QLabel(advancedWidget);
        quitLabel->setObjectName("quitLabel");
        sizePolicy4.setHeightForWidth(quitLabel->sizePolicy().hasHeightForWidth());
        quitLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, quitLabel);

        m_quitEdit = new KLineEdit(advancedWidget);
        m_quitEdit->setObjectName("m_quitEdit");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, m_quitEdit);

        partLabel = new QLabel(advancedWidget);
        partLabel->setObjectName("partLabel");
        sizePolicy4.setHeightForWidth(partLabel->sizePolicy().hasHeightForWidth());
        partLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, partLabel);

        m_partEdit = new KLineEdit(advancedWidget);
        m_partEdit->setObjectName("m_partEdit");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, m_partEdit);

        kickLabel = new QLabel(advancedWidget);
        kickLabel->setObjectName("kickLabel");
        sizePolicy4.setHeightForWidth(kickLabel->sizePolicy().hasHeightForWidth());
        kickLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, kickLabel);

        m_kickEdit = new KLineEdit(advancedWidget);
        m_kickEdit->setObjectName("m_kickEdit");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, m_kickEdit);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(6, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        tabWidget->addTab(advancedWidget, QString());

        verticalLayout_2->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        label->setBuddy(m_identityCBox);
        realNameLabel->setBuddy(m_realNameEdit);
        authTypeLabel->setBuddy(m_authTypeCombo);
        nickservNicknameLabel->setBuddy(m_nickservNicknameEdit);
        nickservCommandLabel->setBuddy(m_nickservCommandEdit);
        saslAccountLabel->setBuddy(m_saslAccountEdit);
        authPasswordLabel->setBuddy(m_authPasswordEdit);
        awayMessageLabel->setBuddy(m_awayMessageEdit);
        awayNicknameLabel->setBuddy(m_awayNickEdit);
        awayLabel->setBuddy(m_awayEdit);
        unAwayLabel->setBuddy(m_unAwayEdit);
        sCommandLabel->setBuddy(m_sCommandEdit);
        codecLabel->setBuddy(m_codecCBox);
        loginLabel->setBuddy(m_loginEdit);
        quitLabel->setBuddy(m_quitEdit);
        partLabel->setBuddy(m_partEdit);
        kickLabel->setBuddy(m_kickEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(m_identityCBox, newBtn);
        QWidget::setTabOrder(newBtn, copyBtn);
        QWidget::setTabOrder(copyBtn, m_editBtn);
        QWidget::setTabOrder(m_editBtn, m_delBtn);
        QWidget::setTabOrder(m_delBtn, tabWidget);
        QWidget::setTabOrder(tabWidget, m_realNameEdit);
        QWidget::setTabOrder(m_realNameEdit, m_authTypeCombo);
        QWidget::setTabOrder(m_authTypeCombo, m_nickservNicknameEdit);
        QWidget::setTabOrder(m_nickservNicknameEdit, m_nickservCommandEdit);
        QWidget::setTabOrder(m_nickservCommandEdit, m_saslAccountEdit);
        QWidget::setTabOrder(m_saslAccountEdit, m_authPasswordEdit);
        QWidget::setTabOrder(m_authPasswordEdit, m_pemClientCertFile);
        QWidget::setTabOrder(m_pemClientCertFile, m_insertRememberLineOnAwayChBox);
        QWidget::setTabOrder(m_insertRememberLineOnAwayChBox, m_awayMessageEdit);
        QWidget::setTabOrder(m_awayMessageEdit, m_awayNickEdit);
        QWidget::setTabOrder(m_awayNickEdit, automaticAwayGroup);
        QWidget::setTabOrder(automaticAwayGroup, m_awayInactivitySpin);
        QWidget::setTabOrder(m_awayInactivitySpin, m_automaticUnawayChBox);
        QWidget::setTabOrder(m_automaticUnawayChBox, awayCommandsGroup);
        QWidget::setTabOrder(awayCommandsGroup, m_awayEdit);
        QWidget::setTabOrder(m_awayEdit, m_unAwayEdit);
        QWidget::setTabOrder(m_unAwayEdit, m_sCommandEdit);
        QWidget::setTabOrder(m_sCommandEdit, m_codecCBox);
        QWidget::setTabOrder(m_codecCBox, m_loginEdit);
        QWidget::setTabOrder(m_loginEdit, m_quitEdit);
        QWidget::setTabOrder(m_quitEdit, m_partEdit);
        QWidget::setTabOrder(m_partEdit, m_kickEdit);

        retranslateUi(IdentityDialog);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(IdentityDialog);
    } // setupUi

    void retranslateUi(QWidget *IdentityDialog)
    {
        label->setText(tr2i18n("&Identity:", nullptr));
#if QT_CONFIG(tooltip)
        newBtn->setToolTip(tr2i18n("Add", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        copyBtn->setToolTip(tr2i18n("Duplicate", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_editBtn->setToolTip(tr2i18n("Rename", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_delBtn->setToolTip(tr2i18n("Remove", nullptr));
#endif // QT_CONFIG(tooltip)
        realNameLabel->setText(tr2i18n("&Real name:", nullptr));
#if QT_CONFIG(whatsthis)
        m_realNameEdit->setWhatsThis(tr2i18n("Enter your real name here. IRC is not intended to keep you hidden from your friends or enemies. Keep this in mind if you are tempted to behave maliciously. A fake \"real name\" can be a good way to mask your gender from all the nerds out there, but the PC you use can always be traced so you will never be truly anonymous.", nullptr));
#endif // QT_CONFIG(whatsthis)
        nickGroupBox->setTitle(tr2i18n("Nickname", nullptr));
        autoIdentifyGroup->setTitle(tr2i18n("Auto Identify", nullptr));
        authTypeLabel->setText(tr2i18n("Type:", nullptr));
        nickservNicknameLabel->setText(tr2i18n("Ser&vice:", nullptr));
#if QT_CONFIG(whatsthis)
        m_nickservNicknameEdit->setWhatsThis(tr2i18n("Service name can be <b><i>nickserv</i></b> or a network-dependent name such as <b><i>nickserv@services.dal.net</i></b>", nullptr));
#endif // QT_CONFIG(whatsthis)
        nickservCommandLabel->setText(tr2i18n("Command:", nullptr));
        saslAccountLabel->setText(tr2i18n("Account:", nullptr));
        authPasswordLabel->setText(tr2i18n("Pa&ssword:", nullptr));
        pemClientCertFileLabel->setText(tr2i18n("PEM file:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(generalWidget), tr2i18n("General", nullptr));
#if QT_CONFIG(whatsthis)
        m_insertRememberLineOnAwayChBox->setWhatsThis(tr2i18n("If you check this box, whenever you perform an <b>/away</b> command, a horizontal line will appear in the channel, marking the point where you went away. Other IRC users do not see this horizontal line.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_insertRememberLineOnAwayChBox->setText(tr2i18n("Mark the last position in chat windows when going away", nullptr));
        awayMessageLabel->setText(tr2i18n("Default away message:", nullptr));
#if QT_CONFIG(whatsthis)
        m_awayMessageEdit->setWhatsThis(tr2i18n("The text you enter here is used as the away message when no message is entered as an argument to the <b>/away</b> or <b>/aaway</b> commands, and also when Global Away is toggled from the menu or via the keyboard shortcut.", nullptr));
#endif // QT_CONFIG(whatsthis)
        awayNicknameLabel->setText(tr2i18n("Away nickname:", nullptr));
#if QT_CONFIG(whatsthis)
        m_awayNickEdit->setWhatsThis(tr2i18n("Enter a nickname that indicates you are away. Whenever you perform an <b>/away msg</b> command in any channel joined with this Identity, Konversation will automatically change your nickname to the Away nickname. Other users will be able to tell you are away from your computer. Whenever you perform an <b>/away</b> command in any channel in which you are away, Konversation will automatically change your nickname back to the original. If you do not wish to automatically change your nickname when going away, leave blank.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        automaticAwayGroup->setWhatsThis(tr2i18n("If you check this box, Konversation will automatically set all connections using this Identity away when the screensaver starts or after a period of user inactivity configured below.", nullptr));
#endif // QT_CONFIG(whatsthis)
        automaticAwayGroup->setTitle(tr2i18n("Automatic Away", nullptr));
        setAwayAfterLabel->setText(tr2i18n("Set away after", nullptr));
        timeOfUserInactivityLabel->setText(tr2i18n("of user inactivity", nullptr));
#if QT_CONFIG(whatsthis)
        m_automaticUnawayChBox->setWhatsThis(tr2i18n("If you check this box, Konversation will automatically cancel away for all connections using this Identity when the screensaver stops or new user activity is detected.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_automaticUnawayChBox->setText(tr2i18n("Automatically return on activity", nullptr));
#if QT_CONFIG(whatsthis)
        awayCommandsGroup->setWhatsThis(tr2i18n("If you check this box, Konversation will automatically run the away command in all channel tabs using this Identity. <b>%s</b> in the away command is replaced with the away message. When you return, it will run the return command. <b>%t</b> in the return command is replaced with the length of time you were away.", nullptr));
#endif // QT_CONFIG(whatsthis)
        awayCommandsGroup->setTitle(tr2i18n("Away Commands", nullptr));
        awayLabel->setText(tr2i18n("Away command:", nullptr));
        unAwayLabel->setText(tr2i18n("Return command:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(awayWidget), tr2i18n("Away", "@title:tab"));
        sCommandLabel->setText(tr2i18n("&Pre-shell command:", nullptr));
#if QT_CONFIG(whatsthis)
        m_sCommandEdit->setWhatsThis(tr2i18n("Here you can enter a command to be executed before connection to server starts<br>If you have multiple servers in this identity this command will be executed for each server", nullptr));
#endif // QT_CONFIG(whatsthis)
        codecLabel->setText(tr2i18n("&Encoding:", nullptr));
#if QT_CONFIG(whatsthis)
        m_codecCBox->setWhatsThis(tr2i18n("This setting affects how characters you type are encoded for sending to the server. It also affects how messages are displayed. When you first open Konversation, it automatically retrieves this setting from the operating system. If you seem to be having trouble seeing other user's messages correctly, try changing this setting.", nullptr));
#endif // QT_CONFIG(whatsthis)
        loginLabel->setText(tr2i18n("I&dent:", nullptr));
#if QT_CONFIG(whatsthis)
        m_loginEdit->setWhatsThis(tr2i18n("When you connect, many servers query your computer for an IDENT response. If your computer is not running an IDENT server, this response is sent by Konversation. No spaces are allowed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        quitLabel->setText(tr2i18n("&Quit reason:", nullptr));
#if QT_CONFIG(whatsthis)
        m_quitEdit->setWhatsThis(tr2i18n("Whenever you leave a server, this message is shown to others.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_quitEdit->setText(tr2i18n("Konversation terminated.", nullptr));
        partLabel->setText(tr2i18n("&Part reason:", nullptr));
#if QT_CONFIG(whatsthis)
        m_partEdit->setWhatsThis(tr2i18n("Whenever you leave a channel, this message is sent to the channel.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_partEdit->setText(tr2i18n("Konversation terminated.", nullptr));
        kickLabel->setText(tr2i18n("&Kick reason:", nullptr));
#if QT_CONFIG(whatsthis)
        m_kickEdit->setWhatsThis(tr2i18n("Whenever you are kicked from a channel (usually by an IRC operator), this message is sent to the channel.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_kickEdit->setText(tr2i18n("User terminated.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(advancedWidget), tr2i18n("Advanced", nullptr));
        (void)IdentityDialog;
    } // retranslateUi

};

namespace Ui {
    class IdentityDialog: public Ui_IdentityDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IDENTITYDIALOG_H

