/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

*/

/********************************************************************************
** Form generated from reading UI file 'channeloptionsui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHANNELOPTIONSUI_H
#define UI_CHANNELOPTIONSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "ktreewidgetsearchline.h"
#include "topicedit.h"
#include "topichistoryview.h"

QT_BEGIN_NAMESPACE

class Ui_ChannelOptionsUI
{
public:
    QVBoxLayout *verticalLayout_3;
    QTabWidget *channelTabWidget;
    QWidget *topicTab;
    QHBoxLayout *horizontalLayout_4;
    QSplitter *splitter;
    QWidget *widget;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_3;
    QLabel *textLabel2_2;
    QLineEdit *topicHistorySearchLine;
    TopicHistoryView *topicHistoryView;
    TopicEdit *topicEdit;
    QWidget *modesPage;
    QGridLayout *gridLayout;
    QCheckBox *topicModeChBox;
    QCheckBox *messageModeChBox;
    QCheckBox *secretModeChBox;
    QCheckBox *inviteModeChBox;
    QCheckBox *moderatedModeChBox;
    QCheckBox *userLimitChBox;
    QSpinBox *userLimitEdit;
    QSpacerItem *spacer10;
    QCheckBox *keyModeChBox;
    KLineEdit *keyModeEdit;
    QPushButton *toggleAdvancedModes;
    QSpacerItem *spacer3;
    QTreeView *otherModesList;
    QSpacerItem *verticalSpacer;
    QWidget *TabPage;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *textLabel2;
    KTreeWidgetSearchLine *banListSearchLine;
    QTreeWidget *banList;
    QHBoxLayout *horizontalLayout_2;
    QLabel *hostmaskLabel;
    KLineEdit *hostmask;
    QPushButton *updateBan;
    QPushButton *addBan;
    QPushButton *removeBan;

    void setupUi(QWidget *ChannelOptionsUI)
    {
        if (ChannelOptionsUI->objectName().isEmpty())
            ChannelOptionsUI->setObjectName("ChannelOptionsUI");
        ChannelOptionsUI->resize(458, 377);
        verticalLayout_3 = new QVBoxLayout(ChannelOptionsUI);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, -1);
        channelTabWidget = new QTabWidget(ChannelOptionsUI);
        channelTabWidget->setObjectName("channelTabWidget");
        topicTab = new QWidget();
        topicTab->setObjectName("topicTab");
        horizontalLayout_4 = new QHBoxLayout(topicTab);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        splitter = new QSplitter(topicTab);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Vertical);
        widget = new QWidget(splitter);
        widget->setObjectName("widget");
        verticalLayout_2 = new QVBoxLayout(widget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        textLabel2_2 = new QLabel(widget);
        textLabel2_2->setObjectName("textLabel2_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel2_2->sizePolicy().hasHeightForWidth());
        textLabel2_2->setSizePolicy(sizePolicy);
        textLabel2_2->setWordWrap(false);

        horizontalLayout_3->addWidget(textLabel2_2);

        topicHistorySearchLine = new QLineEdit(widget);
        topicHistorySearchLine->setObjectName("topicHistorySearchLine");
        topicHistorySearchLine->setClearButtonEnabled(true);

        horizontalLayout_3->addWidget(topicHistorySearchLine);


        verticalLayout_2->addLayout(horizontalLayout_3);

        topicHistoryView = new TopicHistoryView(widget);
        topicHistoryView->setObjectName("topicHistoryView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(topicHistoryView->sizePolicy().hasHeightForWidth());
        topicHistoryView->setSizePolicy(sizePolicy1);

        verticalLayout_2->addWidget(topicHistoryView);

        splitter->addWidget(widget);
        topicEdit = new TopicEdit(splitter);
        topicEdit->setObjectName("topicEdit");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(2);
        sizePolicy2.setHeightForWidth(topicEdit->sizePolicy().hasHeightForWidth());
        topicEdit->setSizePolicy(sizePolicy2);
        splitter->addWidget(topicEdit);

        horizontalLayout_4->addWidget(splitter);

        channelTabWidget->addTab(topicTab, QString());
        modesPage = new QWidget();
        modesPage->setObjectName("modesPage");
        gridLayout = new QGridLayout(modesPage);
        gridLayout->setObjectName("gridLayout");
        topicModeChBox = new QCheckBox(modesPage);
        topicModeChBox->setObjectName("topicModeChBox");

        gridLayout->addWidget(topicModeChBox, 0, 0, 1, 4);

        messageModeChBox = new QCheckBox(modesPage);
        messageModeChBox->setObjectName("messageModeChBox");

        gridLayout->addWidget(messageModeChBox, 1, 0, 1, 3);

        secretModeChBox = new QCheckBox(modesPage);
        secretModeChBox->setObjectName("secretModeChBox");

        gridLayout->addWidget(secretModeChBox, 2, 0, 1, 4);

        inviteModeChBox = new QCheckBox(modesPage);
        inviteModeChBox->setObjectName("inviteModeChBox");

        gridLayout->addWidget(inviteModeChBox, 3, 0, 1, 3);

        moderatedModeChBox = new QCheckBox(modesPage);
        moderatedModeChBox->setObjectName("moderatedModeChBox");

        gridLayout->addWidget(moderatedModeChBox, 4, 0, 1, 5);

        userLimitChBox = new QCheckBox(modesPage);
        userLimitChBox->setObjectName("userLimitChBox");

        gridLayout->addWidget(userLimitChBox, 5, 0, 1, 1);

        userLimitEdit = new QSpinBox(modesPage);
        userLimitEdit->setObjectName("userLimitEdit");
        userLimitEdit->setEnabled(false);
        userLimitEdit->setMinimum(0);
        userLimitEdit->setMaximum(99999);

        gridLayout->addWidget(userLimitEdit, 5, 1, 1, 2);

        spacer10 = new QSpacerItem(207, 23, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer10, 5, 3, 1, 1);

        keyModeChBox = new QCheckBox(modesPage);
        keyModeChBox->setObjectName("keyModeChBox");

        gridLayout->addWidget(keyModeChBox, 6, 0, 1, 1);

        keyModeEdit = new KLineEdit(modesPage);
        keyModeEdit->setObjectName("keyModeEdit");
        keyModeEdit->setEnabled(false);

        gridLayout->addWidget(keyModeEdit, 6, 1, 1, 4);

        toggleAdvancedModes = new QPushButton(modesPage);
        toggleAdvancedModes->setObjectName("toggleAdvancedModes");
        toggleAdvancedModes->setCheckable(true);

        gridLayout->addWidget(toggleAdvancedModes, 7, 0, 1, 2);

        spacer3 = new QSpacerItem(301, 31, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer3, 7, 2, 1, 2);

        otherModesList = new QTreeView(modesPage);
        otherModesList->setObjectName("otherModesList");
        otherModesList->setRootIsDecorated(false);
        otherModesList->setAllColumnsShowFocus(true);

        gridLayout->addWidget(otherModesList, 8, 0, 1, 4);

        verticalSpacer = new QSpacerItem(1, 112, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 8, 4, 1, 1);

        channelTabWidget->addTab(modesPage, QString());
        TabPage = new QWidget();
        TabPage->setObjectName("TabPage");
        verticalLayout = new QVBoxLayout(TabPage);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        textLabel2 = new QLabel(TabPage);
        textLabel2->setObjectName("textLabel2");
        sizePolicy.setHeightForWidth(textLabel2->sizePolicy().hasHeightForWidth());
        textLabel2->setSizePolicy(sizePolicy);
        textLabel2->setWordWrap(false);

        horizontalLayout->addWidget(textLabel2);

        banListSearchLine = new KTreeWidgetSearchLine(TabPage);
        banListSearchLine->setObjectName("banListSearchLine");

        horizontalLayout->addWidget(banListSearchLine);


        verticalLayout->addLayout(horizontalLayout);

        banList = new QTreeWidget(TabPage);
        banList->setObjectName("banList");
        banList->setRootIsDecorated(false);
        banList->setSortingEnabled(true);

        verticalLayout->addWidget(banList);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        hostmaskLabel = new QLabel(TabPage);
        hostmaskLabel->setObjectName("hostmaskLabel");

        horizontalLayout_2->addWidget(hostmaskLabel);

        hostmask = new KLineEdit(TabPage);
        hostmask->setObjectName("hostmask");

        horizontalLayout_2->addWidget(hostmask);

        updateBan = new QPushButton(TabPage);
        updateBan->setObjectName("updateBan");
        updateBan->setEnabled(false);

        horizontalLayout_2->addWidget(updateBan);

        addBan = new QPushButton(TabPage);
        addBan->setObjectName("addBan");
        addBan->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(addBan->sizePolicy().hasHeightForWidth());
        addBan->setSizePolicy(sizePolicy3);

        horizontalLayout_2->addWidget(addBan);

        removeBan = new QPushButton(TabPage);
        removeBan->setObjectName("removeBan");
        removeBan->setEnabled(false);
        sizePolicy3.setHeightForWidth(removeBan->sizePolicy().hasHeightForWidth());
        removeBan->setSizePolicy(sizePolicy3);

        horizontalLayout_2->addWidget(removeBan);


        verticalLayout->addLayout(horizontalLayout_2);

        channelTabWidget->addTab(TabPage, QString());

        verticalLayout_3->addWidget(channelTabWidget);


        retranslateUi(ChannelOptionsUI);
        QObject::connect(keyModeChBox, SIGNAL(toggled(bool)), keyModeEdit, SLOT(setEnabled(bool)));
        QObject::connect(userLimitChBox, &QCheckBox::toggled, userLimitEdit, &QSpinBox::setEnabled);

        channelTabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ChannelOptionsUI);
    } // setupUi

    void retranslateUi(QWidget *ChannelOptionsUI)
    {
        textLabel2_2->setText(tr2i18n("Search:", nullptr));
        channelTabWidget->setTabText(channelTabWidget->indexOf(topicTab), tr2i18n("Topi&c", nullptr));
        topicModeChBox->setText(tr2i18n("&Topic can only be changed by channel operators", nullptr));
        messageModeChBox->setText(tr2i18n("&No messages from outside the channel", nullptr));
        secretModeChBox->setText(tr2i18n("&Secret channel, the channel is not listed in the channel list", nullptr));
        inviteModeChBox->setText(tr2i18n("Only &invited are allowed to join the channel", nullptr));
        moderatedModeChBox->setText(tr2i18n("&Moderated channel, only people with voice can write to the channel", nullptr));
        userLimitChBox->setText(tr2i18n("User &limit:", nullptr));
        keyModeChBox->setText(tr2i18n("Channel &password:", nullptr));
        toggleAdvancedModes->setText(tr2i18n("Show &Advanced Modes >>", nullptr));
        channelTabWidget->setTabText(channelTabWidget->indexOf(modesPage), tr2i18n("Mo&des", nullptr));
        textLabel2->setText(tr2i18n("Search:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = banList->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("Time Set", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Set By", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Hostmask", nullptr));
        hostmaskLabel->setText(tr2i18n("Hostmask:", nullptr));
#if QT_CONFIG(tooltip)
        updateBan->setToolTip(tr2i18n("Update Ban", nullptr));
#endif // QT_CONFIG(tooltip)
        updateBan->setText(QString());
#if QT_CONFIG(tooltip)
        addBan->setToolTip(tr2i18n("Add Ban", nullptr));
#endif // QT_CONFIG(tooltip)
        addBan->setText(QString());
#if QT_CONFIG(tooltip)
        removeBan->setToolTip(tr2i18n("Remove Ban", nullptr));
#endif // QT_CONFIG(tooltip)
        removeBan->setText(QString());
        channelTabWidget->setTabText(channelTabWidget->indexOf(TabPage), tr2i18n("&Ban List", nullptr));
        (void)ChannelOptionsUI;
    } // retranslateUi

};

namespace Ui {
    class ChannelOptionsUI: public Ui_ChannelOptionsUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHANNELOPTIONSUI_H

