/****************************************************************************
** Meta object code from reading C++ file 'serverlistdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/irc/serverlistdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'serverlistdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Konversation16ServerListDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::ServerListDialog::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation16ServerListDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::ServerListDialog",
        "connectTo",
        "",
        "Konversation::ConnectionFlag",
        "flag",
        "serverGroupId",
        "ConnectionSettings",
        "connectionSettings",
        "serverGroupsChanged",
        "Konversation::ServerGroupSettingsPtr",
        "serverGroup",
        "updateServerList",
        "slotOk",
        "slotAdd",
        "slotEdit",
        "slotDelete",
        "slotSetGroupExpanded",
        "QTreeWidgetItem*",
        "item",
        "slotSetGroupCollapsed",
        "slotAboutToMove",
        "slotMoved",
        "updateButtons",
        "setShowAtStartup",
        "show"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, ConnectionSettings)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'serverGroupsChanged'
        QtMocHelpers::SignalData<void(const Konversation::ServerGroupSettingsPtr)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'serverGroupsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'updateServerList'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOk'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAdd'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEdit'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDelete'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetGroupExpanded'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'slotSetGroupCollapsed'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'slotAboutToMove'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoved'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateButtons'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setShowAtStartup'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ServerListDialog, qt_meta_tag_ZN12Konversation16ServerListDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konversation::ServerListDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation16ServerListDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation16ServerListDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation16ServerListDialogE_t>.metaTypes,
    nullptr
} };

void Konversation::ServerListDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ServerListDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ConnectionSettings>>(_a[2]))); break;
        case 2: _t->serverGroupsChanged((*reinterpret_cast<std::add_pointer_t<Konversation::ServerGroupSettingsPtr>>(_a[1]))); break;
        case 3: _t->serverGroupsChanged(); break;
        case 4: _t->updateServerList(); break;
        case 5: _t->slotOk(); break;
        case 6: _t->slotAdd(); break;
        case 7: _t->slotEdit(); break;
        case 8: _t->slotDelete(); break;
        case 9: _t->slotSetGroupExpanded((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 10: _t->slotSetGroupCollapsed((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 11: _t->slotAboutToMove(); break;
        case 12: _t->slotMoved(); break;
        case 13: _t->updateButtons(); break;
        case 14: _t->setShowAtStartup((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ServerListDialog::*)(Konversation::ConnectionFlag , int )>(_a, &ServerListDialog::connectTo, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerListDialog::*)(Konversation::ConnectionFlag , ConnectionSettings )>(_a, &ServerListDialog::connectTo, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerListDialog::*)(const Konversation::ServerGroupSettingsPtr )>(_a, &ServerListDialog::serverGroupsChanged, 2))
            return;
    }
}

const QMetaObject *Konversation::ServerListDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::ServerListDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation16ServerListDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::ServerListDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Konversation::ServerListDialog::connectTo(Konversation::ConnectionFlag _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Konversation::ServerListDialog::connectTo(Konversation::ConnectionFlag _t1, ConnectionSettings _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Konversation::ServerListDialog::serverGroupsChanged(const Konversation::ServerGroupSettingsPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
