/********************************************************************************
** Form generated from reading UI file 'serverlistdialogui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SERVERLISTDIALOGUI_H
#define UI_SERVERLISTDIALOGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "serverlistview.h"

QT_BEGIN_NAMESPACE

class Ui_ServerListDialogUI
{
public:
    QGridLayout *gridLayout;
    QPushButton *m_addButton;
    QPushButton *m_delButton;
    QPushButton *m_editButton;
    ServerListView *m_serverList;
    QCheckBox *m_showAtStartup;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QWidget *ServerListDialogUI)
    {
        if (ServerListDialogUI->objectName().isEmpty())
            ServerListDialogUI->setObjectName("ServerListDialogUI");
        ServerListDialogUI->resize(533, 274);
        gridLayout = new QGridLayout(ServerListDialogUI);
        gridLayout->setObjectName("gridLayout");
        m_addButton = new QPushButton(ServerListDialogUI);
        m_addButton->setObjectName("m_addButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_addButton->sizePolicy().hasHeightForWidth());
        m_addButton->setSizePolicy(sizePolicy);
        m_addButton->setAutoDefault(false);
        m_addButton->setFlat(false);

        gridLayout->addWidget(m_addButton, 0, 2, 1, 1);

        m_delButton = new QPushButton(ServerListDialogUI);
        m_delButton->setObjectName("m_delButton");
        sizePolicy.setHeightForWidth(m_delButton->sizePolicy().hasHeightForWidth());
        m_delButton->setSizePolicy(sizePolicy);
        m_delButton->setAutoDefault(false);

        gridLayout->addWidget(m_delButton, 2, 2, 1, 1);

        m_editButton = new QPushButton(ServerListDialogUI);
        m_editButton->setObjectName("m_editButton");
        sizePolicy.setHeightForWidth(m_editButton->sizePolicy().hasHeightForWidth());
        m_editButton->setSizePolicy(sizePolicy);
        m_editButton->setAutoDefault(false);

        gridLayout->addWidget(m_editButton, 1, 2, 1, 1);

        m_serverList = new ServerListView(ServerListDialogUI);
        m_serverList->setObjectName("m_serverList");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(2);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_serverList->sizePolicy().hasHeightForWidth());
        m_serverList->setSizePolicy(sizePolicy1);
        m_serverList->setFocusPolicy(Qt::WheelFocus);
        m_serverList->setAcceptDrops(true);
        m_serverList->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        m_serverList->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        m_serverList->setDragEnabled(true);
        m_serverList->setDragDropMode(QAbstractItemView::InternalMove);
        m_serverList->setSelectionMode(QAbstractItemView::ExtendedSelection);
        m_serverList->setSelectionBehavior(QAbstractItemView::SelectRows);
        m_serverList->setRootIsDecorated(true);
        m_serverList->setUniformRowHeights(false);
        m_serverList->setSortingEnabled(true);
        m_serverList->setAllColumnsShowFocus(true);
        m_serverList->setWordWrap(false);
        m_serverList->setHeaderHidden(false);
        m_serverList->setExpandsOnDoubleClick(false);
        m_serverList->header()->setVisible(true);
        m_serverList->header()->setCascadingSectionResizes(true);
        m_serverList->header()->setDefaultSectionSize(200);
        m_serverList->header()->setHighlightSections(false);
        m_serverList->header()->setProperty("showSortIndicator", QVariant(true));
        m_serverList->header()->setStretchLastSection(true);

        gridLayout->addWidget(m_serverList, 0, 0, 4, 2);

        m_showAtStartup = new QCheckBox(ServerListDialogUI);
        m_showAtStartup->setObjectName("m_showAtStartup");

        gridLayout->addWidget(m_showAtStartup, 4, 0, 1, 1);

        m_buttonBox = new QDialogButtonBox(ServerListDialogUI);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Ok);

        gridLayout->addWidget(m_buttonBox, 5, 0, 1, 3);


        retranslateUi(ServerListDialogUI);

        m_addButton->setDefault(false);


        QMetaObject::connectSlotsByName(ServerListDialogUI);
    } // setupUi

    void retranslateUi(QWidget *ServerListDialogUI)
    {
#if QT_CONFIG(whatsthis)
        m_addButton->setWhatsThis(tr2i18n("Click here to define a new Network, including the server to connect to, and the Channels to automatically join once connected.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_addButton->setText(tr2i18n("&New...", nullptr));
        m_delButton->setText(tr2i18n("&Delete", nullptr));
        m_editButton->setText(tr2i18n("&Edit...", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = m_serverList->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("Channels", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Identity", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Network", nullptr));
#if QT_CONFIG(whatsthis)
        m_serverList->setWhatsThis(tr2i18n("This shows the list of configured IRC networks. An IRC network is a collection of cooperating servers. You need only connect to one of the servers in the network to be connected to the entire IRC network. Once connected, Konversation will automatically join the channels shown. When Konversation is started for the first time, the Libera network and the <i>#kde</i> channel are already entered for you.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_showAtStartup->setText(tr2i18n("&Show at application startup", nullptr));
        (void)ServerListDialogUI;
    } // retranslateUi

};

namespace Ui {
    class ServerListDialogUI: public Ui_ServerListDialogUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SERVERLISTDIALOGUI_H

