/********************************************************************************
** Form generated from reading UI file 'whiteboardfontchooserui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WHITEBOARDFONTCHOOSERUI_H
#define UI_WHITEBOARDFONTCHOOSERUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_WhiteBoardFontChooserUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QFontComboBox *m_fontComboBox;
    KComboBox *m_fontPointComboBox;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QToolButton *m_boldPushButton;
    QToolButton *m_italicPushButton;
    QToolButton *m_underlinePushButton;
    QToolButton *m_strikeoutPushButton;

    void setupUi(QWidget *WhiteBoardFontChooserUi)
    {
        if (WhiteBoardFontChooserUi->objectName().isEmpty())
            WhiteBoardFontChooserUi->setObjectName("WhiteBoardFontChooserUi");
        WhiteBoardFontChooserUi->resize(427, 37);
        gridLayout = new QGridLayout(WhiteBoardFontChooserUi);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 5, 3, 3);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_fontComboBox = new QFontComboBox(WhiteBoardFontChooserUi);
        m_fontComboBox->setObjectName("m_fontComboBox");

        horizontalLayout_2->addWidget(m_fontComboBox);

        m_fontPointComboBox = new KComboBox(WhiteBoardFontChooserUi);
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->addItem(QString());
        m_fontPointComboBox->setObjectName("m_fontPointComboBox");
        m_fontPointComboBox->setEditable(true);
        m_fontPointComboBox->setInsertPolicy(QComboBox::NoInsert);
        m_fontPointComboBox->setFrame(true);

        horizontalLayout_2->addWidget(m_fontPointComboBox);


        horizontalLayout_3->addLayout(horizontalLayout_2);

        line = new QFrame(WhiteBoardFontChooserUi);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout_3->addWidget(line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        m_boldPushButton = new QToolButton(WhiteBoardFontChooserUi);
        m_boldPushButton->setObjectName("m_boldPushButton");
        m_boldPushButton->setCheckable(true);

        horizontalLayout->addWidget(m_boldPushButton);

        m_italicPushButton = new QToolButton(WhiteBoardFontChooserUi);
        m_italicPushButton->setObjectName("m_italicPushButton");
        m_italicPushButton->setCheckable(true);

        horizontalLayout->addWidget(m_italicPushButton);

        m_underlinePushButton = new QToolButton(WhiteBoardFontChooserUi);
        m_underlinePushButton->setObjectName("m_underlinePushButton");
        m_underlinePushButton->setCheckable(true);

        horizontalLayout->addWidget(m_underlinePushButton);

        m_strikeoutPushButton = new QToolButton(WhiteBoardFontChooserUi);
        m_strikeoutPushButton->setObjectName("m_strikeoutPushButton");
        m_strikeoutPushButton->setCheckable(true);

        horizontalLayout->addWidget(m_strikeoutPushButton);


        horizontalLayout_3->addLayout(horizontalLayout);


        gridLayout->addLayout(horizontalLayout_3, 0, 0, 1, 1);


        retranslateUi(WhiteBoardFontChooserUi);

        m_fontPointComboBox->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(WhiteBoardFontChooserUi);
    } // setupUi

    void retranslateUi(QWidget *WhiteBoardFontChooserUi)
    {
        WhiteBoardFontChooserUi->setWindowTitle(tr2i18n("Whiteboard Font Chooser", nullptr));
        m_fontPointComboBox->setItemText(0, tr2i18n("6", nullptr));
        m_fontPointComboBox->setItemText(1, tr2i18n("7", nullptr));
        m_fontPointComboBox->setItemText(2, tr2i18n("8", nullptr));
        m_fontPointComboBox->setItemText(3, tr2i18n("9", nullptr));
        m_fontPointComboBox->setItemText(4, tr2i18n("10", nullptr));
        m_fontPointComboBox->setItemText(5, tr2i18n("11", nullptr));
        m_fontPointComboBox->setItemText(6, tr2i18n("12", nullptr));
        m_fontPointComboBox->setItemText(7, tr2i18n("14", nullptr));
        m_fontPointComboBox->setItemText(8, tr2i18n("16", nullptr));
        m_fontPointComboBox->setItemText(9, tr2i18n("18", nullptr));
        m_fontPointComboBox->setItemText(10, tr2i18n("20", nullptr));
        m_fontPointComboBox->setItemText(11, tr2i18n("22", nullptr));
        m_fontPointComboBox->setItemText(12, tr2i18n("24", nullptr));
        m_fontPointComboBox->setItemText(13, tr2i18n("26", nullptr));
        m_fontPointComboBox->setItemText(14, tr2i18n("28", nullptr));
        m_fontPointComboBox->setItemText(15, tr2i18n("36", nullptr));
        m_fontPointComboBox->setItemText(16, tr2i18n("48", nullptr));
        m_fontPointComboBox->setItemText(17, tr2i18n("72", nullptr));

        m_boldPushButton->setText(QString());
        m_italicPushButton->setText(QString());
        m_underlinePushButton->setText(QString());
        m_strikeoutPushButton->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class WhiteBoardFontChooserUi: public Ui_WhiteBoardFontChooserUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WHITEBOARDFONTCHOOSERUI_H

