/********************************************************************************
** Form generated from reading UI file 'serverdialogui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SERVERDIALOGUI_H
#define UI_SERVERDIALOGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "kpasswordlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ServerDialogUI
{
public:
    QGridLayout *gridLayout;
    QLabel *serverLbl;
    KLineEdit *m_serverEdit;
    QLabel *portLbl;
    QSpinBox *m_portSBox;
    QLabel *passwordLbl;
    KPasswordLineEdit *m_passwordEdit;
    QCheckBox *m_sslChBox;
    QCheckBox *m_proxyChBox;

    void setupUi(QWidget *ServerDialogUI)
    {
        if (ServerDialogUI->objectName().isEmpty())
            ServerDialogUI->setObjectName("ServerDialogUI");
        ServerDialogUI->resize(297, 129);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ServerDialogUI->sizePolicy().hasHeightForWidth());
        ServerDialogUI->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(ServerDialogUI);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        serverLbl = new QLabel(ServerDialogUI);
        serverLbl->setObjectName("serverLbl");
        serverLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(serverLbl, 0, 0, 1, 1);

        m_serverEdit = new KLineEdit(ServerDialogUI);
        m_serverEdit->setObjectName("m_serverEdit");

        gridLayout->addWidget(m_serverEdit, 0, 1, 1, 1);

        portLbl = new QLabel(ServerDialogUI);
        portLbl->setObjectName("portLbl");

        gridLayout->addWidget(portLbl, 0, 2, 1, 1);

        m_portSBox = new QSpinBox(ServerDialogUI);
        m_portSBox->setObjectName("m_portSBox");
        m_portSBox->setMinimum(1);
        m_portSBox->setMaximum(65535);
        m_portSBox->setValue(6667);

        gridLayout->addWidget(m_portSBox, 0, 3, 1, 1);

        passwordLbl = new QLabel(ServerDialogUI);
        passwordLbl->setObjectName("passwordLbl");
        passwordLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(passwordLbl, 1, 0, 1, 1);

        m_passwordEdit = new KPasswordLineEdit(ServerDialogUI);
        m_passwordEdit->setObjectName("m_passwordEdit");

        gridLayout->addWidget(m_passwordEdit, 1, 1, 1, 3);

        m_sslChBox = new QCheckBox(ServerDialogUI);
        m_sslChBox->setObjectName("m_sslChBox");

        gridLayout->addWidget(m_sslChBox, 2, 0, 1, 4);

        m_proxyChBox = new QCheckBox(ServerDialogUI);
        m_proxyChBox->setObjectName("m_proxyChBox");
        m_proxyChBox->setChecked(true);

        gridLayout->addWidget(m_proxyChBox, 3, 0, 1, 2);

#if QT_CONFIG(shortcut)
        serverLbl->setBuddy(m_serverEdit);
        portLbl->setBuddy(m_portSBox);
        passwordLbl->setBuddy(m_passwordEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ServerDialogUI);

        QMetaObject::connectSlotsByName(ServerDialogUI);
    } // setupUi

    void retranslateUi(QWidget *ServerDialogUI)
    {
        serverLbl->setText(tr2i18n("&Server:", nullptr));
#if QT_CONFIG(whatsthis)
        m_serverEdit->setWhatsThis(tr2i18n("The name or IP number of the server. irchelp.org maintains a list of servers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        portLbl->setText(tr2i18n("&Port:", nullptr));
#if QT_CONFIG(whatsthis)
        m_portSBox->setWhatsThis(tr2i18n("Enter the port number required to connect to the server. For most servers, this should be <b>6667</b>.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_portSBox->setSuffix(QString());
        m_portSBox->setPrefix(QString());
        passwordLbl->setText(tr2i18n("Pass&word:", nullptr));
#if QT_CONFIG(whatsthis)
        m_sslChBox->setWhatsThis(tr2i18n("Check if you want to use the Secure Socket Layer (SSL) protocol to communicate with the server. This protects the privacy of your communications between your computer and the IRC server. The server must support SSL protocol for this to work. In most cases, if the server does not support SSL, the connection will fail.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_sslChBox->setText(tr2i18n("S&ecure Connection (SSL)", nullptr));
#if QT_CONFIG(whatsthis)
        m_proxyChBox->setWhatsThis(tr2i18n("Check if you want to use the global proxy configuration to communicate with this server.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_proxyChBox->setText(tr2i18n("&Use global proxy", nullptr));
        (void)ServerDialogUI;
    } // retranslateUi

};

namespace Ui {
    class ServerDialogUI: public Ui_ServerDialogUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SERVERDIALOGUI_H

