/****************************************************************************
** Meta object code from reading C++ file 'outputfilter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/irc/outputfilter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'outputfilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Konversation12OutputFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::OutputFilter::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation12OutputFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::OutputFilter",
        "openDccSend",
        "",
        "recipient",
        "QUrl",
        "url",
        "requestDccSend",
        "openDccChat",
        "nick",
        "openDccWBoard",
        "addDccPanel",
        "closeDccPanel",
        "acceptDccGet",
        "file",
        "openRawLog",
        "show",
        "closeRawLog",
        "openKonsolePanel",
        "openChannelList",
        "parameter",
        "sendToAllChannels",
        "text",
        "launchScript",
        "connectionId",
        "target",
        "banUsers",
        "userList",
        "channel",
        "option",
        "unbanUsers",
        "mask",
        "multiServerCommand",
        "command",
        "reconnectServer",
        "quitMessage",
        "disconnectServer",
        "quitServer",
        "connectTo",
        "Konversation::ConnectionFlag",
        "flag",
        "hostName",
        "port",
        "password",
        "useSSL",
        "showView",
        "ChatWindow*",
        "view",
        "encodingChanged",
        "execBan",
        "OutputFilterResult",
        "channels",
        "execUnban",
        "command_op",
        "OutputFilterInput",
        "input",
        "command_deop",
        "command_hop",
        "command_dehop",
        "command_voice",
        "command_unvoice",
        "command_devoice",
        "command_join",
        "_input",
        "command_j",
        "command_kick",
        "command_part",
        "command_leave",
        "command_topic",
        "command_away",
        "command_unaway",
        "command_back",
        "command_aaway",
        "command_aunaway",
        "command_aback",
        "command_names",
        "command_close",
        "command_reconnect",
        "command_disconnect",
        "command_quit",
        "command_notice",
        "command_me",
        "command_msg",
        "command_m",
        "command_query",
        "command_smsg",
        "command_ping",
        "command_ctcp",
        "command_ame",
        "command_amsg",
        "command_omsg",
        "command_onotice",
        "command_quote",
        "command_say",
        "command_dcc",
        "command_invite",
        "command_exec",
        "command_raw",
        "command_notify",
        "command_oper",
        "command_ban",
        "command_kickban",
        "command_unban",
        "command_ignore",
        "command_unignore",
        "command_server",
        "command_charset",
        "command_encoding",
        "command_setkey",
        "command_keyx",
        "command_delkey",
        "command_showkey",
        "command_kill",
        "command_dns",
        "command_list",
        "command_konsole",
        "command_queuetuner",
        "command_sayversion",
        "command_cycle",
        "command_clear",
        "command_umode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openDccSend'
        QtMocHelpers::SignalData<void(const QString &, const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'requestDccSend'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestDccSend'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'openDccChat'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'openDccWBoard'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'addDccPanel'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeDccPanel'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'acceptDccGet'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'openRawLog'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'closeRawLog'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openKonsolePanel'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openChannelList'
        QtMocHelpers::SignalData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'sendToAllChannels'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'launchScript'
        QtMocHelpers::SignalData<void(int, const QString &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::QString, 24 }, { QMetaType::QString, 19 },
        }}),
        // Signal 'banUsers'
        QtMocHelpers::SignalData<void(const QStringList &, const QString &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 26 }, { QMetaType::QString, 27 }, { QMetaType::QString, 28 },
        }}),
        // Signal 'unbanUsers'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'multiServerCommand'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 19 },
        }}),
        // Signal 'reconnectServer'
        QtMocHelpers::SignalData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Signal 'disconnectServer'
        QtMocHelpers::SignalData<void(const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Signal 'quitServer'
        QtMocHelpers::SignalData<void(const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &, const QString &, const QString &, bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 42 },
            { QMetaType::QString, 8 }, { QMetaType::QString, 27 }, { QMetaType::Bool, 43 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &, const QString &, const QString &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 42 },
            { QMetaType::QString, 8 }, { QMetaType::QString, 27 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &, const QString &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 42 },
            { QMetaType::QString, 8 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &, const QString &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 42 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &, const QString &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 },
        }}),
        // Signal 'connectTo'
        QtMocHelpers::SignalData<void(Konversation::ConnectionFlag, const QString &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::QString, 40 },
        }}),
        // Signal 'showView'
        QtMocHelpers::SignalData<void(ChatWindow *)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Signal 'encodingChanged'
        QtMocHelpers::SignalData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'execBan'
        QtMocHelpers::SlotData<OutputFilterResult(const QString &, const QString &)>(48, 2, QMC::AccessPublic, 0x80000000 | 49, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 50 },
        }}),
        // Slot 'execUnban'
        QtMocHelpers::SlotData<OutputFilterResult(const QString &, const QString &)>(51, 2, QMC::AccessPublic, 0x80000000 | 49, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 50 },
        }}),
        // Slot 'command_op'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(52, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_deop'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(55, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_hop'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(56, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_dehop'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(57, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_voice'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(58, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_unvoice'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(59, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_devoice'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(60, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_join'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(61, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 62 },
        }}),
        // Slot 'command_j'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(63, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_kick'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(64, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_part'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(65, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_leave'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(66, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_topic'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(67, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_away'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(68, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_unaway'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(69, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_back'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(70, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_aaway'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(71, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_aunaway'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(72, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_aback'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(73, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_names'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(74, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_close'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(75, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 62 },
        }}),
        // Slot 'command_reconnect'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(76, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_disconnect'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(77, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_quit'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(78, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_notice'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(79, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_me'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(80, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_msg'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(81, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_m'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(82, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_query'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(83, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_smsg'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(84, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_ping'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(85, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_ctcp'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(86, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_ame'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(87, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_amsg'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(88, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_omsg'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(89, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_onotice'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(90, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_quote'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(91, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_say'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(92, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_dcc'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(93, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 62 },
        }}),
        // Slot 'command_invite'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(94, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_exec'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(95, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_raw'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(96, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_notify'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(97, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_oper'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(98, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_ban'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(99, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_kickban'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(100, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_unban'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(101, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_ignore'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(102, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_unignore'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(103, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_server'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(104, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_charset'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(105, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_encoding'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(106, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_setkey'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(107, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_keyx'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(108, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_delkey'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(109, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 62 },
        }}),
        // Slot 'command_showkey'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(110, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 62 },
        }}),
        // Slot 'command_kill'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(111, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_dns'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(112, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_list'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(113, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_konsole'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(114, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_queuetuner'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(115, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_sayversion'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(116, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_cycle'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(117, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_clear'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(118, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'command_umode'
        QtMocHelpers::SlotData<OutputFilterResult(const OutputFilterInput &)>(119, 2, QMC::AccessPrivate, 0x80000000 | 49, {{
            { 0x80000000 | 53, 54 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OutputFilter, qt_meta_tag_ZN12Konversation12OutputFilterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konversation::OutputFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation12OutputFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation12OutputFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation12OutputFilterE_t>.metaTypes,
    nullptr
} };

void Konversation::OutputFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OutputFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openDccSend((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 1: _t->requestDccSend(); break;
        case 2: _t->requestDccSend((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->openDccChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->openDccWBoard((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->addDccPanel(); break;
        case 6: _t->closeDccPanel(); break;
        case 7: _t->acceptDccGet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->openRawLog((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->closeRawLog(); break;
        case 10: _t->openKonsolePanel(); break;
        case 11: _t->openChannelList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->sendToAllChannels((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->launchScript((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 14: _t->banUsers((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->unbanUsers((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->multiServerCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->reconnectServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->disconnectServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->quitServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7]))); break;
        case 21: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 22: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 23: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 24: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 25: _t->connectTo((*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionFlag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: _t->showView((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1]))); break;
        case 27: _t->encodingChanged(); break;
        case 28: { OutputFilterResult _r = _t->execBan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 29: { OutputFilterResult _r = _t->execUnban((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 30: { OutputFilterResult _r = _t->command_op((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 31: { OutputFilterResult _r = _t->command_deop((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 32: { OutputFilterResult _r = _t->command_hop((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 33: { OutputFilterResult _r = _t->command_dehop((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 34: { OutputFilterResult _r = _t->command_voice((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 35: { OutputFilterResult _r = _t->command_unvoice((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 36: { OutputFilterResult _r = _t->command_devoice((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 37: { OutputFilterResult _r = _t->command_join((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 38: { OutputFilterResult _r = _t->command_j((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 39: { OutputFilterResult _r = _t->command_kick((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 40: { OutputFilterResult _r = _t->command_part((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 41: { OutputFilterResult _r = _t->command_leave((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 42: { OutputFilterResult _r = _t->command_topic((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 43: { OutputFilterResult _r = _t->command_away((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 44: { OutputFilterResult _r = _t->command_unaway((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 45: { OutputFilterResult _r = _t->command_back((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 46: { OutputFilterResult _r = _t->command_aaway((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 47: { OutputFilterResult _r = _t->command_aunaway((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 48: { OutputFilterResult _r = _t->command_aback((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 49: { OutputFilterResult _r = _t->command_names((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 50: { OutputFilterResult _r = _t->command_close((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 51: { OutputFilterResult _r = _t->command_reconnect((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 52: { OutputFilterResult _r = _t->command_disconnect((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 53: { OutputFilterResult _r = _t->command_quit((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 54: { OutputFilterResult _r = _t->command_notice((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 55: { OutputFilterResult _r = _t->command_me((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 56: { OutputFilterResult _r = _t->command_msg((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 57: { OutputFilterResult _r = _t->command_m((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 58: { OutputFilterResult _r = _t->command_query((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 59: { OutputFilterResult _r = _t->command_smsg((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 60: { OutputFilterResult _r = _t->command_ping((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 61: { OutputFilterResult _r = _t->command_ctcp((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 62: { OutputFilterResult _r = _t->command_ame((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 63: { OutputFilterResult _r = _t->command_amsg((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 64: { OutputFilterResult _r = _t->command_omsg((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 65: { OutputFilterResult _r = _t->command_onotice((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 66: { OutputFilterResult _r = _t->command_quote((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 67: { OutputFilterResult _r = _t->command_say((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 68: { OutputFilterResult _r = _t->command_dcc((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 69: { OutputFilterResult _r = _t->command_invite((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 70: { OutputFilterResult _r = _t->command_exec((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 71: { OutputFilterResult _r = _t->command_raw((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 72: { OutputFilterResult _r = _t->command_notify((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 73: { OutputFilterResult _r = _t->command_oper((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 74: { OutputFilterResult _r = _t->command_ban((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 75: { OutputFilterResult _r = _t->command_kickban((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 76: { OutputFilterResult _r = _t->command_unban((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 77: { OutputFilterResult _r = _t->command_ignore((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 78: { OutputFilterResult _r = _t->command_unignore((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 79: { OutputFilterResult _r = _t->command_server((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 80: { OutputFilterResult _r = _t->command_charset((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 81: { OutputFilterResult _r = _t->command_encoding((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 82: { OutputFilterResult _r = _t->command_setkey((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 83: { OutputFilterResult _r = _t->command_keyx((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 84: { OutputFilterResult _r = _t->command_delkey((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 85: { OutputFilterResult _r = _t->command_showkey((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 86: { OutputFilterResult _r = _t->command_kill((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 87: { OutputFilterResult _r = _t->command_dns((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 88: { OutputFilterResult _r = _t->command_list((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 89: { OutputFilterResult _r = _t->command_konsole((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 90: { OutputFilterResult _r = _t->command_queuetuner((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 91: { OutputFilterResult _r = _t->command_sayversion((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 92: { OutputFilterResult _r = _t->command_cycle((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 93: { OutputFilterResult _r = _t->command_clear((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 94: { OutputFilterResult _r = _t->command_umode((*reinterpret_cast<std::add_pointer_t<OutputFilterInput>>(_a[1])));
            if (_a[0]) *reinterpret_cast<OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & , const QUrl & )>(_a, &OutputFilter::openDccSend, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)()>(_a, &OutputFilter::requestDccSend, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & )>(_a, &OutputFilter::requestDccSend, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & )>(_a, &OutputFilter::openDccChat, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & )>(_a, &OutputFilter::openDccWBoard, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)()>(_a, &OutputFilter::addDccPanel, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)()>(_a, &OutputFilter::closeDccPanel, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & , const QString & )>(_a, &OutputFilter::acceptDccGet, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(bool )>(_a, &OutputFilter::openRawLog, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)()>(_a, &OutputFilter::closeRawLog, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)()>(_a, &OutputFilter::openKonsolePanel, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & )>(_a, &OutputFilter::openChannelList, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & )>(_a, &OutputFilter::sendToAllChannels, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(int , const QString & , const QString & )>(_a, &OutputFilter::launchScript, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QStringList & , const QString & , const QString & )>(_a, &OutputFilter::banUsers, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & , const QString & )>(_a, &OutputFilter::unbanUsers, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & , const QString & )>(_a, &OutputFilter::multiServerCommand, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & )>(_a, &OutputFilter::reconnectServer, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & )>(_a, &OutputFilter::disconnectServer, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(const QString & )>(_a, &OutputFilter::quitServer, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(Konversation::ConnectionFlag , const QString & , const QString & , const QString & , const QString & , const QString & , bool )>(_a, &OutputFilter::connectTo, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)(ChatWindow * )>(_a, &OutputFilter::showView, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputFilter::*)()>(_a, &OutputFilter::encodingChanged, 27))
            return;
    }
}

const QMetaObject *Konversation::OutputFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::OutputFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation12OutputFilterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::OutputFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 95)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 95;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 95)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 95;
    }
    return _id;
}

// SIGNAL 0
void Konversation::OutputFilter::openDccSend(const QString & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Konversation::OutputFilter::requestDccSend()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Konversation::OutputFilter::requestDccSend(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Konversation::OutputFilter::openDccChat(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Konversation::OutputFilter::openDccWBoard(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Konversation::OutputFilter::addDccPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Konversation::OutputFilter::closeDccPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Konversation::OutputFilter::acceptDccGet(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Konversation::OutputFilter::openRawLog(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Konversation::OutputFilter::closeRawLog()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Konversation::OutputFilter::openKonsolePanel()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Konversation::OutputFilter::openChannelList(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Konversation::OutputFilter::sendToAllChannels(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Konversation::OutputFilter::launchScript(int _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void Konversation::OutputFilter::banUsers(const QStringList & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void Konversation::OutputFilter::unbanUsers(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void Konversation::OutputFilter::multiServerCommand(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}

// SIGNAL 17
void Konversation::OutputFilter::reconnectServer(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Konversation::OutputFilter::disconnectServer(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Konversation::OutputFilter::quitServer(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void Konversation::OutputFilter::connectTo(Konversation::ConnectionFlag _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, bool _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 26
void Konversation::OutputFilter::showView(ChatWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void Konversation::OutputFilter::encodingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}
QT_WARNING_POP
