/****************************************************************************
** Meta object code from reading C++ file 'notificationhandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/notificationhandler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Konversation19NotificationHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::NotificationHandler::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation19NotificationHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::NotificationHandler",
        "message",
        "",
        "ChatWindow*",
        "chatWin",
        "fromNick",
        "nick",
        "join",
        "part",
        "quit",
        "nickChange",
        "oldNick",
        "newNick",
        "dccIncoming",
        "dccError",
        "error",
        "dccTransferDone",
        "file",
        "Konversation::DCC::Transfer*",
        "transfer",
        "mode",
        "subject",
        "change",
        "query",
        "queryMessage",
        "nickOnline",
        "nickOffline",
        "kick",
        "channel",
        "dccChat",
        "highlight",
        "connectionFailure",
        "server",
        "channelJoin"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'message'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 1 },
        }}),
        // Slot 'nick'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 1 },
        }}),
        // Slot 'join'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'part'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'quit'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'nickChange'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'dccIncoming'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'dccError'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'dccTransferDone'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &, Konversation::DCC::Transfer *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Slot 'mode'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &, const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 }, { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'query'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'queryMessage'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 1 },
        }}),
        // Slot 'nickOnline'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'nickOffline'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'kick'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &, const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 28 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'dccChat'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'highlight'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &, const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 1 },
        }}),
        // Slot 'connectionFailure'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 32 },
        }}),
        // Slot 'channelJoin'
        QtMocHelpers::SlotData<void(ChatWindow *, const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotificationHandler, qt_meta_tag_ZN12Konversation19NotificationHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konversation::NotificationHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation19NotificationHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation19NotificationHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation19NotificationHandlerE_t>.metaTypes,
    nullptr
} };

void Konversation::NotificationHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->message((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->nick((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->join((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->part((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->quit((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->nickChange((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->dccIncoming((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->dccError((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->dccTransferDone((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Konversation::DCC::Transfer*>>(_a[3]))); break;
        case 9: _t->mode((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 10: _t->query((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->queryMessage((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 12: _t->nickOnline((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->nickOffline((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->kick((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->dccChat((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->highlight((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 17: _t->connectionFailure((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->channelJoin((*reinterpret_cast<std::add_pointer_t<ChatWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *Konversation::NotificationHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::NotificationHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation19NotificationHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::NotificationHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
