/****************************************************************************
** Meta object code from reading C++ file 'whiteboardtoolbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/dcc/whiteboardtoolbar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'whiteboardtoolbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Konversation3DCC17WhiteBoardToolBarE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::DCC::WhiteBoardToolBar::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation3DCC17WhiteBoardToolBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::DCC::WhiteBoardToolBar",
        "toolChanged",
        "",
        "Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool",
        "tool",
        "colorsSwapped",
        "QColor",
        "newForegroundColor",
        "newBackgroundColor",
        "foregroundColorChanged",
        "color",
        "backgroundColorChanged",
        "fontChanged",
        "QFont",
        "font",
        "lineWidthChanged",
        "width",
        "save",
        "filename",
        "clear",
        "enableTool",
        "disableTool",
        "setSupportedTextType",
        "Konversation::DCC::WhiteBoardToolBar::TextType",
        "textType",
        "setForegroundColor",
        "foregroundColor",
        "setBackgroundColor",
        "backgroundColor",
        "clearClicked",
        "saveClicked",
        "pencilToggled",
        "checked",
        "lineToggled",
        "rectangleToggled",
        "ellipseToggled",
        "textToggled",
        "selectionToggled",
        "eraseToggled",
        "fillToggled",
        "arrowToggled",
        "colorPickerToggled",
        "updateLineWidthPixmap",
        "lineWidth",
        "formSelectionChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'toolChanged'
        QtMocHelpers::SignalData<void(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'colorsSwapped'
        QtMocHelpers::SignalData<void(const QColor &, const QColor &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Signal 'foregroundColorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 10 },
        }}),
        // Signal 'backgroundColorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 10 },
        }}),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'lineWidthChanged'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'save'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'clear'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableTool'
        QtMocHelpers::SlotData<void(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'disableTool'
        QtMocHelpers::SlotData<void(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setSupportedTextType'
        QtMocHelpers::SlotData<void(Konversation::DCC::WhiteBoardToolBar::TextType)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'textType'
        QtMocHelpers::SlotData<Konversation::DCC::WhiteBoardToolBar::TextType() const>(24, 2, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'setForegroundColor'
        QtMocHelpers::SlotData<void(const QColor &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 26 },
        }}),
        // Slot 'setBackgroundColor'
        QtMocHelpers::SlotData<void(const QColor &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 28 },
        }}),
        // Slot 'clearClicked'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveClicked'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pencilToggled'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'lineToggled'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'rectangleToggled'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'ellipseToggled'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'textToggled'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'selectionToggled'
        QtMocHelpers::SlotData<void(bool)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'eraseToggled'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'fillToggled'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'arrowToggled'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'colorPickerToggled'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'updateLineWidthPixmap'
        QtMocHelpers::SlotData<void(int)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'formSelectionChanged'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WhiteBoardToolBar, qt_meta_tag_ZN12Konversation3DCC17WhiteBoardToolBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konversation::DCC::WhiteBoardToolBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC17WhiteBoardToolBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC17WhiteBoardToolBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation3DCC17WhiteBoardToolBarE_t>.metaTypes,
    nullptr
} };

void Konversation::DCC::WhiteBoardToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WhiteBoardToolBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->toolChanged((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool>>(_a[1]))); break;
        case 1: _t->colorsSwapped((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        case 2: _t->foregroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 3: _t->backgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 4: _t->fontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 5: _t->lineWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->save((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->clear(); break;
        case 8: _t->enableTool((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool>>(_a[1]))); break;
        case 9: _t->disableTool((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool>>(_a[1]))); break;
        case 10: _t->setSupportedTextType((*reinterpret_cast<std::add_pointer_t<Konversation::DCC::WhiteBoardToolBar::TextType>>(_a[1]))); break;
        case 11: { Konversation::DCC::WhiteBoardToolBar::TextType _r = _t->textType();
            if (_a[0]) *reinterpret_cast<Konversation::DCC::WhiteBoardToolBar::TextType*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setForegroundColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 13: _t->setBackgroundColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 14: _t->clearClicked(); break;
        case 15: _t->saveClicked(); break;
        case 16: _t->pencilToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->lineToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->rectangleToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->ellipseToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->textToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->selectionToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->eraseToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->fillToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->arrowToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->colorPickerToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->updateLineWidthPixmap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->formSelectionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardToolBar::*)(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool )>(_a, &WhiteBoardToolBar::toolChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardToolBar::*)(const QColor & , const QColor & )>(_a, &WhiteBoardToolBar::colorsSwapped, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardToolBar::*)(const QColor & )>(_a, &WhiteBoardToolBar::foregroundColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardToolBar::*)(const QColor & )>(_a, &WhiteBoardToolBar::backgroundColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardToolBar::*)(const QFont & )>(_a, &WhiteBoardToolBar::fontChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardToolBar::*)(int )>(_a, &WhiteBoardToolBar::lineWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardToolBar::*)(const QString & )>(_a, &WhiteBoardToolBar::save, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (WhiteBoardToolBar::*)()>(_a, &WhiteBoardToolBar::clear, 7))
            return;
    }
}

const QMetaObject *Konversation::DCC::WhiteBoardToolBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::WhiteBoardToolBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation3DCC17WhiteBoardToolBarE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::WhiteBoardToolBarUi"))
        return static_cast< Ui::WhiteBoardToolBarUi*>(this);
    return QWidget::qt_metacast(_clname);
}

int Konversation::DCC::WhiteBoardToolBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::WhiteBoardToolBar::toolChanged(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Konversation::DCC::WhiteBoardToolBar::colorsSwapped(const QColor & _t1, const QColor & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Konversation::DCC::WhiteBoardToolBar::foregroundColorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Konversation::DCC::WhiteBoardToolBar::backgroundColorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Konversation::DCC::WhiteBoardToolBar::fontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Konversation::DCC::WhiteBoardToolBar::lineWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Konversation::DCC::WhiteBoardToolBar::save(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Konversation::DCC::WhiteBoardToolBar::clear()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
