/*
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

*/

/********************************************************************************
** Form generated from reading UI file 'searchbarbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHBARBASE_H
#define UI_SEARCHBARBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_SearchBarBase
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QToolButton *m_closeButton;
    QLabel *m_findLabel;
    KLineEdit *m_searchEdit;
    QToolButton *m_findNextButton;
    QToolButton *m_findPreviousButton;
    QSpacerItem *horizontalSpacer;
    QToolButton *m_optionsButton;

    void setupUi(QWidget *SearchBarBase)
    {
        if (SearchBarBase->objectName().isEmpty())
            SearchBarBase->setObjectName("SearchBarBase");
        SearchBarBase->resize(502, 36);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SearchBarBase->sizePolicy().hasHeightForWidth());
        SearchBarBase->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(SearchBarBase);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_closeButton = new QToolButton(SearchBarBase);
        m_closeButton->setObjectName("m_closeButton");
        m_closeButton->setAutoRaise(true);

        horizontalLayout->addWidget(m_closeButton);

        m_findLabel = new QLabel(SearchBarBase);
        m_findLabel->setObjectName("m_findLabel");

        horizontalLayout->addWidget(m_findLabel);

        m_searchEdit = new KLineEdit(SearchBarBase);
        m_searchEdit->setObjectName("m_searchEdit");

        horizontalLayout->addWidget(m_searchEdit);

        m_findNextButton = new QToolButton(SearchBarBase);
        m_findNextButton->setObjectName("m_findNextButton");
        m_findNextButton->setAutoRaise(true);

        horizontalLayout->addWidget(m_findNextButton);

        m_findPreviousButton = new QToolButton(SearchBarBase);
        m_findPreviousButton->setObjectName("m_findPreviousButton");
        m_findPreviousButton->setAutoRaise(true);

        horizontalLayout->addWidget(m_findPreviousButton);

        horizontalSpacer = new QSpacerItem(12, 26, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        m_optionsButton = new QToolButton(SearchBarBase);
        m_optionsButton->setObjectName("m_optionsButton");
        m_optionsButton->setPopupMode(QToolButton::InstantPopup);
        m_optionsButton->setAutoRaise(true);

        horizontalLayout->addWidget(m_optionsButton);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        m_findLabel->setBuddy(m_searchEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SearchBarBase);

        QMetaObject::connectSlotsByName(SearchBarBase);
    } // setupUi

    void retranslateUi(QWidget *SearchBarBase)
    {
#if QT_CONFIG(tooltip)
        m_closeButton->setToolTip(tr2i18n("Close", nullptr));
#endif // QT_CONFIG(tooltip)
        m_closeButton->setText(QString());
        m_findLabel->setText(tr2i18n("F&ind:", nullptr));
#if QT_CONFIG(tooltip)
        m_findNextButton->setToolTip(tr2i18n("Jump to next match", nullptr));
#endif // QT_CONFIG(tooltip)
        m_findNextButton->setText(tr2i18n("&Next", nullptr));
#if QT_CONFIG(tooltip)
        m_findPreviousButton->setToolTip(tr2i18n("Jump to previous match", nullptr));
#endif // QT_CONFIG(tooltip)
        m_findPreviousButton->setText(tr2i18n("&Previous", nullptr));
#if QT_CONFIG(tooltip)
        m_optionsButton->setToolTip(tr2i18n("Modify search behavior", nullptr));
#endif // QT_CONFIG(tooltip)
        m_optionsButton->setText(tr2i18n("&Options", nullptr));
        (void)SearchBarBase;
    } // retranslateUi

};

namespace Ui {
    class SearchBarBase: public Ui_SearchBarBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHBARBASE_H

