/********************************************************************************
** Form generated from reading UI file 'irccolorchooserui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IRCCOLORCHOOSERUI_H
#define UI_IRCCOLORCHOOSERUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_IRCColorChooserUI
{
public:
    QGridLayout *gridLayout;
    QLabel *m_previewLbl;
    KComboBox *m_fgColorCBox;
    QLabel *m_fgColorLbl;
    KComboBox *m_bgColorCBox;
    QLabel *m_bgColorLbl;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QWidget *IRCColorChooserUI)
    {
        if (IRCColorChooserUI->objectName().isEmpty())
            IRCColorChooserUI->setObjectName("IRCColorChooserUI");
        IRCColorChooserUI->resize(249, 126);
        gridLayout = new QGridLayout(IRCColorChooserUI);
        gridLayout->setObjectName("gridLayout");
        m_previewLbl = new QLabel(IRCColorChooserUI);
        m_previewLbl->setObjectName("m_previewLbl");
        m_previewLbl->setFrameShape(QFrame::Panel);
        m_previewLbl->setFrameShadow(QFrame::Sunken);
        m_previewLbl->setAlignment(Qt::AlignCenter);
        m_previewLbl->setWordWrap(false);

        gridLayout->addWidget(m_previewLbl, 2, 0, 1, 2);

        m_fgColorCBox = new KComboBox(IRCColorChooserUI);
        m_fgColorCBox->setObjectName("m_fgColorCBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_fgColorCBox->sizePolicy().hasHeightForWidth());
        m_fgColorCBox->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_fgColorCBox, 0, 1, 1, 1);

        m_fgColorLbl = new QLabel(IRCColorChooserUI);
        m_fgColorLbl->setObjectName("m_fgColorLbl");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_fgColorLbl->sizePolicy().hasHeightForWidth());
        m_fgColorLbl->setSizePolicy(sizePolicy1);
        m_fgColorLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_fgColorLbl->setWordWrap(false);

        gridLayout->addWidget(m_fgColorLbl, 0, 0, 1, 1);

        m_bgColorCBox = new KComboBox(IRCColorChooserUI);
        m_bgColorCBox->setObjectName("m_bgColorCBox");
        m_bgColorCBox->setEnabled(true);
        sizePolicy.setHeightForWidth(m_bgColorCBox->sizePolicy().hasHeightForWidth());
        m_bgColorCBox->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_bgColorCBox, 1, 1, 1, 1);

        m_bgColorLbl = new QLabel(IRCColorChooserUI);
        m_bgColorLbl->setObjectName("m_bgColorLbl");
        m_bgColorLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_bgColorLbl->setWordWrap(false);

        gridLayout->addWidget(m_bgColorLbl, 1, 0, 1, 1);

        m_buttonBox = new QDialogButtonBox(IRCColorChooserUI);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(m_buttonBox, 3, 0, 1, 2);

#if QT_CONFIG(shortcut)
        m_fgColorLbl->setBuddy(m_fgColorCBox);
        m_bgColorLbl->setBuddy(m_bgColorCBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(IRCColorChooserUI);

        QMetaObject::connectSlotsByName(IRCColorChooserUI);
    } // setupUi

    void retranslateUi(QWidget *IRCColorChooserUI)
    {
#if QT_CONFIG(tooltip)
        m_previewLbl->setToolTip(tr2i18n("This is how your message will look with these colors", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_previewLbl->setWhatsThis(tr2i18n("<qt>This is a preview of how your readers may see view your message if you select these colors.<br>\n"
"<b>Note: Not all clients support this, and some users may have chosen to ignore your color changes.</b>\n"
"</qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_previewLbl->setText(tr2i18n("Preview", nullptr));
#if QT_CONFIG(tooltip)
        m_fgColorCBox->setToolTip(tr2i18n("The chosen text color is added to the input line.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_fgColorCBox->setWhatsThis(tr2i18n("<qt>Here you choose what color you want you the text in the next message you send to be.  If you choose a color and click Ok, the chosen color is added to the Input Line.  Any text written after this will be in the chosen color, until you change the color again.<br>\n"
"<b>Note:  Not all users turn on the option to see this.</b></qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        m_fgColorLbl->setToolTip(tr2i18n("The chosen text color is added to the input line.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_fgColorLbl->setWhatsThis(tr2i18n("<qt>Here you choose what color you want you the text in the next message you send to be.  If you choose a color and click Ok, the chosen color is added to the Input Line.  Any text written after this will be in the chosen color, until you change the color again.<br>\n"
"<b>Note:  Not all users turn on the option to see this.</b></qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_fgColorLbl->setText(tr2i18n("Fore&ground color:", nullptr));
#if QT_CONFIG(tooltip)
        m_bgColorCBox->setToolTip(tr2i18n("The chosen text-background color is added to the input line.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_bgColorCBox->setWhatsThis(tr2i18n("<qt>Here you choose what color you want you background for the text in the next message you send to be.\n"
"If you choose a color and click Ok, the chosen color is added to the Input Line.\n"
"Any text written after this will have the chosen color, until you change the color again.<br>\n"
"Choosing the default \"<i>None</i>\" will not change the background color of your message, so your readers will view your message with their normal background text color.<br>\n"
"<b>Note:  Not all clients support this, and not all users turn on the option to see this.</b></qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        m_bgColorLbl->setToolTip(tr2i18n("The chosen text-background color is added to the input line.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_bgColorLbl->setWhatsThis(tr2i18n("<qt>Here you choose what color you want you background for the text in the next message you send to be.\n"
"If you choose a color and click Ok, the chosen color is added to the Input Line.\n"
"Any text written after this will have the chosen color, until you change the color again.<br>\n"
"Choosing the default \"<i>None</i>\" will not change the background color of your message, so your readers will view your message with their normal background text color.<br>\n"
"<b>Note:  Not all clients support this, and not all users turn on the option to see this.</b></qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_bgColorLbl->setText(tr2i18n("&Background color:", nullptr));
        (void)IRCColorChooserUI;
    } // retranslateUi

};

namespace Ui {
    class IRCColorChooserUI: public Ui_IRCColorChooserUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IRCCOLORCHOOSERUI_H

