/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
*/

/********************************************************************************
** Form generated from reading UI file 'log_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOG_CONFIG_H
#define UI_LOG_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_Log_Config
{
public:
    QGridLayout *gridLayout;
    QGroupBox *kcfg_Log;
    QFormLayout *formLayout;
    QCheckBox *kcfg_PrivateOnly;
    QCheckBox *kcfg_LowerLog;
    QCheckBox *kcfg_AddHostnameToLog;
    QLabel *textLabel1;
    KUrlRequester *kcfg_LogfilePath;
    QCheckBox *kcfg_UseExternalLogViewer;
    QSpacerItem *spacer1;

    void setupUi(QWidget *Log_Config)
    {
        if (Log_Config->objectName().isEmpty())
            Log_Config->setObjectName("Log_Config");
        Log_Config->resize(410, 164);
        gridLayout = new QGridLayout(Log_Config);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        kcfg_Log = new QGroupBox(Log_Config);
        kcfg_Log->setObjectName("kcfg_Log");
        kcfg_Log->setCheckable(true);
        formLayout = new QFormLayout(kcfg_Log);
        formLayout->setObjectName("formLayout");
        kcfg_PrivateOnly = new QCheckBox(kcfg_Log);
        kcfg_PrivateOnly->setObjectName("kcfg_PrivateOnly");

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, kcfg_PrivateOnly);

        kcfg_LowerLog = new QCheckBox(kcfg_Log);
        kcfg_LowerLog->setObjectName("kcfg_LowerLog");

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, kcfg_LowerLog);

        kcfg_AddHostnameToLog = new QCheckBox(kcfg_Log);
        kcfg_AddHostnameToLog->setObjectName("kcfg_AddHostnameToLog");

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, kcfg_AddHostnameToLog);

        textLabel1 = new QLabel(kcfg_Log);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, textLabel1);

        kcfg_LogfilePath = new KUrlRequester(kcfg_Log);
        kcfg_LogfilePath->setObjectName("kcfg_LogfilePath");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_LogfilePath->sizePolicy().hasHeightForWidth());
        kcfg_LogfilePath->setSizePolicy(sizePolicy);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_LogfilePath);

        kcfg_UseExternalLogViewer = new QCheckBox(kcfg_Log);
        kcfg_UseExternalLogViewer->setObjectName("kcfg_UseExternalLogViewer");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, kcfg_UseExternalLogViewer);


        gridLayout->addWidget(kcfg_Log, 0, 0, 1, 1);

        spacer1 = new QSpacerItem(21, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacer1, 1, 0, 1, 1);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(kcfg_LogfilePath);
#endif // QT_CONFIG(shortcut)

        retranslateUi(Log_Config);

        QMetaObject::connectSlotsByName(Log_Config);
    } // setupUi

    void retranslateUi(QWidget *Log_Config)
    {
        kcfg_Log->setTitle(tr2i18n("&Enable Logging", nullptr));
        kcfg_PrivateOnly->setText(tr2i18n("Only log private conversations (queries, DCC chats)", nullptr));
        kcfg_LowerLog->setText(tr2i18n("Enable &lower case logfile names", nullptr));
        kcfg_AddHostnameToLog->setText(tr2i18n("&Append hostname to logfile names", nullptr));
        textLabel1->setText(tr2i18n("Logfile &path:", nullptr));
        kcfg_UseExternalLogViewer->setText(tr2i18n("Use system text editor to open logs", nullptr));
        (void)Log_Config;
    } // retranslateUi

};

namespace Ui {
    class Log_Config: public Ui_Log_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOG_CONFIG_H

