/********************************************************************************
** Form generated from reading UI file 'channellistpanelui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHANNELLISTPANELUI_H
#define UI_CHANNELLISTPANELUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ChannelListWidgetUI
{
public:
    QWidget *gridLayoutWidget;
    QGridLayout *gridLayout_2;
    QLabel *m_lblMaxUser;
    QLabel *m_lblMinuser;
    QTreeView *m_channelListView;
    QCheckBox *m_channelBox;
    QCheckBox *m_topicBox;
    KLineEdit *m_filterLine;
    QSpacerItem *horizontalSpacer;
    QCheckBox *m_regexBox;
    QHBoxLayout *horizontalLayout_3;
    QLabel *m_statsLabel;
    QSpinBox *m_minUser;
    QSpinBox *m_maxUser;

    void setupUi(QWidget *ChannelListWidgetUI)
    {
        if (ChannelListWidgetUI->objectName().isEmpty())
            ChannelListWidgetUI->setObjectName("ChannelListWidgetUI");
        ChannelListWidgetUI->resize(813, 503);
        gridLayoutWidget = new QWidget(ChannelListWidgetUI);
        gridLayoutWidget->setObjectName("gridLayoutWidget");
        gridLayoutWidget->setGeometry(QRect(0, 0, 811, 501));
        gridLayout_2 = new QGridLayout(gridLayoutWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        m_lblMaxUser = new QLabel(gridLayoutWidget);
        m_lblMaxUser->setObjectName("m_lblMaxUser");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_lblMaxUser->sizePolicy().hasHeightForWidth());
        m_lblMaxUser->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(m_lblMaxUser, 2, 0, 1, 1);

        m_lblMinuser = new QLabel(gridLayoutWidget);
        m_lblMinuser->setObjectName("m_lblMinuser");
        sizePolicy.setHeightForWidth(m_lblMinuser->sizePolicy().hasHeightForWidth());
        m_lblMinuser->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(m_lblMinuser, 1, 0, 1, 1);

        m_channelListView = new QTreeView(gridLayoutWidget);
        m_channelListView->setObjectName("m_channelListView");
        m_channelListView->setContextMenuPolicy(Qt::CustomContextMenu);
        m_channelListView->setIndentation(0);
        m_channelListView->setSortingEnabled(true);
        m_channelListView->setAllColumnsShowFocus(true);
        m_channelListView->header()->setDefaultSectionSize(115);

        gridLayout_2->addWidget(m_channelListView, 5, 0, 1, 7);

        m_channelBox = new QCheckBox(gridLayoutWidget);
        m_channelBox->setObjectName("m_channelBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_channelBox->sizePolicy().hasHeightForWidth());
        m_channelBox->setSizePolicy(sizePolicy1);
        m_channelBox->setChecked(true);

        gridLayout_2->addWidget(m_channelBox, 2, 2, 1, 1);

        m_topicBox = new QCheckBox(gridLayoutWidget);
        m_topicBox->setObjectName("m_topicBox");
        sizePolicy1.setHeightForWidth(m_topicBox->sizePolicy().hasHeightForWidth());
        m_topicBox->setSizePolicy(sizePolicy1);
        m_topicBox->setChecked(false);

        gridLayout_2->addWidget(m_topicBox, 2, 3, 1, 1);

        m_filterLine = new KLineEdit(gridLayoutWidget);
        m_filterLine->setObjectName("m_filterLine");
        m_filterLine->setContextMenuPolicy(Qt::CustomContextMenu);
        m_filterLine->setProperty("showClearButton", QVariant(true));

        gridLayout_2->addWidget(m_filterLine, 1, 2, 1, 5);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 2, 4, 1, 1);

        m_regexBox = new QCheckBox(gridLayoutWidget);
        m_regexBox->setObjectName("m_regexBox");
        sizePolicy1.setHeightForWidth(m_regexBox->sizePolicy().hasHeightForWidth());
        m_regexBox->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(m_regexBox, 2, 5, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        m_statsLabel = new QLabel(gridLayoutWidget);
        m_statsLabel->setObjectName("m_statsLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(m_statsLabel->sizePolicy().hasHeightForWidth());
        m_statsLabel->setSizePolicy(sizePolicy2);

        horizontalLayout_3->addWidget(m_statsLabel);


        gridLayout_2->addLayout(horizontalLayout_3, 13, 0, 1, 7);

        m_minUser = new QSpinBox(gridLayoutWidget);
        m_minUser->setObjectName("m_minUser");
        sizePolicy1.setHeightForWidth(m_minUser->sizePolicy().hasHeightForWidth());
        m_minUser->setSizePolicy(sizePolicy1);
        m_minUser->setMaximum(9999);

        gridLayout_2->addWidget(m_minUser, 1, 1, 1, 1);

        m_maxUser = new QSpinBox(gridLayoutWidget);
        m_maxUser->setObjectName("m_maxUser");
        sizePolicy1.setHeightForWidth(m_maxUser->sizePolicy().hasHeightForWidth());
        m_maxUser->setSizePolicy(sizePolicy1);
        m_maxUser->setMaximum(9999);

        gridLayout_2->addWidget(m_maxUser, 2, 1, 1, 1);

#if QT_CONFIG(shortcut)
        m_lblMaxUser->setBuddy(m_maxUser);
        m_lblMinuser->setBuddy(m_minUser);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ChannelListWidgetUI);

        QMetaObject::connectSlotsByName(ChannelListWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *ChannelListWidgetUI)
    {
        ChannelListWidgetUI->setWindowTitle(tr2i18n("Channel List", nullptr));
        m_lblMaxUser->setText(tr2i18n("Ma&ximum users:", nullptr));
        m_lblMinuser->setText(tr2i18n("&Minimum users:", nullptr));
#if QT_CONFIG(whatsthis)
        m_channelListView->setWhatsThis(tr2i18n("<p>The filtered list of channels is displayed here. Notice that if you do not use regular expressions, Konversation lists any channel whose name contains the filter string you entered. The channel name does not have to start with the string you entered.</p><p>Select a channel you want to join by clicking on it. Right click on the channel to get a list of all web addresses mentioned in the channel's topic.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_channelBox->setText(tr2i18n("&Channel", nullptr));
        m_topicBox->setText(tr2i18n("&Topic", nullptr));
#if QT_CONFIG(whatsthis)
        m_filterLine->setWhatsThis(tr2i18n("Enter a filter string here.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_filterLine->setText(QString());
        m_filterLine->setPlaceholderText(tr2i18n("Search", nullptr));
        m_regexBox->setText(tr2i18n("&Regular expression", nullptr));
        m_statsLabel->setText(QString());
#if QT_CONFIG(whatsthis)
        m_minUser->setWhatsThis(tr2i18n("You can limit the channel list to those channels with a minimum number of users here. Choosing \"No Limit\" disables this criterion.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_minUser->setSpecialValueText(tr2i18n("No Limit", nullptr));
#if QT_CONFIG(whatsthis)
        m_maxUser->setWhatsThis(tr2i18n("You can limit the channel list to those channels with a maximum number of users here. Choosing \"No Limit\" disables this criterion.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_maxUser->setSpecialValueText(tr2i18n("No Limit", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ChannelListWidgetUI: public Ui_ChannelListWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHANNELLISTPANELUI_H

