/********************************************************************************
** Form generated from reading UI file 'launcherentry_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LAUNCHERENTRY_CONFIG_H
#define UI_LAUNCHERENTRY_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LauncherEntry_Config
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_ShowLauncherEntryCount;
    QGroupBox *generalGroupBox;
    QFormLayout *formLayout;
    QLabel *modeLbl;
    QComboBox *kcfg_LauncherEntryCountMode;
    QGroupBox *countedEventsGroupBox;
    QVBoxLayout *vboxLayout1;
    QCheckBox *kcfg_LauncherEntryCountUseMsgs;
    QCheckBox *kcfg_LauncherEntryCountUsePrivate;
    QCheckBox *kcfg_LauncherEntryCountUseNick;
    QCheckBox *kcfg_LauncherEntryCountUseHighlights;
    QCheckBox *kcfg_LauncherEntryCountUseChannelEvents;
    QCheckBox *kcfg_LauncherEntryCountUseSystem;
    QSpacerItem *spacer1;

    void setupUi(QWidget *LauncherEntry_Config)
    {
        if (LauncherEntry_Config->objectName().isEmpty())
            LauncherEntry_Config->setObjectName("LauncherEntry_Config");
        LauncherEntry_Config->resize(447, 525);
        vboxLayout = new QVBoxLayout(LauncherEntry_Config);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_ShowLauncherEntryCount = new QCheckBox(LauncherEntry_Config);
        kcfg_ShowLauncherEntryCount->setObjectName("kcfg_ShowLauncherEntryCount");

        vboxLayout->addWidget(kcfg_ShowLauncherEntryCount);

        generalGroupBox = new QGroupBox(LauncherEntry_Config);
        generalGroupBox->setObjectName("generalGroupBox");
        generalGroupBox->setEnabled(false);
        formLayout = new QFormLayout(generalGroupBox);
        formLayout->setObjectName("formLayout");
        modeLbl = new QLabel(generalGroupBox);
        modeLbl->setObjectName("modeLbl");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, modeLbl);

        kcfg_LauncherEntryCountMode = new QComboBox(generalGroupBox);
        kcfg_LauncherEntryCountMode->addItem(QString());
        kcfg_LauncherEntryCountMode->addItem(QString());
        kcfg_LauncherEntryCountMode->setObjectName("kcfg_LauncherEntryCountMode");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_LauncherEntryCountMode);


        vboxLayout->addWidget(generalGroupBox);

        countedEventsGroupBox = new QGroupBox(LauncherEntry_Config);
        countedEventsGroupBox->setObjectName("countedEventsGroupBox");
        countedEventsGroupBox->setEnabled(false);
        vboxLayout1 = new QVBoxLayout(countedEventsGroupBox);
        vboxLayout1->setObjectName("vboxLayout1");
        kcfg_LauncherEntryCountUseMsgs = new QCheckBox(countedEventsGroupBox);
        kcfg_LauncherEntryCountUseMsgs->setObjectName("kcfg_LauncherEntryCountUseMsgs");
        kcfg_LauncherEntryCountUseMsgs->setChecked(false);

        vboxLayout1->addWidget(kcfg_LauncherEntryCountUseMsgs);

        kcfg_LauncherEntryCountUsePrivate = new QCheckBox(countedEventsGroupBox);
        kcfg_LauncherEntryCountUsePrivate->setObjectName("kcfg_LauncherEntryCountUsePrivate");
        kcfg_LauncherEntryCountUsePrivate->setChecked(true);

        vboxLayout1->addWidget(kcfg_LauncherEntryCountUsePrivate);

        kcfg_LauncherEntryCountUseNick = new QCheckBox(countedEventsGroupBox);
        kcfg_LauncherEntryCountUseNick->setObjectName("kcfg_LauncherEntryCountUseNick");
        kcfg_LauncherEntryCountUseNick->setChecked(true);

        vboxLayout1->addWidget(kcfg_LauncherEntryCountUseNick);

        kcfg_LauncherEntryCountUseHighlights = new QCheckBox(countedEventsGroupBox);
        kcfg_LauncherEntryCountUseHighlights->setObjectName("kcfg_LauncherEntryCountUseHighlights");
        kcfg_LauncherEntryCountUseHighlights->setChecked(false);

        vboxLayout1->addWidget(kcfg_LauncherEntryCountUseHighlights);

        kcfg_LauncherEntryCountUseChannelEvents = new QCheckBox(countedEventsGroupBox);
        kcfg_LauncherEntryCountUseChannelEvents->setObjectName("kcfg_LauncherEntryCountUseChannelEvents");
        kcfg_LauncherEntryCountUseChannelEvents->setChecked(false);

        vboxLayout1->addWidget(kcfg_LauncherEntryCountUseChannelEvents);

        kcfg_LauncherEntryCountUseSystem = new QCheckBox(countedEventsGroupBox);
        kcfg_LauncherEntryCountUseSystem->setObjectName("kcfg_LauncherEntryCountUseSystem");
        kcfg_LauncherEntryCountUseSystem->setChecked(false);

        vboxLayout1->addWidget(kcfg_LauncherEntryCountUseSystem);


        vboxLayout->addWidget(countedEventsGroupBox);

        spacer1 = new QSpacerItem(21, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer1);

#if QT_CONFIG(shortcut)
        modeLbl->setBuddy(kcfg_LauncherEntryCountMode);
#endif // QT_CONFIG(shortcut)

        retranslateUi(LauncherEntry_Config);
        QObject::connect(kcfg_ShowLauncherEntryCount, &QCheckBox::toggled, generalGroupBox, &QGroupBox::setEnabled);
        QObject::connect(kcfg_ShowLauncherEntryCount, &QCheckBox::toggled, countedEventsGroupBox, &QGroupBox::setEnabled);

        QMetaObject::connectSlotsByName(LauncherEntry_Config);
    } // setupUi

    void retranslateUi(QWidget *LauncherEntry_Config)
    {
        kcfg_ShowLauncherEntryCount->setText(tr2i18n("&Enable Display of Unseen Events Count On Launcher Entry", nullptr));
        generalGroupBox->setTitle(tr2i18n("General", nullptr));
        modeLbl->setText(tr2i18n("Count &mode:", nullptr));
        kcfg_LauncherEntryCountMode->setItemText(0, tr2i18n("All events", nullptr));
        kcfg_LauncherEntryCountMode->setItemText(1, tr2i18n("Channels and queries with events", nullptr));

        countedEventsGroupBox->setTitle(tr2i18n("Counted Events", nullptr));
        kcfg_LauncherEntryCountUseMsgs->setText(tr2i18n("Message", nullptr));
        kcfg_LauncherEntryCountUsePrivate->setText(tr2i18n("Private message", nullptr));
        kcfg_LauncherEntryCountUseNick->setText(tr2i18n("Current nick used", nullptr));
        kcfg_LauncherEntryCountUseHighlights->setText(tr2i18n("Highlight", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_LauncherEntryCountUseChannelEvents->setWhatsThis(tr2i18n("Channel events are mode changes or users joining/leaving a channel.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_LauncherEntryCountUseChannelEvents->setText(tr2i18n("Channel event", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_LauncherEntryCountUseSystem->setWhatsThis(tr2i18n("Application events occur in Konsole tabs, the DCC Status tab and other application tabs not used directly for chatting.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_LauncherEntryCountUseSystem->setText(tr2i18n("Application event", nullptr));
        (void)LauncherEntry_Config;
    } // retranslateUi

};

namespace Ui {
    class LauncherEntry_Config: public Ui_LauncherEntry_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LAUNCHERENTRY_CONFIG_H

