/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

*/

/********************************************************************************
** Form generated from reading UI file 'joinchannelui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JOINCHANNELUI_H
#define UI_JOINCHANNELUI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "khistorycombobox.h"
#include "kpasswordlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_JoinChannelUI
{
public:
    QGridLayout *gridLayout;
    QLabel *channelLabel;
    KHistoryComboBox *channelCombo;
    QLabel *textLabel8;
    QLabel *passwordLabel;
    QPushButton *delBtn;
    KComboBox *networkNameCombo;
    KPasswordLineEdit *passwordEdit;

    void setupUi(QWidget *JoinChannelUI)
    {
        if (JoinChannelUI->objectName().isEmpty())
            JoinChannelUI->setObjectName("JoinChannelUI");
        JoinChannelUI->resize(426, 94);
        gridLayout = new QGridLayout(JoinChannelUI);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        channelLabel = new QLabel(JoinChannelUI);
        channelLabel->setObjectName("channelLabel");
        channelLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        channelLabel->setWordWrap(false);

        gridLayout->addWidget(channelLabel, 1, 0, 1, 1);

        channelCombo = new KHistoryComboBox(JoinChannelUI);
        channelCombo->setObjectName("channelCombo");
        channelCombo->setAutoCompletion(true);
        channelCombo->setProperty("contextMenuEnabled", QVariant(true));

        gridLayout->addWidget(channelCombo, 1, 2, 1, 1);

        textLabel8 = new QLabel(JoinChannelUI);
        textLabel8->setObjectName("textLabel8");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel8->sizePolicy().hasHeightForWidth());
        textLabel8->setSizePolicy(sizePolicy);
        textLabel8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel8->setWordWrap(false);

        gridLayout->addWidget(textLabel8, 0, 0, 1, 1);

        passwordLabel = new QLabel(JoinChannelUI);
        passwordLabel->setObjectName("passwordLabel");
        passwordLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        passwordLabel->setWordWrap(false);

        gridLayout->addWidget(passwordLabel, 2, 0, 1, 1);

        delBtn = new QPushButton(JoinChannelUI);
        delBtn->setObjectName("delBtn");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(delBtn->sizePolicy().hasHeightForWidth());
        delBtn->setSizePolicy(sizePolicy1);
        delBtn->setMinimumSize(QSize(28, 28));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        delBtn->setIcon(icon);
        delBtn->setIconSize(QSize(16, 16));

        gridLayout->addWidget(delBtn, 1, 3, 1, 1);

        networkNameCombo = new KComboBox(JoinChannelUI);
        networkNameCombo->setObjectName("networkNameCombo");

        gridLayout->addWidget(networkNameCombo, 0, 2, 1, 2);

        passwordEdit = new KPasswordLineEdit(JoinChannelUI);
        passwordEdit->setObjectName("passwordEdit");

        gridLayout->addWidget(passwordEdit, 2, 2, 1, 2);

#if QT_CONFIG(shortcut)
        channelLabel->setBuddy(channelCombo);
        passwordLabel->setBuddy(passwordEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(networkNameCombo, channelCombo);
        QWidget::setTabOrder(channelCombo, passwordEdit);

        retranslateUi(JoinChannelUI);

        QMetaObject::connectSlotsByName(JoinChannelUI);
    } // setupUi

    void retranslateUi(QWidget *JoinChannelUI)
    {
        channelLabel->setText(tr2i18n("C&hannel:", nullptr));
        textLabel8->setText(tr2i18n("Connection:", nullptr));
        passwordLabel->setText(tr2i18n("&Password:", nullptr));
#if QT_CONFIG(tooltip)
        delBtn->setToolTip(tr2i18n("Remove", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)JoinChannelUI;
    } // retranslateUi

};

namespace Ui {
    class JoinChannelUI: public Ui_JoinChannelUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // JOINCHANNELUI_H

