/****************************************************************************
** Meta object code from reading C++ file 'channel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/irc/channel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'channel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7ChannelE_t {};
} // unnamed namespace

template <> constexpr inline auto Channel::qt_create_metaobjectdata<qt_meta_tag_ZN7ChannelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Channel",
        "joined",
        "",
        "Channel*",
        "channel",
        "modesChanged",
        "banAdded",
        "newban",
        "banRemoved",
        "banListCleared",
        "sendFile",
        "setNickname",
        "newNickname",
        "scheduleAutoWho",
        "msec",
        "setAutoUserhost",
        "state",
        "rejoin",
        "serverOnline",
        "online",
        "autoUserhost",
        "autoWho",
        "updateAutoWho",
        "fadeActivity",
        "delayedSortNickList",
        "purgeNicks",
        "processQueuedNicks",
        "flush",
        "updateNickInfos",
        "updateChannelNicks",
        "updateAppearance",
        "updateQuickButtons",
        "channelTextEntered",
        "channelPassthroughCommand",
        "sendText",
        "line",
        "showOptionsDialog",
        "showQuickButtons",
        "show",
        "showModeButtons",
        "indicateAway",
        "showTopic",
        "showNicknameBox",
        "showNicknameList",
        "setAutoJoin",
        "autojoin",
        "connectionStateChanged",
        "Server*",
        "Konversation::ConnectionState",
        "completeNick",
        "endCompleteNick",
        "quickButtonClicked",
        "definition",
        "modeButtonClicked",
        "id",
        "on",
        "channelLimitChanged",
        "doubleClickCommand",
        "QTreeWidgetItem*",
        "item",
        "column",
        "changeNickname",
        "textPasted",
        "text",
        "sendFileMenu",
        "nicknameComboboxChanged",
        "refreshModeButtons",
        "requestNickListSort",
        "sortNickList",
        "delayed",
        "nicknameListViewTextChanged",
        "textChangedFlags"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'joined'
        QtMocHelpers::SignalData<void(Channel *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'modesChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'banAdded'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'banRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'banListCleared'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sendFile'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setNickname'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'scheduleAutoWho'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'scheduleAutoWho'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setAutoUserhost'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'rejoin'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'serverOnline'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'autoUserhost'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'autoWho'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateAutoWho'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fadeActivity'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'delayedSortNickList'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'purgeNicks'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processQueuedNicks'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'processQueuedNicks'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'updateNickInfos'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateChannelNicks'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'updateAppearance'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateQuickButtons'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'channelTextEntered'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'channelPassthroughCommand'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendText'
        QtMocHelpers::SlotData<void(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'showOptionsDialog'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showQuickButtons'
        QtMocHelpers::SlotData<void(bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'showModeButtons'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'indicateAway'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'showTopic'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'showNicknameBox'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'showNicknameList'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'setAutoJoin'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'connectionStateChanged'
        QtMocHelpers::SlotData<void(Server *, Konversation::ConnectionState)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 2 }, { 0x80000000 | 48, 2 },
        }}),
        // Slot 'completeNick'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'endCompleteNick'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'quickButtonClicked'
        QtMocHelpers::SlotData<void(const QString &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 52 },
        }}),
        // Slot 'modeButtonClicked'
        QtMocHelpers::SlotData<void(int, bool)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 54 }, { QMetaType::Bool, 55 },
        }}),
        // Slot 'channelLimitChanged'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doubleClickCommand'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 58, 59 }, { QMetaType::Int, 60 },
        }}),
        // Slot 'changeNickname'
        QtMocHelpers::SlotData<void(const QString &)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'textPasted'
        QtMocHelpers::SlotData<void(const QString &)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 63 },
        }}),
        // Slot 'sendFileMenu'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'nicknameComboboxChanged'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshModeButtons'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'requestNickListSort'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sortNickList'
        QtMocHelpers::SlotData<void(bool)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 69 },
        }}),
        // Slot 'sortNickList'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'nicknameListViewTextChanged'
        QtMocHelpers::SlotData<void(int)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 71 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Channel, qt_meta_tag_ZN7ChannelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Channel::staticMetaObject = { {
    QMetaObject::SuperData::link<ChatWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ChannelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ChannelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7ChannelE_t>.metaTypes,
    nullptr
} };

void Channel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Channel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->joined((*reinterpret_cast<std::add_pointer_t<Channel*>>(_a[1]))); break;
        case 1: _t->modesChanged(); break;
        case 2: _t->banAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->banRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->banListCleared(); break;
        case 5: _t->sendFile(); break;
        case 6: _t->setNickname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->scheduleAutoWho((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->scheduleAutoWho(); break;
        case 9: _t->setAutoUserhost((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->rejoin(); break;
        case 11: _t->serverOnline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->autoUserhost(); break;
        case 13: _t->autoWho(); break;
        case 14: _t->updateAutoWho(); break;
        case 15: _t->fadeActivity(); break;
        case 16: _t->delayedSortNickList(); break;
        case 17: _t->purgeNicks(); break;
        case 18: _t->processQueuedNicks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->processQueuedNicks(); break;
        case 20: _t->updateNickInfos(); break;
        case 21: _t->updateChannelNicks((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->updateAppearance(); break;
        case 23: _t->updateQuickButtons(); break;
        case 24: _t->channelTextEntered(); break;
        case 25: _t->channelPassthroughCommand(); break;
        case 26: _t->sendText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->showOptionsDialog(); break;
        case 28: _t->showQuickButtons((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->showModeButtons((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->indicateAway((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->showTopic((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->showNicknameBox((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->showNicknameList((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->setAutoJoin((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->connectionStateChanged((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionState>>(_a[2]))); break;
        case 36: _t->completeNick(); break;
        case 37: _t->endCompleteNick(); break;
        case 38: _t->quickButtonClicked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->modeButtonClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 40: _t->channelLimitChanged(); break;
        case 41: _t->doubleClickCommand((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 42: _t->changeNickname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 43: _t->textPasted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 44: _t->sendFileMenu(); break;
        case 45: _t->nicknameComboboxChanged(); break;
        case 46: _t->refreshModeButtons(); break;
        case 47: _t->requestNickListSort(); break;
        case 48: _t->sortNickList((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 49: _t->sortNickList(); break;
        case 50: _t->nicknameListViewTextChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Channel* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Server* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Channel::*)(Channel * )>(_a, &Channel::joined, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Channel::*)()>(_a, &Channel::modesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Channel::*)(const QString & )>(_a, &Channel::banAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Channel::*)(const QString & )>(_a, &Channel::banRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Channel::*)()>(_a, &Channel::banListCleared, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Channel::*)()>(_a, &Channel::sendFile, 5))
            return;
    }
}

const QMetaObject *Channel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Channel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ChannelE_t>.strings))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int Channel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    return _id;
}

// SIGNAL 0
void Channel::joined(Channel * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Channel::modesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Channel::banAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Channel::banRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Channel::banListCleared()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Channel::sendFile()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
