/********************************************************************************
** Form generated from reading UI file 'invitedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INVITEDIALOG_H
#define UI_INVITEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_InviteDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *m_iconLabel;
    QLabel *m_textLabel;
    QTreeView *m_channelView;
    KComboBox *m_joinPreferences;
    QSpacerItem *horizontalSpacer;
    QLabel *label;

    void setupUi(QWidget *InviteDialog)
    {
        if (InviteDialog->objectName().isEmpty())
            InviteDialog->setObjectName("InviteDialog");
        InviteDialog->resize(696, 276);
        gridLayout = new QGridLayout(InviteDialog);
        gridLayout->setObjectName("gridLayout");
        m_iconLabel = new QLabel(InviteDialog);
        m_iconLabel->setObjectName("m_iconLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_iconLabel->sizePolicy().hasHeightForWidth());
        m_iconLabel->setSizePolicy(sizePolicy);
        m_iconLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout->addWidget(m_iconLabel, 0, 0, 1, 1);

        m_textLabel = new QLabel(InviteDialog);
        m_textLabel->setObjectName("m_textLabel");

        gridLayout->addWidget(m_textLabel, 0, 1, 1, 3);

        m_channelView = new QTreeView(InviteDialog);
        m_channelView->setObjectName("m_channelView");

        gridLayout->addWidget(m_channelView, 1, 1, 1, 3);

        m_joinPreferences = new KComboBox(InviteDialog);
        m_joinPreferences->addItem(QString());
        m_joinPreferences->addItem(QString());
        m_joinPreferences->addItem(QString());
        m_joinPreferences->setObjectName("m_joinPreferences");

        gridLayout->addWidget(m_joinPreferences, 2, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(521, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 2, 3, 1, 1);

        label = new QLabel(InviteDialog);
        label->setObjectName("label");

        gridLayout->addWidget(label, 2, 1, 1, 1);


        retranslateUi(InviteDialog);

        QMetaObject::connectSlotsByName(InviteDialog);
    } // setupUi

    void retranslateUi(QWidget *InviteDialog)
    {
        m_iconLabel->setText(tr2i18n("...", nullptr));
        m_textLabel->setText(tr2i18n("You have received invites for the following channels. Select the channels you want to join:", nullptr));
        m_joinPreferences->setItemText(0, tr2i18n("Always Ask", nullptr));
        m_joinPreferences->setItemText(1, tr2i18n("Always Join", nullptr));
        m_joinPreferences->setItemText(2, tr2i18n("Always Ignore", nullptr));

        label->setText(tr2i18n("From now on:", nullptr));
        (void)InviteDialog;
    } // retranslateUi

};

namespace Ui {
    class InviteDialog: public Ui_InviteDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INVITEDIALOG_H

