/****************************************************************************
** Meta object code from reading C++ file 'channeloptionsdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/viewer/channeloptionsdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'channeloptionsdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Konversation20ChannelOptionsDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Konversation::ChannelOptionsDialog::qt_create_metaobjectdata<qt_meta_tag_ZN12Konversation20ChannelOptionsDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konversation::ChannelOptionsDialog",
        "refreshAllowedChannelModes",
        "",
        "refreshModes",
        "refreshEnableModes",
        "forceUpdate",
        "toggleAdvancedModes",
        "refreshBanList",
        "addBan",
        "newban",
        "addBanClicked",
        "updateBanClicked",
        "removeBan",
        "ban",
        "removeBanClicked",
        "banSelectionChanged",
        "hostmaskChanged",
        "changeOptions",
        "topicHistoryItemClicked",
        "QItemSelection",
        "selection",
        "topicBeingEdited",
        "edited",
        "startHistorySearchTimer",
        "filter",
        "updateHistoryFilter"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'refreshAllowedChannelModes'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshModes'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshEnableModes'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'refreshEnableModes'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'toggleAdvancedModes'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshBanList'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addBan'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'addBanClicked'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateBanClicked'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeBan'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'removeBanClicked'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'banSelectionChanged'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hostmaskChanged'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'changeOptions'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'topicHistoryItemClicked'
        QtMocHelpers::SlotData<void(const QItemSelection &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'topicBeingEdited'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'startHistorySearchTimer'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'updateHistoryFilter'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ChannelOptionsDialog, qt_meta_tag_ZN12Konversation20ChannelOptionsDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konversation::ChannelOptionsDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation20ChannelOptionsDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation20ChannelOptionsDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Konversation20ChannelOptionsDialogE_t>.metaTypes,
    nullptr
} };

void Konversation::ChannelOptionsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ChannelOptionsDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshAllowedChannelModes(); break;
        case 1: _t->refreshModes(); break;
        case 2: _t->refreshEnableModes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->refreshEnableModes(); break;
        case 4: _t->toggleAdvancedModes(); break;
        case 5: _t->refreshBanList(); break;
        case 6: _t->addBan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->addBanClicked(); break;
        case 8: _t->updateBanClicked(); break;
        case 9: _t->removeBan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->removeBanClicked(); break;
        case 11: _t->banSelectionChanged(); break;
        case 12: _t->hostmaskChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->changeOptions(); break;
        case 14: _t->topicHistoryItemClicked((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1]))); break;
        case 15: _t->topicBeingEdited((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->startHistorySearchTimer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->updateHistoryFilter(); break;
        default: ;
        }
    }
}

const QMetaObject *Konversation::ChannelOptionsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::ChannelOptionsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Konversation20ChannelOptionsDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::ChannelOptionsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
