/*
    SPDX-License-Identifier: GPL-2.0-or-later

    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
*/

#include "whiteboardglobals.h"

namespace Konversation
{
    namespace DCC
    {
        const int WhiteBoardGlobals::MaxImageSize = 2048;
        const int WhiteBoardGlobals::MaxPenWidth = 20;
    }
}
