/********************************************************************************
** Form generated from reading UI file 'queuetunerbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUEUETUNERBASE_H
#define UI_QUEUETUNERBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_QueueTunerBase
{
public:
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QSpacerItem *spacer34;
    QToolButton *m_closeButton;
    QSpacerItem *spacer35;
    QGroupBox *m_slowBox;
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout1;
    QSpinBox *m_slowRate;
    KComboBox *m_slowType;
    QSpinBox *m_slowInterval;
    QGridLayout *gridLayout1;
    QLabel *m_slowAge;
    QLabel *m_slowCount;
    QLabel *m_textLabel3_2;
    QLabel *m_textLabel3;
    QGridLayout *gridLayout2;
    QLabel *textLabel4_2_2;
    QLabel *textLabel5_2_2;
    QLabel *m_slowLines;
    QLabel *m_slowBytes;
    QGroupBox *m_normalBox;
    QGridLayout *gridLayout3;
    QHBoxLayout *hboxLayout2;
    QSpinBox *m_normalRate;
    KComboBox *m_normalType;
    QSpinBox *m_normalInterval;
    QGridLayout *gridLayout4;
    QLabel *textLabel4_2;
    QLabel *textLabel5_2;
    QLabel *m_normalLines;
    QLabel *m_normalBytes;
    QGridLayout *gridLayout5;
    QLabel *m_textLabel3_4;
    QLabel *m_normalAge;
    QLabel *m_normalCount;
    QLabel *m_textLabel3_2_3;
    QGroupBox *m_fastBox;
    QGridLayout *gridLayout6;
    QHBoxLayout *hboxLayout3;
    QSpinBox *m_fastRate;
    KComboBox *m_fastType;
    QSpinBox *m_fastInterval;
    QGridLayout *gridLayout7;
    QLabel *m_textLabel3_2_3_2;
    QLabel *m_fastAge;
    QLabel *m_fastCount;
    QLabel *m_textLabel3_4_2;
    QGridLayout *gridLayout8;
    QLabel *textLabel4;
    QLabel *textLabel5;
    QLabel *m_fastLines;
    QLabel *m_fastBytes;
    QGroupBox *m_globalBox;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout9;
    QLabel *textLabel13;
    QLabel *m_recvBytes;
    QLabel *m_globalLines;
    QLabel *textLabel9;
    QLabel *textLabel4_3;
    QLabel *m_globalBytes;
    QLabel *m_srverBytes;
    QLabel *textLabel8;

    void setupUi(QWidget *QueueTunerBase)
    {
        if (QueueTunerBase->objectName().isEmpty())
            QueueTunerBase->setObjectName("QueueTunerBase");
        QueueTunerBase->resize(750, 112);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(QueueTunerBase->sizePolicy().hasHeightForWidth());
        QueueTunerBase->setSizePolicy(sizePolicy);
        hboxLayout = new QHBoxLayout(QueueTunerBase);
        hboxLayout->setSpacing(1);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(0);
        vboxLayout->setContentsMargins(1, 1, 1, 1);
        vboxLayout->setObjectName("vboxLayout");
        spacer34 = new QSpacerItem(16, 34, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer34);

        m_closeButton = new QToolButton(QueueTunerBase);
        m_closeButton->setObjectName("m_closeButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_closeButton->sizePolicy().hasHeightForWidth());
        m_closeButton->setSizePolicy(sizePolicy1);
        m_closeButton->setAutoRaise(true);

        vboxLayout->addWidget(m_closeButton);

        spacer35 = new QSpacerItem(16, 33, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer35);


        hboxLayout->addLayout(vboxLayout);

        m_slowBox = new QGroupBox(QueueTunerBase);
        m_slowBox->setObjectName("m_slowBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(m_slowBox->sizePolicy().hasHeightForWidth());
        m_slowBox->setSizePolicy(sizePolicy2);
        m_slowBox->setProperty("lineWidth", QVariant(1));
        gridLayout = new QGridLayout(m_slowBox);
        gridLayout->setContentsMargins(5, 5, 5, 5);
        gridLayout->setObjectName("gridLayout");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(0);
#ifndef UI_Q_OS_MAC
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout1->setObjectName("hboxLayout1");
        m_slowRate = new QSpinBox(m_slowBox);
        m_slowRate->setObjectName("m_slowRate");
        m_slowRate->setEnabled(true);
        m_slowRate->setMaximum(999);

        hboxLayout1->addWidget(m_slowRate);

        m_slowType = new KComboBox(m_slowBox);
        m_slowType->addItem(QString());
        m_slowType->addItem(QString());
        m_slowType->setObjectName("m_slowType");
        m_slowType->setEnabled(false);

        hboxLayout1->addWidget(m_slowType);

        m_slowInterval = new QSpinBox(m_slowBox);
        m_slowInterval->setObjectName("m_slowInterval");
        m_slowInterval->setMaximum(999);

        hboxLayout1->addWidget(m_slowInterval);


        gridLayout->addLayout(hboxLayout1, 1, 0, 1, 2);

        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(0);
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        gridLayout1->setObjectName("gridLayout1");
        m_slowAge = new QLabel(m_slowBox);
        m_slowAge->setObjectName("m_slowAge");
        m_slowAge->setScaledContents(false);
        m_slowAge->setWordWrap(false);

        gridLayout1->addWidget(m_slowAge, 1, 1, 2, 1);

        m_slowCount = new QLabel(m_slowBox);
        m_slowCount->setObjectName("m_slowCount");
        m_slowCount->setScaledContents(false);
        m_slowCount->setWordWrap(false);

        gridLayout1->addWidget(m_slowCount, 0, 1, 1, 1);

        m_textLabel3_2 = new QLabel(m_slowBox);
        m_textLabel3_2->setObjectName("m_textLabel3_2");
        m_textLabel3_2->setWordWrap(false);

        gridLayout1->addWidget(m_textLabel3_2, 2, 0, 1, 1);

        m_textLabel3 = new QLabel(m_slowBox);
        m_textLabel3->setObjectName("m_textLabel3");
        m_textLabel3->setWordWrap(false);

        gridLayout1->addWidget(m_textLabel3, 0, 0, 2, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);

        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(0);
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        gridLayout2->setObjectName("gridLayout2");
        textLabel4_2_2 = new QLabel(m_slowBox);
        textLabel4_2_2->setObjectName("textLabel4_2_2");
        textLabel4_2_2->setWordWrap(false);

        gridLayout2->addWidget(textLabel4_2_2, 0, 0, 1, 1);

        textLabel5_2_2 = new QLabel(m_slowBox);
        textLabel5_2_2->setObjectName("textLabel5_2_2");
        textLabel5_2_2->setWordWrap(false);

        gridLayout2->addWidget(textLabel5_2_2, 1, 0, 1, 1);

        m_slowLines = new QLabel(m_slowBox);
        m_slowLines->setObjectName("m_slowLines");
        m_slowLines->setWordWrap(false);

        gridLayout2->addWidget(m_slowLines, 0, 1, 1, 1);

        m_slowBytes = new QLabel(m_slowBox);
        m_slowBytes->setObjectName("m_slowBytes");
        m_slowBytes->setWordWrap(false);

        gridLayout2->addWidget(m_slowBytes, 1, 1, 1, 1);


        gridLayout->addLayout(gridLayout2, 0, 1, 1, 1);


        hboxLayout->addWidget(m_slowBox);

        m_normalBox = new QGroupBox(QueueTunerBase);
        m_normalBox->setObjectName("m_normalBox");
        sizePolicy2.setHeightForWidth(m_normalBox->sizePolicy().hasHeightForWidth());
        m_normalBox->setSizePolicy(sizePolicy2);
        m_normalBox->setProperty("lineWidth", QVariant(1));
        gridLayout3 = new QGridLayout(m_normalBox);
        gridLayout3->setContentsMargins(5, 5, 5, 5);
        gridLayout3->setObjectName("gridLayout3");
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(0);
#ifndef UI_Q_OS_MAC
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout2->setObjectName("hboxLayout2");
        m_normalRate = new QSpinBox(m_normalBox);
        m_normalRate->setObjectName("m_normalRate");
        m_normalRate->setEnabled(true);
        m_normalRate->setMaximum(999);

        hboxLayout2->addWidget(m_normalRate);

        m_normalType = new KComboBox(m_normalBox);
        m_normalType->addItem(QString());
        m_normalType->addItem(QString());
        m_normalType->setObjectName("m_normalType");
        m_normalType->setEnabled(false);

        hboxLayout2->addWidget(m_normalType);

        m_normalInterval = new QSpinBox(m_normalBox);
        m_normalInterval->setObjectName("m_normalInterval");
        m_normalInterval->setMaximum(999);

        hboxLayout2->addWidget(m_normalInterval);


        gridLayout3->addLayout(hboxLayout2, 1, 0, 1, 2);

        gridLayout4 = new QGridLayout();
        gridLayout4->setSpacing(0);
        gridLayout4->setContentsMargins(0, 0, 0, 0);
        gridLayout4->setObjectName("gridLayout4");
        textLabel4_2 = new QLabel(m_normalBox);
        textLabel4_2->setObjectName("textLabel4_2");
        textLabel4_2->setWordWrap(false);

        gridLayout4->addWidget(textLabel4_2, 0, 0, 1, 1);

        textLabel5_2 = new QLabel(m_normalBox);
        textLabel5_2->setObjectName("textLabel5_2");
        textLabel5_2->setWordWrap(false);

        gridLayout4->addWidget(textLabel5_2, 1, 0, 1, 1);

        m_normalLines = new QLabel(m_normalBox);
        m_normalLines->setObjectName("m_normalLines");
        m_normalLines->setWordWrap(false);

        gridLayout4->addWidget(m_normalLines, 0, 1, 1, 1);

        m_normalBytes = new QLabel(m_normalBox);
        m_normalBytes->setObjectName("m_normalBytes");
        m_normalBytes->setWordWrap(false);

        gridLayout4->addWidget(m_normalBytes, 1, 1, 1, 1);


        gridLayout3->addLayout(gridLayout4, 0, 1, 1, 1);

        gridLayout5 = new QGridLayout();
        gridLayout5->setSpacing(0);
        gridLayout5->setContentsMargins(0, 0, 0, 0);
        gridLayout5->setObjectName("gridLayout5");
        m_textLabel3_4 = new QLabel(m_normalBox);
        m_textLabel3_4->setObjectName("m_textLabel3_4");
        m_textLabel3_4->setWordWrap(false);

        gridLayout5->addWidget(m_textLabel3_4, 0, 0, 1, 1);

        m_normalAge = new QLabel(m_normalBox);
        m_normalAge->setObjectName("m_normalAge");
        m_normalAge->setScaledContents(false);
        m_normalAge->setWordWrap(false);

        gridLayout5->addWidget(m_normalAge, 1, 1, 1, 1);

        m_normalCount = new QLabel(m_normalBox);
        m_normalCount->setObjectName("m_normalCount");
        m_normalCount->setScaledContents(false);
        m_normalCount->setWordWrap(false);

        gridLayout5->addWidget(m_normalCount, 0, 1, 1, 1);

        m_textLabel3_2_3 = new QLabel(m_normalBox);
        m_textLabel3_2_3->setObjectName("m_textLabel3_2_3");
        m_textLabel3_2_3->setWordWrap(false);

        gridLayout5->addWidget(m_textLabel3_2_3, 1, 0, 1, 1);


        gridLayout3->addLayout(gridLayout5, 0, 0, 1, 1);


        hboxLayout->addWidget(m_normalBox);

        m_fastBox = new QGroupBox(QueueTunerBase);
        m_fastBox->setObjectName("m_fastBox");
        sizePolicy2.setHeightForWidth(m_fastBox->sizePolicy().hasHeightForWidth());
        m_fastBox->setSizePolicy(sizePolicy2);
        m_fastBox->setProperty("lineWidth", QVariant(1));
        gridLayout6 = new QGridLayout(m_fastBox);
        gridLayout6->setContentsMargins(5, 5, 5, 5);
        gridLayout6->setObjectName("gridLayout6");
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(0);
#ifndef UI_Q_OS_MAC
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout3->setObjectName("hboxLayout3");
        m_fastRate = new QSpinBox(m_fastBox);
        m_fastRate->setObjectName("m_fastRate");
        m_fastRate->setMaximum(999);

        hboxLayout3->addWidget(m_fastRate);

        m_fastType = new KComboBox(m_fastBox);
        m_fastType->addItem(QString());
        m_fastType->addItem(QString());
        m_fastType->setObjectName("m_fastType");
        m_fastType->setEnabled(false);

        hboxLayout3->addWidget(m_fastType);

        m_fastInterval = new QSpinBox(m_fastBox);
        m_fastInterval->setObjectName("m_fastInterval");
        m_fastInterval->setEnabled(true);
        m_fastInterval->setMaximum(999);
        m_fastInterval->setSingleStep(1);

        hboxLayout3->addWidget(m_fastInterval);


        gridLayout6->addLayout(hboxLayout3, 1, 0, 1, 2);

        gridLayout7 = new QGridLayout();
        gridLayout7->setSpacing(0);
        gridLayout7->setContentsMargins(0, 0, 0, 0);
        gridLayout7->setObjectName("gridLayout7");
        m_textLabel3_2_3_2 = new QLabel(m_fastBox);
        m_textLabel3_2_3_2->setObjectName("m_textLabel3_2_3_2");
        m_textLabel3_2_3_2->setWordWrap(false);

        gridLayout7->addWidget(m_textLabel3_2_3_2, 1, 0, 1, 1);

        m_fastAge = new QLabel(m_fastBox);
        m_fastAge->setObjectName("m_fastAge");
        m_fastAge->setScaledContents(false);
        m_fastAge->setWordWrap(false);

        gridLayout7->addWidget(m_fastAge, 1, 1, 1, 1);

        m_fastCount = new QLabel(m_fastBox);
        m_fastCount->setObjectName("m_fastCount");
        m_fastCount->setScaledContents(false);
        m_fastCount->setWordWrap(false);

        gridLayout7->addWidget(m_fastCount, 0, 1, 1, 1);

        m_textLabel3_4_2 = new QLabel(m_fastBox);
        m_textLabel3_4_2->setObjectName("m_textLabel3_4_2");
        m_textLabel3_4_2->setWordWrap(false);

        gridLayout7->addWidget(m_textLabel3_4_2, 0, 0, 1, 1);


        gridLayout6->addLayout(gridLayout7, 0, 0, 1, 1);

        gridLayout8 = new QGridLayout();
        gridLayout8->setSpacing(0);
        gridLayout8->setContentsMargins(0, 0, 0, 0);
        gridLayout8->setObjectName("gridLayout8");
        textLabel4 = new QLabel(m_fastBox);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setWordWrap(false);

        gridLayout8->addWidget(textLabel4, 0, 0, 1, 1);

        textLabel5 = new QLabel(m_fastBox);
        textLabel5->setObjectName("textLabel5");
        textLabel5->setWordWrap(false);

        gridLayout8->addWidget(textLabel5, 1, 0, 1, 1);

        m_fastLines = new QLabel(m_fastBox);
        m_fastLines->setObjectName("m_fastLines");
        m_fastLines->setWordWrap(false);

        gridLayout8->addWidget(m_fastLines, 0, 1, 1, 1);

        m_fastBytes = new QLabel(m_fastBox);
        m_fastBytes->setObjectName("m_fastBytes");
        m_fastBytes->setWordWrap(false);

        gridLayout8->addWidget(m_fastBytes, 1, 1, 1, 1);


        gridLayout6->addLayout(gridLayout8, 0, 1, 1, 1);


        hboxLayout->addWidget(m_fastBox);

        m_globalBox = new QGroupBox(QueueTunerBase);
        m_globalBox->setObjectName("m_globalBox");
        sizePolicy2.setHeightForWidth(m_globalBox->sizePolicy().hasHeightForWidth());
        m_globalBox->setSizePolicy(sizePolicy2);
        m_globalBox->setProperty("lineWidth", QVariant(1));
        vboxLayout1 = new QVBoxLayout(m_globalBox);
        vboxLayout1->setContentsMargins(5, 5, 5, 5);
        vboxLayout1->setObjectName("vboxLayout1");
        gridLayout9 = new QGridLayout();
        gridLayout9->setSpacing(2);
#ifndef UI_Q_OS_MAC
        gridLayout9->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout9->setObjectName("gridLayout9");
        textLabel13 = new QLabel(m_globalBox);
        textLabel13->setObjectName("textLabel13");
        textLabel13->setWordWrap(false);

        gridLayout9->addWidget(textLabel13, 3, 0, 1, 1);

        m_recvBytes = new QLabel(m_globalBox);
        m_recvBytes->setObjectName("m_recvBytes");
        m_recvBytes->setWordWrap(false);

        gridLayout9->addWidget(m_recvBytes, 3, 1, 1, 1);

        m_globalLines = new QLabel(m_globalBox);
        m_globalLines->setObjectName("m_globalLines");
        m_globalLines->setWordWrap(false);

        gridLayout9->addWidget(m_globalLines, 0, 1, 1, 1);

        textLabel9 = new QLabel(m_globalBox);
        textLabel9->setObjectName("textLabel9");
        textLabel9->setWordWrap(false);

        gridLayout9->addWidget(textLabel9, 1, 0, 1, 1);

        textLabel4_3 = new QLabel(m_globalBox);
        textLabel4_3->setObjectName("textLabel4_3");
        textLabel4_3->setWordWrap(false);

        gridLayout9->addWidget(textLabel4_3, 2, 0, 1, 1);

        m_globalBytes = new QLabel(m_globalBox);
        m_globalBytes->setObjectName("m_globalBytes");
        m_globalBytes->setWordWrap(false);

        gridLayout9->addWidget(m_globalBytes, 1, 1, 1, 1);

        m_srverBytes = new QLabel(m_globalBox);
        m_srverBytes->setObjectName("m_srverBytes");
        m_srverBytes->setWordWrap(false);

        gridLayout9->addWidget(m_srverBytes, 2, 1, 1, 1);

        textLabel8 = new QLabel(m_globalBox);
        textLabel8->setObjectName("textLabel8");
        textLabel8->setWordWrap(false);

        gridLayout9->addWidget(textLabel8, 0, 0, 1, 1);


        vboxLayout1->addLayout(gridLayout9);


        hboxLayout->addWidget(m_globalBox);


        retranslateUi(QueueTunerBase);

        QMetaObject::connectSlotsByName(QueueTunerBase);
    } // setupUi

    void retranslateUi(QWidget *QueueTunerBase)
    {
#if QT_CONFIG(tooltip)
        m_closeButton->setToolTip(tr2i18n("Close", nullptr));
#endif // QT_CONFIG(tooltip)
        m_closeButton->setText(QString());
        m_slowBox->setTitle(tr2i18n("Slow Queue", nullptr));
        m_slowType->setItemText(0, tr2i18n("Lines", nullptr));
        m_slowType->setItemText(1, tr2i18n("Bytes", nullptr));

        m_slowAge->setText(tr2i18n("888", nullptr));
        m_slowCount->setText(tr2i18n("888", nullptr));
        m_textLabel3_2->setText(tr2i18n("Age:", nullptr));
        m_textLabel3->setText(tr2i18n("Count:", nullptr));
        textLabel4_2_2->setText(tr2i18n("Lines:", nullptr));
        textLabel5_2_2->setText(tr2i18n("Bytes:", nullptr));
        m_slowLines->setText(tr2i18n("888", nullptr));
        m_slowBytes->setText(tr2i18n("888", nullptr));
        m_normalBox->setTitle(tr2i18n("Normal Queue", nullptr));
        m_normalType->setItemText(0, tr2i18n("Lines", nullptr));
        m_normalType->setItemText(1, tr2i18n("Bytes", nullptr));

        textLabel4_2->setText(tr2i18n("Lines:", nullptr));
        textLabel5_2->setText(tr2i18n("Bytes:", nullptr));
        m_normalLines->setText(tr2i18n("888", nullptr));
        m_normalBytes->setText(tr2i18n("888", nullptr));
        m_textLabel3_4->setText(tr2i18n("Count:", nullptr));
        m_normalAge->setText(tr2i18n("888", nullptr));
        m_normalCount->setText(tr2i18n("888", nullptr));
        m_textLabel3_2_3->setText(tr2i18n("Age:", nullptr));
        m_fastBox->setTitle(tr2i18n("Fast Queue", nullptr));
        m_fastType->setItemText(0, tr2i18n("Lines", nullptr));
        m_fastType->setItemText(1, tr2i18n("Bytes", nullptr));

        m_textLabel3_2_3_2->setText(tr2i18n("Age:", nullptr));
        m_fastAge->setText(tr2i18n("888", nullptr));
        m_fastCount->setText(tr2i18n("888", nullptr));
        m_textLabel3_4_2->setText(tr2i18n("Count:", nullptr));
        textLabel4->setText(tr2i18n("Lines:", nullptr));
        textLabel5->setText(tr2i18n("Bytes:", nullptr));
        m_fastLines->setText(tr2i18n("888", nullptr));
        m_fastBytes->setText(tr2i18n("888", nullptr));
        m_globalBox->setTitle(tr2i18n("All Queues", nullptr));
        textLabel13->setText(tr2i18n("Received:", nullptr));
        m_recvBytes->setText(tr2i18n("888", nullptr));
        m_globalLines->setText(tr2i18n("888", nullptr));
        textLabel9->setText(tr2i18n("Bytes (Raw):", nullptr));
        textLabel4_3->setText(tr2i18n("Bytes (Encoded):", nullptr));
        m_globalBytes->setText(tr2i18n("888", nullptr));
        m_srverBytes->setText(tr2i18n("888", nullptr));
        textLabel8->setText(tr2i18n("Lines:", nullptr));
        (void)QueueTunerBase;
    } // retranslateUi

};

namespace Ui {
    class QueueTunerBase: public Ui_QueueTunerBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QUEUETUNERBASE_H

