/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konversation-26.04.0/src/mainwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "showQuickConnectDialog",
        "",
        "nicksNowOnline",
        "Server*",
        "resetFrontViewUnseenEventsCount",
        "endNotification",
        "serverStateChanged",
        "server",
        "Konversation::ConnectionState",
        "state",
        "triggerRememberLine",
        "triggerRememberLines",
        "cancelRememberLine",
        "insertMarkerLine",
        "activateAndRaiseWindow",
        "quitProgram",
        "updateTrayIcon",
        "openServerList",
        "openIdentitiesDialog",
        "editIdentity",
        "IdentityPtr",
        "identity",
        "setOnlineList",
        "notifyServer",
        "list",
        "changed",
        "settingsChangedSlot",
        "resetHasDirtySettings",
        "toggleMenubar",
        "dontShowWarning",
        "openPrefsDialog",
        "openKeyBindings",
        "openQuickConnectDialog",
        "openNotifications",
        "notifyAction",
        "connectionId",
        "nick",
        "toggleVisibility"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showQuickConnectDialog'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nicksNowOnline'
        QtMocHelpers::SignalData<void(Server *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'resetFrontViewUnseenEventsCount'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endNotification'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serverStateChanged'
        QtMocHelpers::SignalData<void(Server *, Konversation::ConnectionState)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'triggerRememberLine'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggerRememberLines'
        QtMocHelpers::SignalData<void(Server *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'cancelRememberLine'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'insertMarkerLine'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateAndRaiseWindow'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quitProgram'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateTrayIcon'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openServerList'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openIdentitiesDialog'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editIdentity'
        QtMocHelpers::SlotData<IdentityPtr(const IdentityPtr &)>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setOnlineList'
        QtMocHelpers::SlotData<void(Server *, const QStringList &, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 24 }, { QMetaType::QStringList, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'settingsChangedSlot'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetHasDirtySettings'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleMenubar'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'toggleMenubar'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'openPrefsDialog'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openKeyBindings'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openQuickConnectDialog'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openNotifications'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'notifyAction'
        QtMocHelpers::SlotData<void(int, const QString &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'toggleVisibility'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showQuickConnectDialog(); break;
        case 1: _t->nicksNowOnline((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 2: _t->resetFrontViewUnseenEventsCount(); break;
        case 3: _t->endNotification(); break;
        case 4: _t->serverStateChanged((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Konversation::ConnectionState>>(_a[2]))); break;
        case 5: _t->triggerRememberLine(); break;
        case 6: _t->triggerRememberLines((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1]))); break;
        case 7: _t->cancelRememberLine(); break;
        case 8: _t->insertMarkerLine(); break;
        case 9: _t->activateAndRaiseWindow(); break;
        case 10: _t->quitProgram(); break;
        case 11: _t->updateTrayIcon(); break;
        case 12: _t->openServerList(); break;
        case 13: _t->openIdentitiesDialog(); break;
        case 14: { IdentityPtr _r = _t->editIdentity((*reinterpret_cast<std::add_pointer_t<IdentityPtr>>(_a[1])));
            if (_a[0]) *reinterpret_cast<IdentityPtr*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setOnlineList((*reinterpret_cast<std::add_pointer_t<Server*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 16: _t->settingsChangedSlot(); break;
        case 17: _t->resetHasDirtySettings(); break;
        case 18: _t->toggleMenubar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->toggleMenubar(); break;
        case 20: _t->openPrefsDialog(); break;
        case 21: _t->openKeyBindings(); break;
        case 22: _t->openQuickConnectDialog(); break;
        case 23: _t->openNotifications(); break;
        case 24: _t->notifyAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 25: _t->toggleVisibility(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::showQuickConnectDialog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(Server * )>(_a, &MainWindow::nicksNowOnline, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::resetFrontViewUnseenEventsCount, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::endNotification, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(Server * , Konversation::ConnectionState )>(_a, &MainWindow::serverStateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::triggerRememberLine, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(Server * )>(_a, &MainWindow::triggerRememberLines, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::cancelRememberLine, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::insertMarkerLine, 8))
            return;
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::showQuickConnectDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MainWindow::nicksNowOnline(Server * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MainWindow::resetFrontViewUnseenEventsCount()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MainWindow::endNotification()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MainWindow::serverStateChanged(Server * _t1, Konversation::ConnectionState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void MainWindow::triggerRememberLine()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MainWindow::triggerRememberLines(Server * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MainWindow::cancelRememberLine()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MainWindow::insertMarkerLine()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
