/********************************************************************************
** Form generated from reading UI file 'watchednicknames_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WATCHEDNICKNAMES_CONFIGUI_H
#define UI_WATCHEDNICKNAMES_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_WatchedNicknames_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QCheckBox *kcfg_UseNotify;
    QCheckBox *kcfg_OpenWatchedNicksAtStartup;
    QFormLayout *formLayout;
    QLabel *notifyActionLabel;
    KLineEdit *kcfg_NotifyDoubleClickAction;
    QLabel *notifyDelayLabel;
    QSpinBox *kcfg_NotifyDelay;

    void setupUi(QWidget *WatchedNicknames_ConfigUI)
    {
        if (WatchedNicknames_ConfigUI->objectName().isEmpty())
            WatchedNicknames_ConfigUI->setObjectName("WatchedNicknames_ConfigUI");
        WatchedNicknames_ConfigUI->resize(438, 416);
        gridLayout = new QGridLayout(WatchedNicknames_ConfigUI);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        kcfg_UseNotify = new QCheckBox(WatchedNicknames_ConfigUI);
        kcfg_UseNotify->setObjectName("kcfg_UseNotify");

        gridLayout->addWidget(kcfg_UseNotify, 0, 0, 1, 1);

        kcfg_OpenWatchedNicksAtStartup = new QCheckBox(WatchedNicknames_ConfigUI);
        kcfg_OpenWatchedNicksAtStartup->setObjectName("kcfg_OpenWatchedNicksAtStartup");
        kcfg_OpenWatchedNicksAtStartup->setEnabled(false);

        gridLayout->addWidget(kcfg_OpenWatchedNicksAtStartup, 1, 0, 1, 1);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        notifyActionLabel = new QLabel(WatchedNicknames_ConfigUI);
        notifyActionLabel->setObjectName("notifyActionLabel");
        notifyActionLabel->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(notifyActionLabel->sizePolicy().hasHeightForWidth());
        notifyActionLabel->setSizePolicy(sizePolicy);
        notifyActionLabel->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, notifyActionLabel);

        kcfg_NotifyDoubleClickAction = new KLineEdit(WatchedNicknames_ConfigUI);
        kcfg_NotifyDoubleClickAction->setObjectName("kcfg_NotifyDoubleClickAction");
        kcfg_NotifyDoubleClickAction->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_NotifyDoubleClickAction->sizePolicy().hasHeightForWidth());
        kcfg_NotifyDoubleClickAction->setSizePolicy(sizePolicy1);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_NotifyDoubleClickAction);

        notifyDelayLabel = new QLabel(WatchedNicknames_ConfigUI);
        notifyDelayLabel->setObjectName("notifyDelayLabel");
        notifyDelayLabel->setEnabled(false);
        notifyDelayLabel->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, notifyDelayLabel);

        kcfg_NotifyDelay = new QSpinBox(WatchedNicknames_ConfigUI);
        kcfg_NotifyDelay->setObjectName("kcfg_NotifyDelay");
        kcfg_NotifyDelay->setEnabled(false);
        kcfg_NotifyDelay->setMinimumSize(QSize(120, 0));
        kcfg_NotifyDelay->setMinimum(5);
        kcfg_NotifyDelay->setMaximum(1000);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_NotifyDelay);


        gridLayout->addLayout(formLayout, 2, 0, 1, 1);

#if QT_CONFIG(shortcut)
        notifyActionLabel->setBuddy(kcfg_NotifyDoubleClickAction);
        notifyDelayLabel->setBuddy(kcfg_NotifyDelay);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_UseNotify, kcfg_OpenWatchedNicksAtStartup);
        QWidget::setTabOrder(kcfg_OpenWatchedNicksAtStartup, kcfg_NotifyDoubleClickAction);
        QWidget::setTabOrder(kcfg_NotifyDoubleClickAction, kcfg_NotifyDelay);

        retranslateUi(WatchedNicknames_ConfigUI);
        QObject::connect(kcfg_UseNotify, &QCheckBox::toggled, kcfg_OpenWatchedNicksAtStartup, &QCheckBox::setEnabled);
        QObject::connect(kcfg_UseNotify, &QCheckBox::toggled, kcfg_NotifyDelay, &QSpinBox::setEnabled);
        QObject::connect(kcfg_UseNotify, &QCheckBox::toggled, notifyDelayLabel, &QLabel::setEnabled);
        QObject::connect(kcfg_UseNotify, &QCheckBox::toggled, notifyActionLabel, &QLabel::setEnabled);
        QObject::connect(kcfg_UseNotify, SIGNAL(toggled(bool)), kcfg_NotifyDoubleClickAction, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(WatchedNicknames_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *WatchedNicknames_ConfigUI)
    {
#if QT_CONFIG(whatsthis)
        kcfg_UseNotify->setWhatsThis(tr2i18n("<qt>\n"
"<p>\n"
"When the nickname watcher is turned on, you will be notified when the nicknames appearing in the <b>Watched Networks/Nicknames</b> list come online or go offline.</p>\n"
"<p>You can also open the <b>Watched Nicks</b> window to see the status of all the watched nicknames.</p>\n"
"</qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseNotify->setText(tr2i18n("Enable nic&kname watcher", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_OpenWatchedNicksAtStartup->setWhatsThis(tr2i18n("<qt>When checked, the <b>Watched Nicks</b> window will be automatically opened when starting Konversation.</qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_OpenWatchedNicksAtStartup->setText(tr2i18n("Show Watched Nicks tab on &application startup", nullptr));
#if QT_CONFIG(whatsthis)
        notifyActionLabel->setWhatsThis(tr2i18n("<qt>\n"
"<p>When you double click a nickname in the <b>Watched Nicks</b> window, this\n"
"command is placed in the <b>Input Line</b> on the server window.</p>\n"
"<p>The following symbols can be used in the command:</p><ul>\n"
"<li>%u: The nickname double clicked.</li>\n"
"<li>%K: Server password.</li>\n"
"<li>%n: Send command directly to the server instead of your input line.</li>\"\n"
"</ul>\n"
"</qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
        notifyActionLabel->setText(tr2i18n("Command e&xecuted when nickname is double clicked:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_NotifyDoubleClickAction->setWhatsThis(tr2i18n("<qt>\n"
"<p>When you double click a nickname in the <b>Watched Nicks</b> window, this\n"
" command is placed in the <b>Input Line</b> on the server window.</p>\n"
"<p>The following symbols can be used in the command:</p><ul>\n"
"<li>%u: The nickname double clicked.</li>\n"
"<li>%K: Server password.</li>\n"
"<li>%n: Send command directly to the server instead of your input line.</li>\n"
"</ul>\n"
"</qt>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        notifyDelayLabel->setWhatsThis(tr2i18n("Konversation will check the status of the nicknames listed below at this interval.", nullptr));
#endif // QT_CONFIG(whatsthis)
        notifyDelayLabel->setText(tr2i18n("&Update interval:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_NotifyDelay->setWhatsThis(tr2i18n("Konversation will check the status of the nicknames listed below at this interval.", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)WatchedNicknames_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class WatchedNicknames_ConfigUI: public Ui_WatchedNicknames_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WATCHEDNICKNAMES_CONFIGUI_H

