/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

*/

/********************************************************************************
** Form generated from reading UI file 'nicklistbehavior_configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NICKLISTBEHAVIOR_CONFIGUI_H
#define UI_NICKLISTBEHAVIOR_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_NicklistBehavior_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QLabel *textLabel1_2;
    QCheckBox *kcfg_SortCaseInsensitive;
    QCheckBox *kcfg_SortByActivity;
    QCheckBox *kcfg_SortByStatus;
    KLineEdit *kcfg_ChannelDoubleClickAction;
    QLabel *orderHintLabel;
    QTreeWidget *sortOrder;

    void setupUi(QWidget *NicklistBehavior_ConfigUI)
    {
        if (NicklistBehavior_ConfigUI->objectName().isEmpty())
            NicklistBehavior_ConfigUI->setObjectName("NicklistBehavior_ConfigUI");
        NicklistBehavior_ConfigUI->resize(692, 480);
        gridLayout = new QGridLayout(NicklistBehavior_ConfigUI);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        textLabel1_2 = new QLabel(NicklistBehavior_ConfigUI);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        gridLayout->addWidget(textLabel1_2, 0, 0, 1, 2);

        kcfg_SortCaseInsensitive = new QCheckBox(NicklistBehavior_ConfigUI);
        kcfg_SortCaseInsensitive->setObjectName("kcfg_SortCaseInsensitive");

        gridLayout->addWidget(kcfg_SortCaseInsensitive, 1, 0, 1, 3);

        kcfg_SortByActivity = new QCheckBox(NicklistBehavior_ConfigUI);
        kcfg_SortByActivity->setObjectName("kcfg_SortByActivity");

        gridLayout->addWidget(kcfg_SortByActivity, 2, 0, 1, 3);

        kcfg_SortByStatus = new QCheckBox(NicklistBehavior_ConfigUI);
        kcfg_SortByStatus->setObjectName("kcfg_SortByStatus");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_SortByStatus->sizePolicy().hasHeightForWidth());
        kcfg_SortByStatus->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcfg_SortByStatus, 3, 0, 1, 1);

        kcfg_ChannelDoubleClickAction = new KLineEdit(NicklistBehavior_ConfigUI);
        kcfg_ChannelDoubleClickAction->setObjectName("kcfg_ChannelDoubleClickAction");

        gridLayout->addWidget(kcfg_ChannelDoubleClickAction, 0, 2, 1, 1);

        orderHintLabel = new QLabel(NicklistBehavior_ConfigUI);
        orderHintLabel->setObjectName("orderHintLabel");
        orderHintLabel->setEnabled(false);
        orderHintLabel->setWordWrap(false);

        gridLayout->addWidget(orderHintLabel, 3, 1, 1, 2);

        sortOrder = new QTreeWidget(NicklistBehavior_ConfigUI);
        sortOrder->setObjectName("sortOrder");
        sortOrder->setEnabled(false);
        sortOrder->setDragEnabled(true);
        sortOrder->setDragDropMode(QAbstractItemView::InternalMove);
        sortOrder->setRootIsDecorated(false);
        sortOrder->setAllColumnsShowFocus(true);

        gridLayout->addWidget(sortOrder, 4, 0, 1, 3);

#if QT_CONFIG(shortcut)
        textLabel1_2->setBuddy(kcfg_ChannelDoubleClickAction);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_ChannelDoubleClickAction, kcfg_SortCaseInsensitive);
        QWidget::setTabOrder(kcfg_SortCaseInsensitive, kcfg_SortByActivity);
        QWidget::setTabOrder(kcfg_SortByActivity, kcfg_SortByStatus);
        QWidget::setTabOrder(kcfg_SortByStatus, sortOrder);

        retranslateUi(NicklistBehavior_ConfigUI);
        QObject::connect(kcfg_SortByStatus, &QCheckBox::toggled, sortOrder, &QTreeWidget::setEnabled);
        QObject::connect(kcfg_SortByStatus, &QCheckBox::toggled, orderHintLabel, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(NicklistBehavior_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *NicklistBehavior_ConfigUI)
    {
        textLabel1_2->setText(tr2i18n("&Command to be executed on double click:", nullptr));
        kcfg_SortCaseInsensitive->setText(tr2i18n("Sort case &insensitive", nullptr));
        kcfg_SortByActivity->setText(tr2i18n("Sort by &activity", nullptr));
        kcfg_SortByStatus->setText(tr2i18n("Sort b&y user status", nullptr));
        orderHintLabel->setText(tr2i18n("(Reorder nick sorting order by drag and drop)", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = sortOrder->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Explanation", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Mode", nullptr));
        (void)NicklistBehavior_ConfigUI;
    } // retranslateUi

};

namespace Ui {
    class NicklistBehavior_ConfigUI: public Ui_NicklistBehavior_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NICKLISTBEHAVIOR_CONFIGUI_H

