/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
*/

/********************************************************************************
** Form generated from reading UI file 'chatwindowappearance_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHATWINDOWAPPEARANCE_CONFIG_H
#define UI_CHATWINDOWAPPEARANCE_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ChatWindowAppearance_Config
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *kcfg_Timestamping;
    QFormLayout *formLayout;
    QLabel *textLabel1;
    QComboBox *kcfg_TimestampFormat;
    QCheckBox *kcfg_ShowDate;
    QCheckBox *kcfg_ShowDateLine;
    QGroupBox *kcfg_ShowBacklog;
    QFormLayout *formLayout_2;
    QLabel *textLabel1_2;
    QSpinBox *kcfg_BacklogLines;
    QGroupBox *groupBox2;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_ShowTopic;
    QCheckBox *kcfg_ShowModeButtons;
    QCheckBox *kcfg_ShowNickList;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *indentAutoUserhostSpacer;
    QCheckBox *kcfg_AutoUserhost;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *indentShowRealNamesSpacer;
    QCheckBox *kcfg_ShowRealNames;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *indentShowQuickButtonsSpacer;
    QCheckBox *kcfg_ShowQuickButtons;
    QCheckBox *kcfg_ShowNicknameBox;
    QCheckBox *kcfg_ShowIRCViewScrollBar;
    QGroupBox *kcfg_ShowBackgroundImage;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel4;
    KUrlRequester *kcfg_BackgroundImage;
    QSpacerItem *spacer90;

    void setupUi(QWidget *ChatWindowAppearance_Config)
    {
        if (ChatWindowAppearance_Config->objectName().isEmpty())
            ChatWindowAppearance_Config->setObjectName("ChatWindowAppearance_Config");
        ChatWindowAppearance_Config->resize(401, 558);
        verticalLayout_2 = new QVBoxLayout(ChatWindowAppearance_Config);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        kcfg_Timestamping = new QGroupBox(ChatWindowAppearance_Config);
        kcfg_Timestamping->setObjectName("kcfg_Timestamping");
        kcfg_Timestamping->setCheckable(true);
        formLayout = new QFormLayout(kcfg_Timestamping);
        formLayout->setObjectName("formLayout");
        textLabel1 = new QLabel(kcfg_Timestamping);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel1);

        kcfg_TimestampFormat = new QComboBox(kcfg_Timestamping);
        kcfg_TimestampFormat->setObjectName("kcfg_TimestampFormat");
        kcfg_TimestampFormat->setEditable(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_TimestampFormat);

        kcfg_ShowDate = new QCheckBox(kcfg_Timestamping);
        kcfg_ShowDate->setObjectName("kcfg_ShowDate");

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, kcfg_ShowDate);

        kcfg_ShowDateLine = new QCheckBox(kcfg_Timestamping);
        kcfg_ShowDateLine->setObjectName("kcfg_ShowDateLine");

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, kcfg_ShowDateLine);


        verticalLayout_2->addWidget(kcfg_Timestamping);

        kcfg_ShowBacklog = new QGroupBox(ChatWindowAppearance_Config);
        kcfg_ShowBacklog->setObjectName("kcfg_ShowBacklog");
        kcfg_ShowBacklog->setCheckable(true);
        formLayout_2 = new QFormLayout(kcfg_ShowBacklog);
        formLayout_2->setObjectName("formLayout_2");
        textLabel1_2 = new QLabel(kcfg_ShowBacklog);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel1_2);

        kcfg_BacklogLines = new QSpinBox(kcfg_ShowBacklog);
        kcfg_BacklogLines->setObjectName("kcfg_BacklogLines");
        kcfg_BacklogLines->setValue(10);
        kcfg_BacklogLines->setProperty("maxValue", QVariant(100));

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_BacklogLines);


        verticalLayout_2->addWidget(kcfg_ShowBacklog);

        groupBox2 = new QGroupBox(ChatWindowAppearance_Config);
        groupBox2->setObjectName("groupBox2");
        verticalLayout = new QVBoxLayout(groupBox2);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_ShowTopic = new QCheckBox(groupBox2);
        kcfg_ShowTopic->setObjectName("kcfg_ShowTopic");

        verticalLayout->addWidget(kcfg_ShowTopic);

        kcfg_ShowModeButtons = new QCheckBox(groupBox2);
        kcfg_ShowModeButtons->setObjectName("kcfg_ShowModeButtons");

        verticalLayout->addWidget(kcfg_ShowModeButtons);

        kcfg_ShowNickList = new QCheckBox(groupBox2);
        kcfg_ShowNickList->setObjectName("kcfg_ShowNickList");

        verticalLayout->addWidget(kcfg_ShowNickList);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        indentAutoUserhostSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(indentAutoUserhostSpacer);

        kcfg_AutoUserhost = new QCheckBox(groupBox2);
        kcfg_AutoUserhost->setObjectName("kcfg_AutoUserhost");
        kcfg_AutoUserhost->setEnabled(false);

        horizontalLayout->addWidget(kcfg_AutoUserhost);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        indentShowRealNamesSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(indentShowRealNamesSpacer);

        kcfg_ShowRealNames = new QCheckBox(groupBox2);
        kcfg_ShowRealNames->setObjectName("kcfg_ShowRealNames");
        kcfg_ShowRealNames->setEnabled(false);

        horizontalLayout_2->addWidget(kcfg_ShowRealNames);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        indentShowQuickButtonsSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(indentShowQuickButtonsSpacer);

        kcfg_ShowQuickButtons = new QCheckBox(groupBox2);
        kcfg_ShowQuickButtons->setObjectName("kcfg_ShowQuickButtons");
        kcfg_ShowQuickButtons->setEnabled(false);

        horizontalLayout_3->addWidget(kcfg_ShowQuickButtons);


        verticalLayout->addLayout(horizontalLayout_3);

        kcfg_ShowNicknameBox = new QCheckBox(groupBox2);
        kcfg_ShowNicknameBox->setObjectName("kcfg_ShowNicknameBox");

        verticalLayout->addWidget(kcfg_ShowNicknameBox);

        kcfg_ShowIRCViewScrollBar = new QCheckBox(groupBox2);
        kcfg_ShowIRCViewScrollBar->setObjectName("kcfg_ShowIRCViewScrollBar");

        verticalLayout->addWidget(kcfg_ShowIRCViewScrollBar);


        verticalLayout_2->addWidget(groupBox2);

        kcfg_ShowBackgroundImage = new QGroupBox(ChatWindowAppearance_Config);
        kcfg_ShowBackgroundImage->setObjectName("kcfg_ShowBackgroundImage");
        kcfg_ShowBackgroundImage->setCheckable(true);
        hboxLayout = new QHBoxLayout(kcfg_ShowBackgroundImage);
        hboxLayout->setObjectName("hboxLayout");
        textLabel4 = new QLabel(kcfg_ShowBackgroundImage);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setWordWrap(false);

        hboxLayout->addWidget(textLabel4);

        kcfg_BackgroundImage = new KUrlRequester(kcfg_ShowBackgroundImage);
        kcfg_BackgroundImage->setObjectName("kcfg_BackgroundImage");

        hboxLayout->addWidget(kcfg_BackgroundImage);


        verticalLayout_2->addWidget(kcfg_ShowBackgroundImage);

        spacer90 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacer90);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(kcfg_TimestampFormat);
        textLabel1_2->setBuddy(kcfg_BacklogLines);
        textLabel4->setBuddy(kcfg_BackgroundImage);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_Timestamping, kcfg_TimestampFormat);
        QWidget::setTabOrder(kcfg_TimestampFormat, kcfg_ShowDate);
        QWidget::setTabOrder(kcfg_ShowDate, kcfg_ShowBacklog);
        QWidget::setTabOrder(kcfg_ShowBacklog, kcfg_BacklogLines);
        QWidget::setTabOrder(kcfg_BacklogLines, kcfg_ShowTopic);
        QWidget::setTabOrder(kcfg_ShowTopic, kcfg_ShowModeButtons);
        QWidget::setTabOrder(kcfg_ShowModeButtons, kcfg_ShowNickList);
        QWidget::setTabOrder(kcfg_ShowNickList, kcfg_AutoUserhost);
        QWidget::setTabOrder(kcfg_AutoUserhost, kcfg_ShowRealNames);
        QWidget::setTabOrder(kcfg_ShowRealNames, kcfg_ShowQuickButtons);
        QWidget::setTabOrder(kcfg_ShowQuickButtons, kcfg_ShowNicknameBox);
        QWidget::setTabOrder(kcfg_ShowNicknameBox, kcfg_ShowIRCViewScrollBar);
        QWidget::setTabOrder(kcfg_ShowIRCViewScrollBar, kcfg_ShowBackgroundImage);
        QWidget::setTabOrder(kcfg_ShowBackgroundImage, kcfg_BackgroundImage);

        retranslateUi(ChatWindowAppearance_Config);
        QObject::connect(kcfg_ShowNickList, &QCheckBox::toggled, kcfg_AutoUserhost, &QCheckBox::setEnabled);
        QObject::connect(kcfg_ShowNickList, &QCheckBox::toggled, kcfg_ShowQuickButtons, &QCheckBox::setEnabled);
        QObject::connect(kcfg_ShowNickList, &QCheckBox::toggled, kcfg_ShowRealNames, &QCheckBox::setEnabled);
        QObject::connect(kcfg_ShowDate, &QCheckBox::toggled, kcfg_ShowDateLine, &QCheckBox::setDisabled);

        QMetaObject::connectSlotsByName(ChatWindowAppearance_Config);
    } // setupUi

    void retranslateUi(QWidget *ChatWindowAppearance_Config)
    {
        kcfg_Timestamping->setTitle(tr2i18n("Enable &Timestamps", nullptr));
        textLabel1->setText(tr2i18n("&Format:", nullptr));
        kcfg_ShowDate->setText(tr2i18n("Sho&w dates", nullptr));
        kcfg_ShowDateLine->setText(tr2i18n("Show date marker when date changes", nullptr));
        kcfg_ShowBacklog->setTitle(tr2i18n("Show &Backlog", nullptr));
        textLabel1_2->setText(tr2i18n("&Lines: ", nullptr));
        groupBox2->setTitle(tr2i18n("&Layout", nullptr));
        kcfg_ShowTopic->setText(tr2i18n("&Show channel topic", nullptr));
        kcfg_ShowModeButtons->setText(tr2i18n("Show channel &mode buttons", nullptr));
        kcfg_ShowNickList->setText(tr2i18n("Show channel &nick list and quick buttons", nullptr));
        kcfg_AutoUserhost->setText(tr2i18n("Show hostmas&ks in nickname list", nullptr));
        kcfg_ShowRealNames->setText(tr2i18n("Show real names in nickname list", nullptr));
        kcfg_ShowQuickButtons->setText(tr2i18n("Show &quick buttons", nullptr));
        kcfg_ShowNicknameBox->setText(tr2i18n("Show bo&x to change own nickname", nullptr));
        kcfg_ShowIRCViewScrollBar->setText(tr2i18n("Show sc&rollbar", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_ShowIRCViewScrollBar->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        kcfg_ShowBackgroundImage->setTitle(tr2i18n("Enable Back&ground Image", nullptr));
        textLabel4->setText(tr2i18n("P&ath:", nullptr));
        (void)ChatWindowAppearance_Config;
    } // retranslateUi

};

namespace Ui {
    class ChatWindowAppearance_Config: public Ui_ChatWindowAppearance_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHATWINDOWAPPEARANCE_CONFIG_H

